<?php
/**
 * File name: agents.php
 * Description: List Agents depending on login status.
 *
 * Accessibility:
 * - All users can view this page.
 * - Actual agents displayed will be determined by ajax_listagents.php
 *
 * Input: Direct
 * Output: Direct
 */
include 'start.php';
global $settings, $login_user;

// TODO: minify and revert back to agents.js
$scriptinclude = 'agents.source.js';

include 'header.php';
// header_html is separated from header.php on purpose.
include 'includes/header_html.php';

$agent_limit = $settings['agents_limit'];
$agent_add_label = 'Add An Agent';     // default string
$agent_add = $agent_add_popup = $non_agent_count = ''; // variable init
$show_non_billable = false;

if ( $settings['agent_classes'] ):
    // two separate counters for billable & non-billable members
    $agent_count        = list_agents(array('billable' => 1), 'ord', 'ASC', 500, 1, true);
    $non_agent_count    = list_agents(array('billable' => 0), 'ord', 'ASC', 500, 1, true);
    $show_non_billable  = true;
else:
    // just count all members.
    $agent_count        = list_agents('', 'ord', 'ASC', 500, 1, true);
endif;

if ($agent_count >= $agent_limit):
    $agent_add = 'disabled';
    $agent_add_label = 'Agents Seats Full';
    $agent_add_popup = 'data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-placement="bottom" data-bs-title="Contact Support to Add More Seats!"';
endif;
?>

<div id="agents_gallery_intro" class="brixwork_admin_container title">
    <h1 id="admin_page__title">Your Team Members</h1>
    <p>These are not users with website admin access. They are displayed on the public website.</p>

    <?php // creation of agents are not available to agents.
    if ($login_user->getLevel() != USER_LOGIN_AGENT) {
        $billable_href = login_level_check(USER_LOGIN_MANAGER) ? "agents_mod.php?mode=new&billable=true" : "" // billable agent creation is only for ?>
        <div id="agents_overview" class="col-12">
            <div class="row">
                <div class="col-sm-6 col-md-12 col-lg-6 mb-3 mb-sm-0 mb-md-3 mb-lg-0">
                    <div class="billable_wrapper" <?=$agent_add_popup?>>
                        <h3>Agent Seats: <?=$agent_count?> / <?=$agent_limit?></h3>
                        <h6 class="seat_available"><?=$agent_limit - $agent_count?> Available</h6>
                        <a class="btn btn-admin white mt-1 <?=$agent_add?> px-4" href="agents_mod.php?mode=new&billable=true"><?=$agent_add_label?></a>
                    </div>
                </div>

                <div class="col-sm-6 col-md-12 col-lg-6" style="display: <?=$show_non_billable ? 'block' : 'none'?>;">
                    <div class="billable_wrapper not_billable">
                        <h3>Non-Agent Seats: <?=$non_agent_count?></h3>
                        <h6 class="seat_available">No Limit</h6>
                        <a class="btn btn-admin white mt-1 px-4" href="agents_mod.php?mode=new&billable=false">Add Non-Agent</a>
                    </div>
                </div>
            </div>
        </div>

    <?php
    } ?>


    <div id="agents_filter_row" class="row">
        <label class="col-12 orange">Filter</label>
        <div id="listings_filter__status" class="col-md-3 py-1 py-lg-0 m-auto">
            <input aria-label="Filter by Agent's First Name" type="text" class="form-control agents_filter" id="agents_filter_fname" name="fname" placeholder="i.e. John" size="20"/>
        </div>

        <div id="agent_filter__lastname" class="col-md-3 py-1 py-lg-0 m-auto">
            <input aria-label="Filter by Agent's Last Name" type="text" class="form-control agents_filter" id="agents_filter_lname" name="lname" placeholder="i.e. Doe" size="20" />
        </div>

        <div id="agent_filter__lastname" class="col-md-3 py-1 py-lg-0 m-auto">
            <input aria-label="Filter by Agent's ID" type="text" class="form-control agents_filter" id="agents_filter_agentid" name="agentid" placeholder="i.e. V0123" size="20" />
        </div>

        <div id="agent_filter__btn" class="col-md-3 py-1 py-lg-0 m-auto">
            <a type="button" class="btn btn-admin add_spacing" id="agents_filter_trigger">Filter</a>
        </div>
    </div>

    <div id="agents_filter_row" class="row">
        <label class="col-12 orange">Agents per Page</label>
        <div id="agents_filter__perpage" class="col-md-4 col-sm-5">
            <select id="perpage" class="form-select" aria-label="Per Page Filter">
                <option value="25">25 per page</option>
                <option value="50">50 per page</option>
                <option value="100">100 per page</option>
                <option value="250">250 per page</option>
            </select>
        </div>
    </div>
</div>

<div class="brixwork_admin_container" id="agentslist">
	<?php // AJAX loaded list of homes here. ?>
</div>


<?php
// Delete Modal
$delete_agent_modal__body   = 'Auto Filled';
$delete_agent_modal__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Keep Agent</button>
    <button type="button" class="btn btn-admin light_blue" id="delete_agent_btn" data-bs-dismiss="modal">Delete Agent</button>';
$delete_agent_modal__options = array(
    'header_content' => 'Delete a Member',
    'body_content' => $delete_agent_modal__body,
    'footer_content' => $delete_agent_modal__footer,
    'id' => 'delete_agent'
);
brixwork_modal_html($delete_agent_modal__options);

include 'footer.php';