<?php
/*
Filename: ajax_listagents.php

Method: AJAX
Output: AJAX/HTML

Description: Generates the agents list with wide icons that display each agent like a business card.

Author: Jeff Kee
*/
include 'start.php';

// start.php runs validate_login() function
global $settings;
global $login_user;

// default folder
$destinationfolder = 'agents';
$destinationtable = 'agents';


// Query settings.
$orderby    = array('ord', 'create_date');
$ascordesc  = array('ASC', 'DESC');
$perpage    = $_REQUEST['perpage'] ?? 10000;
$page       = $_REQUEST['page'] ?? 1;

if (isset($_REQUEST['filters']) && is_array($_REQUEST['filters']) && count($_REQUEST['filters']) > 0 ) {
    $query = param_to_query($_REQUEST['filters']);
    $filters = true;
}

if (!login_level_check(USER_LOGIN_MANAGER)) {
    // Login user is below Manager level ... query for agents associated with login user.
    $query['id'] = $login_user->getAgents();

    // Query for non-billable profiles (unlicensed assistants) to be merged with $agents array under certain condition.
    $non_billable_query = array('billable' => 0);
    $non_billable_profiles = get_agents($non_billable_query, $orderby, $ascordesc, $perpage, $page, false, true) ?: array();
}

// query agents
$agents = get_agents($query, $orderby, $ascordesc, $perpage, $page, false, true) ?: array(); // for merging array, make sure to return empty array instead of "false"

// Content Manager & below will see both their associated agents & non-billable profiles.
if (!login_level_check(USER_LOGIN_AGENT) && is_array($non_billable_profiles)) {
    $agents = array_merge($agents, $non_billable_profiles);
}

// final agent query array counter ... need a separate query for getting total number of objects, ignoring the $perpage var.
$agentscount = get_agents($query, $orderby, $ascordesc, 100000, 1, true);


if (!$agents) {
    // no agents queried - display appropriate errors.
    ?>
    <div class="row justify-content-center">
        <div class="col-lg-4 col-sm-6 col-xs-12" style="padding-top: 50px">
            <?php
            if ($login_user->getLevel() == USER_LOGIN_AGENT && !$login_user->getAgents()) {
                // no agent attached to user error
                echo alert_display('<p><strong>No Agent Attached to User</strong><br />Currently logged-in user does not have agent profile attached, which prevents any agent profiles to display. Please contact site admin for support.</p>');
            } else {
                // no homes queried error
                echo alert_display('<p><strong>No Agents yet!</strong><br />Start adding new agents or Contact site admin for support.</p>', 'warning');
            }
            ?>
        </div>
    </div>

<?php
} else {
    $numpages = ceil($agentscount / $perpage);
    if ($numpages > 1) // no need for pagination if just one page.
        echo brixwork_object_pagination('agent', $page, $numpages);

    // build list agents block
    ?>
    <div id="agentstable">
        <?php
        foreach($agents as $agent):
            // Initialize and display agents...
            $each_agent = new agent;
            $each_agent->initialize($agent['id'], $agent);

            $display_cell = $each_agent->cell ? 'block' : 'none';
            $display_email = $each_agent->email ? 'block' : 'none';

            $added_tags = $each_agent->publish == 1 ?	'agent_publish' : '';
            $each_agent_img_class = login_level_check(USER_LOGIN_MANAGER) ? array('img-full', 'agent_portrait', 'orderhandle') : array('img-full', 'agent_portrait');
            ?>
            <div class="each_admin_listing row <?=$added_tags?>" id="agent_<?=$each_agent->id?>">
                <div class="admin_listing__img_wrapper">
                    <?=$each_agent->get_main_images(0, 275, 200, $settings['sitepath'].'admin/images/noimage.jpg', $each_agent_img_class)?>
                </div>

                <div class="admin_listing__summary">
                    <h3 class="full_name"><?=$each_agent->displayname?></h3>
                    <h5 class="position"><?=$each_agent->position ?: $each_agent->class?></h5>

                    <div class="contact_wrapper my-3">
                        <a href="tel:<?=$each_agent->cell?>" class="agent_contact" style="display:<?=$display_cell?>;"><?=$each_agent->cell?></a>
                        <a href="mailto:<?=$each_agent->email?>" class="agent_contact" style="display:<?=$display_email?>"><?=$each_agent->email?></a>
                    </div>

                    <div class="agent_sns_wrapper">
                        <?=$each_agent->instagram       ? '<a href="'.$each_agent->instagram.'" class="agent_sns"><i class="bi bi-instagram"></i></a>' : ''?>
                        <?=$each_agent->twitter         ? '<a href="'.$each_agent->twitter.'" class="agent_sns"><i class="bi bi-twitter"></i></a>' : ''?>
                        <?=$each_agent->facebook        ? '<a href="'.$each_agent->facebook.'" class="agent_sns"><i class="bi bi-facebook"></i></a>' : ''?>
                        <?=$each_agent->youtubechannel  ? '<a href="'.$each_agent->youtubechannel.'" class="agent_sns"><i class="bi bi-youtube"></i></a>' : ''?>
                        <?=$each_agent->linkedin        ? '<a href="'.$each_agent->linkedin.'" class="agent_sns"><i class="bi bi-linkedin"></i></a>' : ''?>
                        <?=$each_agent->pinterest       ? '<a href="'.$each_agent->pinterest.'" class="agent_sns"><i class="bi bi-pinterest"></i></a>' : ''?>
                        <?=$each_agent->tiktok          ? '<a href="'.$each_agent->tiktok.'" class="agent_sns"><i class="bi bi-tiktok"></i></a>' : ''?>
                    </div>
                </div>

                <div class="admin_listing__functions row">
                    <div class="status_wrapper col-lg-6 mb-4">
                        <label for="visibility_toggle" class="control-label orange">STATUS</label>
                        <select id="visibility_toggle" class="form-select agent_publish_toggle" rel="<?=$each_agent->id?>" aria-label="Hide or Publish Agent to the public">
                            <option value="0" <?=$each_agent->publish == 0 ? 'selected' : ''?>>Hidden</option>
                            <option value="1" <?=$each_agent->publish == 1 ? 'selected' : ''?>>Published</option>
                        </select>
                    </div>

                    <?=$each_agent->agentid ? '<h6 class="agent_id">Agent ID: '.$each_agent->agentid.'</h6>' : ''?>

                    <div class="buttons_wrapper">
                        <a class="agent_function_btn btn btn-admin light_blue" href="agents_mod.php?idr=<?=$each_agent->id?>">Edit</a>
                        <a class="agent_function_btn btn btn-admin reddish agent_delete" rel="<?=$each_agent->id?>">Delete</a>
                    </div>
                </div>
            </div>

        <?php
        endforeach; // foreach($agents as $agent_id) ?>
    </div>

    <?php
    if ($numpages > 1)
        echo brixwork_object_pagination('agent', $page, $numpages);
}

require_once 'ajax_footer.php';