<?php
/*
Filename: ajax_listareas.php

Method: AJAX
Output: AJAX/HTML

Description: Lists all areas & subareas, expandable via click right away. 

Author: Jeff Kee
*/
include 'start.php';

// start.php runs validate_login() function.
$destinationfolder = 'areas';
$destinationtable = 'areas';

$areas = get_areas();

if ( !$areas ):

    echo '<div class="row justify-content-center">';
    echo '    <div class="col-lg-4 col-sm-6 col-xs-12" style="padding-top:50px;">';
    echo alert_display('<p><b>No Areas!</b></br>Running MLS&reg; Sync will automatically populate the areas and subareas data</p>', 'warning');
    echo '    </div>';
    echo '</div>';

else:
    ?>

    <div class="collapse_wrapper" rel="0">
        <?php list_areas($areas); ?>
    </div>

<?php
endif;
require_once 'ajax_footer.php';




/**
 * list areas (collapsible) for 2023 upgrade
 * @param $areas
 * @param int $level
 * @param int $parent
 * @param bool $parent_last_elem
 * @return void
 */
function list_areas($areas, int $level = 0, int $parent = 0, bool $parent_last_elem = false): void {
    if (!is_array($areas)) return;  // no child ... return

    $top_list = $level == 0;

    // collapse div wrapper ... only for second loop and more.
    if (!$top_list) {
        $last_collapse = $parent_last_elem ? 'last_collapse_elem' : '';
        $rel = $parent ? "rel='$parent'" : '';
        echo "<div class='$last_collapse level_$level collapse_wrapper collapse' id='collapse_$parent' $rel>";
    }

    // loop through areas array
    foreach ($areas as $area_id):
        if ($top_list)
            $each_area = new area;
        else {
            $parent_area = new area;
            $parent_area->initialize($parent);

            $each_area = new subarea;
        }

        $each_area->initialize($area_id);
        $last_element_bool = $area_id === end($areas) || $level == 0; // the collapse for level 0 (top parent) is also considered "last collapse elem"

        if ($top_list)
            $sub_area = get_subareas($area_id);
        else
            $sub_area = false;

        $each_area__listings = $each_area->get_num_listings();
        $font_weight = 500 - $level * 100;

        $child_list_class   = (!$top_list) ? ' child_list' : '';
        $hidden_class       = $top_list ? ($each_area->publish == 0 ? ' hidden_list' : '') : ($parent_area->publish == 0 ? ' hidden_list' : '');
        $last_element_class = $last_element_bool ? ' last_elem' : '';


        // overall wrapper for each top parent div
        if ($top_list)
            echo "<div id='area_$area_id' class='brixwork_list_wrapper top_list'>";
        ?>

        <div id="area_<?=$area_id?>" class="each_list<?=$child_list_class?><?=$hidden_class?><?=$last_element_class?>" style="padding-left: <?=22 + (18 * $level)?>px">
            <div class="expand_toggle">
                <?php
                if ($top_list && $sub_area)
                    echo '<a class="collapse_control collapsed" href="#collapse_'.$area_id.'" data-bs-toggle="collapse" aria-expanded="false" aria-controls="collapse_'.$area_id.'"><i class="bi bi-plus-circle-fill"></i></a>'; ?>
            </div>

            <?php // AREA TITLE ?>
            <h5 class="each_list__title" style="font-weight: <?=$font_weight?>"><?=$each_area->name?><?=login_level_check(1) ? ' (ID: '.$area_id.')' : false?></h5>

            <?php // FUNCTION BUTTONS WRAPPER ?>
            <div class="each_list__functions_wrapper">
                <?php // manual adding is only available for brixwork login.
                if ($top_list && login_level_check(USER_LOGIN_ADMIN))
                    echo '<button type="button" data-href="subareas_mod.php?mode=new&area='.$area_id.'" data-city="'.$each_area->name.'" class="btn btn-admin grey_teal each_list__btn add_new_subarea_button">Add Subarea</a>';

                // only enable delete button IF area has no listings
                $delete_btn_class = ($each_area__listings == 0) ? 'each_area__delete' : 'disabled';
                $each_area__category = ($top_list) ? 'area' : 'subarea';
                $each_area__href = ($top_list) ? "areas_mod.php?idr=$area_id&mode=modify" : "subareas_mod.php?idr=$area_id&mode=modify";
                $tooltip = ($each_area__listings == 0) ? '' : "data-bs-toggle='tooltip' data-bs-placement='bottom' data-bs-custom-class='brixwork-tooltip' data-bs-title='Cannot delete Area, $each_area__listings listings present'";
                // also delete button is only available for brixwork user.
                if (login_level_check(USER_LOGIN_ADMIN)) {
                ?>
                    <button class='btn btn-admin reddish each_list__btn <?=$delete_btn_class?>' data-category="<?=$each_area__category?>" data-listings="<?=$each_area__listings?>" rel=<?=$area_id?> <?=$tooltip?>>Delete</button>
                <?php
                } ?>

                <a href="<?=$each_area__href?>" class="btn btn-admin light_blue each_list__btn">Edit</a>

                <?php // drop down is only for top city
                if ($top_list) {
                    $checked = $each_area->feature == 1 ? 'checked' : '';

                    if (login_level_check(USER_LOGIN_MANAGER)) {
                    ?>
                        <select aria-label="Page Publish Status" class="form-select area_publish_toggle" rel="<?=$area_id?>">
                            <option value="0" <?=$each_area->publish == 0 ? 'selected' : ''?>>Hide</option>
                            <option value="1" <?=$each_area->publish == 0 ? '' : 'selected'?>>Published</option>
                        </select>
                    <?php
                    } ?>

                    <div class="form-check" id="brixwork_radio_check" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-custom-class="brixwork-tooltip" data-bs-title="Publish: MLS sync will run on published cities. Featured: City names to be displayed on the website - not all websites support this.">
                        <input class="form-check-input cursor-pointer brixwork_radio area_feature_toggle" type="checkbox" id="<?=$area_id?>" rel="<?=$area_id?>" data-feature="<?=$each_area->feature?>" <?=$checked?>>
                        <label class="form-check-label cursor-pointer" for="<?=$area_id?>">Featured</label>
                    </div>
                <?php
                } ?>
            </div>
        </div>

        <?php // generate collapsed section
        list_areas($sub_area, $level + 1, $area_id, $last_element_class);

        if ($level == 0) // close div "brixwork_list_wrapper
            echo '</div>';
    endforeach; // end of  foreach ($areas as $area_id):

    if ($level != 0) // close child collapse <div class="collapse_wrapper">
        echo '</div>';
}
?>