<?php
/*
Filename: ajax_listphotos.php

Method: AJAX
Output: AJAX/HTML

Description: Master file that loads up the buildings list, as well as the buildings quick search module to help users organize & choose buildings to feature on the website. 

Author: Jeff Kee
*/
include 'start.php';

// start.php runs validate_login() function
$folder = $_REQUEST['folder'];
$idr = trim($_REQUEST['homeid'] ?: ''); // used to be home ID, but now it accepts it all.. homes, pages etc. more modular. Just pass it to $idr so it's universal below.
$photorefcolumn = substr($folder, 0, strlen($folder)-1); // remove the s from the folder tables, as it references to the `home` or `building` columns of the `photos` table.

if($_REQUEST['folder']=='') {
    // if table is not set, default to homes.
    $destinationtable = 'homes';
    $destinationfolder = 'homes';
} else {
    $destinationtable = $_REQUEST['folder'];
    $destinationfolder = $_REQUEST['folder'];
}

// THIS IS AJAX FUNCTION, SO OBJECT DECLARATION FROM OUTSIDE HAS NO EFFECT
if($destinationtable=='pages') {
    $page = new page;
    $page->initialize($idr);
    $subject = $page->title;
    $object = $page;
} else if($destinationtable=='resources') {
    $resource = new resource;
    $resource->initialize($idr);
    $subject = $resource->title;
    $object = $resource;
} else if($destinationtable=='agents') {
    $agent = new agent;
    $agent->initialize($idr);
    $subject = $agent->displayname;
    $object = $agent;
} else if($destinationtable=='buildings') {
    $building = new building;
    $building->initialize($idr);
    $subject = $building->name;
    $object = $building;
} else if($destinationtable=='homes') {
    $home = new home;
    $home->initialize($idr);
    $subject = $home->fulladdress;
    $object = $home;
} else {
    die('invalid object type!');
}

$photos_array = $object->photos ? (array)$object->photos : false; // typcast as array for better syntax

if (!$photos_array): ?>
    <div class="mt-5">
        <h3 class="m-auto text-center">No Photos Yet </h3>
        <p class="m-auto text-center" style="font-size: 18px;">If there are supposed to be photos, contact support</p>
    </div>
<?php
else: // photo array exists, loop through
    foreach ($photos_array as $key => $each_photo): ?>

        <div class="photo_row my-3" id="photo_<?=$each_photo['id']?>">
            <div class="form-check checkbox">
                <input class="form-check-input deletephoto_checkbox" type="checkbox" id="delete_<?=$each_photo['id']?>" name="deletephotos" value="<?=$each_photo['id']?>" aria-label="select photo">
            </div>

            <div class="thumbnail">
                <img src="<?=$each_photo['mobilepath']?>" class="orderhandle img-full" alt="thumbnail_<?=$each_photo['id']?>">
            </div>

            <div class="description">
                <input aria-label="describe the photo" type="text" class="form-control photo_title m-auto" size="25" name="title[]" rel="<?=$each_photo['id']?>" id="title_<?=$each_photo['id']?>" value="<?=$each_photo['title']?>" tabindex="<?=$key?>"/>
            </div>

            <div class="brixwork_img_versions d-flex m-auto">
                <a href="<?=$each_photo['filepath']?>" target="_blank" class="btn btn-secondary" role="button" data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-title="View website size"><i class="bi bi-display"></i></a>
                <a href="<?=$each_photo['mobilepath']?>" target="_blank" class="btn btn-secondary" role="button" data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-title="View mobile size"><i class="bi bi-phone"></i></a>
                <a href="<?=$each_photo['thumbnailpath']?>" target="_blank" class="btn btn-secondary" role="button" data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-title="View thumbnail size"><i class="bi bi-card-image"></i></a>
            </div>
        </div>

    <?php
    endforeach;
endif;
?>

<script>
    // ENABLE BOOTSTRAP TOOLTIPS.
    const photo_list_tooltips = document.querySelectorAll('[data-bs-toggle="tooltip"]')
    const photo_tooltips = [...photo_list_tooltips].map(tooltipTriggerEl => new bootstrap.Tooltip(tooltipTriggerEl))
</script>

<?php
require_once 'ajax_footer.php';