<?php
/*
 * This file provides a list of Mailchimp lists and the merge fields for a specific client.
 * Allows each website user to decide which list their lead form email senders are added to.
 *
 * 2023-05 - workingon upgrading to Mailchiimp's own Marketing API since we got a warning from Mailchiomp that we may be using old versions?
 * */

include 'start.php';

// start.php runs validate_login() function.

$code = 0;
$message = '';

use MailchimpMarketing\ApiClient;

$mailchimp_api_key = trim($mysqli->real_escape_string($_REQUEST['api_key']));
// API key looks like "cef73cc689d44629279140710fb5f25c-us4" - has us4 at the end as the server prefix, so use that.
list($throwaway, $server_prefix) = explode('-', $mailchimp_api_key);
if(isset($server_prefix) && $server_prefix!='') {
	$mailchimp = new MailchimpMarketing\ApiClient();

	$mailchimp->setConfig([
		'apiKey' => $mailchimp_api_key,
		'server' => $server_prefix
	]);

// check connection first.
	$response = $mailchimp->ping->get();

	if(isset($response->detail)) {
		$code = 0;
		$message = $response->title.' : '.$response->detail;
		// if, here, you get no list return.. then also put the MC response code into the message, and return $code =0;
	} else {
		// successful API connection
		$code = 1; // code 1 means successflu connection.. for now. Unless the list resturns false?

		switch($_REQUEST['request_type']) {
			case "list" :
				// start array!
				$mailchimp_lists_result = $mailchimp->lists->getAllLists();
				if(isset($mailchimp_lists_result->lists)) {
					// successful list retrieval
					$mailchimp_options = array(
						array(
							'listid' => '',
							'label' => 'Select a list',
							'selected' => 0
						)
					);

					foreach ($mailchimp_lists_result->lists as $list) {
						$mailchimp_options[] = array(
							'listid' => $list->id,
							'label' => $list->name . ' (' . $list->stats->member_count . ')',
							'selected' => ($settings['mailchimp_api_list']==$list->id ? '1':'0')
						) ;
					}

				} else {
					// list retrieal failed.
					$code = 0;
					$message = $response->title.' : '.$response->detail;
					$mailchimp_options = array(
						array(
							'listid' => '',
							'label' => $response->title,
							'selected' => 0
						)
					);
				}


				break;

			case "fields":

				if(array_key_exists('listid', $_REQUEST) && $_REQUEST['listid']!='') {
					$field_options = array(
						'fieldtype'=>'merge-fields',
						'listid' => trim($mysqli->real_escape_string($_REQUEST['listid']))
					);

					$mailchimp_list_fields = mailchimp_get_list_fields($mailchimp, $field_options);
					$mailchimp_options = array(
						array(
							'fieldid' => '',
							'label' => 'Not Mapped'
						)
					);

					if( isset( $mailchimp_list_fields ) && is_array( $mailchimp_list_fields ) ) {
						// These fields are referenced to the $settings field to see if there's alredayd a FIRST/LAST name mapping selected, and the JS (mailchimp.js) will add selected tags.
						foreach ($mailchimp_list_fields as $optionlist) {
							if($optionlist['tag']==$settings['mailchimp_first_name_tag']) {
								$selected = 'mailchimp_first_name_tag';
							} else if($optionlist['tag']==$settings['mailchimp_last_name_tag']) {
								$selected = 'mailchimp_last_name_tag';
							} else if($optionlist['tag']==$settings['mailchimp_phone_number_tag']) {
								$selected = 'mailchimp_phone_number_tag';
							} else if($optionlist['tag']==$settings['mailchimp_message_tag']) {
								$selected = 'mailchimp_message_tag';
							} else {
								$selected = 0;
							}
							$mailchimp_options[] =array(
								'fieldid'=>$optionlist['tag'],
								'label' => $optionlist['name'],
								'selected' => $selected
							);
						}
					}
					$message .= "Returned ".count($mailchimp_list_fields)." fields from list ID ".$field_options['listid'];

				//$http_code = $mailchimp['client']->getLastResponse()['headers']['http_code'];
				} else {
					$mailchimp_options = array(
						array(
							'fieldid' => '',
							'label' => 'Choose List'
						)
					);
					$message .= "Cannot get fields without a list ID given.";
				}
				break;
		}
	}


} else {
	$code = 0;
	$message = 'Invalid API Key - please check the format, and make sure it ends with -usXX';
	$mailchimp_options = array(
		array(
			'listid' => '',
			'label' => 'Invalid API Key - please check the format.',
			'selected' => 0
		)
	);
}


$json_array = array('code'=>$code, 'options'=>$mailchimp_options, 'message'=>$message);
echo json_encode($json_array);

require_once 'ajax_footer.php';