<?php
/**
 * Filename: areas.php
 * Description: List all cities and subareas that the site uses via AJAX
 *
 * Accessibility: Agent user does not have access to this page.
 */
include 'start.php';
redirect_invalid_user(USER_LOGIN_AGENT, true);

global $login_user;

$scriptinclude_footer = 'areas.js';
$destinationfolder = 'areas'; // although the primary query is through the resourcecategories table, the resources is the money table anyway.
$destinationtable = 'areas';

include 'header.php';
// header_html is separated from header.php on purpose.
include 'includes/header_html.php';
?>

<div id="cities_list_intro" class="brixwork_admin_container manage_object_tab_content title">
    <h1 id="admin_page__title">Manage Cities & Subareas</h1>

    <?php // DISPLAY EXPLANATION FOR FEATURED VS. PUBLISHED CITIES ?>
    <div id="feature_published_container" class="each_tab__category brixwork_inner_spacing mt-5 mb-0">
        <div id="feature_published_banner">
            <?php
            $svg_append = 'images/admin_function_icon/';
            echo get_svg(file_get_contents($svg_append.'brixwork_lightbulb.svg', true));
            ?>
            <h3>Before You Begin</h3>
        </div>
        <hr>
        <div id="feature_published_explained" class="row">
            <div class="each_explain col-md-6 col-lg-5">
                <h5>Published/Hidden Dropdown</h5>
                <p>Setting a city/subarea as ‘hidden’ or ‘published’ determines which areas your website’s MLS® will sync to.</p>
            </div>
            <div class="each_explain col-md-6 col-lg-5 offset-lg-2">
                <h5>Featured Checkbox</h5>
                <p>Used to determine cities to be displayed on your website usually for custom blocks and may not be applicable to your website. Unless instructed by Brixwork staff, leave blank.</p>
            </div>
        </div>
    </div>


    <div class="col-md-12 mt-5" id="areas_list">
        <?php // POPULATE AREA VIA AJAX ?>
    </div>


    <?php // only available for higher access than content manager
    if ($login_user->getLevel() < USER_LOGIN_CONTENT_MANAGER) { ?>
        <div>
            <a class="btn btn-admin" id="new_area_btn">Add a New Area</a>
        </div>
    <?php
    } ?>
</div>

<?php
include 'footer.php';


// ADDING NEW CITY MODAL - MLS
$new_city__body = '<p>You are subscribed to an MLS® Reciprocity (IDX) system, which dictates the cities shown on your site.</p><p>Adding any city requires you to have a custom-defined boundary map ready, or homes need to be manually linked up. Are you sure you want to proceed?</p>';
$new_city__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Cancel</button>
    <a class="btn btn-admin light_blue px-4" href="areas_mod.php?mode=new">Create New City</a>';
$new_city__options = array(
    'header_content' => 'Create New City (Area)',
    'body_content' => $new_city__body,
    'footer_content' => $new_city__footer,
    'id' => 'add_area_mls'
);
brixwork_modal_html($new_city__options);

// ADDING NEW CITY MODAL - NON-MLS
$new_city_non_mls__body = '<p>Adding any city requires you to have a custom-defined boundary map ready, or homes need to be manually linked up. Are you sure you want to proceed?</p>';
$new_city_non_mls__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Cancel</button>
    <a class="btn btn-admin light_blue px-4" href="areas_mod.php?mode=new">Create New City</a>';
$new_city_non_mls__options = array(
    'header_content' => 'Create New City (Area)',
    'body_content' => $new_city_non_mls__body,
    'footer_content' => $new_city_non_mls__footer,
    'id' => 'add_area_non_mls'
);
brixwork_modal_html($new_city_non_mls__options);

// ADDING NEW SUBAREA MODAL
$new_subarea__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Cancel</button>
    <a class="btn btn-admin light_blue px-4" href="">Create New Subarea</a>';
$new_subarea__options = array(
    'header_content' => 'Auto Generated from JS',
    'body_content' => $new_city__body,
    'footer_content' => $new_subarea__footer,
    'id' => 'add_subarea_mls'
);
brixwork_modal_html($new_subarea__options);

//ADDING NEW SUBAREA MODAL - NON-MLS
$new_subarea_non_mls__options = array(
    'header_content' => 'Auto Generated from JS',
    'body_content' => $new_city_non_mls__body,
    'footer_content' => $new_subarea__footer,
    'id' => 'add_subarea_non_mls'
);
brixwork_modal_html($new_subarea_non_mls__options);


// DELETE AREA MODAL - SUCCESS
$delete_area__body = '<p>If this city/area is provisioned by your MLS® feed, this area will be re-created again in the next cycle of MLS® sync.</p> <p>You can always HIDE this instead. Are you sure you want to delete this area?</p>';
$delete_area__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Cancel</button>
    <button type="button" class="btn btn-admin light_blue px-4 delete_area__btn">Delete the Area Data</button>';
$delete_area__options = array(
    'header_content' => 'This Area Could Be From MLS®',
    'body_content' => $delete_area__body,
    'footer_content' => $delete_area__footer,
    'id' => 'delete_area'
);
brixwork_modal_html($delete_area__options);