<?php
include 'cronstart.php';

include $_SERVER['DOCUMENT_ROOT'].'/cron/cron_functions.php'; // this includes cron functions,

// this file creates an SQL output of all the RETS properties (source=1). 
$perfile = 2000; // number of homes per file.

// either needs the 58300774 password as a GET var ['hash'] OR it needs to be the same IP address.
if($_SERVER['SERVER_ADDR']==$_SERVER['HTTP_HOST'] || $_GET['hash']=='58300774') {

	getRetsRunning(); // it will kill this instance, if another one is running already.

	// define file folder and paths.
	$retsfolder = 'retsexport/'; // also used for S3 path (prefix)
	$zipfile = 'export-'.$today.'.zip'; // the actual ZIP file name for today!

	// exclude columns NOT needed for retsimport.php on each client site to process.
	// note that open house string is generated by the generate_listing_array() function based on a separate table, so excluded here.
	// Master ID obviously, along iwth many other vars that are set on each site separately, or never synced from RETS servers to start .
	$avoid = array(
		'id','city','area','masterid','sysid',
		'agent', 'agent_1', 'agent_2', 'agent_3',
		'heading', 'heading2', 'description2', 'description3', 'metatitle', 'metadescription','metakeywords',
		'youtube1', 'vimeo', 'vimeo1', 'building',
		'pdf', 'pdf_labels', 'alt_tags', 'mainphoto',
		'ord', 'remarks', 'views',
		'feature', 'publish', 'views', 'openhouse',
		'slug', 'timestamp', 'phpfile'); // these are the columns we avoid import, as it needs to be synced internally, or are unique fields.

	$fieldssql = "SHOW COLUMNS FROM homes";
	$fieldsresult = $mysqli->query($fieldssql);
	if ($fieldsresult->num_rows > 0) {
		$i = 0;
		while ($columns = $fieldsresult->fetch_assoc()) {
			// we skip the ID column to avoid the duplicate ID issues
			if(!in_array($columns['Field'],$avoid)) {
				$fields[$i]=$columns['Field'];
				$i++;
			}
		}
	}

	// other manual things to add into array
	$fields[] = 'mls_photo_timestamp';

	// fields to include in the JSON has been prepared, so the generate_listing_json() function can accept as 2nd argument (use the $fields array)
	list($cities, $subareas) =  load_cities();
	// generate file that just has array of city->subareas in a JSON format.
	// subareas are referenced by city ID as main key: $subareas[$subarea_array['area']][$subarea_array['id']]

	$citiesarray = array(); // declare.

	foreach($cities as $cityid=>$city) {
		$citiesarray[$city] = array();
		if(array_key_exists($cityid, $subareas)) {
			foreach($subareas[$cityid] as $subareaid => $subarea) {
				$citiesarray[$city][] = $subarea; // keep adding more areas
			}
		}
	}

	$citiesfilecache = serialize($citiesarray);
	$citiesfile = 'citiesarray.log';
	$citiesfilehandle = fopen($retsfolder.$citiesfile,'w');
	fwrite($citiesfilehandle,$citiesfilecache);
	fclose($citiesfilehandle);

	echo "Wrote ".count($citiesarray).' cities array rows into '.$retsfolder.$citiesfile."<br />".PHP_EOL;


	$numsql = "SELECT COUNT(*) as cnt FROM `homes` WHERE `source`='1' AND `publish`='1'";
	$numresult = $mysqli->query($numsql);
	$numarray = $numresult->fetch_assoc();
	$chunks = ceil($numarray['cnt']/$perfile);

	$chunkcount = 0;
	while($chunkcount<$chunks) {
		$startpoint = $chunkcount*$perfile; // get the offset for the mysql query
		$filecache = ''; // filecach is always a fresh blank on each loop run.
		$homes = array(); // homes array should also blank out on each loop run.
		$sql = "SELECT h.*, p.timestamp as mls_photo_timestamp FROM `homes` h LEFT OUTER JOIN `photos` p ON  h.id=p.home WHERE h.source='1' AND h.publish='1' GROUP BY h.id ORDER BY h.id LIMIT ".$startpoint.", ".$perfile;
		$result = $mysqli->query($sql);
		if($result->num_rows>0) {
			// there are rows that match - let's start the export.
			while($array = $result->fetch_assoc()) {
				$homes[] = generate_listing_array($array, $fields) ; // the $insert array as a whole is a new array item in $homes
			}
		}
		$filecache = serialize($homes);
		echo "Wrote ".count($homes).' home rows into retsexport/export-'.$today.'-'.$chunkcount.'.log<br />';
		$file = fopen($retsfolder.'export-'.$today.'-'.$chunkcount.'.log','w');
		fwrite($file,$filecache);
		fclose($file);
		$chunkcount++;
	} // end of loop for file chunks.

	// remove old file first.
	if(file_exists($retsfolder.$zipfile)) {
		unlink($retsfolder.$zipfile);
	}


	// prepare file compression!
	$zip = new ZipArchive;
	$zippath = $retsfolder.$zipfile;
	if ($zip->open($zippath, ZipArchive::CREATE) === TRUE) {
		// Add files to the zip file
		$startchunk = 0;
		while($startchunk<$chunks) {
			$zip->addFile($retsfolder.'export-'.$today.'-'.$startchunk.'.log');
			$startchunk++;
		}
		// add the cities array file now.
		$zip->addFile($retsfolder.$citiesfile);
		echo "add ".$retsfolder.$citiesfile." to ZIP.<br />".PHP_EOL;
	} else {
		echo "Failed to create ZIP archive!<br />\n";
	}
	$zip->close();

	$existingfiles = false;
	// now pump towards S3 (and remove yesterday's!)
	$existingfiles = listObjects($settings['s3_bucket'], $settings['s3_folder'].'/'.$retsfolder);
	if($existingfiles!==false) {
		foreach($existingfiles as $objectkey=>$objectarray) {
			if(preg_match('/\.zip$/', $objectarray['Key'])==1 && verifyExists($settings['s3_bucket'], $objectarray['Key'])===true) {
				// TODO: should we keep 10 days?
				echo "Deleting ".$objectarray['Key']."<br />".PHP_EOL;
				deleteObject($settings['s3_bucket'], $objectarray['Key']);
			}
		}
	}

	$s3path = getS3FilePath($settings, $today, $retsfolder);
	// craeets something like vancouver.brixwork.com/retsexport/2019-08-11/ as the path,
	// The ZIP file, unlike on local, will be simply named retsexport.zip, and be contained in one file,
	// separted by date stamp as the key.

	$result = uploadFile($settings['s3_bucket'], $s3path, 'retsexport_'.md5($now.count($homes)).'.zip', $zippath, 'zip','ONEZONE_IA');

	unlink($zippath);// local zip file is no use.
	echo $result['ObjectURL'].PHP_EOL;

	// now create a single filepath var with timestamp attached, in a txt file.
	$urlfile = 'retsexport_url.txt';

	$retsexport_cloudfront_url = s3_to_cloudfront($result['ObjectURL']);

	$urlfilecontent = $retsexport_cloudfront_url;

	$urlfilehandle = fopen($retsfolder.$urlfile,'w');
	fwrite($urlfilehandle,$urlfilecontent);
	fclose($urlfilehandle);

	// TODO: delete all the local .log files too.. uesless.
} else {
	echo "You are not authorized.";
	retsrunning_close();
}

retsrunning_close();
$mysqli->close();
?>