<?php
/**
 * Brixwork 2023 upgrade side menu
 *
 * This is separated from header.php on purpose.
 * 1. header.php must be included near the top before checking for $_POST
 * 1-1. If not, "DOCTYPE html" declaration doesn't come through, breaking many things
 *
 * 2. header html must come after processing $_POST
 * 2-1. Processing $_POST ends with redirecting using header() function and for it to work, no HTML can be present.
 */
global $login_user;

$display_sidebar = true;
$url = $_SERVER['REQUEST_URI'];
$no_sidebar = array('login', 'lost_password', 'lost_password_reset'); // these pages should never have sidebar.
foreach ($no_sidebar as $keyword) {
    if (str_contains($url, $keyword)) {
        $display_sidebar = false;
    }
}

if (login_level_check() && $display_sidebar): ?>

    <div class="brixwork_nav__overlay"></div>
    <nav id="brixwork_mobile_nav">
        <div id="brixwork_nav_hamburger">
            <span></span>
            <span></span>
            <span></span>
        </div>

        <a href="<?=$adminpath?>index.php" class="brixwork_nav__logo desktop">
            <img src="<?=$settings['master_url']?>admin/images/brixwork_logo_black.png" class="img-full"  alt="Welcome to Brixwork Admin Page"/>
        </a>
    </nav>

    <?php // NAV CONTENT
    $svg_append = 'images/admin_function_icon/'; ?>

    <nav id="brixwork_nav">
        <a href="<?=$adminpath?>index.php" class="brixwork_nav__logo desktop">
            <img src="<?=$settings['master_url']?>admin/images/brixwork_logo_black.png" class="img-full"  alt="Welcome to Brixwork Admin Page"/>
        </a>
        <div class="brixwork_nav__links">
            <?php // THIS IS CONTROLLED BY ASSOCIATED AGENTS OF THE LOGINS. ?>
            <div class="nav-list">
                <a class="nav-header" data-bs-toggle="collapse" href="#people" role="button" aria-expanded="false" aria-controls="people">
                    <?=get_svg(file_get_contents($svg_append.'agents.svg', true))?>
                    <h2>Manage People</h2>
                    <div class="nav-arrow"></div>
                </a>
            </div>
            <div class="expandable nav-list collapse" id="people">
                <div class="each_link">
                    <a href="<?=$adminpath?>users.php" title="Show list of tickets">Users</a>
                </div>
                <?php if ($settings['multiagents'] == 1): ?>
                    <div class="each_links">
                        <a href="<?=$adminpath?>agents.php" title="Edit user accounts">Agents</a>
                    </div>
                <?php endif; ?>
            </div>

            <?php
            // THIS IS CONTROLLED BY ASSOCIATED AGENTS OF THE LOGINS.
            // SPECIAL CASE: for Podium Properties website, agents cannot see listings p
            if (!(str_contains($settings['sitepath'], "https://podium.properties") && !login_level_check(USER_LOGIN_MANAGER))) : ?>
                <div class="nav-list">
                    <a href="<?= $adminpath ?>homes.php" class="nav-header">
                        <?= get_svg(file_get_contents($svg_append . 'listings.svg', true)) ?>
                        <h2>Manage Listings</h2>
                    </a>
                </div>
            <?php
            endif;

            // THIS IS CONTROLLED BY ASSOCIATED AGENTS OF THE LOGINS. ?>
            <div class="nav-list">
                <a href="<?=$adminpath?>buildings.php" class="nav-header">
                    <?=get_svg(file_get_contents($svg_append.'buildings.svg', true))?>
                    <h2>Manage Buildings</h2>
                </a>
            </div>


            <?php
            /**
             * INDIVIDUAL AGENTS SHOULD NOT HAVE ACCESS TO EDITING CITIES, PAGES OR RESOURCES,
             * Did not use login_level_check() because this is an exclusion where Content Manager (which is lower level permission) have access to editing pages.
             */
            if ($login_user->getLevel() !== USER_LOGIN_AGENT) { ?>
                <div class="nav-list">
                    <a href="<?=$adminpath?>areas.php" class="nav-header">
                        <?=get_svg(file_get_contents($svg_append.'areas.svg', true))?>
                        <h2>Manage Cities</h2>
                    </a>
                </div>

                <div class="nav-list">
                    <a class="nav-header" data-bs-toggle="collapse" href="#pages" role="button" aria-expanded="false" aria-controls="pages">
                        <?=get_svg(file_get_contents($svg_append.'pages.svg', true))?>
                        <h2>Edit Pages</h2>
                        <div class="nav-arrow"></div>
                    </a>
                </div>
                <div class="expandable nav-list collapse" id="pages">
                    <div class="each_link">
                        <a href="<?=$adminpath?>pages.php" title="Show list of tickets">Content Pages</a>
                    </div>
                    <div class="each_links">
                        <a href="<?=$adminpath?>links.php" title="Edit user accounts">Links & Resources</a>
                    </div>
                </div>
                <?php
            }

            // the site settings page can only be accessed by admin and up.
            if (login_level_check(USER_LOGIN_ADMIN)) { ?>
                <div class="nav-list">
                    <a href="<?=$adminpath?>setup.php" class="nav-header">
                        <?=get_svg(file_get_contents($svg_append.'settings.svg', true))?>
                        <h2>Settings</h2>
                    </a>
                </div>
                <?php
            } ?>
        </div>

        <div class="logoff">
            <a href="https://support.brixwork.com/" target="_blank" title="BRIXWORK support desk" class="support_link">
                NEED SOME HELP?
            </a>
            <a href="<?= $adminpath; ?>logoff.php" class="btn btn-admin">
                <?=get_svg(file_get_contents($svg_append.'logout.svg', true))?>
                Log Out
            </a>
        </div>
    </nav>
<?php
endif;