<?php
/**
 * CUSTOM FIELDS HTML FOR OBJECTS ( HOME, BUILDING, AGENT, AND PAGE )
 *
 * must declare $custom_field_object_type before including this file. Ex) $custom_field_object_type = $home
 *
 * @var $custom_field_object_type;  // Object initialized in the PHP file that's calling this file. ex) pages_mod__page_content.php
 * @var $custom_field_object_type_string    string  page object identifier when adding new page - because getting sibling custom field is only for page object.
 */
$object = $custom_field_object_type;
$new_key = 0;
$coder_visibility = login_level_check(1);
?>
<div id="custom_fields_sortable" class="mb-4">
    <?php
    // if new page, attempt to get sibling's custom fields. Currently only supported for page object.
    if ($_GET['mode'] == 'new' && $custom_field_object_type_string == 'page') {
        // no need to migrate custom fields for TOP pages.
        if ($_GET['parent']) {
            $parent_page = new page();
            $parent_page->initialize($_GET['parent']); // parent id is exposed in the url.
            $closest_sibling_id = find_siblings_2023($parent_page, $object->id ?: 0);

            if ($closest_sibling_id) {
                $closest_sibling_page = new page;
                $closest_sibling_page->initialize($closest_sibling_id);

                $custom_fields_list = $closest_sibling_page->custom_fields;
            } else {
                //var_dump('no sibling - custom fields not migrated.');
                $custom_fields_list = false;
            }
        } else {
            //var_dump('no parent page - custom fields not migrated.');
            $custom_fields_list = false;
        }
    } else {
        // not new, get existing custom fields from the selected object.
        $custom_fields_list = $object->custom_fields;
    }

    if ($custom_fields_list):
        // print custom fields
        foreach($custom_fields_list as $field_key => $field_array):
            $array_unserialize = unserialize($field_array['value']);
        ?>
            <div class="custom_field_row row align-items-center pb-3" id="custom_field_row_<?=$new_key?>">
                <?php // CUSTOM FIELD NAME ?>
                <div class="col-lg-3 pt-2">
                    <h6 class="fw-bold text-break m-0"><?=$field_key?>:</h6>
                    <input type="hidden" name="custom_field[<?=$new_key?>][name]" value="<?=$field_key?>" />
                    <input type="hidden" name="custom_field[<?=$new_key?>][id]" value="<?=$field_array['id']?>" />
                </div>

                <div class="col-lg-3 pt-2">
                    <?php
                    if ($coder_visibility) {
                        // brixwork login - allow edit
                        echo '<textarea aria-label="Custom Field Description" class="form-control" rows="2" name="custom_field['.$new_key.'][desc]" placeholder="Describe what this field does">'.cleanupfortextfield($field_array['desc']).'</textarea>';
                    } else {
                        // user login - display only
                        echo '<h6 class="m-0">'.$field_array['desc'].'</h6>';
                        echo '<input type="hidden" aria-label="Custom Field Description" name="custom_field['.$new_key.'][desc]" value="'.cleanupfortextfield($field_array['desc']).'">';
                    } ?>
                </div>

                <?php // CUSTOM FIELD VALUE
                if ($array_unserialize):
                    foreach ($array_unserialize as $count => $val):
                        field_value_textarea($new_key, $val);
                    endforeach;
                else:
                    field_value_textarea($new_key, $field_array['value']);
                endif;
                ?>

                <?php // DELETE BUTTON ... should only be visible to brixwork coders
                $button_visibility = $coder_visibility ? 'block' : 'none';
                ?>
                <div class="col-lg-1 pt-2" style="display: <?=$button_visibility?>">
                    <button type="button" rel="<?=$new_key?>" class="btn btn-danger remove_custom_field"><i class="bi bi-trash-fill"></i></button>
                </div>
            </div>

            <?php
            $new_key++;
        endforeach; // foreach($object->custom_fields as $field_key => $field_array):
    endif; // if (!$object->custom_fields)?>
</div>
<div id="new_fields_key" rel="<?=$new_key?>"></div>


<?php // ADDING NEW CUSTOM FIELDS ?>
<div class="row">
    <div class="col-lg-3 col-sm-6">
        <label for="custom_key_name_select" class="control-label orange m-0">Key</label>
        <select id="custom_key_name_select" name="custom_key_name_select" class="selectpicker custom_select w-100" data-live-search="true" aria-label="existing custom fields option">
            <option value="">Select An Existing Key Name</option>
            <?php
            $customkeyssql = "SELECT `name`, `desc` FROM `custom_fields` GROUP BY `name`, `desc` ORDER BY `desc` DESC, `ord` ASC";
            $customkeysresult = $mysqli->query($customkeyssql);
            if($customkeysresult->num_rows>0):
                while($customkeysarray = $customkeysresult->fetch_assoc()):
                    echo '<option value="'.$customkeysarray['name'].'" rel="'.$customkeysarray['desc'].'">'.$customkeysarray['name'].'</option>';
                endwhile;
            endif;
            ?>
        </select>
        <input type="text" id="custom_field_new_name" name="custom_field_new_name" class="form-control" style="display: none;" aria-label="new name of the custom field" placeholder="new_custom_field_name"/>

        <?php // adding a new custom field is only available for coders .... new custom field requires update to the front end code anyways.
        if (login_level_check(USER_LOGIN_BRIXWORK)) { ?>
            <a href="#" id="add_new_custom_field_name" class="">
                <span id="enternew" style="display: inline;">Enter New Key</span>
                <span id="cancelnew" style="display: none;">Choose Existing</span>
            </a>
        <?php
        } ?>
    </div>

    <div class="col-lg-3 col-sm-6 pt-3 pt-sm-0">
        <label for="custom_field_new_desc" class="control-label orange m-0">Description</label>
        <?php
        if ($coder_visibility) {
            // brixwork login - allow edit.
            echo '<textarea id="custom_field_new_desc" name="custom_field_new_desc[]" class="form-control" rows="2" placeholder="Describe what this field does." aria-label="description for the new custom field"></textarea>';
        } else {
            // user login - do not allow edit.
            echo '<h6 class="pt-2" id="custom_field_new_desc"></h6>';
        } ?>
    </div>

    <div class="col-lg-4 col-sm-8 pt-3 pt-lg-0">
        <label for="custom_field_new_desc" class="control-label orange m-0">Value</label>
        <textarea id="custom_field_new_value" name="custom_field_new_value[]" class="form-control" rows="2" placeholder="Enter the value of this field." aria-label="value for the new custom field"></textarea>
    </div>

    <div class="col-lg-2 col-sm-3 pt-3 pt-lg-0 m-auto">
        <button type="button" class="btn btn-admin" id="custom_field_new_add">Add</button>
    </div>
</div>


<?php
// custom field name can't be blank!
brixwork_modal_html(array(
    'header_content' => 'Field Name Mandatory',
    'body_content' => "<p>Custom fields require a field name (key), even though the value can be blank.</p>",
    'footer_content' => "
        <button type='button' class='btn btn-admin' data-bs-dismiss='modal'>Ok</button>",
    'id' => 'custom_field_key_blank'
));