<?php // BASIC INFO TAB - LISTING DETAILS
global $settings;

/**
 * @var $agent  agent   Agent object initialized in agent_mod.php
 */
?>
<div class="d-flex justify-content-between flex-wrap">
    <?php // MAIN DETAILS ?>
    <div id="agent_basic_details" class="each_tab__category brixwork_inner_spacing">
        <h3 class="each_tab__category_title">Main Details</h3>

        <div class="row">
            <div class="col-xl-4 col-sm-6 mb-4 mt-auto">
                <label for="fname" class="control-label orange">First Name</label>
                <input type="text" name="fname" id="fname" class="form-control" tabindex="0" value="<?=htmlspecialchars($agent->fname)?>" placeholder="First Name" />
            </div>
            <div class="col-xl-4 col-sm-6 mb-4 mt-auto">
                <label for="mname" class="control-label orange">Middle Name</label>
                <input type="text" name="mname" id="mname" class="form-control" tabindex="0" value="<?=htmlspecialchars($agent->mname)?>" />
            </div>
            <div class="col-xl-4 col-sm-12 mb-4 mt-auto">
                <label for="lname" class="control-label orange">Last Name</label>
                <input type="text" name="lname" id="lname" class="form-control" tabindex="0" value="<?=htmlspecialchars($agent->lname)?>" placeholder="Last Name" />
            </div>

            <?php // second language enabled - show corresponding form
            if ($settings['description2on'] == 1): ?>
                <label class="orange mt-2">2nd Language Name</label>
                <div class="col-xl-4 col-sm-6 mb-4 mt-auto">
                    <label for="fname2" class="control-label orange">First Name</label>
                    <input type="text" name="fname2" id="fname2" class="form-control" tabindex="0" value="<?=htmlspecialchars($agent->fname2)?>" placeholder="First Name" />
                </div>
                <div class="col-xl-4 col-sm-6 mb-4 mt-auto">
                    <label for="mname2" class="control-label orange">Middle Name</label>
                    <input type="text" name="mname2" id="mname2" class="form-control" tabindex="0" value="<?=htmlspecialchars($agent->mname2)?>" />
                </div>
                <div class="col-xl-4 col-sm-12 mb-4 mt-auto">
                    <label for="lname2" class="control-label orange">Last Name</label>
                    <input type="text" name="lname2" id="lname2" class="form-control" tabindex="0" value="<?=htmlspecialchars($agent->lname2)?>" placeholder="Last Name" />
                </div>
            <?php
            endif; ?>

            <div class="col-12 mb-4 mt-auto">
                <label for="position" class="control-label orange">Position</label>
                <input type="text" name="position" id="position" class="form-control" value="<?=htmlspecialchars($agent->data['position'])?>" placeholder="i.e. Realtor&reg;" />
            </div>

            <?php // AGENT ID INPUT ... DISABLES & ENABLES DEPENDING ON AGENT CLASS (BILLABLE vs. NOT BILLABLE)
            $agent_id_disable = $agent->billable == 0 ? 'disabled' : '' ?>
            <div class="col-xl-6 col-12 mb-4 mt-auto">
                <label for="agentid" class="control-label orange">Agent ID (Board Assigned)</label>
                <input type="text" name="agentid" id="agentid" class="form-control" value="<?=htmlspecialchars($agent->data['agentid'])?>" placeholder="i.e. V05456" <?=$agent_id_disable?>/>
            </div>

            <?php
            /**
             * AGENT SEAT TYPE - EITHER BILLABLE OR NOT-BILLABLE.
             * @var $agents_seats_full; defined in agents_mod.php
             */
            $tooltip = $agents_seats_full && $agent->billable == 0 ? 'data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-placement="right" data-bs-title="Must have an available billable seat to change seat type."' : ''
            ?>
            <div class="col-xl-6 col-12 mb-4 mt-auto" <?=$tooltip?>>
                <?php
                // billable & non-billable - only enable this form if the agent_classes table is used AND login user must be Manager or above.
                if ( $settings['agent_classes'] ): ?>
                    <label for="class" class="control-label orange">Seat Type</label>
                    <?php
                    if (login_level_check(USER_LOGIN_MANAGER)) : ?>
                        <select class="form-select" name="class" id="class">
                            <?php // loop through agent classes table to create options for each.
                            foreach ($settings['agent_classes'] as $each_class):
                                $option_label = $each_class['name'];
                                $billable = $each_class['billable'];

                                // if new, selected is false. if "modify", selected is based off of exiting agent object
                                $selected = !($_GET['mode'] == 'new') && $agent->data['class'] == $each_class['id'];
                                $current_status = $selected && $billable; // currently, editing agent is billable or not

                                // disabled billable option IF billable seat is full AND current agent is non-billable ex) billable agent should still be able to toggle between billable <-> non-billable.
                                $disabled = $agents_seats_full && $billable && !$current_status ? 'disabled' : '';
                                ?>
                                <option value="<?=$each_class['id']?>" data-billable="<?=$billable ? 1 : 0?>" <?=$selected ? 'selected' : ''?> <?=$disabled?>><?=$option_label?></option>
                            <?php
                            endforeach; ?>
                        </select>
                    <?php
                    else: // Agent and below should not get access to this dropdown ... display only!
                        echo "<div class='user_agent_list'><h6 style='line-height: 1.6;'>$agent->class</h6></div>";
                        echo '<input type="hidden" id="class" name="class" value="'.$agent->data['class'].'" />';
                    endif;
                endif; //if ( $settings['agent_classes'] ): ?>
            </div>

            <div class="col-xl-6 col-12 mb-4 mt-auto">
                <label for="hometown" class="control-label orange">Hometown</label>
                <input type="text" name="hometown" id="hometown" class="form-control" value="<?= htmlspecialchars($agent->data['hometown']);?>" placeholder="i.e. West Vancouver, BC" />
            </div>

            <div class="col-xl-6 col-12 mb-4 mt-auto">
                <label for="languages" class="control-label orange">Languages</label>
                <input type="text" name="languages" id="languages" class="form-control" value="<?= htmlspecialchars($agent->data['languages']);?>" placeholder="i.e. English, Cantonese" />
            </div>

            <div class="col-12 mb-4 mt-auto">
                <label for="excerpt" class="control-label orange">Brief Excerpt</label>
                <textarea name="excerpt" id="excerpt" class="form-control" rows="3"><?= htmlspecialchars($agent->data['excerpt']);?></textarea>
            </div>
        </div>
    </div>

    <?php // BIOGRAPHY ?>
    <div id="biography_details" class="each_tab__category brixwork_inner_spacing">
        <h3 class="each_tab__category_title">Biography</h3>

        <div class="row">
            <div class="col-12 mb-4 mt-auto">
                <label for="heading" class="control-label orange">Tagline</label>
                <input type="text" name="heading" id="heading" class="form-control" size="40" value="<?=htmlspecialchars($agent->heading ?: '')?>" placeholder="i.e. Your Client-First Realtor&reg; With..." />
            </div>

            <div class="col-12 mb-4 mt-auto">
                <label for="content" class="control-label orange">Bio</label>
                <textarea name="content" id="content" class="form-control rich_editor" rows="10"><?=htmlspecialchars($agent->data['content']) ?: ''?></textarea>
            </div>

            <?php
            if ($settings['description2on'] == 1): ?>
            <div class="col-12 mb-4 mt-auto">
                <label for="content2" class="control-label orange">Bio 2</label>
                <textarea name="content2" id="content2" class="form-control rich_editor" rows="10"><?= htmlspecialchars($agent->data['content2']);?></textarea>
            </div>
            <?php
            endif; ?>
        </div>
    </div>


    <?php //CUSTOM FIELDS ... only enable when object is available
    if (is_object($agent)) {
        $brixwork_coder_tip = login_level_check(1) ? 'data-bs-toggle="tooltip" data-bs-placement="left" data-bs-custom-class="brixwork-tooltip" data-bs-title="Coder Tip: The custom fields can be reordered by dragging!" ' : '';
    ?>
        <div id="custom_fields_table" class="each_tab__category brixwork_inner_spacing w-100">
            <h3 class="each_tab__category_title">Custom Fields</h3>

            <?php
            $custom_field_object_type = $agent;
            include 'includes/object_custom_field.php';
            ?>
        </div>
    <?php
    } ?>
</div>
