<?php
/**
 * SET $preset_object_type RIGHT BEFORE INCLUDING THIS PHP FILE.
 *
 * object types: pages, resources, agents, buildings, homes;
 *
 * $object_type = formerly used as $destinationtable
 * @var $preset_object_type string      object type string ("home", "building", etc.) declared in php that's calling this file.
 * @var $destinationtable   string      name of file. declared in php that's calling this file.
 */
global $settings;
$object_type = $preset_object_type;

// DETERMINE NUMBER OF PDF DOCS ATTACHED
if($settings[$object_type.'_pdfnum']!='') {
    $pdf_num = $settings[$object_type.'_pdfnum'];
} else {
    $pdf_num = 1;
}

// GET PDF LABELS
if ($pdf_num > 0):
    $labels_sql = 'SELECT pdf_labels FROM '.$destinationtable.' WHERE id = '.$object->id;
    $labels_result = $mysqli->query($labels_sql);
    $labels = null;
    if ($object && $array = $labels_result->fetch_assoc()):
        $labels = unserialize($array['pdf_labels'] ?: '');
    endif;
endif;
?>

<h2 class="pb-4">PDF Attachments</h2>
<div id="pdf_attach_section" class="each_tab__category brixwork_inner_spacing w-100">
    <div class="row">
    <?php
    // loop through the number of PDFs
    for ($pdf_counter = 0; $pdf_counter < $pdf_num; $pdf_counter++):
        $suffix = $pdf_counter > 0 ? $pdf_counter : ''; // first suffix is empty, numbered afterwards
        $filename = $settings[$object_type.'_pdffilename'][$pdf_counter];
        $pdf_link = $object ? $object->pdf_file_link($pdf_counter, 'Preview '.$settings[$object_type.'_pdfname'][$pdf_counter].' PDF') : '';
        $pdf_exists = (bool)$pdf_link;
    ?>
        <div class="col-lg-6 my-4">
            <h4><?=$settings[$object_type.'_pdfname'][$pdf_counter] ?: 'PDF' ?></h4>

            <input
                aria-label = "Drag and Drop"
                data-filename="<?=$filename?>"
                data-uploaded = "<?=$pdf_exists?>"
                data-count = "<?=$pdf_counter?>"
                type = "File"
                name = "pdf_input<?=$suffix?>"
                id = "pdf_input<?=$suffix?>"
            />

            <div class="progress mt-2">
                <div id="pdfprogressbar<?=$suffix?>" class="progress-bar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" role="progressbar" style="width:0;"></div>
            </div>

            <div class="uploadifivequeue" id="pdfqueue<?=$suffix?>"></div>

            <?php // PDF LABELS ?>
            <div class="pdf_label_wrapper d-flex my-3">
                <div class="label_input_wrapper">
                    <input
                        aria-label="PDF Label"
                        class="form-control"
                        name="pdf_label<?=$suffix?>"
                        id="pdf_label<?=$suffix?>"
                        placeholder="PDF Label here. E.g. Floorplan Units 400/500"
                        value="<?=(isset($labels[$pdf_counter]) && is_string($labels[$pdf_counter]) ? htmlentities($labels[$pdf_counter]) : '' )?>"
                    />
                </div>
                <div class="label_btn_wrapper">
                    <button type="button" class="btn btn-admin light_blue px-4" data-input="#pdf_label<?=$suffix?>" id="update_pdflabel<?=$suffix?>" value="Update Label" >Update Label</button>
                </div>
            </div>


            <div class="pdf_attach_functions_wrapper">
                <?php // ADD "DELETE" AND "PREVIEW" BUTTONS HERE ?>
                <div class="delete_pdf_wrapper">
                    <button type="button" class="btn btn-admin reddish px-4 <?=$pdf_exists ? '' : 'disabled'?>" name="removepdf<?=$suffix?>" id="removepdf<?=$suffix?>" value="Remove PDF">Delete</button>
                </div>

                <div id="pdf_preview<?=$suffix?>">
                    <?php if ($pdf_exists):
                        echo $pdf_link;
                    endif; ?>
                </div>

                <?php if (login_level_check(USER_LOGIN_BRIXWORK) && $pdf_exists): ?>
                    <div class="my-0">
                        <a href="#" class="" onclick="$('#mainimageinput<?=$suffix;?>').uploadifive('debug');">Debug</a>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    <?php
    endfor; ?>

    </div> <?php // end of "row" ?>
</div> <?php // end of "pdf_attach_section" ?>



<?php // YOUTUBE AND VIMEO ATTACHMENTS
$youtube_setting    = $settings[$object_type.'_youtubenum'];
$vimeo_setting      = $settings[$object_type.'_vimeonum'];
$youtube_names      = $settings[$object_type.'_youtubefields'];
$vimeo_names        = $settings[$object_type.'_vimeofields'];

$tooltips_init = login_level_check(1) ? 'data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-title="The label can be changed by editing Field Names from the Settings page!"' : '';

if ($youtube_setting > 0 || $vimeo_setting > 0):
    $video_wrapper_title = match ($object_type) {
        "homes"     => "Videos and Home Tours",
        "agents"    => "Agent Videos",
        default     => "Videos",
    }
?>
<h2 class="py-4"><?=$video_wrapper_title?></h2>
<div id="pdf_attach_section" class="each_tab__category brixwork_inner_spacing w-100">
    <div class="row">

        <?php if ($youtube_setting > 0): // YOUTUBE LINK ?>
        <div id="youtube_wrapper" class="col-lg-6">
            <h4>Youtube Video</h4>

            <?php // display all available Youtube
            for ($youtube_counter = 0; $youtube_counter < $youtube_setting; $youtube_counter++):
                $youtube_suffix = $youtube_counter > 0 ? $youtube_counter : '';  // suffix is empty string for first one.
                $youtube_link = $object->data[$settings[$object_type.'_youtubefields'][$youtube_counter]];      // processed YouTube id
            ?>
            <div id="each_youtube<?=$youtube_suffix?>" class="video_upload_js" data-type="youtube" data-count="<?=$youtube_counter?>">
                <div id="youtube_preview<?=$youtube_suffix?>" class="responsive_iframe_container <?=$youtube_link ? '' : 'no_preview'?> my-2">
                    <?php if ($youtube_link): // display already existing YouTube link ?>
                        <iframe class="responsive_iframe" width="560" height="315" src="https://www.youtube.com/embed/<?=$youtube_link?>" title="<?=$object_type?> youtube video" allow="accelerometer; clipboard-write; encrypted-media; gyroscope; picture-in-picture;" allowfullscreen></iframe>
                    <?php else: ?>
                        <div class="responsive_iframe no_preview"><i class="bi bi-play-circle"></i></div>
                    <?php endif; ?>
                </div>
                <label for="youtube<?=$youtube_suffix?>" class="control-label orange mt-2" <?=$youtube_counter == 0 ? $tooltips_init : ''?>><?=$youtube_names[$youtube_counter]?> URL</label>
                <input type="text" name="youtube<?=$youtube_suffix?>" id="youtube<?=$youtube_suffix?>" class="form-control mb-3" size="40" value="<?=$youtube_link?>" placeholder="https://youtube.com/v/6h432fyg..." />

                <div class="video_functions_wrapper d-flex">
                    <input type="button" class="btn btn-admin" name="updateyoutube<?=$youtube_suffix?>" id="updateyoutube<?=$youtube_suffix?>" value="Link" />
                    <a class="remove_video" id="removeyoutube<?=$youtube_suffix?>">Remove Video</a>
                </div>
            </div>
            <?php endfor; ?>
        </div>
        <?php endif; // end if ($youtube_setting > 0) ?>

        <?php if ($vimeo_setting > 0): // YOUTUBE LINK ?>
        <div id="vimeo_wrapper" class="col-lg-6">
            <h4>Vimeo Video</h4>

            <?php // display all available Youtube
            for ($vimeo_counter = 0; $vimeo_counter < $vimeo_setting; $vimeo_counter++):
                $vimeo_suffix = $vimeo_counter > 0 ? $vimeo_counter : '';  // suffix is empty string for first one.
                $vimeo_link = $object->data[$settings[$object_type.'_vimeofields'][$vimeo_counter]];      // processed vimeo id
            ?>
            <div id="each_vimeo<?=$vimeo_suffix?>" class="video_upload_js" data-type="vimeo" data-count="<?=$vimeo_counter?>">
                <div id="vimeo_preview<?=$vimeo_suffix?>" class="responsive_iframe_container my-2">
                    <?php if ($vimeo_link): // display already existing YouTube link ?>
                        <iframe class="responsive_iframe" src="https://player.vimeo.com/video/<?=$vimeo_link?>?h=c81dd19e39&amp;badge=0&amp;autopause=0&amp;player_id=0&amp;app_id=58479" width="560" height="315" frameborder="0" allow="autoplay; picture-in-picture" allowfullscreen title="<?=$object_type?> vimeo video"></iframe>
                    <?php else: ?>
                        <div class="responsive_iframe no_preview"><i class="bi bi-play-circle"></i></div>
                    <?php endif; ?>
                </div>

                <label for="vimeo<?=$vimeo_suffix?>" class="control-label orange mt-2" <?=$vimeo_counter == 0 ? $tooltips_init : ''?>><?=$vimeo_names[$vimeo_counter]?> URL</label>
                <input type="text" name="vimeo<?=$vimeo_suffix?>" id="vimeo<?=$vimeo_suffix?>" class="form-control mb-3" size="40" value="<?=$vimeo_link?>" placeholder="https://vimeo.com/6h432fyg..." />

                <div class="video_functions_wrapper d-flex">
                    <input type="button" class="btn btn-admin" name="updatevimeo<?=$vimeo_suffix?>" id="updatevimeo<?=$vimeo_suffix?>" value="Link" />
                    <a class="remove_video" id="removevimeo<?=$vimeo_suffix?>">Remove Video</a>
                </div>
            </div>
            <?php endfor; ?>
        </div>
        <?php endif; ?>

    </div>
</div>
<?php
endif; //end if ($youtube_setting > 0 || $vimeo_setting > 0) ?>


<?php // VIRTUAL TOUR SECTION for Homes & Buildings
if ($object_type == 'homes' || $object_type == 'buildings'):
?>
<div id="pdf_attach_section" class="each_tab__category brixwork_inner_spacing w-100">
    <div class="row">
        <div id="virtual_tour_wrapper" class="col-lg-6">
            <h4>Virtual Tour Link</h4>

            <div id="each_virtual_tour">
                <div id="virtual_tour_preview" class="responsive_iframe_container my-2">
                    <?php if ($object->data['virtualtour']): ?>
                        <iframe class="responsive_iframe" src="<?=$object->data['virtualtour']?>" width="560" height="315" frameborder="0" allow="autoplay; picture-in-picture" allowfullscreen title="<?=$object_type?> virtual tour"></iframe>
                    <?php else: ?>
                        <div class="responsive_iframe no_preview"><i class="bi bi-play-circle"></i></div>
                    <?php endif; ?>
                </div>
                <label for="virtualtour" class="control-label orange mt-2" >Virtual Tour Link</label>
                <input type="text" name="virtualtour" id="virtualtour" class="form-control mb-3" size="40" value="<?=htmlentities($object->data['virtualtour'] ?: '')?>" placeholder="i.e. https://www.myvirtualtour.com/123-main-street-vancouver" />

                <div class="video_functions_wrapper d-flex">
                    <input type="button" class="btn btn-admin" name="update_virtual_tour" id="update_virtual_tour" value="Link" />
                    <a class="remove_video" id="remove_virtual_tour">Remove Video</a>
                </div>
            </div>

        </div>
    </div>
</div>
<?php
endif;