/*
* Because the core functionality is so similar,
* area_mod.php and subarea_mod.php uses this file together, so far. (2024)
*
* */

let area_map, marker, polyline	// map variable is created by initMap() called by googleapis.

$(document).ready(function(){
	$(window).keydown(function(event){
		if(event.keyCode === 13) {
			event.preventDefault();
			return false;
		}
	});

	document.getElementById('polygon').addEventListener('blur', function () {
		draw_polygon_on_map(this.value)
	})

	init_find_address()
	init_reset_map()
	init_area_name_edit()
});


function initMap() {
	// this initmap function is ran by the script include BEFORE the header.php
	let area_map_data = document.getElementById('areamapcontainer')
	let area_lat    = parseFloat(area_map_data.dataset.lat)
	let area_long   = parseFloat(area_map_data.dataset.long)
	let area_polygon = document.getElementById('polygon').value

	// initialize map with default lat & long data
	area_map = new google.maps.Map(document.getElementById("areamap"), {
		center: {lat: area_lat, lng: area_long},
		zoom: 13,
	})
	marker = new google.maps.Marker({
		position: { lat: area_lat, lng: area_long },
		map: area_map,
	});

	if (area_polygon) {
		// if polygon data exists, draw on map.
		draw_polygon_on_map(area_polygon)
	}


	// make marker move with the map
	google.maps.event.addListener(area_map, 'bounds_changed', function() {
		marker.setPosition(area_map.getCenter());
	});
	// update hidden lat long data fields
	google.maps.event.addListener(area_map, 'idle', function () {
		let new_position = marker.getPosition()
		update_map_lat_long(new_position)
	})

	console.log('Initialized Google Map Objects')
}


function center_on_address(address) {
	const geocoder = new google.maps.Geocoder();
	geocoder.geocode({ address: address }, (results, status) => {
		if (status === "OK") {
			// Set the map center to the city's coordinates
			const location = results[0].geometry.location
			area_map.setCenter(location);
		} else {
			console.log(`Geocode was not successful for the following reason: ${status}`);
		}
	});
}


/**
 * draw polygon lines on the initialized map
 * @param input_data	Format of this data is described in the areas_mod.php page.
 */
function draw_polygon_on_map(input_data) {
	if (input_data !== '') {
		const regex = /LatLng\((-?\d+\.\d+),\s*(-?\d+\.\d+)\)|(-?\d+\.\d+),(-?\d+\.\d+)/g;
		let match;
		const coordinates = [];
		let lat_arr = [];
		let lng_arr = [];
		while (match = regex.exec(input_data)) {
			const lat = parseFloat(match[1] || match[3]);
			const lng = parseFloat(match[2] || match[4]);
			lat_arr.push(lat)
			lng_arr.push(lng)
			coordinates.push({ lat, lng });
		}

		// get average by sum divided by length
		let lat_avg = (lat_arr.reduce((key, val) => key + val, 0)) / lat_arr.length
		let lng_avg = (lng_arr.reduce((key, val) => key + val, 0)) / lng_arr.length
		area_map.setCenter({lat: lat_avg, lng: lng_avg})

		if (polyline) polyline.setMap(null)
		console.log(coordinates)
		// Draw a polyline using the coordinates
		polyline = new google.maps.Polygon({
			path: coordinates,
			strokeColor: "#FF0000",
			strokeOpacity: 0.7,
			strokeWeight: 2,
			fillColor: "#FF0000",
			fillOpacity: 0.25,
		});

		polyline.setMap(area_map);
	}
	else {
		// no data ... delete existing polygon lines
		if (polyline) polyline.setMap(null)
	}
}

/**
 * Move map to center on area name.
 */
function init_find_address() {
	$('#find_address_on_map').on('click', function () {
		let area_name_to_search = $('#name').val(); // the area name entered.
		let city_name = $('#areamapcontainer').data('area-name') // the city above it.
		if (city_name !== undefined && city_name !== '') {
			// if editing city, not subarea, there's no city above to append.
			area_name_to_search += (', ' + city_name)
		}

		if ($('#province').length > 0) {
			// should be there.. but just in case.
			let region = $('#province').val();
			if (region !== '') {
				area_name_to_search += (', ' + region);
			}
		}

// Check if the #country element exists before attempting to read its value
		if ($('#country').length > 0) {
			// should be there.. but just in case.
			let country = $('#country').val();
			if (country !== '') {
				area_name_to_search += (', ' + country);
			}
		}

		console.log("Geocode call for: "+area_name_to_search);
		center_on_address(area_name_to_search)
	})
}

/**
 * Center back to original lat & long ... most likely area name
 * Also remove polygon lines on map.
 */
function init_reset_map() {
	$('#reset_map').on('click', function () {
		let area_map_data = document.getElementById('areamapcontainer')
		let area_name	= area_map_data.dataset.name

		if (polyline) polyline.setMap(null) // delete poly line if any

		center_on_address(area_name)
	})
}

/**
 * Update the hidden lat & long data fields as the map is being moved.
 * @param new_position
 */
function update_map_lat_long(new_position) {
	// select mls map lat long input fields
	$('#lat').attr('value', new_position.lat())
	$('#long').attr('value', new_position.lng())
}

/**
 * Only allow name edit on certain condition.
 * Condition = no MLS, no custom Polygons,
 */
function init_area_name_edit() {
	// show name change modal
	$('#name').on('click', function () {
		if (parseInt($('#mls_integrated').val())===1) {
			$('#change_name').modal('show')
		}
	})

	$('.enable_edit_name').click(function () {
		let name_field = $('#name')
		name_field.off('click')
		name_field.removeAttr('readonly')
	})
}