<?php
/*
Filename: pages_mod.php
Description: Edit each page content, title, etc.

Accessibility: Manager, Admin, Content Manager has access.

Method: Direct
Output: Direct
*/
global $settings;
include 'start.php';

$destinationfolder = 'pages';
$destinationtable = 'pages';

// FORM SUBMIT BEHAVIOR
if ($_POST) {
    $current_mode   = $_POST['mode'];           // either `new` or `modify`.
    $idr            = $_POST['idr'] ?: false;   // could be empty if `new`.
    $allow_submit   = true;                     // verify $_POST data and if not good, turn this variable to false and print error.

    // modify date is always now.
    $_POST['modify_date'] = $now;

    // custom specifications for main images...
    if (is_array($_POST['main_img_titles'])) {
        foreach ($_POST['main_img_titles'] as $title_key => $title_val) {
            $_POST['main_img_titles'][$title_key] = trim($title_val);
        }
        $_POST['main_img_titles'] = serialize($_POST['main_img_titles']);
    }
    if (is_array($_POST['mainwidth'])) {
        foreach ($_POST['mainwidth'] as $width_key => $width_val) {
            $val = $width_val ?: '';
            $_POST['mainwidth'][$width_key] = trim(remove_all_but_numbers($val));
        }
        $_POST['mainwidth'] = serialize($_POST['mainwidth']);
    }
    if (is_array($_POST['mainheight'])) {
        foreach ($_POST['mainheight'] as $height_key => $height_val) {
            $val = $height_val ?: '';
            $_POST['mainheight'][$height_key] = trim(remove_all_but_numbers($val));
        }
        $_POST['mainheight'] = serialize($_POST['mainheight']);
    }

    // New page. Create date = now, and set order to the last.
    if ($current_mode == 'new' && !is_object($page)) {
        $_POST['create_date'] = $now;
        $_POST['ord'] = get_page_endfield($destinationtable, 'ord', $parentpage->id, 'MAX') + 1;
    }

    // single or multi areas?
    if (is_array($_POST['area']) && count($_POST['area']) > 0) {
        $areastring = '';
        foreach ($_POST['area'] as $key => $areaid) {
            if ($key > 0) {
                $areastring .= ';';
            }
            $areastring .= $areaid;
        }
        $_POST['area'] = $areastring;
    } else {
        $_POST['area'] = ''; // nothing selected, leave blank for false result.
    }

    // convert checkboxes with "on" to 1.
    $_POST['embedded'] = ($_POST['embedded'] == 'on' ? 1 : 0);
    $_POST['breed'] = ($_POST['breed'] == 'on' ? 1 : 0);
    $_POST['deepbreed'] = ($_POST['deepbreed'] == 'on' ? 1 : 0);
    $_POST['enable_photo_gallery'] = ($_POST['enable_photo_gallery'] == 'on' ? 1 : 0);

    $_POST['description'] = $_POST['metadescription']; // because I was too retarded to match up column names but it's too late now. Homes and Buildings tables have "metadescription" while Pages table has "description" field..
    $_POST['title'] = $_POST['page_title']; // 'title' is being overwritten by the 'title' from photo gallery. Renamed the page title input, and overwrite here for proper data submission.

    if ($allow_submit) {
        $update_id = form_to_table($destinationtable, $_POST, $idr);
        $memcache_params = array(
            'type'=>'pages'
        );
        get_memcache($memcache_params, 'delete');


        if (is_numeric($update_id)) {
            $page = new page;
            $page->initialize($update_id);

            process_custom_fields($page);

            // must register parent before redirecting. $_POST['parent'] exists when $_GET['parent'] exists
            if ($_POST['parent'] != '') {
                $page->register_parent($_POST['parent']);
                $page->find_parents();
            }

            // different success messages depending on "created" or "modified"
            $post_title         = $_POST['title'] ?: $_POST['menu_title'];
            $page_id_display    = login_level_check(1) ? '(ID: '.$update_id.')' : '';
            $status             = ($current_mode == 'new' && $idr === false) ? 'added' : 'modified';
            $_SESSION['success-message'] = "<p><b>Success!</b> The page data has been $status for <span style='text-decoration: underline'>$post_title $page_id_display</span>.</p>";


            // redirect & refresh the object data.
            header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/').'?idr='.$update_id);
            exit();

        } else {
            $error = '<p><b>Error</b> There was an error while attempting to ' . ($_GET['mode'] == 'modify' ? 'update' : 'create') . ' your new page. Error: <i>' . $mysqli->error . '</i>. Please contact our support desk with this message.</p>';
        }
    } else {
        $error = "<p><b>Warning!</b> Invalid value passed. Please verify your input or contact Brixwork Support.</p>";
    }
// end (if data $_POST has been submitted already).
}

// TODO: Add ?version='.$brixwork_version to js. AND minify!
// these scripts are only need when form is being edited ... do not include when the form is being submitted
$scriptinclude = array('pages_mod.source.js', 'brixwork_images.source.js', 'aws-sdk-2.40.0.min.js', 'brixwork_attach.source.js');

include 'header.php';

$preset_object_type = "pages";                               // essential variable
include "includes/object_mod_tabs/object_mod__prep.php";    // essential file inclusion

/**
 * now load up parent page just in case.
 * @var $page page
 */
if ($page->parents) {
    // only kicks in for editing existing pages tha thave a parent.
    $parentpage = new page;
    $parentpage->initialize($page->parents[count($page->parents)-1]);
}
else if($_REQUEST['parent']!='' && $_REQUEST['mode']=='new') {
    $parentpage = new page;
    $parentpage->initialize($_REQUEST['parent']);
}
else {
    $parentpage = false;
}

if(is_object($parentpage) && $parentpage->parents!=false) {
    $topparentpage = new page;
    $topparentpage->initialize($parentpage->topparent);
} else if(is_object($parentpage)) {
    // only one parent, so top parent and parent are identical.
    $topparentpage = $parentpage;
} else {
    $topparentpage = false;
}

// GET SIBLING ID IF EXISTS,.
if (is_object($parentpage)) {
    $closest_sibling_id = find_siblings_2023($parentpage, $page->id ?: 0);
    $closest_sibling_page = '';

    if ($closest_sibling_id) {
        $closest_sibling_page = new page;
        $closest_sibling_page->initialize($closest_sibling_id);
    }
}

// codes to execute if something has been submitted already - this part loads it up and then takes you back to the whole list.
$success = $error = "";
if ($_GET['add'] == 'success' && $_GET['idr']) {
    // this runs after the new object has been added ... $home object is initialized at the top.
    $success = "<p><b>Success!</b> The page data has been added for <span style='text-decoration: underline'>$page->title</span></p>";
}

// header_html is separated from header.php on purpose.
include 'includes/header_html.php';
?>

<form method="POST" role="form" id="pages_mod_form" class="brixwork_admin_container mod_form" enctype="multipart/form-data" action="<?=$_SERVER['PHP_SELF']?>">
    <?php // hidden input field to store parent page data
    if($_REQUEST['parent']!='' && $_GET['mode']=='new') {
        echo '<input type="hidden" name="parent" value="'.$_REQUEST['parent'].'" />';
    } ?>

    <h1 id="admin_mod__title">
        <?php
        $display_title = $page->menu_title ?: $page->title; // attempt to display menu title if not, fall back to title.
        if ($_GET['mode']=='new') { echo 'Adding A New Page'; } else { echo 'Editing '.$display_title; }
        ?>
    </h1>

    <?php
    // SUCCESS OR ERROR MESSAGE ON FORM SUBMIT.
    session_alert_display('success-message');

    if ($error)
        echo brixwork_alert($error, 'error');

    // BOOTSTRAP 5 TABS - Command + F to find HTML content for each tab
    $nav_tab_array = is_object($page) ? array('Page Content', 'Photos', 'Attachments', 'SEO', 'Admin Panel') : array('Page Content', 'SEO', 'Admin Panel');
    brixwork_object_tabs('page', $nav_tab_array);
    ?>

    <?php // ALL CORRESPONDING TAB CONTENTS ?>
    <div class="manage_object_tab_content tab-content">
        <?php // BASIC INFO CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade show active" id="page-content-tab" role="tabpanel" aria-labelledby="Page-Content" tabindex="0">
            <?php include "includes/object_mod_tabs/pages_mod__page_content.php"; ?>
        </div>

        <?php // PHOTOS TAB CONTENT ... new page will not have this tab.
        if (is_object($page)) {
            // PHOTOS TAB ?>
            <div class="manage_listing_each_tab tab-pane fade" id="photos-tab" role="tabpanel" aria-labelledby="Photos" tabindex="0">
                <?php include "includes/object_mod_tabs/object_mod__photos.php"; ?>
            </div>

            <?php // ATTACHMENTS TAB CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade" id="attachments-tab" role="tabpanel" aria-labelledby="Attachments" tabindex="0">
                <?php include "includes/object_mod_tabs/object_mod__attach.php"; ?>
            </div>
        <?php
        } ?>

        <?php // SEO TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="seo-tab" role="tabpanel" aria-labelledby="SEO" tabindex="0">
            <?php include "includes/object_mod_tabs/object_mod__seo.php"; ?>
        </div>

        <?php // DIMENSIONS TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="admin-panel-tab" role="tabpanel" aria-labelledby="Admin-Panel" tabindex="0">
            <?php include "includes/object_mod_tabs/pages_mod__admin_panel.php"; ?>
        </div>
    </div>

    <div id="submit_button_group" class="" >
        <?php // HIDDEN INPUT TO BE USED IN $_POST
        if (is_object($page)) {
            $idr_val = $page->id;
            $mode_val = 'modify';
        } else {
            $idr_val = "";
            $mode_val = 'new';
        }
        echo "<input type='hidden' name='idr' id='idr' value='$idr_val' />";
        echo "<input type='hidden' name='mode' value='$mode_val' />";
        ?>
        <input type="submit" name="submitform" id="pagesubmit" class="btn btn-admin" value="<?=$mode_val == 'new' ? 'Add Page' : 'Save Changes'?>" />
        <a class="btn btn-admin light_blue" href="pages.php">Back</a>
    </div>
</form>

<?php
include 'footer.php';