<?php
/**
 * Filename: setup.php
 * Description: Site-wide settings are made here.
 *
 * Accessibility: Only Admin has access to edit because this page contains many settings that affects the entire site.
 */
include 'start.php';
global $settings;

header("X-XSS-Protection: 0");
redirect_invalid_user(USER_LOGIN_ADMIN);

$destinationtable = 'settings';

//$section = ($_GET['section']!='' ? $_GET['section'] : 'site');
$scriptinclude = array('setup.js?version='.$brixwork_version, 'mailchimp.source.js?v='.$brixwork_version);
$scriptinsert = '<script defer src="https://maps.googleapis.com/maps/api/js?key='.$settings['google_maps_api_key'].'&callback=initMap"></script>';


if ($_POST) {
	//custom settings tab ... currently disabled. Our setup cannot detect "custom" tab.
	if (isset($_POST['section']) && $_POST['section'] == 'custom') {
		$cs = array();
		foreach($_POST['name'] as $key=>$name) {
			foreach ($_POST as $name=>$notused) {
				if ($name != 'section') {
					$cs[$key][$name] = $_POST[$name][$key];
				}
			}
		}
		// custom settings update.
		foreach ($cs as $k=>$v) {
			$update = update_custom_settings_row($v['name'],$v['value'],$v['editable'],$v['id']);

			if ( $update !== true) {
				$error .= $update.'<br />';
			} else {
				$_SESSION['success-message'] .= "<p><b>Success!</b> Custom Settings successfully saved.</p>";
			}
		}
	} else {
		// PROCESS REGULAR SETTINGS.
		$avoid = array(
			'section',
			'submit'
		);

		$arraymandatory = array(
			'mainphotofilename',
			'mainphotoname'
		);

		foreach($_POST as $name=>$value) {
			if(!in_array($name, $avoid)) {
				if(is_array($value) && count($value)==1  // only ONE in array, so override for the 1st one. 
					&& strpos($name, 'pdffilename')===false // OR these are the mainimage/pdf related strings, which should be array even if there's only one in the array!
					&& strpos($name, 'pdfname')===false
					&& strpos($name, 'mainphotofilename')===false
					&& strpos($name, 'mainphotoname')===false
					&& strpos($name, 'mainphotowidth')===false
					&& strpos($name, 'mainphotoheight')===false
					&& strpos($name, 'youtubefields')===false
					&& strpos($name, 'vimeofields')===false
					&& strpos($name, 'followupboss_tag')===false
					&& strpos($name, 'followupboss_source_page')===false
				) {
					$postvars[$name] = $value[0];
				} else if(is_array($value)) {
					$postvars[$name] = serialize($value);
				} else {
					$postvars[$name] = trim($value);
				}
			}
		}


		// clean up some variables, merge them etc., backwards compatibility issues and what not. 
		if ($postvars['province'] != '') {
			// $settings['location'] driven from 'province' and 'country'
			$postvars['location'] = $postvars['province'].($postvars['country']!='' ? ', '.$postvars['country']: '');
		}
		if ($postvars['mapsearch_lat'] != '') {
			$postvars['baselatlong'] = $postvars['mapsearch_lat'].', '.$postvars['mapsearch_long'];
		}
		if ($postvars['multiagents'] == 0 && $postvars['agents_limit'] != '') {
			$postvars['multiagents'] = 1; // protect multi-agent toggle from accidental click
		}


		// UPDATE THE DATABASE TABLE
		foreach($postvars as $name=>$value) {
			$update = update_settings_row($name,$value);

			if ($update !== true) {
				$error .= $update.'<br />';
			}
		}
		if ($update) {
			// upon successful data save, redirect to form page ... this prevents accidental submission of form via page refresh.
			$_SESSION['success-message'] = "<p><b>Success!</b> Settings successfully saved.</p>";
			header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/'));
			exit();
		}
	}

	// Data has been updated ... reload!
	unset($settings);
	include 'settings.php';
}

// SHOW FORM!
// header_html is separated from header.php on purpose.
include 'header.php';
include 'includes/header_html.php';
?>
    <div class="brixwork_admin_container title">
        <h1 id="admin_page__title">Your Website Settings</h1>
        <h5><?=$settings['sitepath']?></h5>

        <form method="post" enctype="multipart/form-data" action="<?=$_SERVER['PHP_SELF']?>" class="form-horizontal settings_form" role="form" id="settings_form">
			<?php
			// FUNCTIONS ONLY FOR BRIXWORK LOGIN
			if (login_level_check(1)):
				$rets_import_date = $building_group_date = 0;
				$rets_import_file = $building_group_file = '';

				if($settings['mls_integrated']==1) {
					$cron_log_folder = $_SERVER['DOCUMENT_ROOT'].($settings['rootpath']!='' ? $settings['rootpath'] : '').'/cron/logs/';
					$rets_import_info = get_cron_log_info('import_', $cron_log_folder);             // returns array ... arr[0] = timestamp, arr[1] = log file link
					$rets_import_date = intval($rets_import_info[0]);
					$rets_import_file = $rets_import_info[1];

					$building_group_info = get_cron_log_info('groupbuilding_', $cron_log_folder);
					$building_group_date = intval($building_group_info[0]);
					$building_group_file = $building_group_info[1];
				}
				?>
                <div class="row setting_functions">
                    <div class="col-xl-3 col-sm-6">
						<?php // PHP VERSION & CPANEL USERNAME ?>
                        <div id="server_settings" class="setting_functions_content">
                            <p><span class="setting_functions_name">PHP Version:</span> <?=phpversion()?></p>
                            <p><span class="setting_functions_name">cPanel Username:</span> <?=$settings['cpanel_username']?></p>
                            <p><span class="setting_functions_name">MySQL Table:</span> <?=$mysql_table?></p>
                            <p class="pb-3"><span class="setting_functions_name">MySQL Host:</span> <?=$mysqli->host_info?></p>

                            <a href="admin_findsettings.php" class="btn btn-admin light_blue" >Exploded View</a>
                        </div>
                    </div>

                    <div class="col-xl-3 col-sm-6">
						<?php // SCRIPT VERSION ?>
                        <div id="script_settings" class="setting_functions_content">
                            <label class="orange">Last Update Run:</label>
                            <p class="setting_functions_name"><?=date($mysql_time['day'].', '.$mysql_time['hourminute'], filemtime ( 'index.php' ))?></p>
                            <p class="pb-3">Version: <?=$brixwork_version?></p>
							<?php // clicking upgrade from V5 backend should remain in V5. ?>
                            <a href="/upgrade.php?hash=58300774" class="btn btn-admin grey_teal" target="_blank" data-bs-toggle="tooltip" data-bs-placement="bottom" data-bs-custom-class="brixwork-tooltip" data-bs-title="Check the upgrade URL before clicking">Upgrade Script</a>                    </div>
                    </div>

                    <div class="col-xl-3 col-sm-6">
						<?php // MLS SYNC INFO ?>
                        <div id="mls_settings" class="setting_functions_content">
                            <label class="orange">Last Sync Run:</label>
                            <p class="setting_functions_name"><?=$rets_import_date===0 ? 'NO LOGS' : date($mysql_time['full'],$rets_import_date)?></p>
							<?php
							$href = $settings['sitepath']."cron/logs/".$rets_import_file;
							display_log($rets_import_date, $href);
							?>
                            <a href="/cron/retsimport.php?hash=58300774" class="btn btn-admin wheat"  data-toggle="tooltip" data-placement="bottom" title="<?=$settings['mls_import_url']?>" target="_blank">MLS&reg; Sync</a>
                        </div>
                    </div>

                    <div class="col-xl-3 col-sm-6">
						<?php
						if ($settings['mls_integrated'] == 1): ?>
                            <div id="mls_settings" class="setting_functions_content">
                                <label class="orange">Last Sync Run:</label>
                                <p class="setting_functions_name"><?=$building_group_date===0 ? 'NO LOGS' : date($mysql_time['full'],$building_group_date)?></p>
								<?php
								$href = $settings['sitepath']."cron/logs/".$building_group_file;
								display_log($building_group_date, $href);
								?>
                                <a href="/cron/groupbuildings.php?hash=58300774" class="btn btn-admin marine"  data-toggle="tooltip" data-placement="bottom" title="Group Buildings" target="_blank">Group Buildings</a>
                            </div>
						<?php // end of if ($settings['mls_integrated'] == 1):
						endif; ?>
                    </div>
                </div>
			<?php // end of Admin Panel
			endif; ?>


			<?php
			// SUCCESS OR ERROR MESSAGE ON FORM SUBMIT.
			session_alert_display('success-message');

			if ($error) // error means stay on the same pag
				echo brixwork_alert($error, 'error');

			if (!empty($fragment)) {
				var_dump($fragment);  // Output: general-tab or any other dynamic value
			}

			// BOOTSTRAP 5 TABS - Command + F to find HTML content for each tab
			$nav_tab_array = array('General', 'Contact', 'Listing', 'Photos', 'Search', 'Social', 'Tracking', 'Custom');
			brixwork_object_tabs('setting', $nav_tab_array);
			?>

            <div class="manage_object_tab_content tab-content">
				<?php // BASIC INFO CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade <?=isset($_GET['section']) ? '' : 'show active'?>" id="general-tab" role="tabpanel" aria-labelledby="General-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_general.php"; ?>
                </div>

				<?php // CONTACT INFO CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade <?=isset($_GET['section']) && $_GET['section'] == 'contact-tab' ? 'show active' : ''?>" id="contact-tab" role="tabpanel" aria-labelledby="Contact-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_contact.php"; ?>
                </div>

				<?php // LISTINGS CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade <?=isset($_GET['section']) && $_GET['section'] == 'listing-tab' ? 'show active' : ''?>" id="listing-tab" role="tabpanel" aria-labelledby="Listing-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_listing.php"; ?>
                </div>

				<?php // MEDIA CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade <?=isset($_GET['section']) && $_GET['section'] == 'photos-tab' ? 'show active' : ''?>" id="photos-tab" role="tabpanel" aria-labelledby="Photos-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_photos.php"; ?>
                </div>

				<?php // SEARCH CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade <?=isset($_GET['section']) && $_GET['section'] == 'search-tab' ? 'show active' : ''?>" id="search-tab" role="tabpanel" aria-labelledby="Search-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_search.php"; ?>
                </div>

				<?php // SNS CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade <?=isset($_GET['section']) && $_GET['section'] == 'social-tab' ? 'show active' : ''?>" id="social-tab" role="tabpanel" aria-labelledby="Social-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_social.php"; ?>
                </div>

				<?php // TRACKING CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade show" id="tracking-tab" role="tabpanel" aria-labelledby="Tracking-Content" tabindex="0">
					<?php include "includes/settings_tabs/settings_tracking.php"; ?>
                </div>
            </div>

            <div id="submit_button_group" class="">
                <input type="submit" class="btn btn-admin" name="submit" id="settingsubmit" value="Save" />
            </div>
        </form>
    </div>



<?php
// map unable to find location!
modal_html('Cannot Find Address', '<p>The location you entered is not being searched on Google Maps. Please check your address, or manually drag the map to the right position.</p>', 'map_address_notfound', 'Got It!', false);


// S3 FOLDER NAME CHANGE MODAL
brixwork_modal_html(array(
	'header_content' => 'S3 Folder Name Change',
	'body_content' => "<p>Changing S3 folder name will break the photos.</br>Are you sure you want to do this?</p>",
	'footer_content' => "
        <button type='button' class='btn btn-admin' data-bs-dismiss='modal'>Cancel</button>
        <button type='button' class='btn btn-admin light_blue' id='s3_change_name_confirm' data-bs-dismiss='modal'>Ok</button>",
	'id' => 's3_change_modal'
));


/**
 * ECHO LINK TO THE LOG OR DISPLAY ERROR
 * @param $condition
 * @param $file_link
 * @return void
 */
function display_log($condition, $file_link) {
	if ($condition != 0) {
		echo "<a class='pb-3' href='$file_link' target='_blank'>View Latest Log</a>";
	}
	else {
		$settings_home_query = array('sold'=>array(0, 1, 2));
		$settings_home = get_properties('', $settings_home_query, 'ord', 'DESC', 1, 1);
		$warning = $settings_home ? 'No sync but listings exist in the `homes` table' : 'Best to run the MLS&reg; Sync, the database is empty';

		echo "<h6 class='text-danger pb-3'>$warning</h6>";
	}
}

include 'footer.php';