<?php
/**
 * Filename: users_mod.php
 * Description: Edit user data
 *
 * Accessibility: Only admin and currently logged-in user can view this page.
 */
include 'start.php';
global $settings, $login_user;

// only include script for non-post action
$scriptinclude_footer = 'users_mod.source.js';
$return_url = 'users.php';
$save_form_label = 'Create New User';

$user = '';
if($_GET['mode'] == 'modify'):
    $preset_object_type = "users";
    $user = new user(array('id' => $_REQUEST['idr']), $mysqli, $settings);
    $object = $user;
    $save_form_label = 'Save Changes';

    /**
     * Redirect conditions
     * 1. User does not exist with modify tag - user manually entered the id
     * 2. Login user is below admin AND user ID does not match Login user's id.
     */
    if (!$user->getID() || (!login_level_check(USER_LOGIN_ADMIN) && $user->getID() !== $login_user->getID())) {
        header('Location:'.$settings['sitepath'].'admin/');
        exit();
    }
endif;


if ($_GET['mode'] == 'new' && !login_level_check(USER_LOGIN_ADMIN)) {
    // quick level check only admin and brixwork can make new user ... kick out to dashboard if failed
    header('Location:'.$settings['sitepath'].'admin/');
    exit();
}


// PROCESS POST DATA.
$error = '';
if ($_POST) {
    $current_mode   = $_POST['mode'];           // either `new` or `modify`.
    $idr            = $_POST['idr'] ?: false;   // could be empty if `new`.
    $allow_submit   = true;                     // verify $_POST data and if not good, turn this variable to false and print error.

    // codes to execute if something has been submitted already - this part loads it up and then takes you back to the whole list.
    // codes here will input data into the table
    $_POST['level'] = ($_POST['level'] == 0 || $_POST['level'] == 1) ? 8 : $_POST['level'];         // no one should have id 0 or 1 in a form submit

    if ($_POST['password1']) {
        $_POST['password'] = md5($_POST['password1']);       // hash password1 input into password field
    }

    /**
     * Sanitize user level submit
     * 1. First of all, 0 & 1 is reserved for Brixwork login, never accept it from form submit.
     * 2. Any submit data
     */
    if ($_POST['level'] == 0 || $_POST['level'] == 1) {
        $_POST['level'] = $login_user->getLevel();
    }

    // process agents array
    $_POST['agents'] = is_array($_POST['agents']) ? implode(',', $_POST['agents']) : '';


    if ($allow_submit) {
        $update_id = form_to_table('users', $_POST, $idr);

        if (is_numeric($update_id)) {
            // different success messages depending on "created" or "modified"
            $post_title         = $_POST['email'] ?: $_POST['fname'].' '.$_POST['lname'];
            $user_id_display    = login_level_check(USER_LOGIN_BRIXWORK) ? '(ID: '.$update_id.')' : '';
            $status             = ($current_mode == 'new' && $idr === false) ? 'added' : 'modified';
            $_SESSION['success-message'] = "<p><b>Success!</b> The user data has been $status for <span style='text-decoration: underline'>$post_title $user_id_display</span>.</p>";

            // redirect & refresh the object data.
            header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/').'?mode=modify&idr='.$update_id);
            exit();

        } else {
            $error = '<p><b>Error</b> There was an error while attempting to ' . ($_GET['mode'] == 'modify' ? 'update' : 'create') . ' your new page. Error: <i>' . $mysqli->error . '</i>. Please contact our support desk with this message.</p>';
        }
    } else {
        $error = "<p><b>Warning!</b> Invalid value passed. Please verify your input or contact Brixwork Support.</p>";
    }
}

// header_html is separated from header.php on purpose.
include 'header.php';
include 'includes/header_html.php';
?>

<form method="POST" id="user_form" action="<?=$_SERVER['PHP_SELF']?>" class="needs-validation" novalidate>
    <div id="users_gallery_mod" class="brixwork_admin_container title">
        <h1 id="admin_page__title"><?=($_GET['mode']=='modify' ? 'Editing User '.$user->getEmail() ?: $user->getUsername() : 'Add New User')?></h1>

        <?php
        // SUCCESS OR ERROR MESSAGE ON FORM SUBMIT.
        session_alert_display('success-message');

        if ($error)
            echo brixwork_alert($error, 'error');
        ?>

        <div class="d-flex justify-content-between flex-wrap">
            <div id="user_login_details" class="manage_object_tab_content brixwork_inner_spacing">
                <h3 class="each_tab__category_title">Main Login Details</h3>

                <div class="row">
                    <div class="col-12 mb-4 mt-auto">
                        <label for="email" class="control-label orange">Email</label>
                        <input type="email" required name="email" id="email" autocapitalize="off" class="form-control" value="<?=($_GET['mode']=='modify' ? $user->getEmail() : '')?>" placeholder="Email Address" autocomplete="off"/>
                        <div class="invalid-feedback">
                            Please enter an email address to use as login
                        </div>
                        <input type="hidden" id="currentemail" value="<?=($_GET['mode']=='modify' ? $user->getEmail() : '')?>" />
                    </div>

                    <input type="hidden" name="username" id="username" class="form-control" value="<?=($_GET['mode']=='modify' ? $user->getUsername() : '')?>">

                    <div class="col-12 mb-4 mt-auto">
                        <label for="fname" class="control-label orange">First Name</label>
                        <input type="text" name="fname" id="fname" class="form-control" value="<?=($_GET['mode']=='modify' ? $user->fname : '')?>" placeholder="Optional">
                    </div>

                    <div class="col-12 mb-4 mt-auto">
                        <label for="lname" class="control-label orange">Last Name</label>
                        <input type="text" name="lname" id="lname" class="form-control" value="<?=($_GET['mode']=='modify' ? $user->lname : '')?>" placeholder="Optional">
                    </div>


                    <?php
                    if ($_GET['mode'] == 'modify'): // enable "Reset Password" toggle
                        // RESET PASSWORD SHOULD ONLY BE AVAILABLE TO SELF OR ADMIN
                        if ($user->isUserAuthenticated() || login_level_check(USER_LOGIN_ADMIN)) { ?>
                            <div class="col-12 mb-2 pt-3 mt-auto">
                                <button type="button" class="btn btn-admin px-4 reddish" id="reset_pw_switch">Reset Password</button>
                            </div>
                        <?php
                        }
                        // Reset password shouldn't work ... so just display the disabled button without functionality.
                        else { ?>
                            <div class="col-12 mb-2 pt-3 mt-auto" style="width: max-content;" data-bs-toggle="tooltip" data-bs-custom-class="brixwork-tooltip" data-bs-placement="bottom" data-bs-title="Resetting the password can only be done by the admin or the user themselves.">
                                <button type="button" class="btn btn-admin px-4 reddish disabled">Reset Password</button>
                            </div>
                        <?php
                        } ?>

                        <div id="password_reset_wrapper" class="col-12 mt-2 d-none">
                            <label for="password1" class="control-label orange">New Password</label>
                            <div class="mb-2">
                                <input type="password" name="password1" id="password1" class="form-control" placeholder="Min 6 Characters" minlength="6" disabled>
                                <div class="invalid-feedback">
                                    Please enter a password.
                                </div>
                            </div>
                            <input type="password" name="password2" id="password2" class="form-control"  placeholder="Enter Again" aria-label="Enter Password Again" disabled>
                            <div class="invalid-feedback">
                                Please enter a matching password.
                            </div>
                        </div>
                    <?php
                    else: // require new password for new user ?>
                        <div class="col-12 mb-4 mt-auto">
                            <label for="password1" class="control-label orange">Password</label>
                            <div class="mb-2">
                                <input type="password" name="password1" id="password1" class="form-control" placeholder="Min 6 Characters" minlength="6" required>
                                <div class="invalid-feedback">
                                    Please enter a password.
                                </div>
                            </div>
                            <input type="password" name="password2" id="password2" class="form-control"  placeholder="Enter Again" aria-label="Enter Password Again" required>
                            <div class="invalid-feedback">
                                Please enter a matching password.
                            </div>
                        </div>
                    <?php
                    endif; ?>

                </div>
            </div>

            <?php // access level div - should only be available to site admin. ?>
            <div id="user_access_levels" class="manage_object_tab_content brixwork_inner_spacing">
                <h3 class="each_tab__category_title">Access Level</h3>
                <div class="brixwork_info_grid">
                    <i class="bi bi-exclamation-circle"></i>
                    <p class="m-0">This controls what this user is able to manage across the site from listings only, to managing content on individual pages.</p>
                </div>

                <label for="level" class="control-label orange pt-3">Role</label>


                <?php
                // only admin gets the dropdown to edit user's role
                if (login_level_check(USER_LOGIN_ADMIN)) { ?>
                    <select name="level" id="level" class="form-select w-100">
                        <?php
                        /**
                         * USER_LOGIN_BRIXWORK = 0
                         * USER_LOGIN_ADMIN = 2
                         * USER_LOGIN_MANAGER = 4
                         * USER_LOGIN_AGENT = 6
                         * USER_LOGIN_CONTENT_MANAGER = 8;
                         */
                        foreach ($settings['user_level_label'] as $level => $label):
                            $selected = is_object($user) && $user->getLevel() == $level;

                            // continue condition: do not show Brixwork Login Levels OR do not show other role options if login level is not Admin.
                            // do not show "agent" option if multi-agent is disabled.
                            if (($level == USER_LOGIN_BRIXWORK || $level == 1) || (!login_level_check(USER_LOGIN_ADMIN) && !$selected) || ($level == USER_LOGIN_AGENT && $settings['multiagents'] == 0)) continue;
                            ?>
                            <option value="<?=$level?>" <?=$selected ? 'selected' : ''?>><?=$label?></option>
                        <?php
                        endforeach; ?>
                    </select>
                <?php
                } else {
                    // Just a dropdown with one option for display purposed ... the hidden input contains the actual value ?>
                    <select class="form-select w-100" aria-label="user level" disabled>
                        <option value="<?=$user->getLevel()?>" selected><?=$settings['user_level_label'][$user->getLevel()]?></option>
                    </select>
                    <input type="hidden" name="level" id="level" value="<?=$user->getLevel()?>">
                <?php
                } ?>



                <?php
                // this multi select dropdown is only available for manager login & above.
                if (login_level_check(USER_LOGIN_MANAGER)) {
                    // manager login can view all users & listings anyway, so there's no need for them to have dropdown.
                    if (is_object($user) && $user->getLevel() > USER_LOGIN_MANAGER) {
                        ?>
                        <h3 class="each_tab__category_title mt-5 mb-2">Associated Agents</h3>
                        <p>This user has access to edit the below agents' profile & listings.</p>
                        <select name="agents[]" id="agents[]" class="selectpicker my-2 w-100" data-live-search="true" multiple aria-label="agent id select">
                            <?php
                            $agent_ids = $user->getAgents();
                            $agent_query = array(
                                'billable' => 1
                            );
                            $agents = list_agents($agent_query, 'ord', 'ASC', 10000, 1);
                            foreach($agents as $agent_id):
                                $agent = new agent;
                                $agent->initialize($agent_id);
                                if ($agent->displayname == "") continue;
                                $selected = (in_array($agent->id, $agent_ids)) ? 'selected' : '';
                                echo '<option value="'.$agent->id.'" '.$selected.'>'.$agent->displayname.'</option>';
                            endforeach; ?>
                        </select>
                        <?php
                    }
                } else {
                    // No Dropdown ... just display. The hidden input field contains the values ?>
                    <h3 class="each_tab__category_title mt-5 mb-2">Associated Agents</h3>
                    <p>This user has access to edit the below agents' profile & listings.</p>
                    <?php
                    // permission not met ... just display.
                    echo "<div class='user_agent_list'>";
                    if (!empty($user->getAgents())) {
                        foreach ($user->getAgents() as $agent_id) {
                            $agent = new agent;
                            $agent->initialize($agent_id);
                            echo "<h6>$agent->displayname ($agent->position)</h6>";
                        }
                    } else {
                        echo "<h6>No Associated Agent</h6>";
                    }
                    $associated_agents = implode(',', $user->getAgents());
                    echo "<input type='hidden' name='agents[]' id='agents[]' class='d-none' value='$associated_agents'>";
                    echo "</div>";
                } ?>
            </div>
        </div>
    </div>
    
    <div class="brixwork_admin_container" id="submit_button_group">
        <?php // HIDDEN INPUT TO BE USED IN $_POST
        if ($_GET['mode'] == 'modify') {
            $idr_val = $_REQUEST['idr'];
            $mode_val = 'modify';
        } else {
            $idr_val = "";
            $mode_val = 'new';
        }
        echo "<input type='hidden' name='idr' id='idr' value='$idr_val' />";
        echo "<input type='hidden' name='mode' value='$mode_val' />";
        ?>
        <input type="submit" id="user_submit" class="btn btn-admin px-4" value="<?=$save_form_label?>" />
        <a type="button" class="btn btn-admin light_blue" href="<?=$return_url?>">Back</a>
    </div>
</form>


<?php
include 'footer.php';