<?php

require_once '../start.php';
require_once '../admin/admin_functions.php';

// List all objects under /homes folder of the site
$homes_folder = $settings['s3_folder'].'/homes/';
echo "Fetching objects under ".$homes_folder." from bucket ".$settings['s3_bucket']."<br />".PHP_EOL;

if(isset($_REQUEST['commit']) && $_REQUEST['commit']==1) {
	// committing, so do full iteration.
	$all_objects = listObjects($settings['s3_bucket'], $homes_folder);
} else {
	// testing, just do first 20 objects from S3 and compare.
	$all_objects = listObjects($settings['s3_bucket'], $homes_folder, 100);
}

// get all homes (include unpublished - those will be purged automatically later anyway so do not delete. )
$query=array();

if(strpos($settings['sitepath'], 'brixwork.com')!==false && strpos($settings['sitepath'], 'dev.brixwork.com')===false) {
	$query['skipmasterid'] = true;
	$query['source'] = 1;
	echo "MLS Subsite.<br />".PHP_EOL;
} else {
	$query['source'] = 0;
}
$hids = get_properties('', $query, 'create_date', 'asc', 1000000, 1, false, false);

$hcount = 0;
$deletecount = 0;
$home_objects = array(); // start with blank.
$delete_objects = array();

// get unique home IDs first.
if(is_array($all_objects) && count($all_objects)>0) {
	foreach ($all_objects as $object) {
		$home_key = get_home_key($object['Key'], $homes_folder);
		if($home_key!='' && strlen($home_key)>0 && $object['Key']!='') {
			// Unfortunately we get all the subitems under the folder. so once the home key is in the $home_objects as a ID we inspected, we don't nee dto check over and over.
			if(!in_array($home_key, $home_objects)) {
				// the first object is just the top folder such as /100055/

				$home_objects[] = $home_key;
				if(!in_array($home_key, $hids)) {
					echo $home_key." not found, will purge subobjects. Processed from ".$object['Key']."<br />".PHP_EOL;
					$delete_objects[] = $home_key; // we need to remove all the top level folders later, so save this array.
				} else {
					echo $home_key." is in the local DB: ".$object['Key']." will be kept.<br />".PHP_EOL;
				}
			}
			// delete the actual .jpg file if the key is NOT in the local homes. This however will NOT remove the subfolders and the top folder.
			if(!in_array($home_key, $hids)) {
				echo $home_key." not found, so purge ".$object['Key']."<br />".PHP_EOL;
				if(isset($_REQUEST['commit']) && $_REQUEST['commit']==1) {
					deleteObject($settings['s3_bucket'], $object['Key']);
				}
			}
		}
	}
}

// now the JPG files from all the non-existent listings are done.
// WE loop through $delete_objects to actually remove all the $subfolders ,then finally the ID folder itself.

$subfolders = array(
	'web',
	'original',
	'mobile',
	'thumb'
);

if(is_array($delete_objects) && count($delete_objects)>0) {
	foreach($delete_objects as $object) {
		// remove the top level folders after.
		if($object!='') {
			foreach($subfolders as $subfolder) {
				echo "Will delete ".$settings['s3_bucket'], $homes_folder . $object . '/' . $subfolder . '/'."<br />";
				if(isset($_REQUEST['commit']) && $_REQUEST['commit']==1) {
					deleteObject($settings['s3_bucket'], $homes_folder . $object . '/' . $subfolder . '/');
				}
				echo $homes_folder.$object.'/'.$subfolder." being removed,.<br />".PHP_EOL;
			}
			echo $homes_folder.$object." being emptied finally.<br />".PHP_EOL;
			if(isset($_REQUEST['commit']) && $_REQUEST['commit']==1) {
				deleteObject($settings['s3_bucket'], $homes_folder.$object.'/');
			}
		}
	}
}


function get_home_key($objectkey, $homes_folder) {
	$trimmed_path = trim(str_ireplace($homes_folder, '', $objectkey));
	// echo "processing object key: ".$object['Key'].", trimmed to ".$trimmed_path.", then cutting at ".strpos($trimmed_path, '/')."<br />".PHP_EOL;
	$return = substr($trimmed_path, 0, strpos($trimmed_path, '/'));

	return $return;
}
?>
