<?php

/*
 * Part of a CREA DDF fix due to their inconsistent feed format.
 * https://github.com/troydavisson/PHRETS/issues/99
 * */

use PHRETS\Configuration;
use PHRETS\Http\Response;
use PHRETS\Session;
use PHRETS\Strategies\Strategy;

class CreaParser
{
	public function parse(Session $rets, Response $response, $parameters)
	{
		$parser = $rets->getConfiguration()->getStrategy()->provide(Strategy::PARSER_XML);
		$xml = $parser->parse($response);

		$data = $xml->{'RETS-RESPONSE'};

		$rs = new CreaResults;

		if (isset($data->Pagination) && isset($data->Pagination->TotalRecords)) {
			$rs->setTotalResultsCount(intval($data->Pagination->TotalRecords));

			if (isset($data->Pagination->Offset) && isset($data->Pagination->Limit) && $data->Pagination->Offset + $data->Pagination->Limit >= $data->Pagination->TotalRecords) {
				$rs->setMaxRowsReached();
				$rets->debug('Maximum rows returned in response');
			}
		}

		if (isset($data->PropertyDetails)) {
			foreach ($data->PropertyDetails as $property) {
				$rs->addCreaRecord($property);
			};
		}

		unset($xml);

		return $rs;
	}
}