<?php
/*
filename: cron_chunk.php
purpose: Initialize the cron RETS jobs. 
description:
It figures out which chunk to run for which listed date ranges based on input (GET variable) or it checks the last run ranges to keep incrementing on.
$_GET['c'] will override it, whereas without override, it will figure out the chunk range based on the last run date etc from the `cronlog' table. 
Also sets up the timelimit, MySQL modes etc. to get the file ready to rock. =
*/

$start_time = time(); // to figure out how much time each one took.

// auto nondefined ranges - these are Chunks 0 through 12
$cutoffdate[] = strtotime('-730 days'); // ?c=1 - will load listings that are up to 2 years old, but more than 1 year old.
$cutoffdate[] = strtotime('-365 days'); // ?c=1 - will load listings that are less than a year old, but 6 months or older.
$cutoffdate[] = strtotime('-318 days'); // etc. etc. - and it goes on.
$cutoffdate[] = strtotime('-270 days');
$cutoffdate[] = strtotime('-225 days');
$cutoffdate[] = strtotime('-180 days');
$cutoffdate[] = strtotime('-135 days');
$cutoffdate[] = strtotime('-120 days');
$cutoffdate[] = strtotime('-105 days');
$cutoffdate[] = strtotime('-90 days');
$cutoffdate[] = strtotime('-75 days');
$cutoffdate[] = strtotime('-60 days'); // ?c=12

// predefined ranges
$query_ranges = array(
	'2000-01-01|'.date($mysql_time['day'],$cutoffdate[0]-86400), // This is chunk 0... for the oddball listings that are hanging for years and years.
	date($mysql_time['day'],$cutoffdate[0]).'|'.date($mysql_time['day'],$cutoffdate[1]-86400), // this converts the 1~2 year old range ($cutoffdate[0] and [1] into a range
	date($mysql_time['day'],$cutoffdate[1]).'|'.date($mysql_time['day'],$cutoffdate[2]-86400),
	date($mysql_time['day'],$cutoffdate[2]).'|'.date($mysql_time['day'],$cutoffdate[3]-86400),
	date($mysql_time['day'],$cutoffdate[3]).'|'.date($mysql_time['day'],$cutoffdate[4]-86400),
	date($mysql_time['day'],$cutoffdate[4]).'|'.date($mysql_time['day'],$cutoffdate[5]-86400),
	date($mysql_time['day'],$cutoffdate[5]).'|'.date($mysql_time['day'],$cutoffdate[6]-86400),
	date($mysql_time['day'],$cutoffdate[6]).'|'.date($mysql_time['day'],$cutoffdate[7]-86400),
	date($mysql_time['day'],$cutoffdate[7]).'|'.date($mysql_time['day'],$cutoffdate[8]-86400),
	date($mysql_time['day'],$cutoffdate[8]).'|'.date($mysql_time['day'],$cutoffdate[9]-86400),
	date($mysql_time['day'],$cutoffdate[9]).'|'.date($mysql_time['day'],$cutoffdate[10]-86400),
	date($mysql_time['day'],$cutoffdate[10]).'|'.date($mysql_time['day'],$cutoffdate[11]-86400) // last one of the pre-defined zones, 60 to 75 days old listings.
);
// end of defining the OLD timeframe for old stuff!


// now create ranges for 1 day at a time for remaining dates.. so 60 total since the $cutoffdate[11] was -60 days.
$cron_step = 1;
$start_date = $cutoffdate[count($cutoffdate)-1]; // start with -60 days ago,

$max_date = strtotime("+1 day",strtotime($today));

/*
 * This is where chunks 12, 13, 14 etc. are created all the way to 72.
 * 72 will be the current day (today)
 * 71 will be the day before (yesterday)
 * 70
 * ..
 * .
 * .
 * 13 will be 59 days ago.
 * */
while ($start_date < $max_date) {
	$next_month = mktime(0, 0, 0 , date('m', $start_date), date('d', $start_date) + $cron_step, date('Y', $start_date));
	// $query_ranges[] = date($mysql_time['day'], $start_date) . '|' . date($mysql_time['day'], $next_month);
	$query_ranges[] = date($mysql_time['day'], $start_date); // try single dates instead
	$start_date = $next_month;
}

if (isset($_REQUEST['c']) && $_REQUEST['c']!='') {
	$chunk_number = intval($_REQUEST['c']);
} else {
	// calculate the next chunk number we should be running right now.
	// To see how this gathers up, see `cronlog` table in each MLS mothership site MySQL.
	//	$recentstart = count($query_ranges)-11; // the last 10 days range is more frequently updated.
	//	$recentend = $recentstart+9; // the last 10 days, minus today.
	//	$todaychunk = $recentend+1; // and today.,. 99.9999% of the time should end up being 72!

	$recentdays = 20; // determine how many past days we consider "recent" to crawl & udpate more often for new photos, price change etc.

	$recentstart = count($query_ranges)-($recentdays+1); // the last 20 days range is more frequently updated.
	$recentend = $recentstart+($recentdays-1); // the last 10 days, minus today.
	$todaychunk = $recentend+1; // and today.,. 99.9999% of the time should end up being 72!
	// first, see when the last time today's query was run
	// determine how frequently we want to run TODAYs new listing queries.

	$timestampmin = date($mysql_time['full'],strtotime($now)-(60 * 20)); // every 20 mins is fine.;
	$crontodaysql = "SELECT chunk, timestamp FROM cronlog WHERE timestamp>='".$timestampmin."' AND chunk='".$todaychunk."'"; // check for same day one - we run this half hourly!

	$crontodayresult = $mysqli->query($crontodaysql);
	if($crontodayresult->num_rows==0) {
		// today's query has not been run since $timestampmin ago! RUn it.
		$chunk_number = $todaychunk;
		$cron_notes = 'Running today query since no entries found for this chunk within the last hour.';
	} else {
		// today was run already, so now  recent X day's cycle more frequently (hourly) as they tend teo have more photo updates & price changes.
		// see when the last time a RECENT query was run.
		$timestampmin = date($mysql_time['full'],strtotime($now)-(3600*3)); // last 10 days, run every 1 hr since there's photos crawling in often.
		$cronrecentsql = "SELECT chunk, daterange FROM cronlog WHERE timestamp>='".$timestampmin."' AND chunk>='".$recentstart."' AND chunk<='".$recentend."' ORDER BY chunk DESC LIMIT 0,1";
		$cronrecentresult = $mysqli->query($cronrecentsql);
		if($cronrecentresult->num_rows==0) {
			// 0 rows found for today's recent range queries. start with the lowest.
			$chunk_number = $recentstart;
			$cron_notes = 'No recent date range rows found, starting with the lowest recent date range.';
		} else {
			$timestampmin = date($mysql_time['full'],strtotime($now)-(3600*8)); // every 8 hrs for rest fine;

			$cronrecentarray = $cronrecentresult->fetch_assoc();
			$chunk_number = $cronrecentarray['chunk']+1;
			if($chunk_number<$todaychunk) {
				// next recent chunk is still less than the today's range key,
				$cron_notes = $cronrecentarray['chunk'].' was the last recent cron run '.$cronrecentarray['daterange'].'.';
			} else {
				// it appears that the recent ones are all run properly. default back to ID 1 and work up!
				$cronoldsql = "SELECT chunk, daterange FROM cronlog WHERE timestamp>='".$timestampmin."' AND chunk<'".$recentstart."' ORDER BY chunk DESC LIMIT 0,1";
				$cronoldresult = $mysqli->query($cronoldsql);
				if($cronoldresult->num_rows==0) {
					// first run of the old queries, start at #0
					$chunk_number = 0;
					$cron_notes = 'First cron of the old range, since '.$cronoldresult->num_rows.' was returned from the old cron query.';
				} else {
					$cronoldarray = $cronoldresult->fetch_assoc();
					$chunk_number = $cronoldarray['chunk']+1;
					if($chunk_number<$recentstart) {
						// next recent chunk is still less than the first key of the recent day range.
						$cron_notes = $cronoldarray['chunk'].' was the last recent cron run '.$cronoldarray['daterange'].'.';
					} else {
						retsrunning_close();// set the .txt file back to 0.
						die("Shutting her down, nothing more to query");
					}
				}
			}
		}
	}

	$mysqli->query("INSERT INTO cronlog (timestamp, chunk, daterange, notes) VALUES ('".$now."', '".$chunk_number."', '".$query_ranges[$chunk_number]."', '".$cron_notes."')");
	$cronlog_id = $mysqli->insert_id;
}


// split ranges by cron chunks
$total_query = count($query_ranges);
$query_per_chunk = 1;
// Get table metadata


// Log -  prefix by rets_log, only if we didn't skip over.
if(!isset($log_file) || $log_file=='') {
	// if not set yet, create fresh log file with current chunk number auto-generated in there.
	$log_file = 'logs/rets_log-' . str_replace(' ', '-', date($mysql_time['full'])).'-c-'.$chunk_number.'.log';
	if (is_writable(dirname($log_file))) {
		$handle = fopen($log_file, 'a+');
	} else {
		$handle = null;
		echo "cannot generate log file. Proceeding anyway.<br />";
	}
}


?>