<?php

/*
 *
 * Updated in 2023-02
 *
 * CREA DDF connection to scan server for MLS #s, and unpublish/delete inactive listings.
 *
 *
*/

require_once '../start.php';
require_once 'crea_ddf.php'; // credentials for RETS access
// require_once 'column_map_'.$rets_region.'.php';
require_once '../admin/admin_functions.php'; // only thing that's NOT in the public start.php

//
require_once 'creaddf_includes/crearesults.php';
// This does not require a separate parser that modifies the non-RETS compliant XML format to a usable format. Disabling the custom parsers.
//require_once 'creaddf_includes/creaparser.php';
//require_once 'creaddf_includes/creastrategy.php';

// Log
$log_file = 'logs/clean_log.' . date('Y.m.d') . '-cleanup.log';
if (is_writable(dirname($log_file))) {
	$handle = fopen($log_file, 'a+');
} else {
	$handle = null;
}

require_once 'cron_functions.php';

header('Content-Type: text/html; charset=iso-8859-1');
// table + MLS classes

getRetsRunning();

$class_array = array('Property' => 'Property');
//
//$rets = new phRETS;
//// $rets_res->AddHeader("User-Agent", $rets_user_agent);
//$connect = $rets->Connect($rets_login_url, $rets_username, $rets_password);
//if (!$connect) {
//	write_log(print_r($rets_res->Error(), true));
//	retsrunning_close();
//	exit;
//}
//
//$rets->AddHeader("RETS-Version", "RETS/1.7.2");
//$rets->AddHeader('Accept', '/');
//$rets->SetParam('compression_enabled', true);
//
//$params = array("Limit" => 1, "Format" => "STANDARD-XML", "Count" => 1);

include 'creaddf_includes/creaddf_initialize.php'; // gets the query chunk & date range, connects to RETS etc.


// get all active MLS numbers from DB
$publishedhomessql = "SELECT id, sysid, mls FROM `homes` WHERE `publish`=1 ORDER BY mls ASC";
$publishedhomesresult = $mysqli->query($publishedhomessql);
while($publishedhome = $publishedhomesresult->fetch_assoc()) {
	$publishedhomes[] = $publishedhome;
}

$publishedhomescount = count($publishedhomes);

$params = array(
	"Limit" => 1,
	"Format" => "COMPACT",
	"Count" => 2 // just get the listing results onl.
);

$active_mls_numbers = array(); // declare blank array first.

foreach ($class_array as $type_code=>$type_name) {
	echo "Query for clean up, looking for type ".$type_name." with ".$publishedhomescount." publihed listings to compare.<br />".PHP_EOL;
	write_log("Query for clean up, looking for type ".$type_name." with ".$publishedhomescount." publihed listings to compare.\n");

	// DMQL query to get one MLS at a time, see if it exists or not.
	foreach($publishedhomes as $publishedmls) {
		$rets_query = "(ID=".$publishedmls['sysid'].")";
		/*
		 * Every once in a while RETS queries to CREA DDF returns error:
		 * [28-Oct-2023 00:22:07 America/Toronto] PHP Fatal error:  Uncaught GuzzleHttp\Exception\ServerException: Server error: `GET https://data.crea.ca/Search.svc/Search?SearchType=Property&Class=Property&Query=%28ID%3D26114409%29&QueryType=DMQL2&Count=2&Format=COMPACT&Limit=1&StandardNames=0` resulted in a `502 Bad Gateway` response:
		 * #0.... [stack traces skipped as we dont need it]
		 * #12 /home/brix_mls/public_html/ottawa/cron/cron_crea_cleanup.php(82): PHRETS\Session->Search('Property', 'Property', '(ID=26114409)', Array)
#13 {main}
  thrown in /home/brix_mls/public_html/ottawa/packages_8/vendor/guzzlehttp/guzzle/src/Exception/RequestException.php on line 113
		 *
		 * */
		try {
			$search = $rets->Search("Property", $type_code, $rets_query, $params);
		} catch (Error $e) {
			$error_info = $e->getMessage();
			$search = false;
		}
		if($search!==false)  {
			$error_info = $search->getError();
		}

		if(!is_null($error_info)) {
			echo "Error (if any): <br />".PHP_EOL;
			write_log("MLS cleanup DMQL :".$rets_query." returned ".$error_info.". Skipping to next query.".PHP_EOL);
		} else {
			$listingcount = $search->getTotalResultsCount();
			// $listings = $search->toArray();
			if($listingcount==1) {
				write_log($listingcount." rows found for MLS # :".$publishedmls['mls']." so keeping it!!!.\r\n");
				$active_mls_numbers[] = $publishedmls['mls']; // while we query RETS by sysid, we compare what to keep or delete by MLS #s.
			} else {
				write_log($listingcount." rows found for MLS # :".$publishedmls['mls']." so removing.\r\n");
			}
//			if(is_object($listings_xml) && isset($listings_xml[0])) {
//				$listings =  json_decode(json_encode($listings_xml[0]), true); ;
//				$numlistings = count($listings); // 1 if theres at least one listing.
//			} else {
//				$listings = false;
//				$numlistings = 0;
//			}
		}

	}

}

// delete non-ative record
$deleted_rows = 0;
echo count($active_mls_numbers).' listings to keep active out of '.$publishedhomescount.'.<br />';
//if(count($active_mls_numbers)<1000) {
//	write_log('There area less than 2,000 records ('.count($active_mls_numbers).'. Terminate process to not accidentally delete.\n');
//	echo count($active_mls_numbers).' rows found so terminating... Ottawa has to have more than that!<br />';
//	die('Terminated.');
//}

// delete non-ative record
$deleted_rows = 0;
$disabled_rows = 0;

$oldhomesquery = "SELECT `id`, `mls`, `create_date`, `modify_date`, `publish` FROM `homes` 
					WHERE `source` = 1";
echo '<br /><br />'.$oldhomesquery.'<br />';
$oldhomesresult = $mysqli->query($oldhomesquery);
echo $oldhomesresult->num_rows.' found in total, lets purge!';

while ($row = $oldhomesresult->fetch_assoc()) {
	if(!in_array($row['mls'], $active_mls_numbers)) {

		if(strtotime($row['modify_date'])+(3600*24*5)<$local) {
			$deleted = remove_home($row['id']);
			if ($deleted) {
				write_log("Deleted ".$row['id']." (".$row['mls'].")\n");
				echo "Deleted ".$row['mls'].'<br />';
				$deleted_rows++;
			}
		} else if($row['publish']==1) {
			$deleted = $mysqli->query("UPDATE `homes` SET `publish`=0, `modify_date`='".$now."' WHERE `source` = 1 AND `id` = '".$row['id']."'");
			if ($deleted) {
				write_log("Disabled (publish set to 0) ".$row['id']." (".$row['mls'].")\n");
				echo "Disabled  (publish set to 0) ".$row['id']."  (".$row['mls'].")<br />";
				$disabled_rows++;
			}
		} else {
			// already set to hidden, BUT not 5 days old yet so leave it just in case.
			echo "Leaving alone ".$row['id']."  (".$row['mls'].")<br />";

		}
	}
}


write_log("Disabled Rows: $disabled_rows rows".PHP_EOL);
write_log("Deleted Rows: $deleted_rows rows".PHP_EOL);

$stop_time = time();
$execute_time = ($stop_time - $start_time) / 60;
write_log("Execution time: $execute_time mins".PHP_EOL);

// close connections
if (!empty($handle)) {
	fclose($handle);
}
retsrunning_close();
$rets->Disconnect();

if ($mysqli->ping()) {
	$mysqli->close();
}

?>