<?php
/*

@author: Steven Stark Oct 3rd, 2016

*/

require_once $_SERVER['DOCUMENT_ROOT'].$settings['rootpath'].'includes/s3/config.php';

//use GuzzleHttp\Client;


function verifyFolder($bucket, $folder) {
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
	$folderResponse = $s3->doesObjectExist( $bucket, $folder );

	// create the folder if it doesn't exist
	if( !$folderResponse ) {
		createFolder( $bucket, $folder );
	}
}

function createFolder($bucket, $folder) {
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
	$s3->putObject(array(
		'Bucket' => $bucket,
		'Key' => $folder,
		'Body'   => ""
	));

	// echo "<p>CREATED FOLDER: ".$folder."</p>";
}

function verifyBucket($bucket) {
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
	$bucketResponse = $s3->doesBucketExist($bucket);

	// create the bucket if it doesn't exist
	if( !$bucketResponse ) {
		createBucket( $bucket );
	}
}

function createBucket($bucket) {
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
	$s3->createBucket(array(
		'Bucket' => $bucket
	));

	// echo "<p>CREATED BUCKET: ".$bucket."</p>";
}

function verifyBucketPath($bucket, $path) {
	$delimiter = "/"; // don't change.

	// verify bucket exists, else create it.
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.

	verifyBucket($bucket);

	// check if the first character of the path is the delimiter, and if so remove it.
	if(substr($path, 0, 1) == $delimiter) {
		$path = substr( $path, 1 );
	};

	// crawl the folder structure, veryfiy, and create sub-folders where needed.
	$split = explode( $delimiter, $path );
	$history = "";
	foreach ( $split as $p ) {
		$history .= $p.$delimiter;
		verifyFolder( $bucket, $history );
	}

}

function verifyExists($bucket, $filename) {
	// verify bucket exists, else create it.
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.

	try {
		$info = $s3->doesObjectExist($bucket, $filename);
		if ($info) {
			return true;
		} else {
			return false;
		}
	} catch (\RuntimeException $e) {
		echo $e->getMessage();
		return false;
	}
}

function folderExists($bucket, $folder) {
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.

	$folderResponse = $s3->listObjects([
		'Bucket' => $bucket,
		'MaxKeys' => 1,
		'Prefix' => $folder.'/'
	]);

	if($folderResponse['Contents']!='') {
		return true;
	}

	return false;
}

function validateFolderName($bucket, $folder) {
	if ( preg_match('/brixwork/', $folder)
		|| $folder == ''
		|| $folder === false
		|| strlen($folder)<5
		|| strpos($folder, '/') !== false) {

		return false;
	}

	return true;
}

function uploadFile( $bucket, $folder, $fileName, $filePath, $ext="jpg", $storageclass = 'ONEZONE_IA' ) {

	// important to note that the $folder here has multiple levels set already, so processing whether it is /homes or /pages or /buildings etc. is lready done - this si the FINAL function that actually talks to the S3 server.
	if( !isset( $filePath ) || $filePath == "" ||
		!isset( $bucket ) ||
		!isset( $folder ) ||
		!isset( $fileName ) || $fileName == "") {

		return;
	}

	if($storageclass=='') {
		$storageclass = 'ONEZONE_IA';
	}

	if(substr($filePath, 0, 1) == '/') {
		// this is just a local file
		$size = filesize($filePath);
		if( $size <= 0 ) {
			echo "ERROR: S3 File asked to be uploaded was void of any data.";
		}
	} else {
		$size = "N/A"; // TODO: Get file size from a remote URL. Not needed yet.
	}
	switch ( $ext ) {
		case 'jpg':
		case 'jpeg':
			$type = "image/jpeg";
			break;
		case 'png':
			$type = "image/png";
			break;
		case 'gif':
			$type = "image/gif";
			break;
		case 'pdf':
			$type = "application/pdf";
			break;
		case 'zip':
			$type = "application/zip";
			break;
		default:
			// other types. TODO: add more types as needed
			$type = "text/plain";
			break;
	}

	// echo "UPLOADING TO S3 {$bucket}.s3.ca-central-1.amazonaws.com/{$folder}/{$fileName} FROM {$filePath} ({$size} bytes) with mime type: {$type}\r\n";


	// Which bucket to upload to?
	// lambda function to convert photo gallery jpgs (original) to web, mobile & thumb sizes run the DROP one.
	if(strpos($bucket, 'photodrop')!==false) {
		$s3client = 'S3_CLIENT_DROP';
	} else {
		$s3client = 'S3_CLIENT';
	}

	// $filepath is the LOCAL file path (what we need to upload to S3)
	if(!is_writable($filePath)) {
		$chmodresult = chmod($filePath, 0755);
	} else {
		$chmodresult = true;
	}

	if($chmodresult) {
		$s3 = $GLOBALS[$s3client]; // Defined in config.
		$req = array(
			'Bucket'       => $bucket,
			'Key'          => "{$folder}/{$fileName}",
			'ContentType'  => $type,
			'SourceFile' => $filePath,
//	       'Body'         => EntityBody::factory(fopen($filePath, 'r+')),
			'StorageClass' => $storageclass // STANDARD was used, but now using ONEZONE_IA. Do not use GLACIER as its not accessible via Cloudfront or HTTP(S).
			//        'Metadata'     => array(
			//            'param1' => 'test value 1',
			//            'param2' => 'test value 2'
			//        )
		);
		$result = $s3->putObject($req);
	} else {
		// file permission of the temp file did not allow for modification.
		$result['ObjectURL'] = "Failed due to temporary file permission issues.";
	}
	return $result;
}

function uploadFileFromURL( $url, $bucket, $settings, $idr, $type, $filename="1.jpg", $gallery = true ) {
	$s3 = $GLOBALS['S3_CLIENT']; // to get URl etc.
	if( !isset( $url ) || $url == "" || !isset( $bucket ) || !isset( $idr ) ) {
		echo "ERROR: File url, bucket or homeid is not defined.\r\n";
		return;
	}
	$file = pathinfo($filename);
	$ext  = $file['extension'];
	$path = getS3FilePath( $settings, $idr, $type ); // define where the file goes.. is it building, homes etc., and what ID is the object? This is obsolete for galleries, as it goes to brixwork-photodrop bucket for LAMBDA processing. 
	$emptyfile = false;

	if(strpos($url, 'http')===false) {
		// this is just a local file simply force localFilePath to the $_FILE['tmp'] location.
		$localFilePath = $url;
		if(!file_exists($localFilePath)) {
			// file does not exist! abort.
			$emptyfile = true;
			echo 'Local file does not exist at '.$localFilePath.'<br />';
		}
//         echo "USING LOCAL FILE {$localFilePath} AS {$filename}.\r\n";
	} else {
		// this is a remote file, download to a temp location first.
		$localFilePath = $_SERVER['DOCUMENT_ROOT']."/tmp/s3_temp_".$type."_".$idr."_".$filename;
		$filedata = curl_get_file_contents($url,'GET');
		if(strlen($filedata)<1000) {
			// file fetch failed? 
			$emptyfile = true;
		} else {
			file_put_contents($localFilePath, $filedata); // fetch remote file here. 
		}
//         echo "UPLOADING URL {$url} TO {$localFilePath} AS {$filename}.\r\n";
	}
	$results = array();

	if($emptyfile!==true) {
		// confirm file is not empty/dead. 
		// IMAGES are sized and put into sub directories

		if( in_array(strtolower($ext), array('jpg', 'jpeg', 'png', 'gif'), true ) && $gallery==true ) {
			// File name key for the brixwork-photodrop bucket should be modified to the following:
			// brixwork:www.jeffkee.com:homes:8899:1280:900:420:320:160:120:1234-mainstreet-yaletown-vancouver-west.jpg
			$dropkey = generateGalleryDropKey($type, $idr);
			$result = uploadFile( $settings['s3_photodrop_bucket'], $dropkey, $filename, $localFilePath, $ext, 'ONEZONE_IA');
			$results = array(); // prepare array.
			if($result['ObjectURL']!='') {
				/*
					If the uploadFile() function was successful, we need to presume that
					the file was put to the brixwork-photodrop bucket, therefor will end up in all 4 image spots.
					Generate the keys below as if it worked - these are not verified yet, we are conjuring them based on previous patterns, which means that we trust LAMBDA that it worked.

					IF LAMBDA did indeed fail (for instance, whne .jpeg files were being rejected at LAMBDA level) this return of good values means nothing.

					At this stage we don't want to create script lag by actually waiting for all 4 phtos to be generated, so we just go with faith on LAMBDA & S3.
				*/
				foreach ($GLOBALS['S3_IMAGE_SIZES'] as $tag => $data) {
					// get raw S3 object urls.
					$objectURL = s3_to_cloudfront($s3->getObjectUrl($settings['s3_bucket'],getS3FilePath($settings, $idr, $type).'/'.$tag.'/'.$filename));
					array_push( $results, array( $tag => array('ObjectURL'=>$objectURL) ) );
				}
			}
		} else { // All other files stay at the main directory level such as main.jpg etc.
			$result = uploadFile($bucket, $path, $filename, $localFilePath, $ext,'ONEZONE_IA');
			array_push( $results, array( 'file' => $result ) );
		}


		$return = $results;
	} else {
		$return = false;
	}

	// remove the s3_temp______.jpg file created:
	if(file_exists($localFilePath)) {
		unlink($localFilePath);
	}
	return $return;
}

function listObjects($bucket, $folder, $limit = 0) {
	global $settings;
	if(preg_match('/\/$/', $folder)==0) {
		$folder = $folder.'/';
	}
	if( !isset( $bucket ) || $folder=='') {
		echo "<p>ERROR: Folder (prefix) or bucket is not defined.</p>";
		echo "<p>BUCKET: {$bucket}";
		echo "<p>FOLDER (PREFIX): {$folder}";
		return;
	}
	$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
	$options = array(
		"Bucket" => $bucket,
		"Prefix" => $folder
	);

	if(is_int($limit) && $limit>0) {
		$options['MaxKeys'] = $limit;
	}
	// $objects = $s3->getIterator('ListObjects', $options);

	// Using getIterator to fetch objects
	$count = -1; // to allow for the first folder to be ignored in case of limit?
	foreach ($s3->getIterator('ListObjects', $options) as $object) {
		$count++;
		$objects[] = $object;
		// Break the loop if the limit is reached
		if ($limit>0 && $count >= $limit) {
			break;
		}
	}

	$result = array();

	$objectcount=0;
	foreach($objects as $objectkey => $objectarray) {
		if($folder==$objectarray['Key']) {
			// do nothing - this is the very first result that echoes simply the path (folder) given, so ignore.
		} else if($objectarray['Key']!='') {
			$result[] = $objectarray; // start adding to new result array.
			$objectcount++;
		}
	}
	if($objectcount==0) {
		$result = false;
	}
	return $result;

}

function getFile($bucket, $folder, $idr, $fileName, $type = 'homes') {
	global $settings;

	if( !isset( $bucket ) || $idr=='' || $fileName=='') {
		echo "<p>ERROR: File name, object ID, or bucket is not defined.</p>";
		echo "<p>BUCKET: {$bucket}";
		echo "<p>FILE NAME: {$fileName}";
		echo "<p>OBJECT ID: {$idr}";
		return;
	}
	$s3_filepath = getS3FilePath( $settings, $idr, $type); // get mother path of the object such as /homes/[id]/
	// folder can be blank if its not within the /web or /mobile etc. folders. Filename genreally cannot be blank.

	$getfile = $s3_filepath."/".($folder!='' ? $folder."/": "").($fileName!='' ? $fileName : '');

	$result = getObject($bucket, $getfile);

	return $result;
}


function getObject($bucket, $getfile) {
	global $settings;
	if( !isset( $bucket ) || $getfile=='') {
		echo "<p>ERROR: File url, bucket or folder is not defined.</p>";
		echo "<p>BUCKET: {$bucket}";
		echo "<p>FILE NAME: {$getfile}";
		return;
	}

	$result = false;
	if(strlen($getfile)>3 && $getfile!='' && is_string($getfile)) {
		$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
		$result = $s3->getObject(array(
			'Bucket' => $bucket,
			'Key'    => $getfile
		));
	}

	return $result;
	/*
	 * To interact with result,
	 * $result['Body'] for the content,
	 * and other methods available on https://docs.aws.amazon.com/aws-sdk-php/v2/api/class-Aws.S3.S3Client.html#_getObject
	 * */
}



// the following deleteFile function is very specific to object and its gallery/media/attachemnt files.
function deleteFile($bucket, $folder, $idr, $fileName, $type = 'homes') {
	// author Jeff Kee, built on the framework done by Steven Stark. 
	global $settings;

	if( !isset( $bucket ) || $idr=='') {
		echo "<p>ERROR: File url, bucket or folder is not defined.</p>";
		echo "<p>BUCKET: {$bucket}";
		echo "<p>FILE NAME: {$fileName}";
		return false;
	}
	$s3_filepath = getS3FilePath( $settings, $idr, $type);

	// note that the folder can often be blank, unless removing gallery photos. 
	$deletefile = $s3_filepath."/".($folder!='' ? $folder."/": "").($fileName!='' ? $fileName : '');
	// echo 'removing '.$deletefile."\r\n";
//	$result = $s3->deleteObject(array(
//	    'Bucket' => $bucket,
//	    'Key'    => $deletefile
//	));

	return deleteObject($bucket, $deletefile);
	/*
		
	[structure:protected] =>
    [data:protected] => Array
        (
            [DeleteMarker] => 
            [VersionId] => 
            [RequestCharged] => 
            [RequestId] => 7605F2687BA8A3D1
        )
	*/
}

function deleteObject($bucket, $deletefile) {
	if( !isset( $bucket ) || $deletefile=='') {
		echo "<p>ERROR: File url, bucket or folder is not defined.</p>";
		echo "<p>BUCKET: {$bucket}";
		echo "<p>FILE NAME: {$deletefile}";
		return "";
	}

	$result = false;
	if(strlen($deletefile)>3 && $deletefile!='' && is_string($deletefile)) {
		$s3 = $GLOBALS['S3_CLIENT']; // Defined in config.
		$result = $s3->deleteObject(array(
			'Bucket' => $bucket,
			'Key'    => $deletefile
		));
	}
	return $result;
}




function getResizeValue( $data, $settings, $value='width' ) {
	if( isset($data[$value]) ) {
		// Is this a number?
		if( is_numeric( $data[$value] ) ) {
			return $data[$value];
		} else if ( $data[$value] !== "" ) {
			// not a number, is it a settings variable?
			if( isset( $settings ) && isset( $settings[$data[$value]] ) ) {
				return $settings[$data[$value]];
			} else if( isset( $data["default_{$value}"] ) ) {
				// not a settings variuable, is there a valid default?
				if( is_numeric( $data["default_{$value}"] ) ) {
					return $data["default_{$value}"];
				}
			}
		}
	}

	// no valid valued found.
	return '';
}


// S3 Utils

function getS3FilePath( $settings, $idr, $type='homes' ) {
	// simply return the host and homeid pattern. 
	// does not include the preceding URL such as https://s3.ca-central-1.amazonaws.com/brixwork/
	if( !isset($settings) || !isset($idr) ) {
		die(" ERROR: Settings or Unique ID undefined.");
	}
	if($settings['s3_folder']!='') {
		$host = $settings['s3_folder'];
	} else {
		$url_data = parse_url($settings['sitepath']);
		$host = $url_data['host'];
	}
	$test_path = "{$host}/{$type}/{$idr}"; // no trailing slash
	return $test_path;
}

function checkS3Bucket( $bucket, $settings, $idr, $type = 'homes' ) {
	if( !isset($bucket) || !isset($settings) || !isset($idr) ) {
		die(" ERROR: Bucket, Settings or Home ID undefined.");
	}
	$path = getS3FilePath( $settings, $idr, $type );
	verifyBucketPath( $bucket, $path );
}

function generateGalleryDropKey($objecttype, $objectid) {
	// brixwork:www.jeffkee.com:homes:8899:1280:900:420:320:160:120:1234-mainstreet-yaletown-vancouver-west.jpg. This function runs by the LAMBDA setup that automaticlaly generates web/mobile/thumb versions of a JPG for galleries upon file drop. 
	global $settings;
	$delimeter = '/';

	$settings['imagewidthhorizontal'] = ($settings['imagewidthhorizontal']!='' ? $settings['imagewidthhorizontal'] : 1280);

	$settings['mobilewidth'] = ($settings['mobilewidth']!='' ? $settings['mobilewidth'] : 420);

	$settings['thumbnailwidth'] = ($settings['thumbnailwidth']!='' ? $settings['thumbnailwidth'] : 150);

	$data = array(
		$settings['s3_bucket'], // defaults to brixwork
		$settings['s3_folder'], // defaults to sitepath.
		$objecttype,
		$objectid,
		$settings['imagewidthhorizontal'],
		($settings['imagewidthvertical']!='' ? $settings['imagewidthvertical'] : $settings['imagewidthhorizontal']),
		$settings['mobilewidth'],
		(array_key_exists('mobileheight', $settings) && $settings['mobileheight']!='' ? $settings['mobileheight'] : $settings['mobilewidth']),
		$settings['thumbnailwidth'],
		(array_key_exists('thumbnailheight', $settings) && $settings['thumbnailheight']!='' ? $settings['thumbnailheight'] : $settings['thumbnailwidth']),
	);

	$return = '';
	foreach($data as $count=> $snippet) {
		if($count>0) {
			$return.=$delimeter;
		}
		if($snippet!='') {
			$return.=$snippet;
		} else {
			die('CANNOT BE BLANK, NOTHING on key '.$count.' - so far we have'.$return);
		}
	}

	return $return;
}

function CheckPathAndUploadFile( $settings, $idr, $type, $url, $filename, $s3_bucket, $gallery) {
	if( !isset( $url ) || $url == "" || !isset( $settings ) || !isset( $idr ) || $s3_bucket=='' ) {
		echo "ERROR: File url, settings, object id ".$idr.", or bucket is not defined.\r\n";
		return;
	}
	// check S3 bucket abd path
	// $s3_filepath = getS3FilePath( $settings, $idr, $type );
	checkS3Bucket($s3_bucket, $settings, $idr, $type);
	return uploadFileFromURL( $url, $s3_bucket, $settings, $idr, $type,  $filename, $gallery); // $gallery==true means it will trigger to photodrop bucket, and create web/mobile/thumb etc.
}

function waitUntilObjectExists( $bucket, $key ) {
	$s3 = $GLOBALS['S3_CLIENT'];

	try {
		//echo "\nWe are inside the waitUNTILOBJECT";
		$s3->waitUntil('ObjectExists', array(
			'Bucket' 	=>	$bucket,
			'Key'		=> 	$key,
			'waiter.interval'     => 1,
			'waiter.max_attempts' => 30
		));
	}

	catch (S3Exception $e) {
		echo $e->getMessage();
	}
}
?>