<?php
session_start();


/*
 * Basic cache control mechanisms here.
 * Overall cache times are very long to improve caching, speed up pageload,
 * and also aiming at decreasing AWS bills.
 *
 * However, listings_prep.php, showlisting_prep.php, building_prep.php will have cache headers
 * to override to shorter cache time for new listings and what not to show up faster.
 * */
global $seconds_to_cache;

$start_microtime = microtime(true);

// load DB etc. first before determining cache time?
require_once $_SERVER['DOCUMENT_ROOT'].'/includes/common.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/admin/basics.php';

$versiontxt = file_get_contents($_SERVER['DOCUMENT_ROOT'].'/brixwork_version.txt');
$versions = explode(':', $versiontxt);
$brixwork_version = $versions[0];
$brixwork_update_date = $versions[1];


require_once $_SERVER['DOCUMENT_ROOT'].'/admin/settings.php';

require_once $_SERVER['DOCUMENT_ROOT'].'/admin/functions.php'; // contains autoload.php
require_once $_SERVER['DOCUMENT_ROOT'].'/admin/classes.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/includes/s3/utils.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/admin/svg_icons.php';

global $settings;
if(isset($seconds_to_cache)) {
	$seconds_to_cache = $seconds_to_cache*1;// for cache duration set on a page-by-page basis for ajax calls etc.
} else {
	$seconds_to_cache = $settings['cache_duration'];
}

$ts = gmdate("D, d M Y H:i:s", time() + $seconds_to_cache) . " GMT";
header("Pragma: cache");
header('Cache-Control: public');
header("Expires: $ts");
header("Cache-Control: max-age=$seconds_to_cache");


header ('Content-type: text/html; charset=utf-8');

header("Access-Control-Allow-Origin: http://brixwork.com");
header("Access-Control-Allow-Origin: https://brixwork.com");
header("Access-Control-Allow-Origin: https://cloudfront.net");
header("Access-Control-Allow-Origin: https://facebook.com");
header("Access-Control-Allow-Origin: ".$settings['cloudfront_url']);

if(DEBUG===true) {
	ini_set('display_errors', 'on');
}
// suspend or forward intercept!
// if one or other is set, send to $GLOBALS[BRIX_FORWARD_DESTINATION_URL]
if((isset($_COOKIE['username']) && $_COOKIE['username']=='brixwork') || validate_login()) {
	// do mothin g - logged in users can still see preview
} else if( $settings['forward_website']==1 || $settings['suspend_website']==1 ) {
	$seconds_to_cache = 600; // 10 mins for forwarded or suspended sites.
	$ts = gmdate("D, d M Y H:i:s", time() + $seconds_to_cache) . " GMT";
	// turns out we needed to do 307 is better than 302 for temp redirects.
	header("Expires: $ts");
	header("Cache-Control: max-age=0");
	header('Location: '.$GLOBALS[BRIX_FORWARD_DESTINATION_URL], TRUE, 307);
	exit();
}

// force forwadr to https:// for SSL enabled sites!
if( (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] == "off") && strpos($settings['sitepath'], 'https')!==false){
	$redirect = 'https://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	header('Location: ' . $redirect, true, 301);
	exit();
}

// This was a quick patch for that botched update in 2018-04 when all sites forwarded to https by mistake and we had to
// reverse the effects.. don't think we need it?
if( (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == "on") && strpos($settings['sitepath'], 'https')===false){
	$redirect = 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	header('Location: ' . $redirect, true, 301);
	exit();
}


if(file_exists($_SERVER['DOCUMENT_ROOT'].'/'.($settings['rootpath']!='' ? $settings['rootpath'] : '/').'includes/dropdown.inc')) {
	require_once $_SERVER['DOCUMENT_ROOT'].'/'.($settings['rootpath']!='' ? $settings['rootpath'] : '/').'includes/dropdown.inc';
}

$visitor = new visitor;
// Visitor cookies etc. (2017-10)
if(isset($_COOKIE['sessionid'])) {
	$visitor->initialize($_COOKIE['sessionid']);
} else {
	if(isset($_COOKIE['PHPSESSID']) && $_COOKIE['PHPSESSID']!='') {
		$session_id = $_COOKIE['PHPSESSID'];
	} else {
		$session_id = session_create_id();
	}
	set_visitor_cookie($session_id); // fresh cookie, no way its connected to a visitor ID.
	$visitor->initialize($session_id);
}

global $visitor;

// mysql_set_charset("utf8");
if(file_exists($settings['includepath'].'functions.php')) {
	// this should dnever NOT exist.. but.
	require_once $settings['includepath'].'functions.php';
} else {
	echo "<strong>Warning</strong>: Template functions.php file not found!<br />".PHP_EOL;
}

?>