<?
/*
Filename: functions_new.php

Method: Include
Output: N/A

Description: Master functions file, for stuff used on both front end and back-end.  
Jump to any section by looking for #brix_00 in this file.

Author: Jeff Kee
00. Basic settings and variables.
01. Basic functions, widgets, error displays, email alerts etc.
02. File structure & folder processing.
03. String processing, clean ups, trims, etc.
04. MySQL data insert/modification 
05. Homes fetching, processing mechanisms, Google Geocode.
06. Pages fetching, processing mechanisms.
07. Resources & Other fetching, processing mechanisms.
08. Agents fetching, processing mechanisms.
09. Neighbourhoods fetching, processing mechanisms.
10. CURL, file fetch mechanisms, etc.
11. Media (Photo, attachmetns, video handling)
12. Interactive Google Map Search (new in 2016) related items.
13. PopUp Functions (jun 2016, JJ).
14. Cookie related functions?
15. CRM Integration (Mailchimp, FollowupBoss etc.) related functions.
*/

global $settings;

/*
 * 2018-04-09 update by Jeff Kee
 *
 * Some core dependancies such as S3 (AWS) utils,
 * Mailchimp API utils etc.
 *
 *
 * in case we need to load functions, but without all the MySQL/Database stuff
 * (for quick AJAX calls that do NOT need MySQL connection)
 * the functions should only include other essential libraries etc. only that do
 * not automatically need or forge connection.
 * settings.php
 * common.php
 * should NOT be called in here, call separately on start.php for front-end or back-end full pages, or on a case-by-case basis.
 *
 *
 * */

if(strpos(phpversion(), '8.')===0) {
	// if version starrts with 8
	require_once $_SERVER['DOCUMENT_ROOT'].$settings['rootpath']."packages_8/vendor/autoload.php"; // loads AWS SDI and all that.
} else {
	require_once $_SERVER['DOCUMENT_ROOT'].$settings['rootpath']."packages/vendor/autoload.php"; // loads AWS SDI and all that.
}

require_once $_SERVER['DOCUMENT_ROOT'].$settings['rootpath'].'admin/basics.php'; // in case this is called in by a blog, might as well put it here.
require_once $_SERVER['DOCUMENT_ROOT'].$settings['rootpath'].'includes/s3/utils.php'; // enables all the AWS related functions (mostly S3)
// require_once $_SERVER['DOCUMENT_ROOT'].'/'.($settings['rootpath']!='' ? $settings['rootpath'] : '/').'includes/MailChimp.php'; // enables the Mailchimp API.
// moved over.

/* ######################################################
#brix_00
Basic settings, time strings, error logs, functions etc. 

###################################################### */


/* @ Put in date format in UTC (GMT) and it returns fully formatted time in local timezone format.
 * @param $input Should be valid time format such as '2018-10-30 09:17:32' or 'October 29th 2018 4pm' etc., whatever PHP can parse using strtotime();
 * @param string $outputtimezone Leave blank for local default timezone (99% of time)
 * @param string $outputformat Leave blank for $mysql_time['full'] which is xxxx-xx-xx 00:00:00 format.
 * @return integer
 */
function utc_to_local_time($input, $inputtimezone = 'UTC', $outputtimezone='', $outputformat='') {
	global $settings;
	global $mysql_time;
	if($outputtimezone=='') {
		// if blank, get default timezone as final output destination.
		$outputtimezone = date_default_timezone_get();
	}

	if($outputformat=='') {
		// default to full
		$outputformat = $mysql_time['full'];
	}

	// remove alphabets from $input.
	$input = preg_replace('/[a-zA-Z]{3,}$/', ' ', $input); // if appended with GMT etc. we gotta kill it.
	$input = preg_replace('/[a-zA-Z]{1,1}$/', ' ', $input); // if single character followed for some reasson
	$input = trim($input); // then remove excess string.
	// all this should really be not necessary, we expect good datetime strings from most sources.
	// put in the time as UTC, assuming this is UTC only.
	$time = new DateTime($input, new DateTimeZone($inputtimezone));
	$output = date($outputformat, $time->getTimestamp());
	return $output;
}

/* ######################################################
#brix_01
Display functions of sorts, basic login functions etc.

###################################################### */
/**
 * @param $path: enter full URL of JS file to call, whether internal or external.
 * @param $defer: Whether to defer this javascript load or not.
 * @return string: <script> tag with the JS if valid URL, blank if entry is invalid URL.
 */

function generate_js_script_tag($path, $defer = false) {
	$js_defer = '';
	if($defer){
		$js_defer = 'defer';
	}
	$return = ''; // declare empty string.
	if(is_url($path)) {
		$return = '
		<script type="text/javascript" src="'.$path.'" '.$js_defer.'></script>';
	}
	return $return;
}

/**
 * @param $scriptinclude - Either full URL of a script, or a js file within templates/main/js/
 * @return string - Returns full <script> tag ready to go.
 */
function scriptinclude($scriptinclude, $defer_js_default = '') {
	global $settings;
	$return = '';

	if(!is_bool($defer_js_default)){
		//if $defer_js is not a boolean fallback to the settings setting for defer JS
		$defer_js_default = $settings['defer_js'] == 1 ? true : false;
	}

	$basepath = $settings['templatepath'].'js/'; // [clientdomain].com/templates/msin/js/_____
	if(is_array($scriptinclude)) {
		foreach($scriptinclude as $include) {
			// if this is an array.. it means we psased more data to determine the defer path etc.
			/*
			 * 99% it will be just a string with URL.
			 * https://-______/main/js/whatever.js
			 *
			 * however, we want to gice option for some JS to hace its own defer true/false, regardless of site wide settings.
			 * Example array:
			 * $scriptinclude_footer = array(
			 * 	'https://whateve.rcom/common.js',
			 * 	'https://whatever.com/jquery.numbers.min.js;',
			 * 	array(
			 * 		'url' = 'https://mypath.com/script_cannot_defer.js',
			 * 		'defer'= false
			 * 		),
			 * 'https://www.mysite.com/i_need_defer_again.js'
			 * )
			 *
			 * */
			// detect if it is an array or not.
			if(is_array($include)) {
				// split it up!
				$filepath = $include['url'];
				$defer_js = $include['defer'];
			} else {
				$filepath = $include; // pass the raw URL as it is, just a string.
				$defer_js = $defer_js_default; // follow default as this row does not have specific preference.
			}

			if(!is_url($filepath)) {
				// if we pass a jS file without http(S) base, appened with local path.
				$filepath = $basepath.$filepath; // add the sitepath base. .
			}
			$return .= generate_js_script_tag($filepath, $defer_js);
		}
	} else if($scriptinclude !='') {
		// single string passed.. just one script.
		if(!is_url($scriptinclude)) {
			$scriptinclude = $basepath.$scriptinclude; // add the site base.
		}
		$return .= generate_js_script_tag($scriptinclude, $defer_js_default);
	}

	return $return;
}
// create new funcction whose sole job is to generate a <script>
/*
 * Function that gets full <Script> tag for Google maps code.
 * Note that this function is disabled on all brixwork.ca subdomains as we don't need to consume API key usage during testing.
 */
function get_google_maps($version=3, $defer = false, $api_key = '') {
	global $settings;
	$api_key = ($api_key!='' ? $api_key : $settings['google_maps_api_key']);
	$gmap_js_file_url = 'https://maps.googleapis.com/maps/api/js?key='.$api_key.'&v='.$version.'"'.($defer===true ? ' defer="defer"' : '');
	$return = generate_js_script_tag($gmap_js_file_url);
	return $return;
}

function generate_mainimage($mainimage) {
	// Based on main image path given, generates the right meta and open graph image tags for aech page.
	// used in header_tags.php to finalize the image output.
	// OG image tag geneartor, basically.
	if($mainimage!=''){
		return '<meta property="og:image" content="'.$mainimage.'"/>
		<link rel="image_src" href="'.$mainimage.'" / >';
	}
}


function curpageurl() {
// get current page URL at any given page, based on what's on the browser address field!
	// TODO:  probably should update to use GUZZLE (new library)
	$pageURL = 'http';
	if ($_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
	$pageURL .= "://";
	if ($_SERVER["SERVER_PORT"] != "80" && $_SERVER["SERVER_PORT"] != "443") {
		$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
	} else {
		$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
	}

	// TODO: remove anything after ? if present?
	return $pageURL;
}


function logged_in($level=0) {
	/* 
	0 means no login check. 
	1 or above, lower number means higher authority. 
	i.e. If a page requires login level 3, and the user's level is 9, DENY. 
	*/
	global $mysqli;
	global $now;
	global $local;
	global $mysql_time;

	if(isset($_COOKIE['hash']) && $_COOKIE['hash']!='') {
		$levelquery = '';
		if($level>0) {
			$levelquery = " AND users.level<=".$level;
		}

		$select = "SELECT login.id as loginid, users.level as level, login.duration as duration, login.user as id FROM login LEFT JOIN users ON login.user=users.id WHERE login.hash='".$_COOKIE['hash']."' AND login.user='".$_COOKIE['userid']."' AND login.expiry>'".$now."'".$levelquery;
		$result = $mysqli->query($select);
		if($result->num_rows>0) {
			$user = $result->fetch_assoc();
			// now extend the login based on the current duration
			$newexp = date($mysql_time['full'],$local+$user['duration']);
			$extendsql = "UPDATE login SET expiry='".$newexp."' WHERE id='".$user['loginid']."'";
			setcookie('hash',$_COOKIE['hash'],strtotime($newexp),'/');
			setcookie('userid',$_COOKIE['userid'],strtotime($newexp),'/');
			setcookie('duration',$_COOKIE['duration'],strtotime($newexp),'/');
			setcookie('username',$_COOKIE['username'],strtotime($newexp),'/');
			setcookie('loginid',$_COOKIE['loginid'],strtotime($newexp),'/');
			$_SESSION['logged'] = "valid";
			$mysqli->query($extendsql);
			$return = true;
		} else {
			$return = false;
		}
	} else {
		// no ookies at all, def not logged in .
		$return = false;
	}

	return $return;
}

function check_login($level) {
	/* 
	0 means no login check. 
	1 or above, lower number means higher authority. 
	i.e. If a page requires login level 3, and the user's level is 9, DENY. 
	*/
	global $settings;
	$result = logged_in($level);

	// utilizing the logged_in function, determines whether to bounce the user or not.
	if(preg_match('/login\.php$/',$_SERVER['PHP_SELF'])==0 && $result==false) {
		header('Location: '.$settings['sitepath'].'admin/login.php'.($_SERVER['REQUEST_URI']!=''?'?req='.urlencode($_SERVER['REQUEST_URI']):''));
		exit();
	}
	else {return $result;}
}

/**
 * V5 Backend - LIGHTER FUNCTION THAT DOES NOT RUN SQL QUERY - STRICTLY FOR CHECKING LOGIN LEVEL ONLY.
 * No need to check cookie
 * - this function runs in the middle of page, after validate_login() runs.
 * @param int $level	BY DEFAULT IS 100 => EVERY USER LEVEL IS BELOW 100, SO MEANS EVERYONE GETS ACCESS ... pretty dumb way to use this function but i guess just have it...
 * @return bool			TRUE if login user level is less than $level (login user has higher permission than $level)
 */
function login_level_check(int $level = 100): bool {
	global $login_user;

	if ($login_user->getLevel() >= 0 && $login_user->getLevel() !== null) {
		return $login_user->getLevel() <= $level;
	}
	else {
		return false;
	}
}

/**
 * V5 Backend - Verify user level, and if not valid, redirect.
 * @param $verify_level	int			Level to be verified. $exclude boolean will decide how to interact with this value
 * @param $exclude		bool		exclude = false will simply run login_level_check() function. Exclude = true will compare to logged in user directly.
 * @param $redirect_url	string		URL to redirect user to. By default, it will be backend dashboard.
 * @return void
 */
function redirect_invalid_user(int $verify_level, bool $exclude = false, string $redirect_url = ''): void {
	global $settings, $login_user;
	$redirect_url_default = $redirect_url ?: $settings['sitepath'].'admin/';

	// Not doing exclusion - so all levels below the specified level is rejected
	if (!$exclude && !login_level_check($verify_level)) {
		header('Location:'.$redirect_url_default);
		exit();
	}

	// this means that $valid_level is specifically the level that's not allowed - redirect!
	if ($exclude && $login_user->getLevel() == $verify_level) {
		header('Location:'.$redirect_url_default);
		exit();
	}
}


/**
 * V5 Backend - USUALLY AT THE TOP OF THE PAGE TO ONLY RUN ONCE.
 * Replaces the old `check_login()` function.
 * Check login by comparing to COOKIE and database - only checking if there's a valid login, regardless of level.
 * @return bool        Upon successful login check, return true or false depending on user login status.
 */
function validate_login(): bool {
	global $mysqli;
	global $now;

	if (isset($_COOKIE['hash']) && $_COOKIE['hash']!='') {
		$select = "SELECT users.level as level, login.id as loginid, login.duration as duration, login.user as id FROM login LEFT JOIN users ON login.user=users.id WHERE login.hash='".$_COOKIE['hash']."' AND login.user='".$_COOKIE['userid']."' AND login.expiry>'".$now."'";
		$result = $mysqli->query($select);

		if ($result->num_rows > 0) {
			$_SESSION['logged'] = "valid";
			$login_status = true;
		} else {
			// query match does not exist ... false
			$login_status = false;
		}
	} else {
		// no cookies at all, def not logged in .
		$login_status = false;
	}

	// login check success
	return $login_status;
}


function logoff() {
	/* not gonna explain this... */
	global $mysqli;
	global $now;
	global $local;
	global $mysql_time;

	$select = "SELECT login.id as loginid, users.level as level, login.duration as duration, login.user as id FROM login LEFT JOIN users ON login.user=users.id WHERE login.hash='".$_COOKIE['hash']."' AND login.user='".$_COOKIE['userid']."'";
	$result = $mysqli->query($select);
	$user = $result->fetch_assoc();

	$newexp = date($mysql_time['full'],$local-13600);
	$logoffsql = "DELETE FROM `login` WHERE `id`='".$user['loginid']."'";
	// remove all cookies previously set.
	setcookie('hash',$_COOKIE['hash'],strtotime($newexp),'/');
	setcookie('userid',$_COOKIE['userid'],strtotime($newexp),'/');
	setcookie('username',$_COOKIE['username'], strtotime($newexp), '/');
	setcookie('loginid',$_COOKIE['loginid'],strtotime($newexp),'/');
	setcookie('phone', $_COOKIE['phone'], strtotime($newexp), '/');
	setcookie('email', $_COOKIE['email'], strtotime($newexp), '/');
	setcookie('fname', $_COOKIE['fname'], strtotime($newexp), '/');
	setcookie('sessionid', $_COOKIE['sessionid'], strtotime($newexp), '/');
	$_SESSION['logged'] = false;
	return $mysqli->query($logoffsql);
}


function openmessagebox($level='default') {
	// SOON TO BE DEPRECATED AT VERSION 4.0
	return '<div class="ui-state-'.$level.' ui-corner-all contains_icon message_box">';
}


function display_ui_icon($image) {
	// SOON TO BE DEPRECATED AT VERSION 4.0
	global $settings;
	return '<img src="'.$settings['master_url'].'admin/images/icons/'.$image.'" class="square_button ui-corner-all" align="absmiddle" />';
}


function closediv() {
	// it looks ridiculous, but when a <div> is opened by a PHP function with variables for speed,
	// the closing </div> count messes up coding platforms with unclosed div blocks etc.
	// PHP storm does a better job of detecting HTML within a PHP echo/print function but still nice to have.
	return '</div>';
}


function convert_grid($input) {
	$numbermap = array(
		1 => 'one',
		2 => 'two',
		3 => 'three',
		4 => 'four',
		5 => 'five',
		6 => 'six',
		7 => 'seven',
		8 => 'eight',
		9 => 'nine',
		10 => 'ten',
		11 => 'eleven',
		12 => 'twelve',
		13 => 'thirteen',
		14 => 'fourteen',
		15 => 'fifteen',
		16 => 'sixteen',
	);
	$return = $numbermap[$input];
	if($return=='') {
		$return = false;
	}
	return $return;
}

function post_result($message,$icon = 'Edit_Yes.png') {
	// SOON TO BE DEPRECATED AT VERSION 4.0
	// DO NOT EVER USE.
	global $settings;
	return '
<div class="container_16">
	<div class="grid_8 prefix_3 suffix_5">
	<div class="grid_3 alpha"><img src="'.$settings['master_url'].'admin/images/icons/'.$icon.'" /></div>
	<div class="grid_5 omega" style="padding:30px 0px;">'.openmessagebox('highlight').'<strong>'.$message.'</strong></div></div>
	</div>
</div>';
}


/**
 * @param $params - from_email, from_name, to & cc, subject & body etc.
 * @throws \SendGrid\Mail\TypeException
 */

function prepare_emailto_array($emails, $names) {
	// format either array or comma separated string of emails int
	/*
	 * format either array or commma separated string of emails into sendgrid friendly array scheme.
	 * array key is email address,
	 * array value is recipients name.
	 * $email = array(
	 * 'jeff@brixwork.com'=>'Jeff Kee',
	 * 'sarah@jeffkee.com'=>'Sarah Smith',);\
	 * */
	global $settings;
	global $mysqli;

	$sendgrid_tos = array();

	if($emails===false) {
		$return = false; // fail if there's no email. what's the point?
		$sendgrid_tos = false;
	} else if(is_array($emails)) {
		// array format for contact email field, so loop through each one.
		// Then assume the $names has matching arrays too.
		foreach($emails as $key=>$tovalue) {
			$tovalue = trim($mysqli->real_escape_string($tovalue)); // clean her up first.
			if(is_email_format($tovalue)) {
				$email = $tovalue;
				$sendgrid_tos[$email] = '';
			}
		}
	} else if(strpos($emails, ',')!==false || strpos($emails, ';')!==false) {
		// multiple emails in a string separated by , or ;.
		$to = $mysqli->real_escape_string(str_ireplace(';', ',', $emails));
		$to = explode(',', $to);
		foreach($to as $key=>$tovalue) {
			$tovalue = trim($tovalue); // trim extra spaces.
			if(is_email_format($tovalue)) {
				$email = $tovalue;
				$sendgrid_tos[$email] =  '';
			}
		}
	} else {
		// single email.
		$email =$mysqli->real_escape_string(trim($emails));
		if(is_email_format($email)) {
			$sendgrid_tos[$email] = '';
		}
	}

	// pair them up with the names or fall back to default name(s).
	$defaultname = (is_array($names) && $names[0]!='' ? $names[0] : ($names!='' ? $names : false));

	if(is_array($sendgrid_tos)) {
		$keycount = 0;

		foreach($sendgrid_tos as $email=>$blankname) {
			$sendgrid_tos[$email] = ((is_array($names) && isset($names[$keycount]) && $names[$keycount]!='') ? $names[$keycount] : ((is_string($names) && $names!='') ? $names : ($defaultname!==false ? $defaultname : extract_email_username($email))));
			$keycount++;
		}

		$return = $sendgrid_tos;
	}
	return $return;
}

function validate_emailto_array($array, $debug = false) {
	/*
	 * Ensure it's well formatted for Sendgrid's needs:
	 * $email = array(
	 * 'jeff@brixwork.com'=>'Jeff Kee',
	 * 'sarah@jeffkee.com'=>'Sarah Smith',);\
	 * */

	if(is_array($array) && count($array)>0) {
		// first off, must be a valid array.
		$invalidemail = false; // assume false for now.
		$keycount = 0; // since the keys are email, we need a unique counter.
		foreach($array as $email => $name) {
			if(!is_string($email) || !is_email_format($email) || $email=='') {
				$invalidemail = true;
				if($debug===true) {
					echo "Email address invalid at sequence ".$keycount.": ".$email." => ".$name."<br />".PHP_EOL;
				}
			}
			$keycount++;
		}

		// if any were invalid, flag it.
		if($invalidemail===true) {
			$return = false;
		} else {
			$return = true;
		}
	} else {
		if($debug===true) {
			echo "Emails must be in array and inside key, input was ".gettype($array).".<br />".PHP_EOL;
		}
		$return = false;
	}

	return $return;
}

function send_email($params) {
	global $settings;

	/*
	 * FROM email is singular, never an array.
	 * often from our system if not specified.
	 * $email = new \SendGrid\Mail\Mail();
	 * $email->setFrom('leads@brixwork.com', $_REQUEST['name']);
	 * */

	// Emails usually entered WITHOUT processing through prepare_emailto_array()
	// and we can check them using validate_emailto_array();
	$from_email = ($params['fromemail']!='' ? $params['fromemail'] : 'support@brixwork.com');
	$from_name = ($params['fromname']!='' ? $params['fromname'] : 'Brixwork Support');

	// who does it go to?
	$to_emails = ($params['to_emails']!='' ? $params['to_emails'] : $settings['contactemail']); // guess we can check for comma sep?
	$to_names = ($params['to_names']!='' ? $params['to_names'] : (is_array($settings['owner']) ? $settings['owner'][0] : $settings['owner']));

	// who does it go to?
	$cc_emails = ($params['cc_emails']!='' ? $params['cc_emails'] : false); // This can be false quite often.
	$cc_names = ($params['cc_names']!='' ? $params['cc_names'] : (is_array($settings['owner']) ? $settings['owner'][0] : $settings['owner']));

	// who does it go to?
	$bcc_emails = ($params['bcc_emails']!='' ? $params['bcc_emails'] : false); // This can be false quite often.
	$bcc_names = ($params['bcc_names']!='' ? $params['bcc_names'] : (is_array($settings['owner']) ? $settings['owner'][0] : $settings['owner']));

	// reply-to - default to the FROM email if not specified.
	// Must be string, cannot be array (we only support reply-to to single email)
	// usage: $email->setReplyTo($_REQUEST["email"], $_REQUEST['name']);
	$replyto_email = ($params['replyto_email']!='' ? $params['replyto_email'] : false); // guess we can check for comma sep?
	$replyto_name = ($params['replyto_name']!='' ? $params['replyto_name'] : false);

	$subject =  ($params['subject']!='' ? $params['subject'] : 'Website generated email from '.$settings['sitepath']);
	$body =  ($params['body']!='' ? $params['body'] : false); // body cannot be blank anyway???
	$encoding =  ($params['encoding']!='' ? $params['encoding'] : "text/html"); // body cannot be blank anyway???

	$email = new \SendGrid\Mail\Mail(); // initialize email object first.
	$sendgrid = new \SendGrid($settings['sendgrid_api_key'] ); // initialize API instance to which we connect to send the above email.

	// Process the to_email and

	$email->setFrom($from_email,$from_name);
	$email->setSubject($subject);
	if($replyto_email!=false) {
		$email->setReplyTo($replyto_email, $replyto_name);
	}

	if(!validate_emailto_array($to_emails)) {
		$to_emails = prepare_emailto_array($to_emails, $to_names);
	}
	$email->addTos($to_emails);

	if($cc_emails!==false) {
		if(!validate_emailto_array($cc_emails)) {
			$cc_emails = prepare_emailto_array($cc_emails, $cc_names);
		}
		$email->addCcs($cc_emails);
	}


	if($bcc_emails!==false) {
		if(!validate_emailto_array($bcc_emails)) {
			$bcc_emails = prepare_emailto_array($bcc_emails, $bcc_names);
		}
		$email->addBccs($bcc_emails);
	}

	$email->addContent($encoding, $body);

	try {
		$response = $sendgrid->send($email);
		$result = true;
		$statuscode = $response->statusCode();
		$message = 'Sendgrid API hit successful.';
		// doesn't mean the SEND was successful -= sendgrid coudl have sent back a error message however, which is to be dealt by the executing script such as ajax_sendemail.php
	} catch (Exception $e) {
		// This means the API call to Sendgrid failed altogether.
		$result = false;
		// we won't have a valid $response, nor a statusCode() since it failed before LEAVING our server.
		$message = 'There was an error with our email system - '.$e->getMessage().' - If this error persists, please contact support@brixwork.com.';
	}

	$returnarray = array(
		'result' => $result,
		'message'=> $message,
		'statuscode'=>$statuscode,
		'response'=>$response // pass raw response for error handling if needed.
	);

	return $returnarray;
}


/**
 * @param $title
 * @param $msg
 */

function send_email_to_brixwork($params) {
	global $settings;
	global $now;
	// process inboudn parameters.
	$fromemail = ($params['from']!='' ? $params['from'] : (is_array($settings['email']) ? $settings['email'][0] : $settings['email']));
	$subject =  ($params['subject']!='' ? $params['subject'] : 'System alert from Brixwork website '.$settings['sitepath']);
	$body = ($params['body']!='' ? $params['body'] : ''); //

	$email_params['to_emails'] = 'support@brixwork.com'; // alreaddy processed in this case?
	$email_params['to_names'] = 'Brixwork Coding'; //

	$email_params['fromemail'] = $fromemail;
	$email_params['fromname'] = 'Brixwork System'; // this is a system alert, so always name it as such.

	$body .= "Executing script: ".$_SERVER['SCRIPT_FILENAME']."<br />Time of incident: ".$now;

	$email_params['body'] = $body;
	$email_params['subject'] = $subject;
	$email_params['encoding'] = "text/html"; // always HTML on these emails since we want to add rich tags to this.

	// run the result through send_email() function but with the above specs (noreply etc.)
	// $email_result = send_email($email_params);

	send_brixwork_email(1, $email_params);
	return $email_result;
}

/**
 * @return void
 */
function send_brixwork_email($destination, $params) {

	if($destination===0 || $destination ==='') {
		// by default, send to the website owner.
		// set TO to be $settings['contactemail'] and such.
	} else if ($destination===1) {
		// alert brixwork devs of issues. Set the $param['to'] to be support@brixwork.com and the name to be "Coders" or wahtever.
		// ladn on our support.
	} else if($destination===2) {
		// send to btoh website owner, and brixwork team (hybrid of the above two options)
	}
	// by now, the TO variables are set.
	// Then trigger the

}


function log_error($msg) {
	global $handle;
	if (!empty($handle)) {
		fwrite($handle, $msg, strlen($msg));
	}
}


function seekKey($haystack, $needle){
	$output = false;
	foreach($haystack as $key => $value){
		if($key == $needle){
			$output = true;
		}elseif(is_array($value)){
			$output = seekKey($value, $needle);
		}
	}
	return $output;
}

// Returns the filepath appended to the urlbase. Also appends the backend version to invalidate cached files.
function brixwork_core_url($filepath, $version='', $urlbase='') {
	global $settings;
	global $brixwork_version;

	if(strpos($settings['sitepath'], 'dev.brixwork.com')!==false && $urlbase=='') {
		// DEV site!  Don't load through cloudront.
		$urlbase = $settings['sitepath'];
	}

	$urlbase = ($urlbase != '' ? $urlbase : $settings['master_url']); // default to master_url
	$version = ($version != '' ? $version : $brixwork_version);
	if($filepath!='') {
		// generates the URL to fetch core files from demo.brixwork.com, which is routed thorugh our cloudfront. 
		$return = $urlbase.$filepath.'?v='.$version;
	} else {
		$return = false;
	}

	return $return; // whatever is returned has a version appended, so the cloud front cache will load new stuff. 
}


function s3_to_cloudfront($url) {
	// converts S3 bucket URLs to cloudfront URLs on the fly. 
	// only really should be used on data entry, so this isn't constantly being used to swap out. 
	//
	//
	/*
	 * Can be either
	 * https://s3.ca-central-1.amazonaws.com/brixwork-test/dev.brixwork.com/pages/2/main.jpg?mod=1614459463627
	 * Matches $settings['s3_return_url']
	 * or.
	 * https://brixwork-test.s3.ca-central-1.amazonaws.com/dev.brixwork.com/pages/2/main.jpg
	 * Matches $settings['s3_return_url_legacy']
	 * */
	global $settings;
	if(is_string($url) && strlen($url) > 10) {
		if(strpos($url, $settings['cloudfront_url'])==false ) {
			// compare to the return URL format from S3 that has the bucket name as subdomain.
			if(strpos($url, $settings['s3_return_url'])!==false) {
				$url = str_ireplace($settings['s3_return_url'], $settings['cloudfront_url'], $url);
			} else if(strpos($url, $settings['s3_return_url_legacy'])!==false) {
				$url = str_ireplace($settings['s3_return_url_legacy'], $settings['cloudfront_url'], $url);
			}
		} // already cloudfront URL, no need to manipulate?
	}
	return $url;
}


if(!function_exists('mysql_close')) {
	/**
	 * @deprecated No longer used in PHP7, but older templates may try to call this at footer.php. When you see this, kill it!
	 * @return false
	 */
	function mysql_close() {
		return false;
	}
}
/* @
 * Showcase all features in the building system (not for a specific building)
 */
function list_building_features() {
	// look to list_home_features() for the mirror function for the home object, not building object.
	global $settings;
	global $mysqli;

	// load all available features first and put them into id=>label array.
	$featuressql = "SELECT * FROM `buildingfeatures` ORDER BY `ord`";
	$featuresresult = $mysqli->query($featuressql);
	while($features = $featuresresult->fetch_assoc()) {
		$featurearray[$features['id']] = $features['name'];
	}

	return $featurearray;
}

/* @
 * Showcase all features in the building system (not for a specific building)
 */
function list_home_features() {
	// look to list_building_features() for the mirror function for the home object, not building object.
	global $settings;
	global $mysqli;

	// load all available features first and put them into id=>label array.
	$featuressql = "SELECT * FROM `homefeatures` ORDER BY `ord`";
	$featuresresult = $mysqli->query($featuressql);
	while($features = $featuresresult->fetch_assoc()) {
		$featurearray[$features['id']] = $features['name'];
	}

	return $featurearray;
}


function generate_hoodq_widget( $params) {
	global $settings;

	$divid = ($params['divid']!='' ? $params['divid'] : 'hoodq_widget_container');
	$cssclass = ($params['cssclass']!='' ? $params['cssclass']: 'brixwork_hoodq_widget');
	$apikey = ($params['apikey']!='' ? $params['apikey'] : $settings['hoodq_api_key']);
	$script_url = ($params['script_url']!='' ? $params['script_url'] : 'https://sdk.hoodq.com/hq-sdk-v2.js'); // doubt this will change!
	$address = ($params['address']!='' ? $params['address'].', '.$settings['province']: $settings['address1'].' '.$settings['city'].', '.$settings['province']);

	if(strlen($address)>10) {
		$return = '<div id="'.$divid.'" class="'.$cssclass.'"></div>
<script>
  function initSDK() {
    var hq = new HQ.NeighbourhoodHighlights({
      el: "'.$divid.'",
      address: "'.$address.'",
    });
  }
</script>
<script src="'.$script_url.'?key='.$apikey.'&cb=initSDK&libs=ah"></script>';

	} else {

	}

	return $return;
}


/* ######################################################
#brix_02
File & folder processing, deletions etc. 
######################################################*/

// For S3 file handling such as uploads, check paths etc., refer to /includes/s3/utils.php

function list_directory($handle, $exclude, $recurse = true) {// it says $handle but its just a string, not loaded yet. "/homes/2343/" shold be passed. 
	// no file request - retrieve file list.
	if(!is_array($exclude) || !is_array($exclude['files']) || !is_array($exclude['directories'])) {
		// based on our purposes, there will ALWAYS be an exclude of some sort!!! If theres no excludes passed, don't even run this (security purposes).
		return false;
	} else {
		$handle = add_trailing_slash($handle);

		if(!is_array($exclude['extensions'])) {
			// if not an array, force it for blank array so that in_array() does not return silly warning. 
			$exclude['extensions'] = array();
		}

		$dirHandle = opendir($handle);
		if($dirHandle!==false) {
			$return = array();
			while(false!==($file = readdir($dirHandle))) {
				if(is_dir($handle.$file) && $file != '.' && $file != '..'){
					// this is a directory that is NOT .. or .
					if(!in_array($handle.$file, $exclude['directories'])) {
						$return[] = array(
							'type'=>'directory',
							'name'=>$file,
							'content'=>($recurse===true ? list_directory($handle.$file, $exclude) : false)
						);
					}
				} else {
					if($file != '.' && $file != '..' && !preg_match('/^\./',$file) && $file!==false & $file!='') {
						$extension = get_file_extension($file);

						if(
							!in_array($file, $exclude['files']) && // not in the exclude,
							!in_array($extension, $exclude['extensions'])
						) {
							$return[] = array('type'=>'file','name'=>$file, 'extension'=>$extension);
						} else {
							echo 'excluding '.$file.'<br />';
						}
					}
				}
			}
			if(is_array($return) && count($return)>0) {
				sort($return);
				return $return;
			} else {
				return false;
			}
		} else {
			// not a valid folder. 
			return false;
		}

	}
}


function rmdir_files($dir, $deleteitself = true) {
	// recursively empties entire folder, then the folder itself as well. 
	// commonly used when removing property entirely! 
	if($dir!='' && isset($dir) && is_string($dir) && substr_count($dir ,'..')<3) {
		// really no reason to ever recurse more htan 3 folders up through ../ so disabling if .. is detected multiple times. 
		$dir = add_trailing_slash($dir);
		if(!preg_match('/\/$/',$dir)) {
			// add last /
			$dir = $dir.'/';
		}

		if(strpos($dir, $_SERVER['DOCUMENT_ROOT'])!=0) {
			while(preg_match('/^\//',$dir)) {
				// unless the doc root was supplied to avoid removing anything at deeper level, make sure we remove first / to avoid running from root. 
				// remove any / at teh beginning to avoid running from web root! Always sub-items only. 
				$dir = substr($dir, 1, strlen($dir)-1); // if directory path does not end in the slash, add it! Important.
			}
		}

		if(file_exists($dir)) {
			$dh = opendir($dir);
			if ($dh) {
				while($file = readdir($dh)) {
					if (!in_array($file, array('.', '..'))) {
						if (is_file($dir.$file)) {
							unlink($dir.$file);
						} else if (is_dir($dir.$file)) {
							rmdir_files($dir.$file, true);
						} else {
							// no other option really... its either a file, or ., or .., or a folder. 
						}
					}
				}

				if($deleteitself===true) {
					rmdir($dir);
				}
			}
		} else {
			// echo "Does not exist for deletion: ".$dir."<br />< br>";
		}
	} else {
		// echo "Failed to delete ".$dir."<br /><br />";
	}
}

function is_dir_empty($dir) {
	if($dir!='' && file_exists($dir)) {
		$iterator = new \FilesystemIterator($dir);
		$isDirEmpty = !$iterator->valid();
		return $isDirEmpty;
	} else {
		echo "Not a valid directory: ".$dir."<br />\r\n";
	}
}

function get_file_extension($file_name) {
	return strtolower(substr(strrchr($file_name,'.'),1));
}


function truncate_to_last_lines($filepath, $keep=100, $backup=false, $sendbackupto = '') {
	if(file_exists($filepath) && strpos($filepath,'.php')===false) {
		if(filesize($filepath)<20971520) {
			$fd = fopen ($filepath, "r");
			while (!feof ($fd)) {
				$buffer = fgets($fd, 4096);
				$lines_array[] = $buffer;
			}
			fclose ($fd);
		} else {
			file_put_contents($filepath, 'Emptied on '.$today."\r\n");
		}

		//$lines_array = file($filepath, FILE_SKIP_EMPTY_LINES);
		$lines = count($lines_array); // how many lines?  

		$startline = $lines-$keep;// at what line do we start? i.e. if the file has 3,500 lines, 3500-100 lines will be starting at 3,400 only. 
		if($startline>1) {
			// if the # of lines in file is already less than what we keep, no action needs to be takne. 
			$new_output = "";

			for ($i=$lines-$keep; $i<$lines; $i++){
				$new_output .= $lines_array[$i];
			}
			file_put_contents($filepath, $new_output);

			$new_lines_array = file($filepath, FILE_SKIP_EMPTY_LINES);
			$new_lines = count($new_lines_array); // how many lines now?  
			return $new_lines;
			// later we can perhaps work on sending the back up into S3 somewhere but for now, all good. 

		} else {
			return $lines; // return # of lines currently there.. no truncation needed. 
		}
	} else {
		// file does not exist!
		return false;
	}

}


// start with the new S3 related functions. 

function attachment_exists_on_s3($type, $id, $attachment='mainphoto', $count = 0) {
	global $settings;
	// $type = homes or buildings etc. 
	if($type=='' || $id=='' || $settings[$type.'_'.$attachment.'filename'][$count]=='') {
		return false;
	} else {
		// available attachment types are homes_mainphotofilename, buildings_pdffilename etc. 
		// that means $attachment has to return a very precise string. mainphoto will work, mainimage will not.
		$s3filename = getS3FilePath( $settings, $id, $type ).'/'.$settings[$type.'_'.$attachment.'filename'][$count]; // determine file name based on attachment type etc. 
		if(verifyExists($settings['s3_bucket'], $s3filename)) {
			return $settings['s3_url'].$settings['s3_bucket'].'/'.$s3filename;
		} else {
			return false;
		}
	}


}

function gallery_photo_exists_on_s3($type, $id, $filename) {
	global $settings;
	// $type = homes or buildings etc. 
	if($type=='' || $id=='' || $filename=='') {
		return false;
	} else {
		// need to recurse through different file sizes and folders throughout. 

		$s3filename = array(); // set up blank array. 

		foreach($GLOBALS['S3_IMAGE_SIZES'] as $imagesize=>$data) {
			$s3filename[$imagesize] = getS3FilePath( $settings, $id, $type ).'/'.$imagesize.'/'.$filename; // determine file name based on attachment type etc. 

			if(verifyExists($settings['s3_bucket'], $s3filename[$imagesize])) {
				$s3urls[$imagesize] = $settings['s3_url'].$settings['s3_bucket'].'/'.$s3filename[$imagesize];
			} else {
				$s3urls[$imagesize] = false;
			}
		}
		return $s3urls;
	}
}



/* ######################################################
#brix_03
String processing, clean ups, array processing, singular field fetch from MySQL etc. 

###################################################### */

/**
 * Detect alphanumeric strings, but also allow underscores, dashes, and periods.
 * Useful for detecting social media usernames etc.
 * Do not use for validating URLs etc... there are better tools for that..
 * @param $input
 * @return bool
 */
function is_alphanumeric($input) {
	// alphanumeric, plus -._ etc. - useful for filtering for generic usernames that may have periods, -, or _
	if (preg_match('/[^a-z_.\-0-9]/i', $input)===0) {
		// if any character OUTSIDE the a-z, -_. are NOT found, the preg_match is true, so this needs to be false.
		$return = true;
	} else {
		$return = false;
	}

	return $return;
}

function removespecialquotes($string) {

	$string = str_replace('“','&ldquo;',$string);
	$string = str_replace('”','&rdquo;',$string);
	$string = str_replace("‘","&lsquo;",$string);
	$string = str_replace("’","&rsquo;",$string);

	global $specialcharacters;

	$string = strtr($string,$specialcharacters);

	return $string;

}

/**
 * @param $string
 * @return mixed|string
 * Removes excess spaces before & after, also removes special quotes.
 */
function cleanupforentry($string) {

	global $mysqli;
	if(is_string($string)) {
		// to prevent any frivolous "this is not a string, but an array" warnings.
		$string = trim($string);
		$string = removespecialquotes($string);
		$string = $mysqli->real_escape_string($string);
	}
	return $string;
}

function cleanupfortextfield($string) {
	if(is_string($string)) {
		$result = htmlspecialchars($string, ENT_QUOTES, 'UTF-8'); // default is UTF-8.. don't think we ever need to change this?
	} else {
		$result = $string;// as it is?
	}
	return $result;
}


function reverse_htmlentities($mixed) {
	$htmltable = get_html_translation_table(HTML_ENTITIES);
	foreach($htmltable as $key => $value) {
		$mixed = ereg_replace(addslashes($value),$key,$mixed);
	}
	return $mixed;
}


function add_trailing_slash($path) {
	global $mysqli;

	$cleanpath = $mysqli->real_escape_string(trim($path));
	if(!preg_match('/\/$/',$cleanpath)) {
		$cleanpath = $cleanpath.'/';
	}

	return $cleanpath;
}

/**
 * @param $input
 * @return mixed
 * @deprecated Use cleanupforentry() instead.
 */
function single_quote_to_html($input) {
	$string = str_replace("'","&#39;",$input);
	return $string;
}

/**
 * @deprecated use get_host() or get_host_url() etc. instead to get portions of URLs and re-construct.
 * @param $url
 * @return false|mixed|string
 */
function strip_get_vars($url) {
	// function to get rid of everything after the ? for URLs, to clean it down. 
	// especially handy when the ?mod=2015-09-09 appends JPG paths for get_main_images_path() functions on home/building object.
	// update on 2017-07-23, disabled this on lot of cases because the timestamps need to be kept to invalidate the cache on cloudfront. 
	if(strpos($url, '?')) {
		$url = substr($url, 0, strpos($url, '?'));
	} else {
		$url = $url;
	}
	return $url;
}

function array_sort_by_column(&$arr, $col, $dir = SORT_ASC) {
	$sort_col = array();
	foreach ($arr as $key=> $row) {
		$sort_col[$key] = $row[$col];
	}

	array_multisort($sort_col, $dir, $arr);
}

function print_array_or_string($input, $delimiter=', ', $lastdelimiter = ' and ') {
	// useful when there are multiple owners and you want to type out John, Judy and Josh from 3 arrays of $settings['owner'] etc. 

	$return = '';
	if(is_array($input)) {
		// array, so formulate XXXX, XXXX and XXXX type of output. 
		$totalcount = count($input)-1; // see how many we have... then minus 1 so we can use with 0, 1, 2 sequence.
		if($totalcount>0) {
			foreach($input as $count=>$value) {
				if($count==$totalcount && $lastdelimiter!==false) {
					//  XXX, XXX and XXXX for the final item. 
					$return.=$lastdelimiter;
				} else if($count>0) {
					// otherwise, as long as it's not the FIRST iteration, add the delimter such as XXX, XXX
					$return.=$delimiter;
				}
				$return.=$value;
			}
		} else {
			$return = $input[0]; // single array, so treat first array as string. 
		}
	} else if((is_string($input) || is_int($input)) && $input!='') {
		$return = $input;
	} else {
		$return = false; // $input was neither array nor string. 
	}

	return $return;
}

function find_longer_value($a, $b) {
	// useful for merging fields. Find the field that has more daata, and return that instead. i.e. if One has West, and the other has W, will take that. if one is blank and the other isn't then take the non-blank field. 
	$return = '';
	if($a!='' & $b=='') {
		$return =  $a;
	} else if($a=='' && $b!='') {
		$return =  $b;
	} else if($a!='' && $b!='') {
		// has a value on both inputs. 
		if(strlen($a)>=strlen($b)) {
			$return = $a;
		} else if(strlen($a)<strlen($b)) {
			$return = $b;
		}
	}

	return $return;
}

function delimited_options_to_array($delimited, $array=false, $delimiter = '|') {
	/* get unit types available for instance. 
	|2|3|5| should equal to condo, townhome & penthouse, for example. 
	The output will be 
	IF array is set:
	array(2=>'Condo', 3=>'Townhome', 5=>'Penthouse);
	
	IF no array, 
	array(2=>2, 3=>3, 5=>5);
	
	reverse function is array_to_delimited_options(); 
	*/
	global $mysqli;
	$return = array(); // by default, set up blank array. 

	if(is_string($delimited) && strlen($delimited)>2 && $delimiter!='' && strlen($delimiter)==1) {
		// unit types is set!
		$types_array = explode($delimiter, $delimited);
		foreach($types_array as $type_id) {
			if(isset($type_id) && $type_id.''!='') {
				// there will be blank arrays before and after, so skip blanks. 
				$return[$type_id] = ($array!==false ? $array[$type_id] : $type_id);
			}
		}
	} else {
		$return = false;
	}

	return $return;
}

function array_to_delimited_options($array, $delimiter = '|') {
	// reverse function of delimited_options_to_array()
	// processes entry into DB from multiple selections. 
	// array(2, 3, 5) turns into |2|3|5| for raw entry into string. 
	global $mysqli;
	if($delimiter!='' && strlen($delimiter)==1) {
		if(is_array($array)) {
			$return = $delimiter; // start with |. 
			foreach($array as $count=>$val) {
				$val = $val.''; // force it to be a string!	
				if($val!='') {
					$return.=$mysqli->real_escape_string($val).$delimiter; // always add | at end, so it ends with |. 
				}
			}

		} else if(is_string($array) && $string!='') {
			$return = $delimiter.$array.$delimiter; // singular value, still enclose in the |, so it looks like '|3|'
		} else {
			$return = $delimiter.$delimiter; // blank! such as '||'
		}
	} else {
		$return = false;
	}

	return $return;
}

// the function json_decode returns a false if fails.. is this really necessary/
function isJson($string) {
	json_decode($string);
	return (json_last_error() === JSON_ERROR_NONE);
}

function split_name($name) {
	$name = trim($name);
	$last_name = (strpos($name, ' ') === false) ? '' : preg_replace('#.*\s([\w-]*)$#', '$1', $name);
	$first_name = trim( preg_replace('#'.$last_name.'#', '', $name ) );
	return array($first_name, $last_name);
}

// Some static maps don't work for whole numbers
function brixwork_ensure_number_has_one_decimal($num) {
	$return = $num;

	/*
	 * If removing decimal places from number equals the same as
	 * the number, it is a whole number, so add .0 after it.
	 */
	if(floor($num) == $num) {
		$return = number_format($num, 1);
	}

	return $return;
}


function convert_crea_ddf_photo_timestamp($input) {
	// Input is DD/MM/YYYY HH:MM:SS AM
	// need to reverse the DD MM YYYY
	list($date, $time, $ampm) = explode (' ', $input);
	list($day, $month, $year) = explode('/', $date);
	if(strpos($time, ':')===false) {
		$time = '00:00:00'; // default to 0, maybe only date was passed.
	}

	$return = $year.'-'.$month.'-'.$day.' '.$time.$ampm;
	// catch errors!
	if((remove_all_but_numbers($month))>12) {
		$return = false;
	}

	if($year=='' || strlen($year)!=4 || $day=='' || strlen($day)!=2) {
		echo 'Bad value - '.$year;
		$return = false;
	}
	return $return;
}

/**
 * Many CREA DDF areas have a 2 character prefix such as:
 * Ke Keremos
 * PE Penticton Rural
 *
 * We don't need those. However we do need to keep things like NW, NE, as those are direction prefixes.
 *
 * This function cleans out all 2 alphabets + space, except the direction markers.
 * If there's nothing to clean, it will simply return the original string as-it is.
 *
 * @param $input
 *
 * Algorithm provided by a kind stranger on Stack Overflow:
 * https://stackoverflow.com/questions/70205636/regular-expression-replace-preg-replace-to-remove-2-letter-at-beginning-eexcep/70207281#70207281
 */
function trim_two_letter_prefixes($input) {
	if(is_string($input)) {
		$doubleletter = '/^(((?:NW|NE|SW|SE|N|E|S|W)\s)|[a-z]{2}\s)/i';

		$return = preg_replace_callback($doubleletter,
			function ($groups) {
				return isset($groups[2]) ? strtoupper($groups[2]) : '';
			}, $input);

	} else {
		$return = false;
	}
	return $return;
}


/**
 * Return just the host such as www.
 * @param $url
 * @return string
 */
function get_host($url) {
	// for semantic consistency, moved to get_url_host();
	return get_url_host($url);
}

/**
 * Return just the host such as www.
 * @param $url
 * @return string
 */
function get_url_host($url) {
	if(is_url($url)) {
		$return = parse_url($url, PHP_URL_HOST);
	} else {
		$return = false;
	}
	return $return;
}

/**
 * Return http or https
 * @param $url
 * @return string
 */
function get_url_scheme($url) {
	if(is_url($url)) {
		$return = parse_url($url, PHP_URL_SCHEME);
	} else {
		$return = false;
	}
	return $return;
}

/**
 *
 * @param $url
 * @return string
 */
function get_url_path($url) {
	if(is_url($url)) {
		$return = parse_url($url, PHP_URL_PATH);
	} else {
		$return = false;
	}
	return $return;
}


/**
 * Gets query params after ? - only works for GET vars.
 * @param $url
 * @return string
 */
function get_url_query($url) {
	if(is_url($url)) {
		$return = parse_url($url, PHP_URL_QUERY);
	} else {
		$return = false;
	}
	return $return;
}

/**
 *
 * @param $url
 * @return string
 */
function get_url_port($url) {
	if(is_url($url)) {
		$return = parse_url($url, PHP_URL_PORT);
	} else {
		$return = false;
	}
	return $return;
}

function separate_url_components($url) {
	if(is_url($url)) {
		$url_scheme = get_url_scheme($url);
		$url_host = get_url_host($url);
		$url_path = get_url_path($url);
		$url_port = get_url_port($url);

		$return = array(
			0 => $url_scheme,
			1 => $url_host,
			2 => $url_path,
			3 => $url_port,
		);
	} else {
		$return = false;
	}
	return $return;
}


/**
 * @param $input
 * @return String of URL
 */
function get_secured_url($input) {
	global $settings;
	if($input!='' && strlen($input)>12 && strpos($input, 'http')==0) {
		// check valid URL first, and make sure the website sitepath is set as such.
		if(strpos($settings['sitepath'], 'https://')!==false && strpos($input,'http://')!==false) {
			$return = str_ireplace('http://', 'https://', $input);
		} else {
			$return = $input;
		}
	} else {
		// not URL, return as it is?
		$return = $input;
	}
	return $return;
}

/**
 * @param $count
 * @param $singular
 * @return string
 */
function pluralize($singular) {
	// Uncountable nouns
	$uncountables = ['sheep', 'fish', 'deer', 'species'];

	// Check if the word is uncountable
	if (in_array(strtolower($singular), $uncountables)) {
		return "$singular";
	}

	// Special irregular plurals (manually added)
	$irregulars = [
		'person' => 'people',
		'man' => 'men',
		'child' => 'children',
		'tooth' => 'teeth',
		'foot' => 'feet',
		'mouse' => 'mice',
		'octopus' => 'octopi',
		'cactus' => 'cacti',
		// Add more irregular forms as needed
	];

	if (array_key_exists(strtolower($singular), $irregulars)) {
		return $irregulars[strtolower($singular)];
	}

	// Regular pluralization rules
	if (preg_match('/(x|ch|ss|sh)$/i', $singular)) {
		$plural = $singular . 'es'; // Ends in x, ch, ss, sh
	} elseif (preg_match('/([^aeiou])y$/i', $singular, $matches)) {
		$plural = substr($singular, 0, -1) . 'ies'; // Consonant before y
	} elseif (preg_match('/(us)$/i', $singular)) {
		$plural = substr($singular, 0, -2) . 'i'; // Ends in us
	} elseif (preg_match('/(is)$/i', $singular)) {
		$plural = substr($singular, 0, -2) . 'es'; // Ends in is
	} else {
		$plural = $singular . 's'; // Default
	}

	return $plural;
}


/**
 * @param $input
 * @return array
 * Strings such as 55 - 1201 118 Avenue will be split up into 3 arrays and returned;.
 * It splits up unit, street #, and then the whole street as an array().
 * 0 => 55
 * 1 => 1201
 * 2 => 118 Avenue
 * Note - function name is deceiving, sorry. Started out to just spit unit # but ended up splititng to street number, street name as well.
 * most real estate boards have the unit number in separate column so we end up discarding the first array of this result,
 * or not even using this function at all. This is really a fallback for shit feeds.
 */
function separate_unit_number($input, $debug = false) {
	global $settings;
	// find the position of the street type first in the array!
	$rawarray = explode(' ', $input);

	// clean up special chars such as # for unit numbers etc.? Apt? Unit?
	$cleanup_patterns = array(
		'/^apt/i',
		'/^unit/i',
		'/^#/',
		'/^pt/i',
		'/^suite/i',
	);

	if(is_array($rawarray)) {
		$array = array();
		foreach($rawarray as $key=>$var) {
			foreach($cleanup_patterns as $cleanup_pattern) {
				if(preg_match($cleanup_pattern, $var)>0) {
					// remove prefixes like apt or unit from unit number blocks
					// Ottawa is notorious for UNIT32 type of formats.
					$var = remove_all_but_numbers($var);
				}
			}
			if($var!='' && $var!=false) {
				// only add back non-blank arrays.
				// This should account for any double spaces in strings etc.
				$array[] = trim($var);
			}
		}
	} else {
		$array = $input;
	}

	// Set the default returns to false.
	$unit = false;
	$number = false;
	$street = false; // the street portion, later, processes through separate_streetname() function.

	// process odd exceptions first - these are just oddball scenarios, so needs manual human touch.
	if(preg_match('/^lot /i', $input) || preg_match('/^lt /i', $input)) {
		// opens with "Lot " so "Lot X" should be number, rest of it street. Or Unit
		if($debug == true) {
			echo 'Exception: string starts with Lot or LT<br />';
		}
		$number = $array[0].' '.$array[1]; // combine "lot" and "32" to create "lot 32" as street num.
		foreach($array as $key => $var) {
			if($key>1) {
				$street = $street.$var.' ';
			}
		}
		$street = trim($street);
	} else if(preg_match('/^lot/i', $input) || preg_match('/^lt/i', $input)) {
		// opens with "Lot" but no space, so just take first one as street num.
		if($debug == true) {
			echo 'Exception: string starts with lot but no space.<br />';
		}
		$number = "Lot ".remove_all_but_numbers($array[0]); // Clean up "Lot32" or "LT103" to "Lot 32" or Lot "103"
		foreach($array as $key => $var) {
			if($key>0) {
				$street = $street.$var.' ';
			}
		}
		$street = trim($street);
	} else if(strpos($input, '-' )) {
		// has dash,n means it's unit. separate here.
		if($debug == true) {
			echo 'Exception: Dash separates unit.<br />';
		}
		$unitsplitarray = explode('-', $input);
		$unit = $unitsplitarray[0];
		$streetsplitarray = explode(' ',trim($unitsplitarray[1]));
		foreach($streetsplitarray as $key => $streetsplitstring) {
			if($key==0) {
				$number = $streetsplitstring;
			} else $street.=' '.$streetsplitstring;
		}
	} else if(is_array($array) && is_countable($array) &&  count($array)==2 && is_numeric($array[0])) {
		// There's only 2 arrays in full street address, and the first one is a number.. Something like 123 Broadway
		if($debug == true) {
			echo 'Only two arrays, so number and street.<br />';
		}
		$number = $array[0];
		$street = $array[1];
	} else if(is_array($array) && is_countable($array) &&  count($array)==3 && is_numeric($array[0])) {
		// 3 array means number, street & type! bang on, like 3482 Main Street
		if($debug == true) {
			echo 'Three arrays and fist one is number.<br />';
		}
		$number = $array[0];
		$street = $array[1].' '.$array[2];
	} else if(is_countable($array)) {
		if($debug == true) {
			echo 'Array surfing:<br />';
		}
		// find the point of the last string that matches a street type? That's probably the street type..
		$streettypekey = false;
		$streetsuffixkey = false;

		foreach($array as $array_count=>$string) {

			$streettypetest= find_streettype($string, true);
			if ($streettypetest!=false) {
				$streettypekey = $array_count;
				$streettype = $streettypetest;
				if($debug == true) {
					echo 'Found street type at - '.$string.'.<br />';
				}
			} else if($streettypekey!==false && $array_count>$streettypekey) {
				// Not a street type string, but type has been found already.
				// This means it's a suffix such as "Kent Avenue South"
				// or it's one of those "Range Road 222" like in Rural Edmonton.
				$streetsuffixkey = $array_count;
				if($debug == true) {
					echo 'Street has suffix - '.$string.'.<br />';
				}
			}
		}

		// street type wasn't picked up within the array??
		if($streettypekey===false || $streettypekey<2) {
			$streettypekey = count($array)-1; // default to the LAST string.. have no other choice.
			if(array_key_exists($streettypekey, $array)) {
				$streettype = $array[$streettypekey]; // default to the string itself.. whatever.
			} else {
				$streettype = ''; // no street type.. perhaps something like BROADWAY?
			}
		}

		if($debug == true) {
			echo 'Street type key '.$streettypekey.' for '.$streettype.' found.<br />';
		}

		if($streettype == 'Highway') {
			// "Highway 17" type of street.
			if($debug == true) {
				echo 'Highway!<br />';
			}
			// highways can show like highway  17, so the limit should go UP one more.
			$streettypecutoff = $streettypekey;
		} else if($streetsuffixkey!==false) {
			// "Range Road 232" type of display.
			if($debug == true) {
				echo 'Suffix exists after type!<br />';
			}
			$streettypecutoff = $streettypekey+1; // push the cut off one more.
		} else {
			$streettypecutoff = ($streettypekey-1);
		}

		if($debug == true) {
			echo 'Street type cutoff:'.$streettypecutoff.'<br />';
		}

		reset($array);
		$number = '';
		$street = '';
		$numerics = ''; // start this first
		$numericsfound = 0; // numeric strings mean unit # or number, so we count this first.

		foreach($array as $array_count=>$string) {

			if( $array_count<$streettypecutoff && is_numeric($string) && $numericsfound<2 ) {
				// look for unit/number candidates. ($streettypekey - 1 = $streettypecutoff) covers up to the street name portion
				// to be excluded from being considered as number/units.
				// this is part of units or street numbers.
				$numerics.=' '.$string;
				$numericsfound++;
				if($debug == true) {
					echo 'Adding to numerics:'.$string.'<br />';
				}

			} else {
				if($streettypekey==$array_count) {
					$string = $streettype; // put in full proper street type, in case we have St. or AV etc.
				}
				$street.=' '.$string;
			}
		}

		$numerics = trim($numerics);

		if($debug == true) {
			echo 'Numerics: '.$numerics.'<br />';
			echo 'Street: '.$street.'<br />';
		}
		// now process $numerics to unit/number.

		if($numericsfound==2) {
			list($unit, $number) = explode(' ', $numerics);
		} else {
			$number = $numerics;
		}

	} else if(is_string($array)) {
		// $array isn't even an array? Must be missing both unit & street number. street name at most.
		$unit = '';
		$number = '';
		$street = $array; // feed the street as it is I guess? Could even be blank with no address.
	}

	$return = array(
		trim($unit),
		trim($number),
		ucwords(trim($street))
	);

	return $return;
}

/**
 * @param $input Should be the street portion after number or unit has been stripped out.
 * @return array
 * Returns street string split up to direction, street name, type and any suffixes (SE or SW). Not used to parse full addresses.
 * To separate unit numbers, street numbers etc., use separate_unit_number() instead.
 */
function separate_streetname($input, $debug = false) {
	global $street_dir_pairs;
	global $settings;

	$streetvars = explode(' ',trim($input)); // prepare exploded array. 
	$street_dir_key = false; // street dir not found yet. 
	$streettype_key = false; // streettype not found yet. 
	$streetsuffix_key = false; // streetsuffix not found yet. 

	$streettype = '';
	$street_dir = '';
	$street_suffix = '';

	if(count($streetvars)>1) {
		// more than 1 array, so there is a space there somewhere between the name & street type. 
		// first lets get the street suffix, if any. 
		// Such as W kent Avenue South. We need the South. 
		$lastarray = strtolower($streetvars[count($streetvars)-1]); // ONLY check last array for this.
		if(in_array($lastarray, $street_dir_pairs) || array_key_exists($lastarray, $street_dir_pairs)) {
			$street_suffix = ucwords(strtolower(trim($lastarray)));
			$streetsuffix_key = count($streetvars)-1;
			if($debug == true) {
				echo 'Suffix ('.$lastarray.') found at key '.$streetsuffix_key.'!<br />';
			}
		}

		if($streetsuffix_key!==false) {
			unset($streetvars[$streetsuffix_key]); // then remove $street_dir_key from the array so it's no longer serached upon. 
		} else {
			// no direction found, so set to blank. 
			$street_suffix = '';
		}

		// Then pick out a street direction if there is. 
		foreach($streetvars as $key=>$var) {
			if($street_dir_key==false) { // only go until a street direction is found. 
				if(in_array(strtolower(str_replace('.','',$var)), $street_dir_pairs) || array_key_exists(strtolower(str_replace('.','',$var)), $street_dir_pairs)) {
					$street_dir = trim($var);
					$street_dir_key = $key; // notate which key this was on, to remove from the used variables. 
				}
			}
		}
		if($street_dir_key!==false) {
			unset($streetvars[$street_dir_key]); // then remove $street_dir_key from the array
		} else {
			// no direction found, so set to blank. 
			$street_dir = '';
		}

		reset($streetvars); // turn array pointer back to the beginning for another loop. 
		$streetvars = array_values($streetvars);

		// now let's loop through and fetch a type.. if there's more than 1 array left.
		if(count($streetvars)>1) {
			foreach($streetvars as $key=>$var) {
				// loop thorugh the array. Since it keeps going, it will find the LAST of the array that return a reasonalbe street type. 

				if(find_streettype($var, TRUE)!==false && $key>0) {
					// we skip the FIRST array.. because if we have a street like St. Georges Cres, the ST. will be caught as Street, and fail.
					$streettype = find_streettype($var);
					$streettype_key = $key;
					if($debug == true) {
						echo 'Type ('.$var.') found at key '.$streettype_key.'!<br />';
					}
				}
			}
			if($streettype_key) {
				unset($streetvars[$streettype_key]); // then remove $street_dir_key from the array
			} else {
				// no direction found, so set to blank. 
				$streettype = '';
			}
			reset($streetvars);
			$streetvars = array_values($streetvars);
		}

		if($debug == true) {
			echo 'Streetvars remaining:<br />';
			print_r($streetvars);
		}

		// type and direction have been picked out if any, so check remaining array.
		if(count($streetvars)>0) {
			// if there's still shit left over after street type & name is picked out
			$streetname = '';
			foreach($streetvars as $key=>$var) {
				$streetname.=$var.' ';
			}
		}
	} else {
		// only ONE array returned.. so it's something like BROADWAY or another singular street name only.
		$streetname = $streetvars[0];
	}


	$streetname = ucwords(strtolower(trim($streetname))); // finally clean up the bloody street name!
	$streettype = ucwords(strtolower(trim($streettype)));

	if($debug == true) {
		echo 'Streetname: '.$streetname.'<br />';
	}

	// if the string is 2 or less such as N, or NE, then strtoupper the whole thing. if not, Capitalize.
	$street_dir = (strlen($street_dir)>2 ? ucwords(strtolower(trim($street_dir))) : strtoupper(trim($street_dir)));
	$street_suffix = (strlen($street_suffix)>2 ? ucwords(strtolower(trim($street_suffix))) : strtoupper(trim($street_suffix)));

	return array($streetname, $streettype, $street_dir, $street_suffix);
}


function find_streettype($input, $strict = false) {
	global $settings;
	// input can be anything like street, STREET, St., Drive, Way, Wy, Rd., Road.. anything. 
	// first process the variable to clean up
	$input = strtolower(trim($input));
	$input = str_replace('.','',$input); // first remove the period if any

	$street = ''; // declare blank first.
	foreach($settings['streettypes'] as $streettype=>$synonyms) {
		foreach($synonyms as $synonym) {
			if($input==$synonym) {
				// found a street type that matches (i.e. Entered was "St" -> matches to -> "Street" from our streettypes array.
				$street = $streettype;
			}
		}
	}
	if($street=='') {
		if($strict==false) {
			// nothing picked up - return original#
			$street = trim($input);
		} else {
			// return false as we think this is NOT a street type!
			$street = false;
		}
	}
	return $street;
}


function generate_street_dir_array($dir) {
	global $street_dir_pairs;
	// If W is entered, return array of 0=>w, 1=>west etc. for comparison. 
	$dir = strtolower(str_replace(' ', '', str_replace('.', '',$dir))); // clean it up first.

	if(array_key_exists($dir, $street_dir_pairs)) {
		// if array key exists, it was entered as W or N, single char. 
		$array[] = $street_dir_pairs[$dir]; // return the full string, 
		$array[] = $dir;
	} else if(in_array($dir, $street_dir_pairs)) {
		foreach($street_dir_pairs as $key => $val) {
			if($dir==$val) {
				$array[] = $key; // return the full string, 
			}
		}
		$array[] = $dir;
	} else {
		$array = false;
	}
	return $array;
}


function compare_street_dir($a, $b) {
	// Sometimes the listing will say W, whereas building will say West etc. in match-up circumstances.
	// primarily used by the groupbuildings.php CRON file when matching up addresses to buildings. 
	global $street_dir_pairs;


	$avar = strtolower(str_replace(' ', '', $a));
	$bvar = strtolower(str_replace(' ', '', $b)); // clean it up first.. this takes care of trim as well as removing spaces between "south west" => "southwest"
	if($avar==$bvar) {
		// identical strings.
		$return = true;
	} else if(array_key_exists($avar, $street_dir_pairs)) {
		// $a is the short hand one such as W, N etc. 
		if($bvar==$street_dir_pairs[$avar]) {
			$return = true;
		} else {
			$return = false;
		}
	} else if(in_array($avar, $street_dir_pairs)) {
		// $a is the longer pone. 
		if($avar==$street_dir_pairs[$bvar]) {
			$return = true;
		} else {
			$return = false;
		}
	} else {
		$return = false;
	}
	return $return;
}


function cleanup_streetname($var) {
	$array = separate_streetname($var);
	$streetname = $array[0];
	$streettype = find_streettype($array[1]);
	$cleanstreet = ucwords(trim($streetname.' '.$streettype));
	return $cleanstreet;
}


function array_flatten($array) {
	$return = array();
	foreach ($array as $key => $value) {
		if (is_array($value)){ $return = array_merge($return, array_flatten($value));}
		else {$return[$key] = $value;}
	}
	return $return;
}


function limit_string_at_space($string, $max, $trail='') {
	$string = strip_tags($string);
	if(strlen($string)>$max) {
		$string = substr($string,0,$max);
		$last = strrpos($string,' ');
		$string = substr($string,0,$last);
		$string = $string.$trail;
	}
	return $string;
}

function remove_empty_vars($array) {
	// only works with arrays. 
	$outputarray = array();
	if(is_array($array)) {
		foreach($array as $key=>$var) {
			if($var!='' || $var===false || $var===true) { // if it's not blank, or an explicit false or true, keep it!
				$outputarray[$key] = $var;
			}
		}
	} else {
		$outputarray = false;
	}
	return $outputarray;
}

function shorten_display($string, $max, $hellip = true) {
	// used for google description mock display etc. to limit # of characters. 
	// there is javascript equivalent of this function. 
	return (strlen($string)>$max ? substr($string, 0, ($hellip ? $max-3: $max)  ).($hellip ? '&hellip;' : '') : $string);
}

function remove_all_but_numbers($input) {
	if(is_string($input) && $input!='') {
		$return = preg_replace("/[^0-9\. ]/", "", trim($input));
		if($return!=='') {
			$return = intval($return);
		} else {
			$return = '';
		}
	} else if(is_integer($input) || is_numeric($input)) {
		$return = intval($input);
	} else {
		$return = '';
	}
	return $return;
}


function dollar_amount_display($value, $summarize = false, $decimals = 2, $point = '.', $separator = ',', $symbol = '$', $symbolposition = 'before') {
	// assumes that $value is purely numbers!
	// $symbolposition is before or after for multiple currencies!
	if(!is_numeric($value)) {
		$value = remove_all_but_numbers($value);
		if($value == 0) {
			// if removing resulted in 0, that means it was a empty string, so blast it back to 0.
			// this way, intentional 0 passed will still return a $0.
			$value = '';
		}
	}

	if($value=='') {
		// sometimes the price is blank, especially running MLS RETS. number_format used to gracefully ignore these, but php8 gives a fatal error.
		$return = ''; // return blank as it is. !
	} else {
		if($summarize == true && $value > 10000) {
			// 1,455,000 to M denominations, 750,000 to k deonomiations etc.

			if($value>=1000000000000) {
				// over a Trillion.
				$divider = 1000000000000;
				$suffix = 'T';
			} else if($value>=1000000000) {
				// over a Billion.
				$divider = 1000000000;
				$suffix = 'B';
			} else if($value>=1000000) {
				// over a Million.
				$divider = 1000000;
				$suffix = 'M';
			} else {
				// Up to 999k.
				$divider = 1000;
				$suffix = 'K';
			}

			$processednumber = number_format($value/$divider, $decimals, $point, $separator);
			// when summarizing, just remove all decimals or pennies at the end.
			$processednumber = preg_replace ('/\.00$/' , '', $processednumber);

		} else {
			if ($summarize == true){
				$final_decimals = 0;
			}else{
				$final_decimals = $decimals;
			}
			$rawnumber = preg_replace('~\.0+$~','',number_format($value, $final_decimals, $point, $separator));
			$processednumber = $rawnumber; // use as it is.
		}

		$return = ($symbolposition=='before' ? $symbol : '').$processednumber.(isset($suffix) && $suffix!='' ? $suffix : '').($symbolposition=='after' ? $symbol : '');


	}
	return $return;
}

function key_get_parents($subject, $array) {
	// return the parents of an array, all the way to top, based on the value. 
	foreach ($array as $key => $value) {
		if (is_array($value)) {
			if (in_array($subject, array_keys($value))) {
				return array($key);
			} else {
				$chain = key_get_parents($subject, $value);
				if (!is_null($chain)) {
					return array_merge(array($key), $chain);
				}
			}
		}
	}
	return null;
}



function to_rand_ascii($chr) {
	// convets characters to ascii code for obfuscation purposes. 
	// chiefly used by the mungemail() function
	switch (mt_rand(1, 3)) {
		case 1:
			return "&#" . ord($chr) . ";";
			break;
		case 2:
			return "&#000" . ord($chr) . ";";
			break;
		default:
			return "&#x" . dechex(ord($chr)) . ";";
	}
}

/**
 * More useful than is_float(), because sometimes when breaking down lat/lng from input strings default as string, not numeric
 * And using the *1 on value is an unreliable way to verify validity of the decimal as it may force-remove alphabets or symbols etc.
 * @param $input
 * @return bool
 */
function is_decimal($input) {
	$result = preg_match('/^-?(?:\d+|\d*\.\d+)$/', $input);
	return ($result==1 ? true : false);
}

/**
 * Checks if input string is a valid URL or not.
 * @param $url
 * @return bool true or false
 */
function is_url($url) {
	if (filter_var($url, FILTER_VALIDATE_URL)) {
		return true;
	} else {
		return false;
	}
}

function is_email_format($input) {
	return filter_var($input, FILTER_VALIDATE_EMAIL); // boolean true or false.
}

/**
 * @param $input
 * Trims email up to @ and returns the portion before.
 */
function extract_email_username($input) {
	if(is_email_format($input)) {
		$return = substr($input, 0, strpos($input, '@'));
	} else {
		$return = false;
	}
	return $return;
}


/**
 * @param $string
 * @return string
 */
function url_format($string) {
	// converts spaces to dashes, and removes all non-alphanumeric items.
	$string = preg_replace('/\s+/', '-' , trim($string));
	$string = preg_replace('/[^a-zA-Z0-9-_]/', '', $string);
	$string = str_ireplace('---', '-' , $string);
	$string = str_ireplace('--', '-' , $string);
	return $string;
}

function mungemail($str_email, $str_display = '', $link = true, $text = true, $class = false) {
	//obfuscates email to ascii code format so it's hard for robots to scrape emails!

	if(is_array($str_email)) {
		$first = $str_email[0];
		$str_email = $first;
	}

	$return = '
	
	<script type="text/javascript">
	';

	if ($link) {
		$return .= 'document.write("<a href=\"&#x6d;&#00097;&#000105;&#x6c;&#x74;&#x6f;&#x3a;");
		'; // the <a href="mailto: portion.
		$return .= 'document.write("';
		for ($i = 0; $i < strlen($str_email); $i++) {
			$return .= to_rand_ascii(substr($str_email, $i)); // the email!
		}
		$return .= '\"");
		'; // wraps up the href="" attribute by closing the ".

		if($class!=false) {
			$return .= 'document.write("';
			$return .= ' class=\"';
			for ($i = 0; $i < strlen($class); $i++) {
				$return .= to_rand_ascii(substr($class, $i)); // the css class!
			}
			$return .= '\"'; // close the class attribute.
			$return .= '");
		'; // finishes the class display in ascii
		}



		$return .= 'document.write(">'; // wraps up the opening <a href=""> tag.
	} else {
		$return .= 'document.write("';
	}


	if($str_display!='') {
		$tag_stripped = strip_tags($str_display); // see if string contains tags!
		if($tag_stripped==$str_display) {
			// no tags, so it must have been some email entry or raw text only.
			for ($i = 0; $i < strlen($str_display); $i++) {
				$return .= to_rand_ascii(substr($str_display, $i)); // the email!
			}
		} else {
			// display as it is, since it's probably an img tag.
			$return .= addslashes($str_display);
		}
	} else {
		// no string passed, just email address shoudl be displayed.
		for ($i = 0; $i < strlen($str_email); $i++) {
			$return .= to_rand_ascii(substr($str_email, $i)); // the email!
		}
	}

	//************************************************************************************
	//remember to close the A tag manually if displaying just the link or just the text!!!
	//************************************************************************************
	if ($link) {
		$return .= '</a>");
		';// wrap up the email display then closing </a>
	} else {
		$return .= '");';
	}

	$return.='</script>';
	return $return;
}

function tiktok_url($input) {
	if(is_url($input) && strpos($input,'tiktok.com')!=false) {
		// most likely, client entered the URL.
		$return = $input;
	} else if(is_alphanumeric($input)) {
		$return = 'https://www.tiktok.com/@'.$input;
	}
	return $return;
}

/**
 * Opposite of the tiktok_url function - it extracts just the URL from a Tiktok URL.
 * @param $url
 * @return void
 */
function tiktok_get_username($url) {
	if(is_url($url) && strpos($url,'tiktok.com')!=false) {
		$pattern = '/tiktok\.com\/@([^\/]+)(\/|$)/';
		if (preg_match($pattern, $url, $matches)) {
			$username = $matches[1];
		} else {
			$username = false; // Or any other error handling
		}
	} else if(strpos($url, '@')===0) {
		// if it starts with @ then strip it.
		$username = substr($url, 1, strlen($url)-1);
	} else if($url!='' && is_alphanumeric($url)) {
		$username = $url; // assume they just entered a username?
	}
	return $username;
}

function instagram_url($input) {
	if(is_url($input) && strpos($input,'instagram.com')!=false) {
		// most likely, client entered the URL including http.
		$return = $input;
	} else if($input!='' && is_alphanumeric($input)) {
		// just entered the instagtram handle such as ali.khashayar, so turn it into https://instagram.com/alikhashayar
		$return = 'https://www.instagram.com/'.$input;
	}
	return $return;
}


/**
 * EXTRACT INSTAGRAM USERNAME FROM INSTAGRAM URL
 *
 * @param $options          Array Options: instagram link url & fallback name
 * @return mixed|string     Return Username String
 */
function instagram_username(array $options = array()) {
	global $settings;

	$instagram_link = $options['instagram_link'] ?: $settings['instagram'];
	$fallback_name = $options['fallback_name'] ?: $settings['owner'][0];

	// separate the "instagram.com/" and "username" into two keys in an array.
	preg_match('=instagram.com/\s*([^/]*)=u', $instagram_link, $matches);
	return $matches[1] ?: $fallback_name;
}

function twitter_url($input) {
	if(is_url($input) && strpos($input,'twitter.com')!=false) {
		// most likely, client entered the URL including http.
		$return = $input;
	} else if(is_alphanumeric($input)) {
		// just entered the instagtram handle such as ali.khashayar, so turn it into https://instagram.com/alikhashayar
		$return = 'https://twitter.com/'.$input;
	}
	return $return;
}

/* ######################################################
#brix_04
MySQL Data insert, update, manipulation classes.  

###################################################### */
function close_mysql() {
	// universal function to close MySQL connections
	// ensure this is at footer of all pages, as well as ajax call PHP files. otehrwise perpetual connections linger, taking up space & memroy. 
	global $db;
	global $mysqli;

	if(is_resource($db) && function_exists('mysql_close')) {
		mysql_close($db);
	}
	$mysqli->close();
}

/**
 * Gets value of single cell in a table. Not really encouraged to use.
 * City/areas are cached, so are pages. Home & building objects return all data in a rich query that returns array & object. 1
 * @param $table
 * @param $field
 * @param $idr
 * @return false|mixed
 *
 */
function gettablefield($table,$field,$idr) {
	global $mysqli;
	if(!is_null($idr) &&
			(
			(is_string($idr) && $idr!='') ||
			(is_numeric($idr) && $idr>=0)
			)
		)
		{
		if($table=='pages' && is_array($GLOBALS[BRIX_PAGES_CACHE])) {
			$return = $GLOBALS[BRIX_PAGES_CACHE][$idr][$field];
		} else if($table=='areas' && is_array($GLOBALS[BRIX_AREAS_CACHE])) {
			$return = $GLOBALS[BRIX_AREAS_CACHE][$idr][$field];
		} else if($table=='subareas' && is_array($GLOBALS[BRIX_SUBAREAS_CACHE])) {
			$return = $GLOBALS[BRIX_SUBAREAS_CACHE][$idr][$field];
		} else if(!is_null($table) && (is_string($table) && $table!='')) {
			$sql = "SELECT `".$mysqli->real_escape_string($field)."` FROM `".$mysqli->real_escape_string($table)."` WHERE id='".$mysqli->real_escape_string($idr)."'";
			$result = $mysqli->query($sql);
			$GLOBALS[BRIX_PAGES_QUERY]++;
			if($result->num_rows>0) {
				$row = $result->fetch_assoc();
				/*
						print_r($row);
						echo '<br />';
						echo $row[$field].' was result from the '.$table.' table, field '.$field.'<br />';
				*/
				$return = $row[$field];
			} else {
				$return = false;
			}
		} else {
			$return = false;
		}
	} else {
		$return = "ID Cannot be blank for this function! ERROR!";
	}
	return $return;
}

// TODO: remove? hardly useful, as we have all objects returning properly.
function gettablerows($table,$arguments='') {
	global $mysqli;
	$sql = "SELECT * FROM `".$mysqli->real_escape_string($table)."` ".$arguments;
	$result = $mysqli->query($sql);
	return $result->num_rows;
}

/**
 * Gets the last specififed column (most likeky, unique ID or primary key) based on order sequence.
 * @param $table
 * @param $field
 * @param $maxormin
 * @param string $matchfield
 * @param string $match
 * @return mixed
 */
function getendfield($table, $field, $maxormin, $matchfield='',$match='') {
	global $mysqli;
	$sql = 'SELECT '.$maxormin.'(`'.$field.'`) AS `endfield`, `id` FROM `'.$table.'`';
	if($matchfield!='' && $match!='') {
		$sql .= " WHERE `".$matchfield."`='".$match."'";
	}
	$result = $mysqli->query($sql);
	$max = $result->fetch_assoc();
	return $max['endfield'];
}

function get_page_endfield($table,$field,$parent,$maxormin,$matchfield='',$match='') {
	global $mysqli;
	// same as getendfield() but for pages, so that we group them by pages that have the same hierarchy level.
	if($parent!='') {
		$sql = 'SELECT '.$maxormin.'('.$table.'.'.$field.') AS endfield, pages.id FROM `'.$table.'` LEFT JOIN hierarchy ON pages.id=hierarchy.page WHERE hierarchy.parent="'.$parent.'"';
	} else {
		$sql = 'SELECT '.$maxormin.'(p.'.$field.') AS endfield, p.id as id FROM `'.$table.'` p WHERE id NOT IN
		(
		SELECT  page as id
		FROM    hierarchy h
		WHERE h.id!=""
		)';
	}
	if($matchfield!='' && $match!='')
	{
		$sql .= " AND ".$matchfield."='".$match."'";
	}

	$result = $mysqli->query($sql);
	$max = $result->fetch_assoc();
	return $max['endfield'];
}


function latlng_to_point_string($latlng, $separator = ' ') {
	$point = ''; // declare as string.
	if(is_string($latlng) ) {
		// make sure to set to array so we know there's at least 2 vars, even though this seems redundant to explode then rejoin.
		$latlng = explode($separator, trim(str_ireplace(array(',', ';'), $separator, $latlng))); // replace , with space for proper polygon shape.
	}

	// by now it should be in array, and at least 2 vars (we can ignore extra trailing stuff if there was extra spaces or whatever by mistkae.
	if(is_array($latlng) && count($latlng)>1) {
		if(is_decimal($latlng[0])===true && is_decimal($latlng[1])===true) {
			$point = trim($latlng[1]) . $separator . trim($latlng[0]);
		} else {
			// we didn't have solid values on both.
			$point = false;
		}
	} else {
		$point = false; // invalid set.
	}

	return $point;
}


function polygon_to_mysql($polygon) {
	// SELECT * FROM users WHERE Intersects( GeomFromText( 'POINT(50 50)' ), GeomFromText( 'POLYGON(0 0, 100 0, 100 100, 0 100, 0 0)' ) );
	// POINT will be derived from each building/home, so we ionly need to process the POLYGON portion?
	if(isJson($polygon)) {
		// if it's array, the best!!!
		$polygon_array = json_decode($polygon);
	} else if(is_string($polygon)) {
		/*
		 * Often peopel enter:
		 * 49.26864,-123.09959
			49.26877,-123.10663
			49.26878,-123.10942
			49.26616,-123.11495
		*/
		$polygon = nl2br($polygon);
		$splits = array(';', '<br />','|'); // cannot use , as they often split lat/lng.

		$separator = '?'; // use ? as splitter between points as its least commont.
		$polygon = str_ireplace($splits, $separator, $polygon);
		$polygon_array = explode($separator, $polygon); // separate by commma. this is the only accepeted.
	} else if(is_array($polygon)) {
		$polygon_array = $polygon; // use as it is.
	}

	// at this point each array should be a lat & long pair.
	// and better have at least 3 points to be a polygon.
	if(is_array($polygon_array) && count($polygon_array)>2) {
		$sql = "ST_GeomFromText('POLYGON((";
		$firstpoint = ''; // declare empty var.
		foreach($polygon_array as $count => $corner) {

			$point = latlng_to_point_string($corner, ' ');

			if($count==0) {
				$firstpoint = $point;
			}

			if($point!==false) {
				$sql .=($count>0 ? ',' : '').$point;
			}
		}

		// compare last point and first, and close if we need to.
		if($point!==$firstpoint) {
			$sql .=','.$firstpoint;
		}

		$sql .= "))')"; // closes POLYGON first, then ST_GEOFROM..
	} else {
		$sql = false; // invalid array/polygon set.
	}

	return $sql;
}


function insert_to_table($table,$arguments) {
	global $settings;
	global $local; // raw timestampm of NOW.
	global $today;
	global $now; // timestamp turned into YYYY-MM-DD HH:MM:SS format.
	global $mysqli;
	global $filename;
	$tablequery = $mysqli->query("SHOW COLUMNS FROM ".$table);
	$i=0;

	while($tablefields = $tablequery->fetch_assoc()) {
		$tablefield[$i]=$tablefields['Field'];
		$i++;
	}

	// add timestamp array forced in if not already set
	if(!array_key_exists('timestamp', $arguments)) {
		$arguments['timestamp'] = $local;
	}

	// figure out soruce file, fall back to default if not input.
	$arguments['phpfile'] = ($filename!='' ? $filename : $_SERVER["SCRIPT_FILENAME"]);

	foreach($arguments as $field=>$var) {
		$intable = 0;
		foreach($tablefield as $value) {
			if($value==$field) {
				$intable=1;
			}
		}

		if($intable==1) {// if the intable var is turned on that means that the field entered in this array of $arguments IS inthe table, hence part of the INSERT query.
			$insertvars[$field]=$var;
		}
	}
	// now we have the argument filtered down to fields that DO go into the table. Let's start building the query. 
	$sqlhead = "INSERT INTO `".$mysqli->real_escape_string($table)."` (";
	$sqlmiddle = ") VALUES (";
	$sqlend = ")";

	$count = 0;
	$sqlfields = "";
	$sqlvars = "";
	foreach($insertvars as $key=>$rawvalue) {
		if($count>0) {
			$sqlfields .=",";
			$sqlvars .= ",";
		}

		if($rawvalue===NULL) {
			// some values should be NULL, not default to 0 etc. for clarity.
			$value = 'null';
		} else {
			// regular values, so clean up and also put within single quotation marks.
			$value = "'".cleanupforentry($rawvalue)."'";
		}

		$sqlfields .= '`'.$key.'`';
		$sqlvars .= $value;
		$count++;
	}


	$sql = $sqlhead.$sqlfields.$sqlmiddle.$sqlvars.$sqlend;
	if($mysqli->query($sql)) {
		return $mysqli->insert_id;
	} else {
		$message .= "SQL Attempted: ".$sql;
		$message .= PHP_EOL.PHP_EOL;
		$message .= ".Error Message: ".$mysqli->error;
		$message .= PHP_EOL.PHP_EOL;
		$message .= print_r($arguments,TRUE);
		$message .="Attempted to put into table ".$table." with id ".$id.", ".$mysqli->affected_rows." inserted.";
		$message .= PHP_EOL.PHP_EOL;
		return $message;
	}
}

function update_to_table($table,$arguments,$id) {
	global $settings;
	global $today;
	global $now;
	global $year;
	global $mysqli;

	$tablequery = $mysqli->query("SHOW COLUMNS FROM ".$table);
	$i=0;

	while($tablefields = $tablequery->fetch_assoc()) {
		$tablefield[$i]=$tablefields['Field'];
		$i++;
	}

	foreach($arguments as $field=>$var) {
		$intable = 0;
		foreach($tablefield as $value) {
			if($value==$field) {
				$intable=1;
			}
		}

		if($intable==1) {// if the intable var is turned on that means that the field entered in this array of $arguments IS inthe table, hence part of the INSERT query.
			$insertvars[$field]=$var;
		}
	}

	// now we have the argument filtered down to fields that DO go into the table. Let's start building the query. 

	$sqlhead = "UPDATE `".$mysqli->real_escape_string($table)."` SET ";
	$sqlmiddle = "  ";
	$sqlend = " WHERE id=".$id;

	$count = 0;
	$sqlfields = "";
	$sqlvars = "";
	foreach($insertvars as $key=>$rawvalue) {
		if($count>0) {
			$sqlfields .=",";
		}

		// set the value that needs to go in.
		if($rawvalue===NULL) {
			// some values should be NULL, not default to 0 etc. for clarity.
			$value = 'null';
		} else {
			// regular values, so clean up and also put within single quotation marks.
			$value = "'".cleanupforentry($rawvalue)."'";
		}
		$sqlfields .= '`'.$key."`=".$value;
		$count++;
	}

	$sql = $sqlhead.$sqlfields.$sqlmiddle.$sqlvars.$sqlend;
	if($mysqli->query($sql)) {
		return $id;
	} else {
		return false;
	}
}

function form_to_table($table,$arguments,$id="") {
	if(isset($id) && $id!==false && $id != "") {
		$result = update_to_table($table,$arguments,$id);
	} else {
		$result = insert_to_table($table,$arguments);
	}
	return $result;
}


function delete_from_table($table,$id) {
	global $mysqli;
	$sql = "DELETE FROM `".$mysqli->real_escape_string($table)."` WHERE `id`='".$mysqli->real_escape_string($id)."'";
	$result = $mysqli->query($sql);
	return $mysqli->affected_rows;
}


function sql_query($sql) {
	// do we even use this??
	// it's meant to log sql queries that happen for troubleshooting instead of running it directly.
	global $now;
	global $mysqli;
	$mysqli->query("INSERT INTO queries (`sql`,`ip`,`page`,`timestamp`) VALUES ('".$mysqli->real_escape_string($sql)."','".$_SERVER['REMOTE_ADDR']."','".$_SERVER['REQUEST_URI']."','".$now."')"); // log this query!
	$mysqli->query($sql);
	return $mysqli->insert_id;
}


function log_object_view($type, $object_id) {
	// run this via AJAX if possible?
	// also if we run this based on at least being loaded for 1 second,
	// we can avoid excessive logs from crawlers or people hitting refresh a couple times on hard refresh etc.

	global $today;
	global $mysqli;

	switch($type) {
		case "page":
			break;

		case "home":
			break;

		case "building":
			break;

		default:
			$type = false;
	}

	$object_id = remove_all_but_numbers($object_id);

	if($type==false || $type=='' || !is_numeric($object_id)) {
		// can only allow page, building or home only.
		// and ID needs to be integer.
		// this also removes need to do a escape_string type of clean up against injection.
		$return = false;

	} else {
		$args = array();
		$args['object_id'] = $object_id;
		$args['type'] = $type;
		$args['date'] = $today;
		// see if there's an existing row from today already.
		$sql = "SELECT `id`, `count` FROM `views` WHERE `type`='".$args['type']."' AND `date`='".$args['date']."' AND `object_id`='".$args['object_id']."'";
		$result = $mysqli->query($sql);
		if($result->num_rows>0) {
			$array = $result->fetch_assoc();
			$idr = $array['id'];
			$rawcount = remove_all_but_numbers($array['count']);
			$args['count'] = ($rawcount) + 1;
		} else {
			$idr = false;
			$args['count'] = 1;
		}
		$return = form_to_table('views',$args, $idr);

	}

	return $return;
}



/* ######################################################
#brix_05
Homes & buildings, MLS search stuff fetching, processing mechanisms.
###################################################### */


function parse_pagevars($baseurl = '', $requesturi='') {
	// turns all info under the URL after the PHP file into paired arrays. 
	// /page-5/type-2 turns into and array consisting of
	// page=>5
	// type=>2

	/*
	 *
	 * city-Vancouver+West/type-Condo/bedroom-2/available_date-2022-10-04/page-1/varname-value
	 *
	 * This becomes
	 * $params['city'] => Vancouver,
	 * $params['available_date'] => 2022-10-05
	 *
	 *
	 */

	global $settings;
	global $filename;
	// when a manual baseURL is given, this is excluded from the "parameters" of hte page. 
	if($baseurl=='') {
		// when baseurl is not given, use the php script name such as listings or listings.php
		if($filename!='') {
			$baseurl = str_ireplace('.php','',$filename); // from filename called from the template file, replace it.
		} else {
			$baseurl = str_replace('.php','',$_SERVER['SCRIPT_NAME']);
		}
	} else {
		// baseurl is given - if domain is part of it, remove it.
		$baseurl = str_replace($settings['sitepath'], '', $baseurl);
	}

	if($requesturi=='') {
		// first, fetch everything after the [domain].com/ portion.
		$requesturi = $_SERVER['REQUEST_URI'];
	}



	if($settings['rootpath']!='/') {
		// remove root URL to exclude.. in case the site is running inside another folder on domain. 
		$string = str_replace($settings['rootpath'],'',$requesturi);
	} else {
		$string = $requesturi;
	}
	if(preg_match('/^\//', $string)) {
		// if it starts with / then strip it before we remove the $baseurl. 
		$string = substr($string, 1, strlen($string)-1);
	}

	$baseurl = str_replace ('/', '\/', $baseurl);
	$string = preg_replace('/^'.$baseurl.'/', '', $string); // remove the $baseurl (most often 'listings') from beginning of string.

	// remove the GET variables if any.. denoted by ? 
	$qpos = strpos($string, '?');
	if($qpos!==false) {
		$string = substr($string, 0, $qpos); // strip everything after ? from the processing queue. 
	}


	if(strlen($string)>1) {
		$params = explode('/',$string);
		// From a URI such as "city-Vancouver+West/min_bedroom-2", it splits at the /
		// Each $param var looks like "city-Vancouver+west".
		$vars = array(); // declare empty first.
		foreach($params as $paramcount => $pair) {
			if($pair != '' && is_numeric($pair)  && $paramcount <2) {
				// Only a number was passed, no - nor prefixes.
				// MOst likely page ID.. i.e. /featured-bulidings/92/vancouver-west-presale-buildings
				// feed as $params['pageid'] = 92.
				$vars['pageid'] = $pair;
			} else {
				if(strpos($pair, '-')!==false) {
					$value = explode('-',$pair,2);
					// Then break it by "-",
					// $value looks like this: array([0]=>'city', [1] => 'Vancouver+West')
					unset($array);
					$value[1] = str_ireplace('%3b', ';', $value[1]);
					$value[1] = str_ireplace('%2b', ' ', $value[1]);
					if($value[0]!='') {
						if(strpos($value[1],';')) {
							// this is an array
							$arrayvar = explode(';',$value[1]);
							foreach($arrayvar as $val) {
								$array[] = str_replace('|', '/', urldecode($val));
							}
							$vars[$value[0]] = $array;
						} else {
							$vars[$value[0]] = str_replace('|', '/', urldecode($value[1]));
						}
					}
				} else if(is_string($pair) && $pair!='') {
					$vars[$pair] = ''; // blank value, such as just /sold/ or /rental/
				}
			}

		}
		return $vars;
	} else {
		return false;
	}
}

function get_listing_search_url($params) {
	global $settings;
	include $_SERVER['DOCUMENT_ROOT'].'/includes/msg.inc';
	include $_SERVER['DOCUMENT_ROOT'].'/includes/dropdown.inc';
	/*
	 *
	 * VARS passed:
	 * listing_search_city=Vancouver+West     city
		listing_search_subarea[]=Kitsilano     area
		listing_search_subarea[]=Point+Grey     area
		listing_search_subarea[]=Shaughnessy     area
		listing_search_street=East Kent Avenue South street
		listing_search_street_dir = East
		listing_search_street_name = Kent
		listing_search_street_type = Avenue
		listing_search_street_suffix = South
		listing_search_type=Townhome     type
		listing_search_min_bedrooms=3     bedroom
		listing_search_openhouse     do not need value, if it's passed it will trigger
		listing_search_year   =1980
		listing_search_min_bathrooms=2     bathroom
		listing_search_min_sqft=1250     min_sqft
		listing_search_max_sqft=1500     max_sqft
		listing_search_min_price=1250000     min_price
		listing_search_max_price=1500000     max_price

		Commercial stuff:
		listing_search_commercial = commercial (if it's in the URL, such as /listings/commercial/City-XXX/page-2
	    listing_search_available_date = XXXX-XX-XX format.

		listing_bldg=5948
		listing_building=The Marquise Lodge

		listing_search_pets=yes or no
		listing_search_furnished = yes or no

		listing_search_features = array of waterfront, gateed, etc. (Vancouver MLS only)

		listing_order_by
		listing_order_direction


		listing_custom_filename defaults to listings
	 *
	 */
	$code = 0; // code 0 by default

	// for sake of good looking breadcrumbs, major type such as "commerical" or can come first. /listings/commercial/city-Abbotsford/type-Retail
	if(isset($params['listing_search_commercial'])) {
		$query['commercial'] = true; // /listings/commercial/ (nothing needed)
	}

	// first convert the $params array, by key, to a $param var,
	if($params['listing_search_city']!='') {
		$query['city'] = $params['listing_search_city'];
	} else if($params['city']!='') {
		// in case we are using existing $query to generate variant URLs.
		$query['city'] = $params['city'];
	}

	if($params['street']!='') {
		$query['street'] = $params['street'];
	}

	if($params['listing_search_street_dir']!='') {
		$query['street_dir'] = $params['listing_search_street_dir'];
	} else if($params['street_dir']!='') {
		$query['street_dir'] = $params['street_dir'];
	}

	if($params['listing_search_street_name']!='') {
		$query['street_name'] = $params['listing_search_street_name'];
	} else if($params['street_name']!='') {
		$query['street_name'] = $params['street_name'];
	}

	if($params['listing_search_street_type']!='') {
		$query['street_type'] = $params['listing_search_street_type'];
	} else if($params['street_type']!='') {
		$query['street_type'] = $params['street_type'];
	}

	if($params['listing_search_street_suffix']!='') {
		$query['street_suffix'] = $params['listing_search_street_suffix'];
	} else if($params['street_suffix']!='') {
		$query['street_suffix'] = $params['street_suffix'];
	}

	if($params['listing_search_subarea'][0]!='') {
		$query['area'] = $params['listing_search_subarea'];
	} else if($params['area']!='') {
		$query['area'] = $params['area'];
	}

	if($params['listing_search_type']!='') {
		$query['type'] = $params['listing_search_type'];
	} else if($params['type']!='') {
		$query['type'] = $params['type'];
	}

	if($params['listing_search_openhouse']!='') {
		$query['openhouse'] = 1;
	} else if($params['openhouse']!='') {
		$query['openhouse'] = $params['openhouse'];
	}

	if($params['listing_search_year']!='') {
		$query['min_year'] = $params['listing_search_year'];
	} else if($params['min_year']!='') {
		$query['min_year'] = $params['min_year'];
	}

	// 1 means for rent/lease, 0 means not.. so for sale.
	if($params['listing_search_rental']) {
		$query['for_rent'] = $params['listing_search_rental'];
	} else if($params['for_rent']!='') {
		$query['for_rent'] = $params['for_rent'];
	} else if($params['rent']!='') {
		$query['for_rent'] = $params['for_rent'];
	}

	if($params['listing_bldg']!='') {
		$query['bldg'] = $params['listing_bldg'];
	} else if($params['bldg']!='') {
		$query['bldg'] = $params['bldg'];
	}

	// do we even use this? TODO: See if we can kill it.
	if($params['office_listings']!='' || array_key_exists('office_listings',$params)) {
		$query['office_listings'] = $params['office_listings'];
	}

	// other features
	if($params['listing_search_min_bedrooms']!='') {
		$query['min_bedroom'] = $params['listing_search_min_bedrooms'];
	} else if($params['min_bedroom']!='') {
		$query['min_bedroom'] = $params['min_bedroom'];
	}

	if($params['listing_search_min_bathrooms']!='') {
		$query['min_bathroom'] = $params['listing_search_min_bathrooms'];
	} else if($params['min_bathroom']!='') {
		$query['min_bathroom'] = $params['min_bathroom'];
	}

	if($params['listing_search_bedrooms']!='') {
		$query['bedroom'] = $params['listing_search_bedrooms'];
	} else if($params['bedroom']!='') {
		$query['bedroom'] = $params['bedroom'];
	}

	if($params['listing_search_bathrooms']!='') {
		$query['bathroom'] = $params['listing_search_bathrooms'];
	} else if($params['bathroom']!='') {
		$query['bathroom'] = $params['bathroom'];
	}

	if($params['listing_search_min_sqft']!='' && $params['listing_search_min_sqft']!='0') {
		$query['min_sqft'] = $params['listing_search_min_sqft'];
	} else if($params['min_sqft']!='') {
		$query['min_sqft'] = $params['min_sqft'];
	}

	if($params['listing_search_max_sqft']!='' && $params['listing_search_max_sqft']!='0') {
		$query['max_sqft'] = $params['listing_search_max_sqft'];
	} else if($params['max_sqft']!='') {
		$query['max_sqft'] = $params['max_sqft'];
	}

	if($params['listing_search_min_price']!='' && $params['listing_search_min_price']!='0') {
		$query['min_price'] = $params['listing_search_min_price'];
	} else if($params['min_price']!='') {
		$query['min_price'] = $params['min_price'];
	}

	if($params['listing_search_max_price']!='' && $params['listing_search_max_price']!='0') {
		$query['max_price'] = $params['listing_search_max_price'];
	} else if($params['max_price']!='') {
		$query['max_price'] = $params['max_price'];
	}

	if($params['listing_search_available_date']!='' && $params['listing_search_available_date']!='0') {
		$query['available_date'] = $params['listing_search_available_date']; // /listings/available_date-XXXX-XX-XX
	}


	// features to convert to separate queries.
	if(is_array($params['listing_search_features']) && count($params['listing_search_features'])>0) {
		foreach($params['listing_search_features'] as $queryfeature) {
			if(in_array($queryfeature, $settings['home_features'])) {
				$query[$queryfeature] = ''; // no value needed, just use /waterfront/page-1 etc. format like for_rent or rent params.
			}

		}
	}


	// rental specific items
	if($params['listing_search_pets']!='') {
		$query['pets'] = $params['listing_search_pets'];
	} else if ($params['pets']!='') {
		$query['pets'] = $params['pets'];
	}

	if($params['listing_search_furnished']!='') {
		$query['furnished'] = $params['listing_search_furnished'];
	} else if ($params['furnished']!='') {
		$query['furnished'] = $params['furnished'];
	}

	if((($params['listing_order_by']!='create_date' && $params['listing_order_by']!='') || $params['listing_order_direction']!='DESC') && $params['listing_order_by']!='') {
		// skip all defaults create_date DESC.
		$query['order_by'] = $params['listing_order_by'];
		$query['order_direction'] = $params['listing_order_direction'];
	} else if ((($params['order_by']!='create_date' && $params['order_by']!='') || $params['order_direction']!='DESC') && $params['order_by']!='') {
		$query['order_by'] = $params['order_by'];
		$query['order_direction'] = $params['order_direction'];
	}

	if($params['keyword']!='') {
		$query['keyword'] = $params['keyword'];
	}

	if($params['oldhome']!='') {
		$query['oldhome'] = $params['oldhome'];
	}

	$query['page'] = 1; // new saerches always go to page 1 again. In-page nav is available within the results, in $pagelinkshtml.

	$url = $settings['sitepath'].($params['listing_custom_filename']!='' ? $params['listing_custom_filename'] :'listings');
	foreach($query as $key=>$value) {
		$url .= '/'.$key;
		if(is_array($value)) {
			$arraycount = 0;
			$url .= '-';
			foreach($value as $arrayvar) {
				if($arraycount>0) {
					$url .= ';';
				}
				$url .= urlencode(str_replace('/','|',$arrayvar));
				$arraycount++;
			}
		} else if(!is_bool($value) && strlen($value)>0) {
			$url.='-'.urlencode(str_replace('/','|',$value));
		}
	}

	$code = 1;

	// and then we run it through the param_to_query function to filter it out.
	$json_array = array('listingurl'=>$url, 'code' => $code, 'message'=>$message);
	return $json_array; // keep it PHP for now in case we use it within PHP.
}


/**
 *
 * This function builds the search URLs that allow filteration of buildings, much similar to get_listing_search_url()
 * Any sub links within a building/prsale page must use this function to build further links, not wing it with custom PHP.
 *
 * @param $params
 * @return array
 *
 *
 */
function get_building_search_url($params) {
	global $settings;
	/*
	 *
	 * VARS passed:
	 * building_search_city=Vancouver+West     city
		building_search_subarea[]=Kitsilano     area
		building_search_subarea[]=Point+Grey
		can be an array.

		building_search_street=East Kent Avenue South street
		building_search_street_name = Nelson, 114th etc.
		building_search_street_type = Street, Ave, Blvd. etc.
		building_search_street_suffix = SW etc.

	building_search_status = Active, Presale etc.

		building_search_pets=Yes,1, true(boolean) etc. -
		building_search_rental=Yes,1, true(boolean) etc. -
		building_search_short_term_rental=Yes,1, true(boolean) etc. -

		building_search_air_conditioning=Yes,1, true(boolean) etc. -
		building_search_ev_charging=Yes,1, true(boolean) etc. -

		building_order_by
		building_order_direction

		building_custom_filename DOES NOT DEFAULT. Will return an error, unlike get_listing_search_url() - be EXPLICIT!!


	 *
	 */
	$code = 0; // code 0 by default

	if($params['building_custom_filename']=='') {
		$message = "MUST Have file base set (building_custom_filename array key!";
		$listingurl = '';
	} else {
		// file name as the basis is set, move onto complete.
		// first convert the $params array, by key, to a $param var,
		if($params['building_search_city']!='') {
			$urlparam['city'] = $params['building_search_city'];
		} else if($params['city']!='') {
			// in case we are using existing $urlparam to generate variant URLs.
			$urlparam['city'] = $params['city'];
		}


		if((is_array($params['building_search_subarea']) && $params['building_search_subarea'][0]!='') || is_string($params['building_search_subarea']) && $params['building_search_subarea']!='') {
			$urlparam['area'] = $params['building_search_subarea'];
		} else if($params['area']!='') {
			$urlparam['area'] = $params['area'];
		}


		// currently, get_buidlings() does not go as deep as street types suffixes etc.
		// Filters by Just street name & dir only.
		if($params['building_search_street_dir']!='') {
			$urlparam['street_dir'] = $params['building_search_street_dir'];
		} else if($params['street_dir']!='') {
			$urlparam['street_dir'] = $params['street_dir'];
		}

		if($params['building_search_street_name']!='') {
			$urlparam['street'] = $params['building_search_street_name'];
		} else if($params['street_name']!='') {
			$urlparam['street'] = $params['street_name'];
		} else if($params['street']) {
			$urlparam['street'] = $params['street'];
		}


		// Active, Presale, Coming Soon etc.
		if($params['building_search_status']!='') {
			$urlparam['status'] = $params['building_search_status'];
		} else if($params['status']!='') {
			$urlparam['status'] = $params['status'];
		}

		if($params['building_search_year']!='') {
			$urlparam['min_year'] = $params['building_search_year'];
		} else if($params['min_year']!='') {
			$urlparam['min_year'] = $params['min_year'];
		}

		// Pets allowed or not.
		if($params['building_search_pets']) {
			$urlparam['pets'] = $params['building_search_pets'];
		} else if($params['pets']!='') {
			$urlparam['pets'] = $params['pets'];
		}

		// Rental allowed or not?
		if($params['building_search_rental']) {
			$urlparam['rental'] = $params['building_search_rental'];
		} else if($params['building_search_rentals']!='') {
			$urlparam['rental'] = $params['building_search_rental'];
		} else if($params['rental']!='') {
			$urlparam['rental'] = $params['rental'];
		}

		// Short term rental filters
		if($params['building_search_short_term_rental']) {
			$urlparam['short_term_rental'] = $params['building_search_short_term_rental'];
		} else if($params['short_term_rental']!='') {
			$urlparam['short_term_rental'] = $params['short_term_rental'];
		}

		// Air Conditioned building?
		if($params['building_search_air_conditioning']) {
			$urlparam['air_conditioning'] = $params['building_search_air_conditioning'];
		} else if($params['air_conditioning']!='') {
			$urlparam['air_conditioning'] = $params['air_conditioning'];
		}

		// EV charging
		if($params['building_search_ev_charging']) {
			$urlparam['ev_charging'] = $params['building_search_ev_charging'];
		} else if($params['ev_charging']!='') {
			$urlparam['ev_charging'] = $params['ev_charging'];
		}

		if((($params['building_order_by']!='create_date' && $params['building_order_by']!='') || $params['building_order_direction']!='DESC') && $params['building_order_by']!='') {
			// skip all defaults create_date DESC.
			$urlparam['order_by'] = $params['building_order_by'];
			$urlparam['order_direction'] = $params['building_order_direction'];
		} else if ((($params['order_by']!='create_date' && $params['order_by']!='') || $params['order_direction']!='DESC') && $params['order_by']!='') {
			$urlparam['order_by'] = $params['order_by'];
			$urlparam['order_direction'] = $params['order_direction'];
		}

		$urlparam['page'] = 1; // new saerches always go to page 1 again. In-page nav is available within the results, in $pagelinkshtml.

		$url = $settings['sitepath'].$params['building_custom_filename'];
		foreach($urlparam as $key=>$value) {
			$url .= '/'.$key;
			if(is_array($value)) {
				$arraycount = 0;
				$url .= '-';
				foreach($value as $arrayvar) {
					if($arraycount>0) {
						$url .= ';';
					}
					$url .= urlencode($arrayvar);
					$arraycount++;
				}
			} else if(strlen($value)>0) {
				$url.='-'.urlencode($value);
			}
		}
		$code = 1;
	}

	// and then we run it through the param_to_query function to filter it out.
	$json_array = array('buildingurl'=>$url, 'code' => $code, 'message'=>$message);
	return $json_array; // keep it PHP for now in case we use it within PHP.
}

function property_link($id,$trail='',$base = 'showlisting/') {
	// deprecated, old function so linking to the $home object that will run the same thing.
	global $settings;

	$thishome = new home;
	$thishome->initialize($id);

	$urltrail = ($trail!='' ? $trail : $settings['url_trail']);

	return $thishome->get_property_link($urltrail, $base=$base);
	//return $settings['sitepath'].$base.$id.'/'.urlencode(str_replace("#",'',$home['unit'])."-".$home['number']."-".str_replace(" ", "-",$home['street'])."-".str_replace(" ", "-",gettablefield('subareas','name',$home['area']))."-".str_replace(" ", "-",gettablefield('areas','name',$home['city']))."-".$trail);
}

function get_rental_price($dayrate='',$daylabel='', $weekrate='', $weeklabel='', $monthrate='',$monthlabel='', $default = 0, $na = 'N/A') {
	//function to determine the price to display, priority left to right.
	//default variable for overriding order if needed in isolated cases

	$return = $na; // default to NA.

	if($monthrate!='') {
		// if month rate is set, let this be primary.
		$return = $monthrate.$monthlabel;
	} else if ($weekrate!='') {
		$return = $weekrate.$weeklabel;
	} else if ($dayrate!='') {
		$return = $dayrate.$daylabel;
	} else if ($default!='') {
		$return = $default.$monthlabel; // fall back to monthly rate?
	}
	return $return;
}

function floorplan_exists($id) {
	// shit functions that go in multiple calls, do not use.
	// really should only be called from the home object anyway?
	global $settings;
	$thishome = new home;
	$thishome->initialize($id);

	return $thishome->floorplan_exists;
}

function featuresheet_exists($id) {
	// shit functions that go in multiple calls do not use.
	global $settings;
	$thishome = new home;
	$thishome->initialize($id);

	return $thishome->featuresheet_exists;
}


function gallery_exists($id) {
	// shit function that go in multiple calls, od not use.
	global $settings;
	$thishome = new home;
	$thishome->initialize($id);
	return $thishome->gallery_exists;
}

function get_object_gallery_timestamp($objecttype, $idr) {
	// don't pass by default - needs to be specific.
	// check current photo set timestamp
	global $mysqli;
	if(isset($idr) && $idr!='' && isset($objecttype) && $objecttype!='') {
		$phototimesql = "SELECT `timestamp` FROM `photos` WHERE `".$objecttype."` = '$idr' ORDER BY `timestamp` DESC LIMIT 1";
		$phototimeresult = $mysqli->query($phototimesql);
		if($phototimeresult===false) {
			$return = false; // means error... did not return a row at all.
		} else if($phototimeresult->num_rows>0) {
			$irow = $phototimeresult->fetch_assoc();
			$return = intval($irow['timestamp']);
		} else {
			$return = 0; // no error in query or syntax, but no photo - so just 0 is fine as no timesatmp.
		}
	} else {
		$return = 0;
	}
	return $return;
}


function param_to_query($params) {
	/*
	this function filters out the arrays in the $params feed
	to filter out just what's needed for the $query portion that works to filter out specific type fo listings.
	This function is necessary as the $params generated through parge_pagevars() will get everything,
	including page splits etc which are not part of the $query, but rather, used as other arguments elsewhere.

	This function is critical for filtering things to pass from the URL to the get_listings() or get_buildings() query safely.

	i.e. If somebody passes agentname.com/listings/publish-0/page-1 to get publish=0 listings, this will prevent it. Also will prevent any other SQL injection through URL.
	*/
	global $settings;
	$allowed = array(
		'type',
		'typeid',
		'source',
		'sold',
		'status',
		'min_price',
		'max_price',
		'min_sqft',
		'max_sqft',
		'min_lot',
		'max_lot',
		'max_year',
		'min_year',
		'openhouse',
		'keyword',
		'bedroom',
		'bathroom',
		'min_bedroom',
		'min_bathroom',
		'max_bedroom',
		'max_bathroom',
		'plotted',
		'lat_min',
		'lat_max',
		'lng_min',
		'lng_max',
		'firm_id',
		'city',
		'cityid',
		'areaid',
		'area',
		'street',
		'street_dir',
		'street_name',
		'street_type',
		'street_suffix',
		'bldg',
		'mls',
		'feature',
		'office_listings',
		'office_name',
		'list_date',
		'today',
		'ownlisting',
		'mylisting',
		'forsale',
		'for_rent', // filter out HOMES that are for RENT< not for sale.
		'rental', // for HOMES for sale, whether you can rentit out or not. Different from for_rent.

		'short_term_rental', // for buildings usually?
		'available_date', // available date on or before... so turns into a min query at the end.
		'pets', // for BUILDINGS, whether pets are allowed or not. For HOMES, its renatl units that allow pets.

		// filters just for buildings
		'short_term_rental',
		'air_conditioning',
		'ev_charging',
		'rentals', // for BUILDINGS, whether building allows rental or not. Do not confuse with the 'rental' value which limits to FOR RENT listings, not buildlings that allow rentals.

		'residential', // often without a -0 or -1.. just by itself.. Rarely needed as this is default.. This will just get `type`<50.
		'commercial', // often without 0 or 1. Not specifically for detailed types like Industrial, Retail etc. This will just get `type`=>50.

		'furnished', // for HOME, rental units that are funisehd
		'has_listings', // for BUILDINGS, whether buildings have active sold=0 published=1 status listings or not.
		'features', // for BUILDINGS, allows to filter building by hot tub, meeting room, concierge etc.
		'agent',
		'agentid', // filter for agents, OR get listings under a certain agent's board iD
		'fname',
		'lname',
		'name' // used for agents and buildings both!
	);

	// add the $settings['home_features'] array to the allowed list.
	foreach($settings['home_features'] as $queryfeature) {
		array_push($allowed, $queryfeature);
	}
	$query = array(); // blank var.
	if(is_array($params)) {
		foreach($params as $name=>$value) {
			if(in_array(strtolower($name),$allowed)) {
				$query[$name]=$value;
			}
		}
	}
	if(is_array($query) && count($query)>0) {
		return $query;
	} else {
		return false;
	}
}


function get_properties($sold='', $query=array('feature'=>1, 'publish'=>1), $order='ord', $asc='asc', $perpage='', $page='', $getcount = false, $getdata = false) {
	// first variable, $sold, is completely obsolete, do NOT use! $query['sold'] = 0, or $query['sold'] = array(0,2) is right format.
	global $settings;
	global $square;
	global $mysql_time;
	global $today;
	global $bldg;
	global $mysqli;
	global $year;
	global $memcache;

	// first, determine the query structure and type.
	// For rent or for sale?
	if(array_key_exists('for_rent', $query) || array_key_exists('rent', $query)  || array_key_exists('rental', $query)) {
		$rent = true;
	} else {
		$rent = false;
	}

	// deciding whether this is for commercial or residential?
	if(array_key_exists('commercial', $query) || isset($query['typeid'])>50) {
		$commercial = true;
	} else if(isset($query['type'])) {
		$typeid = get_property_type_id($query['type']);
		if($typeid>=50) {
			$commercial = true;
		} else {
			$commercial = false;
		}
	} else {
		$commercial = false;
	}

	if(array_key_exists('skipmasterid', $query) && ($query['skipmasterid']==1 || $query['skipmasterid']==true)) {
		$skipmasterid = true;
	} else {
		$skipmasterid = false;
	}

	// build video columns from settings - only query fields that exist on each site.
	$youtubecolumns = '';

	if(is_array($settings['homes_youtubefields']) && count($settings['homes_youtubefields'])>0) {
		foreach($settings['homes_youtubefields'] as $count => $youtubecolumn) {
			$youtubecolumns.=($count>0 ? ', ' : '').$youtubecolumn;
		}

		if($youtubecolumns!='') {
			$youtubecolumns = $youtubecolumns.', ';
		}
	}

	$vimeocolumns = '';
	if(is_array($settings['homes_vimeofields']) && count($settings['homes_vimeofields'])>0) {
		foreach($settings['homes_vimeofields'] as $count=>$vimeocolumn) {
			$vimeocolumns.=($count>0 ? ', ' : '').$vimeocolumn;
		}

		if($vimeocolumns!='') {
			$vimeocolumns = $vimeocolumns.', ';
		}
	}

	/*
	 * 2024 Memcache upgrades
	 * $getdata==true should mean that it gets the IDs, then goes after the memcache data (and falling back to MySQL one listing at a time.
	 * */

	if($getdata===true && $memcache===false) {
		// full query IF there's no memcache.

		// whatever columns you add here, make sure to add it below in the SUB QUERY (that returns columns from homes table in raw numbers)
		$target_columns = 'h.id, h.lat, h.long, h.source, h.publish, '.($skipmasterid===true ? '' : 'h.masterid,').' h.mainphoto, h.mls_photo_timestamp, h.pdf, h.mls, h.type, h.zoning, h.parcel_id, h.year, h.feature, h.sold, h.remarks, h.heading, h.heading2, h.mls_photo, h.price, h.for_rent, '.
			($rent===true ? "h.rental_price_day, h.rental_price_week, h.rental_price_month, h.rental_availability, h.rental_pets, h.rental_furnished, h.rental_smoking, h.rental_parking, h.rental_washerdryer, h.rental_dishwasher, h.rental_min_term," : "").
			($commercial===true ? "h.comm_price_sqft_y, h.comm_price_addl_y, h.comm_rental_rate, h.comm_sub_type, h.comm_availability, h.comm_min_divisible, h.comm_cap_rate, h.comm_use_type, h.comm_occupancy, h.comm_tenancy, h.comm_tenant_sqft,  " : "").
			' h.openhouse, h.slug, h.metatitle,
			h.firm_1, h.firm_2, h.firm_3, h.realtor_1, h.realtor_2, h.realtor_3, 
			h.firm_1_id, h.firm_2_id, h.firm_3_id,
			h.showaddress,h.name,h.name2,h.building, 
			h.sqft, h.lot, h.frontage, h.depth, h.unit, h.number, h.street, h.street_name, h.street_type, h.street_suffix, h.street_dir, h.street_dir_position, 
			h.waterfront, h.skihill, h.golfcourse, h.marina, h.gatedcomm, h.retirementcomm, h.pool,
			'.$youtubecolumns.$vimeocolumns.' h.videolink, h.bedroom, h.bathroom, 
			h.modify_date, h.timestamp, h.create_date, h.city as cityid, h.area as areaid, h.area_alt as areaaltid, h.land_title, h.virtualtour, 
			h.description, h.agent_1, h.agent_2, h.agent_3, a.name as subarea_name, aa.name AS subarea_alt_name, c.name as city_name, 
			p.id as pid, p.filename as filename, p.timestamp as photo_timestamp  ';

	} else if($getdata===true && $memcache!==false) {
		// full data needed, and memcache is on. Then return ID and MLS and SOURCE so that we can get memcache for each home.
		$target_columns = 'h.id, h.mls, h.source';
	} else if($getcount===true) {
		$target_columns = ' COUNT(*) as cnt ';
	} else {
		$target_columns = 'h.id';
	}
	// Then we construct the query and subquery that generates raw dataset from homes table to the ephemeral storage.
	// This is how we get prices in raw integers, bed/bath/ssqft etc. in - so that the FILTRATION of listings by search query work.s
	// Note that what columns are spat out to the final $result is determined by the $target_columns var defined above.
	// If you add any table JOIN statements here, you probably need to add them to the $home->initialize() SQL too.
	$sqlhead = "SELECT ".$target_columns." FROM 

			(SELECT `lat`, `long`, `source`, `showaddress`, `name`, `name2`, ".($skipmasterid===true ? '' : '`masterid`,')." `publish`, `mainphoto`, `pdf`, `pid` as parcel_id, `zoning`, `mls_photo`, `price`, `unit`, `mls`, 
			`remarks`, `heading`, `heading2`, `openhouse`, `firm_1`, `firm_2`, `firm_3`, `firm_1_id`, `firm_2_id`, `firm_3_id`,`realtor_1`, `realtor_2`, `realtor_3`, `agent_1`, `agent_2`, `agent_3`, `number`, `id`, `sold`,  `for_rent`, 
			`description`, `slug`, `metatitle`, ".
		($rent===true ? "`rental_price_day`, `rental_price_week`, `rental_price_month`, `rental_furnished`, `rental_pets`, `rental_smoking`, `rental_parking`, `rental_washerdryer`, `rental_dishwasher`, `rental_min_term`,
				CAST(REPLACE(REPLACE(`rental_price_month`, ',', ''), '$', '') AS UNSIGNED) as `i_rental_price_month`, 
				CAST(REPLACE(REPLACE(`rental_price_week`, ',', ''), '$', '') AS UNSIGNED) as `i_rental_price_week`, 
				CAST(REPLACE(REPLACE(`rental_price_day`, ',', ''), '$', '') AS UNSIGNED) as `i_rental_price_day`, 
				`rental_availability`," : "")."
				`street`, `street_name`, `street_type`, `street_suffix`, `street_dir`, `street_dir_position`, ".$youtubecolumns.$vimeocolumns." `videolink`, `building`, `city`, `area`, `area_alt`, `bedroom`, `bathroom`, `sqft`, `lot`, `frontage`, `depth`, `type`, `feature`, `ord`, `create_date`, `modify_date`, `mls_photo_timestamp`, `timestamp`, `year`, `features`, `land_title`, `virtualtour`,
				".($commercial===true ? "`comm_price_sqft_y`, `comm_price_addl_y`, `comm_sub_type`, `comm_availability`, `comm_min_divisible`, `comm_cap_rate`, `comm_use_type`, `comm_occupancy`, `comm_tenancy`, `comm_tenant_sqft`, `comm_rental_rate`,
				 CAST(REPLACE(REPLACE(`comm_price_sqft_y`, ',', ''), ' ', '') AS UNSIGNED) as `i_comm_price_sqft_y`,
				 CAST(REPLACE(REPLACE(`comm_price_addl_y`, ',', ''), ' ', '') AS UNSIGNED) as `i_comm_price_addl_y`,
				 CAST(REPLACE(REPLACE(`comm_tenant_sqft`, ',', ''), ' ', '') AS UNSIGNED) as `i_comm_tenant_sqft`,
				" : "")."
				CAST(REPLACE(REPLACE(`sqft`, ',', ''), ' ', '') AS UNSIGNED) as `i_sqft`,
				CAST(REPLACE(REPLACE(`lot`, ',', ''), ' ', '') AS UNSIGNED) as `i_lot`,
				CAST(REPLACE(REPLACE(`year`, ',', ''), ' ', '') AS UNSIGNED) as `i_year`,
				CAST(REPLACE(REPLACE(`price`, ',', ''), '$', '') AS UNSIGNED) as `i_price`,
				CAST(REPLACE(REPLACE(`bedroom`, ',', ''), ' ', '') AS UNSIGNED) as `i_bedroom`,
				CAST(REPLACE(REPLACE(`bathroom`, ',', ''), ' ', '') AS UNSIGNED) as `i_bathroom`,
				`waterfront`, `skihill`, `golfcourse`, `marina`, `gatedcomm`, `retirementcomm`, `pool`
			FROM `homes`) h LEFT OUTER JOIN `subareas` a ON h.area=a.id LEFT OUTER JOIN `subareas` aa ON h.area_alt=aa.id LEFT OUTER JOIN `areas` c ON h.city=c.id "
		.($getcount===false ? "LEFT OUTER JOIN `photos` p on h.id=p.home": "")."  WHERE 1=1 ";

	$sqlfilter = '';
	if(is_array($query)) {
		$count = 0;
		foreach($query as $field=>$value) {
			// first set up the query...
			$condition = '';
			switch($field) {
				case "mls":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $mlsnum) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.mls LIKE '%".$mysqli->real_escape_string(trim($mlsnum)). "%'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='') {
						$condition = "h.mls LIKE '%" . $mysqli->real_escape_string(trim($value)) . "%'";
					} else {
						// blank MLS value, so enter bogus field so nothing comes up!
						$condition = "h.mls = '" . md5($now) . "'";
					}
					break;

				case "id":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $homeid) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.id ='".cleanupforentry($homeid). "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='') {
						$condition = "h.id = '" . cleanupforentry($value) . "'";
					} else {
						// blank ID value, so enter bogus field so nothing comes up!
						$condition = "h.id = '" . md5($now) . "'";
					}
					break;

				case "type":
					// type such as "house" or "Townhome" was passed as string
					// convert to ID using get_property_type_id();



					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $hometype) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$typeid = get_property_type_id($hometype);
							if($typeid>=50) {
								$commercial = true;
							}
							$condition .= "h.type = '" . $typeid . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else {
						$typeid = get_property_type_id($value);

						/*
						special interception - types Penthouse & lofts in certain boards (mainly Vancouver)
						When searching for condos, we need to account to add penthouse & lofts into the search.
						*/

						if(
							isset($settings['mls_import_url_host'])
							&&
							array_key_exists($settings['mls_import_url_host'], $settings['condo_subtypes'])
							&&
							$typeid == array_key_first($settings['condo_subtypes'][$settings['mls_import_url_host']])
						) {
							if(DEBUG===true) {
								echo "MLS Host ".$settings['mls_import_url_host']." detected with Type ID ".$typeid." match for condos<br />".PHP_EOL;
							}

							// Type ID matches the condo type, so add the other ones.
							$condition = "(h.type='".$typeid."'";
							foreach($settings['condo_subtypes'][$settings['mls_import_url_host']][$typeid] as $condosubtype) {
								$condition .= " OR h.type='".$condosubtype."'";
							}
							$condition .= ")";

						} else {
							$condition = "h.type = '" . $typeid . "'";
						}


						if($typeid>=50) {
							$commercial = true;
						}
					}
					break;

				case "typeid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $typeid) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.type = '" . $mysqli->real_escape_string($typeid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else {
						$condition = "h.type = '" . $mysqli->real_escape_string($value) . "'";
					}
					break;

				case "remarks":
					/*
						remarks such as "JUST LISTED" or "Townhome" was passed as string
						convert to ID using get_property_remarks_id();
						Not used too often on regular realtor sites, but specialty contruction

					*/
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $homeremark) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$remarksid = get_property_remarks_id($homeremark);
							$condition .= "h.remarks = '" . $remarksid . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false) {
						$remarksid = get_property_remarks_id($value);
						$condition = "h.remarks = '" . $remarksid . "'";
					} else {
						// default to at least having some remark only.
						$condition = "h.remarks != '0'";
					}
					break;

				case "remarksid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $remarksid) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.remarks = '" . $mysqli->real_escape_string($remarksid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false)  {
						$condition = "h.remarks = '" . $mysqli->real_escape_string($value) . "'";
					} else {
						// default to at least having some remark only.
						$condition = "h.remarks != '0'";
					}
					break;

				case "source":
					// filter by source 0 or 1
					$condition.=" h.source='".intval(trim($value))."' ";
					break;

				case "ownlisting":
					// time to show one's own listings
					// this includes source=0 as well as feature=1 all at once.
					$condition.="(h.feature=1 OR h.source=0)";
					break;

				case "residential":
					// Residnetial is always below 50..
					$condition.="(h.type<50)";
					break;

				case "commercial":
					// Commercial is always 50 and above.
					$condition.="(h.type>=50)";
					break;

				case "mylisting":
					// time to show one's own listings
					// this is ONLY for source=0 listings, featured or not.
					$condition.=" h.source=0 ";
					break;

				case "forsale":
					// for sale stuff wher eits not for rent
					$condition.=" h.for_rent=0 ";
					break;

				case "rent":
				case "for_rent":
				case "rental":
					// for rental, not for sale
					$condition.=" h.for_rent=1 ";
					break;

				case "pets":
					// if value == 1, yes or empty then consider it = 1
					$value = (($value == 'no' || $value === '0') ? 0 : 1);

					// for rental, not for sale
					$condition.=" h.rental_pets=".$value." ";
					break;

				case "furnished":
					// if value == 1, yes or empty then consider it = 1
					$value = (($value == 'no' || $value === '0') ? 0 : 1);

					// for rental, not for sale
					$condition.=" h.rental_furnished=".$value." ";
					break;

				case "available_date":
					// if a date is set, make sure the available date is on or BEFORE this date! MIN filter.
					// Do we filter against past ones by putting last month as a min filteR?
					// residential : rental_availability
					// commercial : comm_availability
					if($commercial===true) {
						// then build off commercial date: comm_availability,
					} else {
						// default to res field: rental_availability.
					}
					break;

				case "sold":
					if(is_array($value) && count($value)>0) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $soldstatus) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.sold = '" . $soldstatus . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if((isset($value) && $value!='') || (isset($value) && gettype($value)=='integer')) {
						$condition = "h.sold = '" . intval($value) . "'";
					} else {
						$condition = "(h.sold = '1' OR h.sold='2')";
					}
					break;

				case "openhouse":
					// where openhouse is NOT empty
					$condition = " h.openhouse != ''";
					break;

				case "feature":
					if($value === '' || $value === false && $value!=0) $value = 1;// override!
					$condition = " h.feature = '" . intval($value) . "'";
					break;

				case "publish":
					if($value === '' || $value === false && $value!=0) $value = 1;// override!
					$condition = " h.publish = '" . intval($value) . "'";

					break;

				case "polygon":
					$condition = "ST_CONTAINS(".polygon_to_mysql($value).", POINT(h.long, h.lat))='1'";
					break;

                case "polygon_exclude":
                    // This filter takes in an Array (MUST)
                    // list of polygon is in format of (long1 lat1, long2 lat2, ..., longN latN)
                    if (is_array($value)) {
                        if (count($value) > 1) {
                            // multiple polygon shapes ... loop!
                            // final query should look like this ...
                            // $condition = "NOT ( ST_Intersects(POINT(h.long, h.lat), ST_PolygonFromText('POLYGON((".$value[0]."))'))   OR    ST_Intersects(POINT(h.long, h.lat), ST_PolygonFromText('POLYGON((".$value[1]."))')) )";
                            $condition = "NOT ("; // start of the polygon query.
                            foreach ($value as $index => $each_polygon_shape) {
                                if ($index > 0) {
                                    $condition .= " OR "; // start with OR for second and onward shapes.
                                }
                                $condition .= "ST_Intersects(POINT(h.long, h.lat), ST_PolygonFromText('POLYGON((".$each_polygon_shape."))'))";
                            }
                            $condition .= ")"; // End of the polygon query.
                        } else {
                            // single polygon shape ...
                            $condition = "NOT ST_Intersects(
                                    POINT(h.long, h.lat), 
                                    ST_PolygonFromText('POLYGON((".$value[0]."))')
                                    )";
                        }
                    }
                    // not in array format ... just break.
                    break;

				case "list_date":
					if($value!='' && $value!==false) {
						$condition = " h.create_date LIKE '" . $mysqli->real_escape_string(trim($value)) . "%'";
					}
					break;

				case "today":
					$condition = " h.create_date LIKE '" . date($mysql_time['day'],strtotime('-36 hours')) . "%'";
					break;

				case "min_year":
					if ($value != '' && $value !== false) {
						$limitage = $year - $mysqli->real_escape_string(trim($value));

						if ($value <= 500) {
							$condition = "
								( `year` >= " . $mysqli->real_escape_string(trim($value)) . " AND `year`<= 500) OR `year`>= ".$limitage." )
							";
						} else {
							$condition = "(
								( `year` >= " . $mysqli->real_escape_string(trim($value)) . " OR `year`<= ".$limitage.")
								AND `year`>=0
							)";
						}

					}
					break;

				case "max_year":
					if ($value != '' && $value !== false) {
						$limitage = $year - remove_all_but_numbers($mysqli->real_escape_string(trim($value)));

						if ($value <= 500) {
							$condition = "
								(`year` <= " . $mysqli->real_escape_string(trim($value)) . " OR `year`>= ".$limitage.")
							";
						} else {
							$condition = " (
								(`year` <= " .$mysqli->real_escape_string(trim($value)). " AND `year`>500)
								OR 
								(`year`>=".$limitage." AND `year` <= 500)
							)";
						}
					}
					break;

				case "min_price":
					// if rental, use i_rental_price_month, i_rental_price_week X 4, or i_rental_price_day * 30.
					if($rent===true) {
						$value = $mysqli->real_escape_string($value);
						$price_week = intval($value)/4;
						$price_day = intval($value)/30;
						$condition = " ( 
						(i_rental_price_month >= '" . intval($value) . "' AND i_rental_price_month!='' AND i_rental_price_month!=0)
						OR 
						(i_rental_price_week >= '".$price_week."' AND i_rental_price_week!='' AND i_rental_price_week!=0)
						OR
						(i_rental_price_day >= '".$price_day."' AND i_rental_price_day!='' AND i_rental_price_day!=0)
						)";
					} else {
						if($value!='' && $value!=false && $value>=0) {
							$condition = " i_price >= '" . intval($value) . "'";
						}
					}
					break;

				case "max_price":
					// if rental, use i_rental_price_month, i_rental_price_week X 4, or i_rental_price_day * 30.

					if($value==0) {
						// 0 means unlimited so do NOTHING!
					} else {
						if($rent===true) {
							$value = $mysqli->real_escape_string($value);
							$price_week = intval($value)/4;
							$price_day = intval($value)/30;
							$condition = " (
							(i_rental_price_month <= '" . intval($value) . "' AND i_rental_price_month!='' AND i_rental_price_month!=0)
							OR 
							(i_rental_price_week <= '".$price_week."' AND i_rental_price_week!='' AND i_rental_price_week!=0)
							OR
							(i_rental_price_day <= '".$price_day."' AND i_rental_price_day!='' AND i_rental_price_day!=0)
							)";
						} else {
							$condition = " i_price <= '" . intval($value) . "'";
						}

					}
					break;

				case "min_sqft":
					$condition =  "i_sqft >= '" . ($value<20 ? intval($square[intval($value)]) : intval($value)) . "'";
					break;

				case "max_sqft":
					if($value==0) {
						// 0 means unlimited
						//$condition = " i_sqft >= '" . intval($value) . "'";
					} else {
						$condition = " i_sqft <= '" . ($value<20 ? intval($square[intval($value)]) : intval($value)) . "'";
					}
					//$condition =  "i_sqft <= '" . intval($square[intval($value)]) . "'";
					break;

				case "min_lot":
					$condition =  "i_lot >= '" . intval($value) . "'";
					break;

				case "max_lot":
					if($value==0) {
						// 0 means unlimited
						//$condition = " i_sqft >= '" . intval($value) . "'";
					} else {
						$condition = " i_lot <= '" . intval($value) . "'";
					}
					break;

				case "bedroom":
					if($value!='' && $value!==false) {
						$condition = " i_bedroom = '" . intval($value) . "'";
					}
					break;

				case "bathroom":
					if($value!='' && $value!==false) {
						$condition = " i_bathroom = " . intval($value) . "";
					}
					break;

				case "min_bedroom":
					if($value!='' && $value!==false) {
						$condition = " i_bedroom >= " . intval($value) . "";
					}
					break;

				case "min_bathroom":
					if($value!='' && $value!==false) {
						$condition = " i_bathroom >= '" . intval($value) . "'";
					}
					break;

				case "max_bedroom":
					if($value!='' && $value!==false) {
						$condition = " i_bedroom <= '" . intval($value) . "'";
					}
					break;

				case "max_bathroom":
					if($value!='' && $value!==false) {
						$condition = " i_bathroom <= '" . intval($value) . "'";
					}
					break;
				// lat long related stuff.
				case "plotted":
					$condition = "(h.lat != 0 AND h.long != 0 AND h.showaddress = '1')";
					break;

				case "lat_min":
					if($value!='' && $value!==false) {
						$condition = "(h.lat >= ".floatval($value)." AND h.lat <= ".floatval($query['lat_max']).")";
					}
					break;

				case "lng_min":
					if($value!='' && $value!==false) {
						$condition = "(h.long >= ".floatval($value)." AND h.long <= ".floatval($query['lng_max']).")";
					}
					break;


				// other boolean features, no value given (/waterfront/marina/page-1 is format)
				// unlike ones that need value.

				case "waterfront":
					$condition.=" h.waterfront=1 ";
					break;

				case "skihill":
					$condition.=" h.skihill=1 ";
					break;

				case "golfcourse":
					$condition.=" h.golfcourse=1 ";
					break;

				case "marina":
					$condition.=" h.marina=1 ";
					break;

				case "gatedcomm":
					$condition.=" h.gatedcomm=1 ";
					break;

				case "retirementcomm":
					$condition.=" h.retirementcomm=1 ";
					break;

				case "pool":
					$condition.=" h.pool!='' ";
					break;

				case "firm_id":
					if(is_array($value)) {
						$condition = '('; // start with blank for this
						foreach($value as $key=>$firm_id) {
							if($key>0) {
								$condition .= " OR ";
							}
							$condition .= " (LOWER(h.firm_1_id) = '" . $firm_id . "' OR LOWER(h.firm_2_id)='".$firm_id."' OR h.LOWER(firm_3_id)='".$firm_id."')";
						}
						$condition.=')';
					} else {
						$condition = " (LOWER(h.firm_1_id) = '" . $value . "' OR LOWER(h.firm_2_id)='".$value."' OR LOWER(h.firm_3_id)='".$value."')";
					}
					break;

				case "agent":
					// Filter by array of agent id - these ids are internally generated.
					if (is_array($value)) {
						$condition = '('; // start with blank for this
						foreach($value as $key=>$agent_id) {
							$agent_id = $mysqli->real_escape_string(strtolower((trim($agent_id))));
							if($key>0) {
								$condition .= " OR ";
							}
							$condition .= " (agent_1 = ' ".$agent_id." ' OR agent_2= ' ".$agent_id." ' OR agent_3= ' ".$agent_id." ' )";
						}
						$condition .= ')';
					} else {
						$agent_id = $mysqli->real_escape_string(strtolower(trim($value)));
						$condition = " (agent_1 = '" . $agent_id . "' OR agent_2='".$agent_id."'  OR agent_3='".$agent_id."')";
					}
					break;

				case "office_listings":
					if(is_array($settings['firm_id'])) {
						$condition = '('; // start with blank for this
						foreach($settings['firm_id'] as $key=>$firm_id) {
							$firm_id = $mysqli->real_escape_string(strtolower(trim($firm_id)));
							if($key>0) {
								$condition .= " OR ";
							}
							$condition .= " (LOWER(h.firm_1_id) = '" . $firm_id . "' OR LOWER(h.firm_2_id)='".$firm_id."'  OR LOWER(h.firm_3_id)='".$firm_id."') ";
						}
						$condition .= ')';
					} else {
						$firm_id = $mysqli->real_escape_string(strtolower(trim($settings['firm_id'])));
						$condition = " (LOWER(h.firm_1_id) = '" . $firm_id . "' OR LOWER(h.firm_2_id)='".$firm_id."' OR LOWER(h.firm_3_id)='".$firm_id."')";
					}

					break;

				case "office_name":
					// raw full string for brokerage to be passed, like "CENTURY 21 WOLSTRONCROFT LTD."
					// really shitty way to do it since even a small change in office name label breaks this,
					// but given that Toronto board supplies neither agent ID nor Office ID, this ist he only option.
					if($value) {
						$condition = "(LOWER(h.firm_1) LIKE '" . $mysqli->real_escape_string(strtolower(trim($value))) . "%' OR LOWER(h.firm_2) LIKE '" . $mysqli->real_escape_string(strtolower(trim($value))) . "%' OR LOWER(h.firm_3) LIKE '" . $mysqli->real_escape_string(strtolower(trim($value))) . "%')";
					}
					break;

				case "street_dir":
					$dir_array = generate_street_dir_array($value);

					if($dir_array != '') {
						$condition = "LOWER(h.street_dir) IN ('" . implode("', '", array_map('strtolower', $dir_array)) . "')";
					}
					break;

				case "street_name":
					if($value) {
						$condition = "(LOWER(h.street_name) LIKE '" . $mysqli->real_escape_string(strtolower(trim($value))) . "')";
					}
					break;

				case "street_type":
					if($value != '') {
						$condition = "(LOWER(h.street_type) LIKE '" . $mysqli->real_escape_string(strtolower(trim($value))) . "')";
					}
					break;

				case "street_suffix":
					$suffix_array = generate_street_dir_array($value);

					if($suffix_array != '') {
						$condition = "LOWER(h.street_suffix) IN ('" . implode("', '", array_map('strtolower', $suffix_array)) . "')";
					}
					break;

//				case "street":
//				if($value!='') {
//					$streetvar = separate_streetname($value);
//					if($streetvar!='') {
//						$condition = "LOWER(h.street) LIKE '" . $mysqli->real_escape_string(strtolower(trim($streetvar[0]))) . "%'";
//					}
//				}
//				break;

				case "street":
					if($value!='') {
						$streets_array = [];
						$streetvar = separate_streetname($value);
						$street_name = $streetvar[0];
						$street_type = $streetvar[1];
						$street_dir = $streetvar[2];
						$street_suffix = $streetvar[3];

						if ($street_dir != '') {
							$dir_array = generate_street_dir_array($street_dir);
						}

						if ($street_suffix != '') {
							$suffix_array = generate_street_dir_array($street_suffix);
						}

						// If any direction variation is found
						if ($dir_array != '') {
							foreach ($dir_array as $direction) {
								// If we also have suffixes
								if ($suffix_array != '') {
									foreach ($suffix_array as $suffix) {
										$streets_array[] = $mysqli->real_escape_string(strtolower(trim(implode(' ', [$direction, $street_name, $street_type, $suffix]))));
									}
								} else {
									$streets_array[] = $mysqli->real_escape_string(strtolower(trim(implode(' ', [$direction, $street_name, $street_type, $street_suffix]))));
								}
							}
						} else {
							if ($suffix_array != '') {
								foreach ($suffix_array as $suffix) {
									$streets_array[] = $mysqli->real_escape_string(strtolower(trim(implode(' ', [$street_dir, $street_name, $street_type, $suffix]))));
								}
							} else {
								$streets_array[] = $mysqli->real_escape_string(strtolower(trim(implode(' ', [$street_dir, $street_name, $street_type, $street_suffix]))));
							}
						}


						if($streetvar!='') {
							$condition = "LOWER(h.street) IN ('" . implode("', '", $streets_array) . "')";
						}
					}
					break;

				case "city":
					if(is_array($value)) {
						$condition = '(';
						$cityarraycount = 0;
						foreach($value as $cityname) {
							$cityname = $mysqli->real_escape_string(strtolower(trim($cityname)));
							/*
														$citysql = "SELECT id FROM areas WHERE LOWER(`name`)='".$mysqli->real_escape_string(strtolower(trim($cityname)))."'";
														$cityresult = $mysqli->query($citysql);
														if($cityresult->num_rows>0) {
															$cityid = $cityresult->fetch_assoc();
							*/
							if($cityarraycount>0) {
								$condition.=' OR ';
							}
							$condition .= "LOWER(c.name)='".$cityname."'";
							$cityarraycount++;
							/*

														}

							*/
						}
						$condition.= ')';
					} else if($value!='') {
						/*
												$citysql = "SELECT id FROM areas WHERE LOWER(`name`)='".$mysqli->real_escape_string(strtolower(trim($value)))."'";
												$cityresult = $mysqli->query($citysql);
												$cityid = $cityresult->fetch_assoc();
						*/
						$condition = " LOWER(c.name) = '" . $mysqli->real_escape_string(strtolower(trim($value))) . "'";
					}
					break;

				case "area":
					if(is_array($value)) {
						$condition = '(';
						$areaarraycount = 0;
						foreach($value as $areaname) {
							$areaname = $mysqli->real_escape_string(strtolower(trim($areaname)));
							/*
														$areasql = "SELECT id FROM subareas WHERE LOWER(`name`)='".$mysqli->real_escape_string(strtolower(trim($cityname)))."'";
														$arearesult = $mysqli->query($areasql);
														if($arearesult->num_rows>0) {
															$areaid = $arearesult->fetch_assoc();
							*/
							if($areaarraycount>0) {
								$condition.=' OR ';
							}
							$condition .= "LOWER(a.name)='".$areaname."' OR LOWER(aa.name)='".$areaname."'";
							$areaarraycount++;
							/*

														}

							*/
						}
						$condition.= ')';
					} else {
						$areaname = $mysqli->real_escape_string(strtolower(trim($value)));
						/*

												$areasql = "SELECT id FROM subareas WHERE LOWER(`name`)='".$mysqli->real_escape_string(strtolower(trim($value)))."'";
												$arearesult = $mysqli->query($areasql);
												$areaid = $arearesult->fetch_assoc();
						*/

						$condition = "( LOWER(a.name) = '".$areaname."' OR LOWER(aa.name) = '".$areaname."')";
					}
					break;

				case "cityid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $cityid) {
							$cityid = $mysqli->real_escape_string($cityid);
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.city = '" . intval($cityid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false && $value>0) {
						$condition = "h.city = '" . intval($value) . "'";
					}
					break;

				case "areaid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $areaid) {
							$areaid = $mysqli->real_escape_string($areaid);
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "h.area = '" . intval($areaid) . "' OR h.area_alt='".intval($areaid)."'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false && $value>0) {
						$condition = "(h.area = '" . intval($mysqli->real_escape_string($value)) . "'  OR h.area_alt='".intval($mysqli->real_escape_string($value))."')";
					}
					break;

				case "bldg":
					$building_filter = "(";
					$fieldcount = 0;
					$barray = false; // by default, array is false.
					if(is_array($value)) {
						// array already passed, so just look for this building and presumably sub-buildings already included!
						$barray = $value;
					} else if($value!='') {
						// single array, so process buildings as additional array.
						$building_filter .= "h.building='".$mysqli->real_escape_string($value)."'";
						$fieldcount++; // to make sure the OR appears since ew already added a line here.
						if(is_object($bldg)) {
							// building object was passed at the page level.
							if($bldg->load_subbuildings()) {
								// gotta get all sub-buildings to get # of listings here!
								$barray = $bldg->subids;
							}
						}
					}

					if(is_array($barray) == true) {
						// additional array passed, or if original value was an array to begin with.
						foreach($barray as $bid) {
							if($fieldcount>0) {
								$building_filter .= ' OR ';
							}
							$building_filter .= "h.building='".$mysqli->real_escape_string($bid)."'";
							$fieldcount++;
						}
					}
					$building_filter .= ")";

					$condition = $building_filter;

					break;

				case "keyword":
					if(is_array($value)) {
						$condition = '(';
						$keywordarraycount = 0;
						foreach($value as $keyword) {
							if(strlen(trim($keyword))>3) {
								if($keywordarraycount>0) {
									$condition.=' OR ';
								}
								if(strlen(trim($keyword))>3) { // should be at least 2 characters.. maybe push to 3?
									$condition .= " LOWER(h.description) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($keyword))) . "%'";
									$keywordarraycount++;
								}
							}
						}
						$condition.= ')';
					} else {
						if(strlen(trim($value))>3) { // do NOT allow for anytihnig less than 3 characters.. will take forever!!!
							$condition = " LOWER(h.description) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%'";
						}
					}

					break;

				case "page":
					$condition = ""; // skip this in case of accidental passing.
					break;

			} // end of switch statement for $query.
			if($condition!='') {
				// if condition is not blank, that means the passed var had good merit and created a condition
				if($count==0) {
					$sqlfilter .= " AND ("; // if it's the first condition block, start a bracket.
					$sqlfilter .= $condition;
				} else {
					$sqlfilter .= " AND ".$condition; // if it's not the first one, keep adding conditions with AND without brackets
				}
				$count++;
			}
		} // end of foreach block that loops through each $query key
		$sqlfilter .= ')'; // All $query parameters grouped into this AND block to meet all conditions.
	} // end of if else block that checks if $query is an array.

	if($sold!='') {
		// pretty much obsolete except VERY old sites from back in days, $query['sold'] handles all this.
		if(is_array($sold)) {
			$count = 0;
			$sqlfilter .= "AND (";
			foreach($sold as $soldkey) {
				if($count==0) {
					$sqlfilter .= "sold='".$soldkey."'";
				} else {
					$sqlfilter .= " OR sold='".$soldkey."'";
				}
				$count++;
			}
			$sqlfilter .= ")";
		} else {
			$sqlfilter .= " AND sold='".$sold."'";
		}
	}

	if($getcount===false) {
		$sqlfilter.=" GROUP BY h.id "; // to prevent multiple rows of each home retruning based on photo count

		if(is_array($order)) {
			// multiple order columns, in sequence.
			if(!is_array($asc)) {
				$usesingularasc = 1;
			} else {
				$usesingularasc = 0;
			}
			foreach($order as $key=>$column) {
				if($usesingularasc==1) {
					// no matter how many column arrays, they are all one order directive only (ASC or DESC) so do not use the array.
					$columnasc = $asc;
				} else {
					// $asc is ALSO an array, so we match them up.
					$columnasc = $asc[$key]; // match the key first.
					if($columnasc=='') {
						// if $columnasc is blank, that means not enough arrays were given..
						// i.e. $order_by was array('ord', 'feature', 'create_date') and the $asc only had array('ASC', 'DESC');
						// so then we default to the last available array.
						$columnasc = $asc[count($asc)-1];
					}
				}

				if($key>0) {
					$sqlorder.= ', '.generate_order_line($column, $columnasc, 'home');
				} else {
					$sqlorder = 'ORDER BY '.generate_order_line($column, $columnasc, 'home');
				}
			}
		} else if($order!='') {
			$sqlorder = 'ORDER BY '.generate_order_line($order, $asc, 'home');
		} else {
			// no order given whatsoever - default to ord by ASC
			$sqlorder = 'ORDER BY '.generate_order_line('ord', 'ASC', 'home');
		}

	}
	// no need to limit on getcount==true, because that's alrady returning just IDs/MLS #s without photos table join.

	// now process the order by columns etc.


	if($getcount!==true) {
		if($perpage==-1) {
			// nothing.. this means unlimited query! shouldn't happen tho, do we send email warning when this happens?
		} else if($perpage!='') {
			if($page<1 || $page=='') {$page = 1;} // override to page
			$truepage = $page-1;
			$start = $perpage*$truepage;
			$sqllimit =' LIMIT '.$start.', '.$perpage.'';
		} else {
			$sqllimit =' LIMIT 0, 10'; // if perpage is blank, default to 10 per page so it doesn't crash system!
		}
	} else {
		// getting count, so do NOT run the limitations.
		$sqllimit = '';
	}

	// set up the FINAL sql
	$sql = $sqlhead.$sqlfilter.$sqlorder.$sqllimit;

	$result = $mysqli->query($sql);
	$GLOBALS[BRIX_PAGES_QUERY]++;
	if($getcount===true) {
		// this query ONLY needs the count of properties of such criteria.
		if($result->num_rows>0) {
			$count = $result->fetch_assoc();
			$id = intval(remove_all_but_numbers($count['cnt'])); // return integer, not a string number!
		} else {
			$id = 0;
		}
	} else if($getdata===true) {
		// get data, so more comprehensive array.
		if($result->num_rows>0) {
			$id = array();
			while($home = $result->fetch_assoc()) {
				if($memcache!==false && isset($home['source']) && isset($home['mls']) && count($home)<5) {
					// $home array has less than 5 - it means source, mls, id at most. So run off memcache.
					$memcache_params = array(
						'type'=>'home',
						'listingsource'=>$home['source']
					);
					if($home['source']==1) {
						$memcache_params['mlsnum'] = $home['mls'];
					} else {
						$memcache_params['objectid'] = $home['id'];
					}
					$data = get_memcache($memcache_params);
					if(DEBUG===true) {
						echo "get_properties() retrieving memcache and retrieved ".($data===false ? 'FALSE' : count($data))." rows, from param: <br />".PHP_EOL;
						print_r($memcache_params);
					}

					if(is_array($data)) {
						$data['memcache']=true; // add as a flag to test?
						$id[$home['id']] = $data; // full array to pass as $data
					} else {
						$id[$home['id']] = $home; // No memcache, so just feed ID, mls, source
					}

					// This does NOT do the $id = array('mls'=>'XXXXXX') retrieval for $home object,
					// But this does not matter - we are alrady running it from memcache and the $data will populate the home data.
					// Whether we initiaze the $home object, in thsi case, from ID or MLS # is not relevant for caching or data accuracy.
					// Also, if $data was false (due to no memcache for thsi key) the $home->initialize($id, $data) will feed FALSE for the $data var.
				} else {
					// Non-memcache - the query has ALL the homes table & areas table columns in there.
					$id[$home['id']] = $home;
					// now process using prcoess_home_data(); also used in the $home object.
				}
			}
		} else {
			$id = false;
		}
	} else {
		// regular get IDs only.
		if($result->num_rows>0) {
			$id = array();
			while($home = $result->fetch_assoc()) {
				$id[] = $home['id'];
			}
		} else {
			$id = false;
		}
	}
	if(DEBUG===true) {
		echo '<p><strong>Properties SQL:</strong> '.$sql.'</p>'.PHP_EOL;
		if(!$result) {
			echo '<p><strong>Error:'.$mysqli->error.'</strong></p>'.PHP_EOL;
		} else {
			echo '<p><strong>Num Rows Returned:'.$result->num_rows.'</strong></p>'.PHP_EOL;
		}
	}
	return $id;
}


function get_buildings($query='', $order='name', $asc='asc', $perpage='', $page='', $getcount = false, $getdata = false) {
	global $settings;
	global $square;
	global $mysql_time;
	global $today;
	global $mysqli;
	global $memcache;


	if($getdata===true && $memcache===false) {
		$target_columns = 'b.id as id, b.lat, b.long, b.status, b.land_title, b.feature, b.publish, b.mainid, 
		b.mainphoto, b.pdf, b.pdf_labels, b.virtualtour, b.youtube, b.vimeo, 
		b.name, b.builder, b.heading, b.heading2, b.number, b.street, b.street_dir, b.street_dir_position, b.street_type, b.street_suffix, 
		b.showroom_number, b.showroom_street, b.showroom_street_name, b.showroom_street_type, b.showroom_street_suffix, b.showroom_street_dir, b.showroom_street_dir_position,
		b.showroom_area, b.showroom_city, b.showroom_lat, b.showroom_long, b.showroom_hours,
		b.description, b.description2, b.slug, b.unittypes, b.remarks, b.remarks2, b.excerpt, b.excerpt2, b.website, b.email,
		b.pets, b.rental, b.short_term_rental, b.air_conditioning, b.ev_charging, 
		b.storeys, b.suites, b.construction, b.year, b.strataid, b.min_beds, b.max_beds, b.min_baths, b.max_baths, b.min_price, b.max_price, b.features,
		b.city, b.area, b.area_alt, 
		b.modify_date, b.create_date, b.timestamp, b.metatitle, b.metadescription,
		b.agent_1, b.agent_2, b.agent_3,
		a.name as subarea_name, 
		aa.name AS subarea_alt_name, 
		c.name as city_name, 
		showroom_a.name as showroom_subarea_name,
		showroom_c.name as showroom_city_name,
		  p.id as pid, p.filename as filename, p.timestamp as photo_timestamp ';
	} else if(($getdata===true || $memcache!==false) && $getcount===false) {
		// Data false means just get ID. But, if Memcache is enabled, we can still work off just ID since the loop will be repeated.
		$target_columns = 'b.id as id';
	} else if($getcount===true) {
		$target_columns = ' COUNT(*) as cnt ';
	} else {
		$target_columns = 'b.id as id';
	}

	$sqlhead = "SELECT ".$target_columns." FROM `buildings` b 
	LEFT OUTER JOIN `subareas` a ON b.area=a.id 
	LEFT OUTER JOIN `subareas` aa ON b.area_alt=aa.id 
	LEFT OUTER JOIN `areas` c ON b.city=c.id 
	LEFT OUTER JOIN `subareas` showroom_a ON b.showroom_area=showroom_a.id 
	LEFT OUTER JOIN `areas` showroom_c ON b.showroom_city=showroom_c.id 
	".($getcount===false ? "LEFT OUTER JOIN `photos` p on b.id=p.building" : "")." WHERE 1=1  ";


	$memcache_params = array(
		'type'=>'buildings',
		'query'=>array() // blank for now,
	); // Type is default buildings (do not confuse wtih singular building, which is for single object.
	// more keys will need to be added for the query to activate. Min 3 needed - will need a query type, and  value.

	$sqlfilter = '';
	if(is_array($query)) {
		$count = 0;
		foreach($query as $field=>$value) {
			// first set up the query...
			$condition = '';
			switch($field) {
				case "id":
					$idr = $mysqli->real_escape_string(strtolower(trim($value)));
					$condition = "b.id = '" . $idr . "'";
					$memcache_params['query']['idr'] = $idr;
					break;
				case "name":
					// pretty wide range search. Don't memcache.
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $name) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "LOWER(b.name) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($name))) . "%'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='') {
						$condition = "LOWER(b.name) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%'";
					}
					break;

				case "mainid":
					// for getting sub-buildings
					// Does not change often at all. memcache for sure.
					$mainid = $mysqli->real_escape_string(strtolower(trim($value)));
					if($mainid!=0 && $mainid!='') {
						$condition = "(b.mainid = '" .$mainid. "' AND b.id!='".$mainid."')";
					} else {
						$condition = "b.mainid > '0'";
					}
					$memcache_params['query']['mainid'] = $mainid; // prepare memcache param for qualifie dvars.

					break;

				case "number":
					// pretty wide range search. Don't memcache.
					$condition = "LOWER(b.number) LIKE '" . $mysqli->real_escape_string(strtolower(trim($value))) . "%'";
					break;

				case "street_dir":
					$dir_array = generate_street_dir_array($value);
					if($dir_array) {
						$condition = "(LOWER(b.street_dir) LIKE '" . $mysqli->real_escape_string(strtolower(trim($dir_array[0]))) . "%' OR LOWER(b.street_dir) LIKE '" . $mysqli->real_escape_string(strtolower(trim($dir_array[1]))) . "%')";
					}
					break;

				case "street":
					$streetvar = separate_streetname($value);
					$condition = "LOWER(b.street) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($streetvar[0]))) . "%'";

					break;

				case "status":
					// Combined with city and area, fairly dynamic.."Presales in West Vancouver" type of pages.
					// Should we eventually cache this? I think so.
					// based on status of the buliding. Raw string fed in. such as "coming soon" etc.
					// compare to the $settings['building_status_display']
					$memcache_params['query']['status'] = ''; // status key will be just continous string. .
					if(!is_array($value)) {
						$value = array($value);// force it into array for easy search & process.
					}

					// now lowercase it all for string comparison & trim.
					foreach($value as $key=>$v) {
						$value[$key] = strtolower(trim($v));
					}
					$condition .= '(';

					foreach($settings['building_status_display'] as $statuskey => $statusstring) {
						if(in_array(strtolower($statusstring), $value)) {
							if($statusarraycount>0) {
								$condition.=' OR ';
							}
							$condition .= "b.status='".$statuskey."'";
							$memcache_params['query']['status'].=$statuskey; // If statuses are 0 and 1, this will just read "01"
							$statusarraycount++;
						}
					}
					if ($statusarraycount == 0) {
						//just here to prevent () in SQL statement that gives out an error IF all status strings were invalid.
						$condition .= '1 = 1';
					}

					$condition .= ')';
					break;

				case "statusid":
					// based on IDs 0 to 4.
					$memcache_params['query']['status'] = '';
					if(!is_array($value)) {
						$value = array($value);// force it into array for easy search & process.
					}

					$condition .= '(';
					foreach($value as $key=>$v) {
						$statusid= remove_all_but_numbers(trim($v));
						// clean it up first.

						if($key>0) {
							$condition.=' OR ';
						}
						$condition .= "b.status='".$statusid."'";
						$memcache_params['query']['status'] .= $statusid;
					}
					$condition .= ')';
					break;


				case "land_title":
					// now lowercase it all for string comparison to the ID key.
					foreach($settings['building_land_title_display'] as $title_key => $title_string) {
						if( $title_string !== false && $mysqli->real_escape_string(strtolower(trim($value))) == strtolower($title_string)) {
							$condition .= "b.land_title='".$title_key."'";
						}
					}
					break;

				case "land_title_id":
					$statusid= remove_all_but_numbers(trim($value));
					if($statusid!='') {
						$condition .= "b.land_title='".$statusid."'";
					}

					break;

				case "featured":
				case "feature":
					// featured buildings only - all buildings are auto-generated upon MLS sync so cannot show them all...
					$condition.= " b.feature='1' ";
					$memcache_params['query']['feature'] = 1;
				break;

				case "publish":
					// Allows client to "hide" building temporarily while being edited.
					$condition .= " b.publish='1'";
					$memcache_params['query']['publish'] = 1;
					break;

				case "named":
					// only show those with a custom name (chances are they overlap with feature=1 but whatever.
					$condition.=" b.name!=''";
					break;

				case "pets":
					// Pets allowed filter. If its set in URL without specific value, it means it's a YES.
					if(strtolower($value)=='on' || strtolower($value)=='yes' || $value==1 || $value===true || $value=='') {
						$condition.= " b.pets='1'";
						$memcache_params['query']['pets'] = 1;
					}
					break;

				case "rentals":
					// Regular rentals allowed filter. If its set in URL without specific value, it means it's a YES.
					// Do not confuse with short term rental boolean (condition right below this) added in 2023.
					if(strtolower($value)=='on' || strtolower($value)=='yes' || $value==1 || $value===true || $value=='') {
						$condition.= " b.rental='1'";
						$memcache_params['query']['rental'] = 1;
					}
					break;

				case "short_term_rental":
					// Unlike pets filter, we specifically filter for buildings that do NOT allow as well, for those who are keen to live without parties around them.
					if(strtolower($value)=='on' || strtolower($value)=='yes' || $value==1 || $value===true || $value=='') {
						$condition.= " b.short_term_rental='1'";
						$memcache_params['query']['short_term_rental'] = 1;
					} else if(strtolower($value)=='off' || strtolower($value)=='no' || $value==0 || $value===false){
						$condition.= " b.short_term_rental='0'";
						$memcache_params['query']['short_term_rental'] = 0;
					}
					break;

				case "air_conditioning":
					// A/C Booleans added 2023-01 for Yuliya
					if(strtolower($value)=='on' || strtolower($value)=='yes' || $value==1 || $value===true || $value=='') {
						$condition.= " b.air_conditioning='1'";
						$memcache_params['query']['air_conditioning'] = 1;
					} else if(strtolower($value)=='off' || strtolower($value)=='no' || $value==0 || $value===false){
						$condition.= " b.air_conditioning='0'";
						$memcache_params['query']['air_conditioning'] = 1;
					}
					break;

				case "ev_charging":
					// EV Charge Booleans added 2023-01 for Yuliya
					if(strtolower($value)=='on' || strtolower($value)=='yes' || $value==1 || $value===true || $value=='') {
						$condition.= " b.ev_charging='1'";
						$memcache_params['query']['ev_charging'] = 1;
					} else if(strtolower($value)=='off' || strtolower($value)=='no' || $value==0 || $value===false){
						$condition.= " b.ev_charging='0'";
						$memcache_params['query']['ev_charging'] = 1;
					}
					break;

				case "has_listings":
					// time to show one's own listings
					// this includes source=0 as well as feature=1 all at once.
					if($value=='on' || $value=='yes' || $value==1) {
						$condition.= "((b.status = 1 OR b.status=2 OR b.status=3) OR EXISTS (SELECT id FROM `homes` h
				WHERE h.building = b.id AND h.publish=1 AND h.sold=0) )";
						$memcache_params['query']['has_listings'] = 1;
					}
					break;

				case "min_year":
					if($value!='') {
						$condition.= "(b.year>='".trim(remove_all_but_numbers($value))."' )";
					}
					break;
				// lat long related stuff.
				case "plotted":
					$condition = "(b.lat != 0 AND b.long != 0)";
					break;

				case "lat_min":
					if($value!='' && $value!==false) {
						$condition = "(b.lat >= ".floatval($value)." AND b.lat <= ".floatval($query['lat_max']).")";
					}
					break;

				case "lng_min":
					if($value!='' && $value!==false) {
						$condition = "(b.long >= ".floatval($value)." AND b.long <= ".floatval($query['lng_max']).")";
					}
					break;

				case "city":
					if(is_array($value)) {
						$memcache_params['query']['city'] = ''; // this, separate by comma between, to avoid cofusion of 1 or 2 digit numbers combining
						$condition = '(';
						foreach($value as $citycount => $cityname) {
							$cityid = get_area_id($cityname, 'areas'); // convert city name to ID first.
							if($citycount>0) {
								$condition.=' OR ';
								$memcache_params['query']['city'].=',';
							}
							$condition .= "b.city='".$cityid."'";
							$memcache_params['query']['city'] .= $cityid;
						}
						$condition.= ')';
					} else if($value!='') {
						/*
												$citysql = "SELECT id FROM areas WHERE LOWER(`name`)='".$mysqli->real_escape_string(strtolower(trim($value)))."'";
												$cityresult = $mysqli->query($citysql);
												$cityid = $cityresult->fetch_assoc();
						*/
						$cityid = get_area_id($value, 'areas');
						$condition = " b.city = '" .$cityid. "'";
						$memcache_params['query']['city'] = $cityid;
					}
					break;

				case "area":
					if(is_array($value)) {
						$memcache_params['query']['area'] = '';
						$condition = '(';
						foreach($value as $areacount => $areaname) {
							$subareaid = get_area_id($areaname, 'subareas');
							if($areacount>0) {
								$condition.=' OR ';
								$memcache_params['query']['area'].=',';
							}
							$condition .= "(b.area = '" .$subareaid. "'  OR b.area_alt='".$subareaid."')";
							$memcache_params['query']['area'] .= $subareaid;
						}
						$condition.= ')';
					} else {
						$subareaid = get_area_id($value, 'subareas');
						$condition = "(b.area = '".$subareaid."' OR b.area_alt = '".$subareaid."')";
						$memcache_params['query']['area'] = $subareaid;
					}
					break;

				case "cityid":
					if(is_array($value)) {
						$memcache_params['query']['city'] = '';
						$condition = '(';
						foreach($value as $citycount => $cityid) {
							$cityid = $mysqli->real_escape_string($cityid);
							if($citycount>0) {
								$condition .= ' OR ';
								$memcache_params['query']['city'].=',';
							}
							$condition .= "b.city = '" . intval($cityid) . "'";
							$memcache_params['query']['city'] .= $cityid;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false && $value>0) {
						$condition = "b.city = '" . intval($value) . "'";
						$memcache_params['query']['city'] = $value;
					}
					break;

				case "areaid":
					if(is_array($value)) {
						$memcache_params['query']['area'] = '';
						$condition = '(';
						foreach($value as $areacount=> $areaid) {
							$areaid = intval($mysqli->real_escape_string($areaid));
							if($areacount>0) {
								$condition .= ' OR ';
								$memcache_params['query']['area'] .= ',';
							}
							$condition .= "b.area = '" . $areaid . "' OR b.area_alt='".$areaid."'";
							$memcache_params['query']['area'] = $areaid;
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false && $value>0) {
						$areaid = intval($mysqli->real_escape_string($value)) ;
						$condition = "(b.area = '" .$areaid. "'  OR b.area_alt='".$areaid."')";
						$memcache_params['query']['area'] = $areaid;
					}
					break;

				case "type":
					// too dybnamic, do not cache.
					// unit types (condos, townhomes etc. offered.. not a building type (no such thing).
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $type) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$typeid = get_property_type_id($type);
							$condition .= "unittypes LIKE '%|" . $typeid . "|%'";
							$fieldcount++;
						}
						$condition .= ')';
					} else {
						$typeid = get_property_type_id($value);
						$condition = "unittypes LIKE '%|" . $typeid . "|%'";
					}
					break;

				case "features":
					// too dybnamic, do not cache.
					//SELECT * FROM `buildings` WHERE CONCAT(',',features,',') LIKE '%,7,%'
					$feats_query = 'SELECT * FROM `buildingfeatures`';
					$feats_result = $mysqli->query($feats_query);
					$bldg_feats = '';
					while($feats = $feats_result->fetch_assoc()) {
						$bldg_feats[strtolower($feats['name'])] = $feats['id'];
					}

					//echo 'printing features query';
					//print_r($value);

					if(is_array($value)) {
						$temp_cond = '';
						$fieldcount = 0;
						foreach($value as $type) {
							if ($bldg_feats[strtolower($type)] != '') {

								if($fieldcount>0) {
									$temp_cond .= ' AND ';
								}
								$temp_cond .= "CONCAT(',',features,',') LIKE '%," . $bldg_feats[strtolower($type)] . ",%'";
								$fieldcount++;

							}
						}
						if ($temp_cond != '') $condition .= '('.$temp_cond.')';
					} else {
						if ($bldg_feats[strtolower($value)] != '') {
							$condition = "CONCAT(',',features,',') LIKE '%," . $bldg_feats[strtolower($value)] . ",%'";
						}
					}
					break;

				case "agent":
					// Filter by array of agent id - these ids are internally generated.
					if(is_array($value)) {
						$memcache_params['query']['agent'] = '';
						$condition = ' ('; // start with blank for this
						foreach($value as $key=>$agent_id) {
							$agent_id = $mysqli->real_escape_string(strtolower(trim($agent_id)));
							if ($key > 0) {
								$condition .= " OR ";
								$memcache_params['query']['agent'].=',';
							}
							$condition .= " (agent_1 = ' ".$agent_id." ' OR agent_2 = ' ".$agent_id." ' OR agent_3 = ' ".$agent_id." ' ) ";
							$memcache_params['query']['agent'].=$agent_id;
						}
						$condition .= ') ';
					} else {
						$agent_id = $mysqli->real_escape_string(strtolower(trim($value)));
						$condition = " (agent_1 = '" . $agent_id . "' OR agent_2='".$agent_id."'  OR agent_3='".$agent_id."')";
						$memcache_params['query']['agent']=$agent_id;
					}
					break;


				default:
					break;
			}
			if($condition!='') {
				// if condition is not blank, that means the passed var had good merit and created a condition
				if($count==0) {
					$sqlfilter .= " AND ("; // if it's the first condition block, start a bracket.
					$sqlfilter .= $condition;
				} else {
					$sqlfilter .= " AND ".$condition; // if it's not the first one, keep adding conditions with AND without brackets
				}
				$count++;
			}
		}
		$sqlfilter .= ')'; // close this condition block with a bracket
	}

	if($getcount===false) {
		$memcache_params['query']['orderby'] = '';
		$memcache_params['query']['asc'] = '';
		// when gettin count we do NOT group at all
		$sqlfilter .= ' GROUP BY id ';
		if(is_array($order)) {
			// multiple order columns, in sequence.
			if(!is_array($asc)) {
				$usesingularasc = 1;
			} else {
				$usesingularasc = 0;
			}
			foreach($order as $key=>$column) {
				$memcache_params['query']['orderby'] .= $column;
				if($usesingularasc==1) {
					// no matter how many column arrays, they are all one order directive only (ASC or DESC) so do not use the array.
					$columnasc = $asc;
					$memcache_params['query']['asc'] = $columnasc;
				} else {
					// $asc is ALSO an array, so we match them up.
					$columnasc = $asc[$key]; // match the key first.
					if($columnasc=='') {
						// if $columnasc is blank, that means not enough arrays were given..
						// i.e. $order_by was array('ord', 'feature', 'create_date') and the $asc only had array('ASC', 'DESC');
						// so then we default to the last available array.
						$columnasc = $asc[count($asc)-1];
					}
					$memcache_params['query']['asc'] .= $columnasc;
				}

				if($key>0) {
					$sqlorder.= ', '.generate_order_line($column, $columnasc, 'building');
				} else {
					$sqlorder = 'ORDER BY '.generate_order_line($column, $columnasc, 'building');
				}
			}
		} else if($order!='') {
			$memcache_params['query']['orderby'] = $order;
			$memcache_params['query']['asc'] = $asc;
			$sqlorder = 'ORDER BY '.generate_order_line($order, $asc, 'building');
		} else {
			// no order given whatsoever - default to ord by ASC
			$memcache_params['query']['orderby'] = 'ord';
			$memcache_params['query']['asc'] = 'asc';
			$sqlorder = 'ORDER BY '.generate_order_line('ord', 'ASC', 'building');
		}

		if($perpage==-1) {
			// nothing.. this means unlimited query! shouldn't happen tho, do we send email warning when this happens?
		} else if($perpage!='') {
			if($page<1 || $page=='') {$page = 1;} // override to page
			$truepage = $page-1;
			$start = $perpage*$truepage;
			$sqllimit =' LIMIT '.$start.', '.$perpage.'';
			$memcache_params['query']['page'] = $page.','.$perpage;
		} else {
			$sqllimit =' LIMIT 0, 10'; // if perpage is blank, default to 10 per page so it doesn't crash system!
			$memcache_params['query']['page'] = '0,10';
		}
	} else {
		// getting count, so do NOT run the limitations.
		$sqllimit = '';
		$sqlorder = ''; // no need for order by when getting count.
		$memcache_params['query']['getcount']=1;
	}

	if(DEBUG==true) {
		echo "memcache_params stacked so far:".PHP_EOL;
		var_dump($memcache_params);
	}

	if(count($memcache_params['query'])>0) {
		// by default, 'type'=='building' is set.
		// To generate a memcache key that's not ALL THE BUILDINGS, it needs at least one query set.
		if(logged_in()) {
			// logged in user! kill memcache. This is probably the realtors/agents updating and checking results.
			// This also force-expires the results cache from all front-end pages.
			get_memcache($memcache_params, 'delete');
			$memcache_data = false;
		} else {
			$memcache_data = get_memcache($memcache_params);
		}

		if(DEBUG===true) {
			echo "get_buildings() memcache retrieved ".(is_countable($memcache_data) ? count($memcache_data) : "FALSE")." rows with parameters: <br />".PHP_EOL;
			print_r($memcache_params);
		}
		if(is_array($memcache_data)) {
			$rows = $memcache_data;
		} else {
			// Get Full SQL
			$sql = $sqlhead.$sqlfilter.$sqlorder.$sqllimit;
			$result = $mysqli->query($sql);
			if(DEBUG===true) {
				echo "get_buildings() SQL: ".$sql." with ".($result===false ? "FALSE" : $result->num_rows)." returned.<br />".PHP_EOL;
				if($result===false) {
					echo "MySQL Error: ".$mysqli->error."<br />".PHP_EOL;
				}
			}
			if($getcount===true) {
				// single row return..
				$rows =  $result->fetch_assoc();

			} else {
				$rows = array();
				if($result->num_rows>0) {
					while($building = $result->fetch_assoc()) {
						$rows[] = $building; // add each row to $data.
					}
				} else {
					$rows = false;
				}
			}
			if(DEBUG===true) {
				echo "Save building cache (".count($rows).") with params:".PHP_EOL;
			}
			get_memcache($memcache_params, $rows);
			$GLOBALS[BRIX_PAGES_QUERY]++;
		}
	}

	if($getcount===true) {
		// this query ONLY needs the count of properties of such criteria.
		if(isset($rows['cnt'])) {
			$id = intval($rows['cnt']);
		} else {
			$id = 0;
		}
	} else if($getdata===true) {
		// get data, so more comprehensive array.
		if(is_array($rows) && count($rows)>0) {
			foreach($rows as $building) {
				if($memcache!==false && count($building)<3) {
					$memcache_params = array(
						'type'=>'building',
						'objectid'=>$building['id']
					);
					$data = get_memcache($memcache_params);
					if(DEBUG===true) {
						echo "get_buildings() looping through buildings ".$building['id'].", got ".($data===false ? 'FALSE' : count($data))." rows, from param: <br />".PHP_EOL;
						print_r($memcache_params);
					}
					if(is_array($data)) {
						$data['memcache']=true; // add as a flag to test?
						$id[$building['id']] = $data; // full array to pass as $data
					} else {
						$id[$building['id']] = $building['id']; // No memcache yet, so just feed ID only, $agent->initialize() can do the work.
					}
				} else {
					// full $data==true for all columns of buildings table row returned.
					$data = $building;
					$id[$building['id']] = $data;
				}
			}
		} else {
			$id = false;
		}
	} else {
		// regular get IDs only.
		if(is_array($rows)) {
			foreach($rows as $row) {
				$id[] = $row['id'];
			}
		} else {
			$id = false;
		}
	}
	return $id;
}

function get_area_id($string, $table = 'areas') {
	// security cleanups!
	global $mysqli;
	$string = strtolower(trim($mysqli->real_escape_string($string)));
	$table = strtolower(trim($mysqli->real_escape_string($table)));

	if($table=='areas' && is_array($GLOBALS[BRIX_AREAS_CACHE])) {
		$search_array = BRIX_AREAS_CACHE;
	} else if($table=='subareas' && is_array($GLOBALS[BRIX_SUBAREAS_CACHE])) {
		$search_array = BRIX_SUBAREAS_CACHE;
	}


	foreach($GLOBALS[$search_array] as $array) {
		if(strtolower($array['name']) == $string) {
			$result = $array['id'];
		}
	}
	return $result;
}

/**
 * @param string $query Array of ['publish']=1, or ['feature']=1 etc. or you can pass name like ['name']="West Vancouver"
 * @param string $order Order by feature Desc? (so that featured ones come first?) or just asc by name (Default if you leave it)
 * @param string $asc Defaults to 'asc' assuming it's by name (alphabetical) but can pass 'desc' - case insensitive.
 * @return array|bool
 */
function get_areas($query='', $order='name', $asc='asc') {
	// simplified compared to other fetch stuff, since list is short. no need for paginations, limits etc.
	global $mysqli;

	if(is_array($GLOBALS[BRIX_AREAS_CACHE]) && count($GLOBALS[BRIX_AREAS_CACHE])>0) {
		// clean up the $query!
		if($query!='') {
			foreach ($query as $field => $value) {
				$query[$field] = cleanupforentry($value);
				if ($field == 'name') {
					// to compare names, lowercase it.
					$query[$field] = strtolower($value);
				}
			}
		} else {
			$query = false;
		}

		$filtered = array(); // filtered array defaults to blank.
		// first, go thorugh the array and return by filter!
		foreach ($GLOBALS[BRIX_AREAS_CACHE] as $area) {
			if($query) {
				foreach ($query as $field => $value) {
					// echo 'Fetching '.$field.'=='.$value.' against '.strtolower($area[$field]).'<br />';
					if (strtolower($area[$field]) == $value && !in_array($area, $filtered)) {
						// match it, but also prevent duplicates.
						// For example when on homes_mod.php or buildings_mod.php,
						// instances where we search for publish=1 OR name=port moody, port moody can return twice if we dont' check in_array().
						$filtered[] = $area;
					}
				}
			} else {
				// no filter, use it all!
				$filtered[] = $area;
			}

		}

		if(count($filtered)>0 && is_array($filtered)) {
			// reorder based on criteria.
			$array_dir = (strtolower($asc) == 'asc' ? SORT_ASC : SORT_DESC);
			array_sort_by_column($filtered, $order, $array_dir);
			foreach($filtered as $area) {
				$array[] = $area['id'];
			}
		} else {
			$array = false;
		}

	} else {

		$sqlhead = "SELECT `id`, `name`, `publish`, `feature` FROM `areas` WHERE id!='' ";

		$sqlfilter = '';
		if(is_array($query)) {
			$count = 0;
			foreach($query as $field=>$value) {
				// first set up the query...
				$condition = '';
				switch($field) {

					case "name":
						if(is_array($value)) {
							$condition = '(';
							$fieldcount = 0;
							foreach($value as $name) {
								if($fieldcount>0) {
									$condition .= ' OR ';
								}
								$condition .= "LOWER(`name`) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($name))) . "%'";
								$fieldcount++;
							}
							$condition .= ')';
						} else if($value!='') {
							$condition = "LOWER(`name`) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%'";
						}
						break;

					case "feature":
						// time to show one's own listings
						// this includes source=0 as well as feature=1 all at once.
						$condition.= " `feature`='1'";
						break;

					case "publish":
						// time to show one's own listings
						// this includes source=0 as well as feature=1 all at once.
						$condition.= " `publish`='1'";
						break;
					default:
						break;
				}
				if($condition!='') {
					// if condition is not blank, that means the passed var had good merit and created a condition
					if($count==0) {
						$sqlfilter .= " AND ("; // if it's the first condition block, start a bracket.
						$sqlfilter .= $condition;
					} else {
						$sqlfilter .= " AND ".$condition; // if it's not the first one, keep adding conditions with AND without brackets
					}
					$count++;
				}
			}
			$sqlfilter .= ')'; // close this condition block with a bracket
		}

		// now process the order by columns etc.
		if(is_array($order)) {
			// multiple order columns, in sequence.
			if(!is_array($asc)) {
				$usesingularasc = 1;
			} else {
				$usesingularasc = 0;
			}
			foreach($order as $key=>$column) {
				if($usesingularasc==1) {
					// no matter how many column arrays, they are all one order directive only (ASC or DESC) so do not use the array.
					$columnasc = $asc;
				} else {
					// $asc is ALSO an array, so we match them up.
					$columnasc = $asc[$key]; // match the key first.
					if($columnasc=='') {
						// if $columnasc is blank, that means not enough arrays were given..
						// i.e. $order_by was array('ord', 'feature', 'create_date') and the $asc only had array('ASC', 'DESC');
						// so then we default to the last available array.
						$columnasc = $asc[count($asc)-1];
					}
				}

				if($key>0) {
					$sqlorder.= ', '.generate_order_line($column, $columnasc, "area");
				} else {
					$sqlorder = 'ORDER BY '.generate_order_line($column, $columnasc, "area");
				}
			}
		} else if($order!='') {
			$sqlorder = 'ORDER BY '.generate_order_line($order, $asc, "area");
		} else {
			// no order given whatsoever - default to ord by ASC
			$sqlorder = 'ORDER BY '.generate_order_line('ord', 'ASC', "area");
		}
		// set up the MAIN sql
		$sql = $sqlhead.$sqlfilter.$sqlorder;

		if(DEBUG===true) {
			echo "Query: ".$sql."<br />\r\n";
		}

		$result = $mysqli->query($sql);
		$GLOBALS[BRIX_PAGES_QUERY]++;
		if($result->num_rows==0) {
			$array = false; // negative results for this children pages query
		} else {
			while($area = $result->fetch_assoc()) {
				$array[] = $area['id'];
			}
		}
	}

	return $array;
}



function get_google_geocode($number, $street, $streettype, $streetdir = '', $city = '') {
	// uses raw $data from MLS before it was conveted to $value_data, as $value_data['city'] will contain ID, not a string of the city name...
	// connect to Google for lat/long
	global $mysqli;
	global $cities;
	global $subareas;
	global $settings;

	$address = urlencode($number." ".($streetdir!='' ? $streetdir.' ' : '').$street." ".$streettype.", ".$city.", ".$settings['province']." ".$settings['country']);
	$url = "https://maps.googleapis.com/maps/api/geocode/json?address=$address&sensor=false";
	$opts = array('http' => array('method' => "GET"));
	$context = stream_context_create($opts);
	$content = @file_get_contents($url, false, $context);
	$position = json_decode($content, true);
	if ($position['status'] == 'OK') {
		$result = true;
		$lat = $position['results'][0]['geometry']['location']['lat'];
		$lng = $position['results'][0]['geometry']['location']['lng'];
	} else {
		$result = false;
		$lat = '';
		$lng = '';
	}
	return array($result, $lat, $lng);
}



function get_subareas($area) {
	// simplified compared to other fetch stuff, since list is short. no need for paginations, limits etc.
	global $mysqli;

	$area = cleanupforentry($area);

	$subareas = array();
	foreach($GLOBALS[BRIX_SUBAREAS_CACHE] as $subareaarray) {
		if($subareaarray['area']==$area) {
			$subareas[] = $subareaarray['id'];
		}
	}

	if(count($subareas)==0) {
		$subareas = false; // negative results for this children pages query
	}

	return $subareas;
}

/**
 * Returns boolean (true or false) on whether polygon is part of it or not.
 * @param $polygon JSON or array of polygon coordinates (from area, city, or custom field)
 * @param $lat duh
 * @param $lng duh
 */
function in_polygon($polygon, $lat, $lng) {

}


function generate_order_line($column, $asc = 'DESC', $type = 'home') {
	// goes into get_properties() or get_buildings, this function is rarely if not ever used alone.
	switch ($type) {
		case "home":
			$prepend = 'h.';
			break;

		case "building":
			$prepend = 'b.';
			break;

		case "agent":
			$prepend = 'a.';
			break;

		case "resourcecategory":
			$prepend = 'c.';
			break;

		case "resource":
			$prepend = 'r.';
			break;

		case "area":
		case "subarea":
		default:
			$prepend = '';
			break;
	}


	switch($column) {

		case "price":
			$sqlorder = " ".$prepend."i_price ".$asc;
			break;

		case "rental_price":
			$sqlorder = " i_rental_price_month ".$asc.", i_rental_price_month ".$asc.", i_rental_price_month ".$asc;
			break;

		case "ord":
			$sqlorder = " ".$prepend."ord ".$asc;
			break;

		case "sold":
			$sqlorder = " ".$prepend."sold ".$asc;// only applies to homes anyway.
			break;

		case "create_date":
			$sqlorder = " ".$prepend."create_date ".$asc;
			break;

		case "bedroom":
			$sqlorder = " i_bedroom ".$asc;
			break;

		case "bathroom":
			$sqlorder = " i_bathroom ".$asc;
			break;

		case "sqft":
			$sqlorder = " i_sqft ".$asc;
			break;

		case "lot":
			$sqlorder = " i_lot ".$asc;
			break;

		// building stuff here
		case "name":
			$sqlorder = " ".$prepend."name ".$asc;
			break;

		case "street":
			$sqlorder = " ".$prepend."street ".$asc;
			break;

		case "number":
			$sqlorder = " ".$prepend."number ".$asc;
			break;

		// other random stuff.
		case "random":
			$sqlorder = " RAND() ";
			break;

		case "b.random":
			$sqlorder = " RAND() ";
			break;

		case "city":
			$sqlorder = " city_name ".$asc; // c.name as city_name is how we retrieve.
			break;

		case "area":
			$sqlorder = " subarea_name ".$asc.", subarea_alt_name ".$asc; // c.name as city_name is how we retrieve.
			break;

		default:
			$sqlorder = " ".$column." ".$asc;
			break;
	}
	return $sqlorder;
}



function generate_listings_url($params) {
	global $settings;
	// first convert the $params array, by key, to a $param var,
	if($params['listing_search_city']!='') {
		$query['city'] = $params['listing_search_city'];
	}

	if($params['listing_search_subarea'][0]!='') {
		$query['area'] = $params['listing_search_subarea'];
	}

	if($params['listing_search_type']!='') {
		$query['type'] = $params['listing_search_type'];
	}

	if($params['listing_bldg']!='') {
		$query['bldg'] = $params['listing_bldg'];
	}


	if($params['listing_search_min_bedrooms']!='') {
		$query['bedroom'] = $params['listing_search_min_bedrooms'];
	}
	if($params['listing_search_min_bathrooms']!='') {
		$query['bathroom'] = $params['listing_search_min_bathrooms'];
	}

	if($params['listing_search_min_sqft']!='') {
		$query['min_sqft'] = $params['listing_search_min_sqft'];
	}

	if($params['listing_search_max_sqft']!='') {
		$query['max_sqft'] = $params['listing_search_max_sqft'];
	}

	if($params['listing_search_min_price']!='') {
		$query['min_price'] = $params['listing_search_min_price'];
	}

	if($params['listing_search_max_price']!='') {
		$query['max_price'] = $params['listing_search_max_price'];
	}

	if($params['listing_order_by']!='') {
		$query['order_by'] = $params['listing_order_by'];
		$query['order_direction'] = ($params['listing_order_direction']!='' ? $params['listing_order_direction'] : 'DESC');
	}

	$query['page'] = 1;

	$url = $settings['sitepath'].($params['listing_custom_filename']!='' ? $params['listing_custom_filename'] :'listings');
	foreach($query as $key=>$value) {
		$url .= '/'.$key.'-';
		if(is_array($value)) {
			$arraycount = 0;
			foreach($value as $arrayvar) {
				if($arraycount>0) {
					$url .= ';';
				}
				$url .= urlencode($arrayvar);
				$arraycount++;
			}
		} else {
			$url.=urlencode($value);
		}
	}

	return $url;
}
//Build out seperate seach desc files for more flexibility
function generate_search_desc_bed_bath($query, $options = array()){

	if(isset($options['separator'])===false || $options['separator']=='') {
		$options['separator'] = ', '; // Almost always loop!!!!
	}
	$separator = $options['separator'];

	$speccomma = false; // do not put commas as default in case we dont have enough.
	$return = '';

	if(array_key_exists('bedroom', $query) && $query['bedroom']!='') {
		$return.= ($speccomma==true ? $separator : ' ').$query['bedroom'].' Bedroom'.($query['bedroom']==1 ? '' : 's').'';
		$speccomma = true;
	}

	if(array_key_exists('min_bedroom', $query) && $query['min_bedroom']!='') {
		$return.= ($speccomma==true ? $separator : ' ').'Minimum '.$query['min_bedroom'].' Bedroom'.($query['min_bedroom']==1 ? '' : 's').'';
		$speccomma = true;
	}

	if(array_key_exists('bathroom', $query) && $query['bathroom']!='') {
		$return.= ($speccomma==true ? $separator : ' ').$query['bathroom'].' Bathroom'.($query['bathroom']==1 ? '' : 's').'';
		$speccomma = true;
	}

	if(array_key_exists('min_bathroom', $query) && $query['min_bathroom']!='') {
		$return.= ($speccomma==true ? $separator : ' ').'Minimum '.$query['min_bathroom'].' Bathroom'.($query['min_bathroom']==1 ? '' : 's').'';
		$speccomma = true;
	}

	return $return;
}
function generate_search_desc_features($query, $options = array()){

	if(isset($options['spec_comma'])===false || $options['spec_comma']=='') {
		$options['spec_comma'] = false; // Almost always loop!!!!
	}

	$speccomma = $options['spec_comma'];

	global $settings;


	foreach($settings['home_features'] as  $featuredesc => $featurefield) {
		// waterfront, golf course, marinaside etc. site influences.
		if(array_key_exists($featurefield, $query)) {
			// there's no value here, this one just gets waterfront added.
			//
			$return .= ($speccomma==true ? ', ' : ' ').$featuredesc;
			$speccomma = true;
		}
	}
	return $return;
}

function generate_search_desc_type_location($query, $options = array()){
	//
	if(isset($options['spec_comma'])===false || $options['spec_comma']=='') {
		$options['spec_comma'] = false; // Almost always loop!!!!
	}

	//will pull type in area, city or buiding if building is set
	//TODO: Need to build an option to change the building prefix depending if its sold out or has listings
	if($query['searchtype']=='buidling') {
		$return  = 'Units'; // defaults to Listings
	}

	$speccomma = $options['spec_comma'];

	if(array_key_exists('type', $query)) {
		if(is_array($query['type']) && count($query['type'])>0) {
			$return = ($speccomma==true ? '' : ' ').''; // if there are specs added such as bed/bath/price, then ammend with a space before goinginto something else.
			foreach($query['type'] as $key=>$type) {
				if($key>0) {
					$return.='/'; // if it's not first one, add a divider before the last home type
				}
				$return.=pluralize(ucwords($type)); // putting in 2 to force plural, but not really just 2 listings.
			}
		} else if($query['type']!='') {
			// singular?
			$return = ($speccomma==true ? ' ' : ' ').pluralize(ucwords($query['type']));
		}
	} else {
		if(isset($query['commercial'])) {
			// Commercial search without specific type such as Industrial or Retail.
			$return = 'Commercial Listings';
		} else if(isset($query['residential'])) {
			// If /residential/ is explicitly set, lets assume it's a site that has both comm and res, so nice to specify.
			$return = 'Residential Listings';
		} else {
			// defaults to Listings
			$return = 'Listings';
		}
	}

	if(array_key_exists('bldg', $query)) {
		// building query
		$building = new building;
		$building->initialize($query['bldg']);
		if($building->defaultname) {
			// default address name.. "at" prefix.
			$return.= ' for sale at '.$building->name;
		} else {
			$return.= ' for sale at '.$building->name.' ('.$building->address.', '.$building->city.')';
		}
	} else {
		if (array_key_exists('street', $query)) {
			$return.=' on '. ucwords($query['street']);
		} else if (array_key_exists('street_dir', $query)
			|| array_key_exists('street_name', $query)
			|| array_key_exists('street_type', $query)
			|| array_key_exists('street_suffix', $query)) {

			$return.=' on '. ucwords(implode(' ', array_filter([$query['street_dir'], $query['street_name'], $query['street_type'], $query['street_suffix']])));
		}

		if(array_key_exists('area', $query)) {
			// area exists.. so we'll skip city and go straight to subareas.
			if(is_array($query['area']) && count($query['area'])>0) {
				$return.=' in ';
				foreach($query['area'] as $key=>$areaname) {
					if($key>0) {
						if(count($query['area'])==2) {
							$return.=' &amp; '; // if there's only two areas, use ampersand to separate
						} else {
							$return.=', '; // if it's not first one, add a comma before the last area name..
						}
					}
					$return.= ucwords($areaname);
				}
			} else if($query['area']!='') {
				// singular area
				$return.=' in '.ucwords($query['area']);
			}
			$subarea_exists = 1;
		}
	}


// no area specified, detect if city is here.
	if(is_array($query['city']) && count($query['city'])>0) {
		if($subarea_exists!=1) {
			$return.=' in ';
		} else {
			$return.=', ';
		}
		foreach($query['city'] as $key=>$cityname) {
			if($key>0) {
				if(count($query['city'])==2) {
					$return.=' &amp; ';
				} else {
					$return.=', '; // if it's not first one, add a comma before the last home type
				}
			}
			$return.= ucwords($cityname);
		}
	} else if($query['city']!='') {
		// singular area
		if($subarea_exists!=1) {
			$return.=' in ';
		} else {
			$return.=', ';
		}
		$return.=ucwords($query['city']);
	}

	// little SEO touch
	$return .= ' For Sale';

	return $return;

}

function generate_search_desc_price_minmax($query, $options = array()){

	if(isset($options['spec_comma'])===false || $options['spec_comma']=='') {
		$options['spec_comma'] = false; // Almost always loop!!!!
	}
	if(isset($options['separator'])===false || $options['separator']=='') {
		$options['separator'] = ', '; // Almost always loop!!!!
	}

	$speccomma = $options['spec_comma'];
	$separator = $options['separator'];

	if(isset($options['prefix_descriptor'])===false || $options['prefix_descriptor']=='') {
		if ($query['max_price']!=''){
			$options['prefix_descriptor'] = 'Priced between';
		}else{
			$options['prefix_descriptor'] = 'Priced from';
		}
	}

	$prefix_desc = $options['prefix_descriptor'];

	$minprice = false;

	if(array_key_exists('min_price', $query) && $query['min_price']!='') {
		$return.= ($speccomma==true ? $separator : ' '). $prefix_desc .' '.dollar_amount_display($query['min_price']);
		$speccomma = true;
		$minprice = true;
	}

	if(array_key_exists('max_price', $query) && $query['max_price']!='') {
		$return.= ($speccomma==true && $minprice==false ? $separator : ' ').($minprice ? ' to ': 'Priced Up To ').($query['max_price']>0 ? dollar_amount_display($query['max_price']) : 'Unlimited');
		$speccomma = true;
	}
	return $return;
}
function generate_search_desc_sqft_minmax($query, $options = array()){

	if(isset($options['spec_comma'])===false || $options['spec_comma']=='') {
		$options['spec_comma'] = false; // Almost always loop!!!!
	}
	if(isset($options['separator'])===false || $options['separator']=='') {
		$options['separator'] = ', '; // Almost always loop!!!!
	}

	$return = '';
	$speccomma = $options['spec_comma'];
	$separator = $options['separator'];

	if(isset($options['prefix_descriptor'])===false || $options['prefix_descriptor']=='') {
		if ($query['max_sqft']!=''){
			$options['prefix_descriptor'] = 'Between';
		}else{
			$options['prefix_descriptor'] = 'From';
		}
	}

	$prefix_desc = $options['prefix_descriptor'];

	$minsqft = false;

	if(array_key_exists('min_sqft', $query) && $query['min_sqft']!='') {
		$return.= ($speccomma==true ? $separator : ' '). $prefix_desc .' '.$query['min_sqft'].' sqft';
		$speccomma = true;
		$minsqft = true;
	}

	if(array_key_exists('max_sqft', $query) && $query['max_sqft']!='') {
		$return.= ($speccomma==true && $minsqft==false ? $separator : ' ').($minsqft ? ' to ': 'Up To '). $query['max_sqft'].' sqft';
		$speccomma = true;
	}
	return $return;
}


function generate_search_desc($query, $params='') {
	/*
	* This function is meant to generate a title & Description array pair based on
	* the $query vars passed through. Same $query vars pass through as get_properties().
	* For example, array('type'=>'1, 2', 'min_price'=>1000000, 'city'=>'Vancouver') returns
	* array('title'=>'Vancouver Houses/Condos Over $1,000,000']';
	*/
	global $settings;

	$desc = 'You are browsing ';

	// set the prefixes fist, such as "FEatured" or "Sold" etc. basic opening statements.
	if(array_key_exists('feature', $query)) {
		switch ($query['feature']) {
			case 1:
				$prefix = "Featured ";
				break;
		}
	} else if(array_key_exists('status', $query)) {
		// buildings!
		switch ($query['status']) {
			case 1:
				$prefix = "Featured ";
				break;
		}
	}

	$prefix = '';
	//Call function that builds bed bath seach description string
	$prefix.= generate_search_desc_bed_bath($query);

	$search_desc_option = array();
	$search_desc_option['spec_comma'] = false;

	if ($prefix != ''){
		$search_desc_option['spec_comma'] = true;
	}

	$prefix .= generate_search_desc_features($query, $search_desc_option);
	// start the suffixes that follow after listing type
	// open houses
	if(array_key_exists('openhouse', $query)) {
		$suffix.= ' with open houses';
	} else {
		// if we end at "with open houses" it's pretty obvious it's for sale, so lets skip it.
		if(array_key_exists('for_rent', $query) && $query['for_rent']!='') {
			$suffix.= ' For Rent';
		} else {
			$suffix.= ' For Sale';
		}
	}

	$suffix = generate_search_desc_price_minmax($query, $search_desc_option);


	if(array_key_exists('pets', $query) && $query['pets']=='on') {
		$suffix.= ($speccomma==true ? ', ' : ' ').'That Allow Pets';
		$speccomma = true;
	}

	if(array_key_exists('furnished', $query) && $query['furnished']!='') {
		$suffix.= ($speccomma==true ? ' and is ' : ' ').($query['furnished']=='yes' ? 'Furnished' : 'Un-Furnished');
		$speccomma = true;
	}

	if(array_key_exists('waterfront', $query) && $query['waterfront']!='') {
		$suffix.= ($speccomma==true ? ', ' : ' ').('Waterfront');
		$speccomma = true;
	}

	$title = generate_search_desc_type_location($query);

	// now detect page # - this avoids duplicate title tags all over.
	if(is_array($params) && array_key_exists('page', $params)) {
		// singular?
		$title .= ' ('.ucwords($params['page']).')';
	}

	$title = $prefix.' '.$title.$suffix;

	$desc = $desc.$title.' on '.$settings['title'].'.';

	return array($title, $desc);

}

function generate_pagelinks($sold = '', $query=array(), $order='ord', $asc='asc', $perpage=10, $page='',$displaynum = 5, $nextprev=0, $params='', $fileurl='listings', $type_queried = 'listings', $returncount = false) {
	// Generates page links for proeprties when the # of proeprties exceeds the required #s.
	global $settings;
	global $pagelinkshtml; // most commonly used variable. This only needs to run once per page, so if its run again, then we just ignore!

	$exclude = array(
		'page',
		$fileurl,
		'oldhome'
	);
	// param keys to avoid copying over to new URL. page is definitely sometihng that needs re-set, not repeated!

	if($pagelinkshtml!='' && isset($pagelinkshtml)) {
		return $pagelinkshtml; // if already set, return the result wihtout another accidental query!
	} else {
		switch($type_queried) {
			case 'buildings':
				$sum = get_buildings($query, $order, $asc, 100000,1, true, false);
				break;

			case 'listings':
			default:
				$sum = get_properties('',$query,$order, $asc, 100000,1,true, false);
				break;
		}
		// we have the sum without any filters, so lets divide to pages now.
		if(DEBUG===true) {
			echo "Total listings returned for pagecount: ".$sum."<br />".PHP_EOL;
		}
		if($perpage=='') {
			$perpage = 10;
		}
		$numpages = ceil($sum/$perpage);
		if($page=='' || !isset($page) || is_null($page)) {
			$page = 1;
		}

		if($displaynum>$numpages) {
			$displaynum = $numpages;
		}

		if($page-ceil($displaynum/2) <= 0) {
			// we are way early.. start at the beginning
			$startpage = 1;
		} else if($page+floor($displaynum/2)>=$numpages) {
			// going over
			$startpage = $numpages-$displaynum+1;
		} else {
			$startpage = $page-floor($displaynum/2);
		}

		$count = $startpage;
		$end = $startpage+$displaynum;
		$return = '';

		if($fileurl!='') {
			//$urlbase = $fileurl;
			$urlbase = str_replace($settings['sitepath'], '', $fileurl);
			// failsafe in case whole URL is passed in.
		} else {
			// default to current running php file path.. i.e. if it's listings.php, then make it listings/
			$urlbase = str_replace('/','',($filename!='' ? $filename : $_SERVER['SCRIPT_NAME'])); // default to the template file being run, and if not on the template system, then the script name running at top. All new template sites will be running off of template.php.
		}
		if($numpages>1) {
			if(DEBUG===true) {
				echo "Splitting to : ".$numpages." in a loop, current page is ".$page.".<br />".PHP_EOL;
			}
			while($count<$end) {
				$url = $urlbase; // start fresh from base!
				if(is_array($params)) {
					foreach($params as $key=>$value) {
						if(!in_array($key, $exclude)) {
							if(is_array($value)) {
								$paramvar = '';
								foreach($value as $paramcount=>$val) {
									if($paramcount>0) {
										$paramvar.=';';
									}
									$paramvar.= urlencode(str_replace('/', '|', urldecode($val)));
								}
								$url.='/'.$key.'-'.$paramvar;
							} else if($value!='') {
								$url.='/'.$key.'-'.urlencode(str_replace('/', '|', urldecode($value)));
							} else {
								$url.='/'.$key;
							}
						}
					}
				}

				$url.='/page-'.$count.'/';


				if($page==$count) {$addclass = ' currentpage';} else {$addclass='';}
				$return.='<div class="listing_page_nav'.$addclass.'"><a href="'.$settings['sitepath'].$url.'">'.$count.'</a></div>';
				$count++;
			}
		} else {
			if(DEBUG===true) {
				echo "No pagination needed!<br />".PHP_EOL;
			}
			// if theer's only 1 page worth, we don't need to return anything.
			// this ELSE statement here is to clarify that... kinda like a "This page intentionally left blank."
			// No action needs to be taken.
		}
		return $return;
	}
}

/**
 * Generates page links for the agents roster.
 *
 * @param string $page_by - The url param we'll be paging by. Can be <b>fname</b> (first name), <b>lname</b> (last name) or <b>name</b> (either first or last name). Default is <b>fname</b>.
 * @param array $query - The query params we'll be getting our agents from. Same as the one being used to retrieve the agents.
 * @param string $order_by - Agents order by. Default is <b>ord</b>
 * @param string $order_direction - Direction of ordering. Default is <b>asc</b>
 * @param int $min_to_page - Minimum # of agents for us to generate pagination. No need to have pages if we only have a couple of agents, for instance. Default is <b>10</b>.
 * @param array $params - Params retrieved from the current url, so we can build the page links with that.
 * @param string $fileurl - The php file name that we're running this function. Used to append this at the url so we stay on the same php page.
 * @param string $scroll_to - The HTML element ID we want the page to scroll to when loading a new page.
 *
 * @return string - the pages links (HTML)
 */
function generate_agents_pagelinks ($page_by = 'fname', $query = [], $order_by = 'ord', $order_direction = 'asc', $min_to_page = 10, $params = [], $fileurl = '', $scroll_to = '') {
	global $settings;
	$return = '';

	// Remove any pagination already in use, so we can process all the agents
	unset($query['fname']);
	unset($query['lname']);
	unset($query['name']);

	$agents = list_agents($query, $order_by, $order_direction, '', 1, false, true);

	if (count($agents) > $min_to_page) {

		// Creates the alphabeth array that will hold the counts per letter.
		$pages_array = array_fill_keys(range('A', 'Z'), 0);

		// Count how many agents per leter there is, so we can disable the ones with 0
		foreach ($agents as $agent_data) {
			$agent = new agent;
			$agent->initialize($agent_data['id'], $agent_data);

			$first_letter = strtoupper($agent->fname[0]);

			if ($page_by == 'fname') {
				$pages_array[$first_letter]++;
			} else if ($page_by == 'lname') {
				$pages_array[$first_letter]++;
			} else if ($page_by == 'name') {
				$pages_array[$first_letter]++;
				$pages_array[$first_letter]++;
			}
		}

		// Builds the url
		$url = $fileurl;

		foreach($params as $key=>$value) {
			if($key != $page_by && $key != $fileurl) {
				if(is_array($value)) {
					$paramvar = '';
					foreach($value as $paramcount=>$val) {
						if($paramcount>0) {
							$paramvar.=';';
						}
						$paramvar.=urlencode($val);
					}
					$url.='/'.$key.'-'.$paramvar;
				} else if($value!='') {
					$url.='/'.$key.'-'.urlencode($value);
				} else {
					$url.='/'.$key;
				}
			}
		}

		$url.='/'.$page_by.'-';

		// Builds the page links by letter
		$page_letter = $params[$page_by];
		foreach ($pages_array as $letter => $count) {

			$addclass = ($page_letter == $letter ? ' currentpage' : '');
			$addclass .= ($count == 0 ? ' disabled' : '');

			$return .= '<div class="agent_page_nav' . $addclass . '"><a href="' . $settings['sitepath'] . $url . $letter . $scroll_to . '" >' . $letter . '</a></div>';
		}
	}


	return $return;
}


function generate_listing_array($array, $fields) {
	/*
	This function is used to generate JSON feed rows for each home.
	This is primarily (only) used on MLS subsites such as vancouver.brixwork.com, viva.brixwork.com,
	and it prepares the export JSON files for client sites to receive new MLS listing data with.
	*/
	global $settings;
	global $mysqli;
	global $mysql_time;

	if(is_array($array))
		// for each row, create an INSERT statement.
		$insert = array(); // start with empty array!
	// get the area/city
	$insert['cityname'] = gettablefield('areas','name',$array['city']);
	$insert['areaname'] = gettablefield('subareas','name',$array['area']);
	if($array['building']!='' && $array['building']>0) {
		$insert['buildingname'] = gettablefield('buildings','name',$array['building']);
	}
	$insert['typename'] = $settings['type'][$array['type']];
	$insert['masterid'] = $array['id'];
	foreach($fields as $key => $field) {
		$insert[$field]=$array[$field];
	}

	if(!isset($insert['mls_photo_timestamp']) || $insert['mls_photo_timestamp']=='' || $insert['mls_photo_timestamp']==null) {
		$insert['mls_photo_timestamp'] = 0; // cannot be null, timestamps can be just 0.
	}

	// now prepare the open house strings...
	$ohstring = '';// start with blank.
	$ohsql = "SELECT `mls`, `date`, `starttime`, `endtime`, `modify_date` FROM `openhouses` WHERE `mls`='".$array['mls']."' ORDER BY date ASC";
	$ohresult = $mysqli->query($ohsql);
	if($ohresult->num_rows>0) {
		$ohstring = 'Open House ';
		$startdate = '';
		$starttime = '';
		$laststarttime = '';
		$lastendtime = '';
		$modify_date = '2001-01-01'; // start with a very small date to force it to be old then start UP to newer records.
		$lastdate = '2001-01-01'; // set up ridiculous date as past as starting point in order to compare date ranges.
		while($oharray = $ohresult->fetch_assoc()) {
			// now generate the string from the rows..
			if($startdate=='') {
				// $startdate not set yet, that means it's the first of the series.. so this is the start date.
				$startdate = date($mysql_time['monthday'],strtotime($oharray['date']));
				$lastdate = $oharray['date']; // set the last date to startdate so that the next day comparison works
				$ohstring.=$startdate; // add start date to the "Open House " string..
				$starttime = str_ireplace(':00', '', date($mysql_time['hourminute'],strtotime($oharray['starttime'])));
				$endtime = str_ireplace(':00', '', date($mysql_time['hourminute'],strtotime($oharray['endtime'])));
				$laststarttime = $oharray['starttime'];
				$lastendtime = $oharray['endtime'];
				if(substr($starttime,strlen($starttime)-2,2) == substr($endtime, strlen($endtime)-2, 2)) {
					$starttime = trim(substr($starttime, 0, strlen($starttime)-2)); // If they are both AM or PM, strip it down from the start time and trim.
				}
			}

			if($laststarttime==$oharray['starttime'] && $lastendtime==$oharray['endtime'] && (strtotime($oharray['date'])-strtotime($lastdate))<=86400) {
				// if the start & end time are idential, and there's no skip in the dates, get the end date appended without change to time.
				// get current end date.
				// echo 'anotehr day with same times<br />';
				$enddate = date($mysql_time['monthday'],strtotime($oharray['date']));
				// if it's same month, skip the month.. so it shows Mar 24-25 rather than Marh 24 - Mar 25.

			} else {
				continue; // once the time changes, break the cycle.
			}


			$lastdate = $oharray['date']; // set up rows for comparison on next cycle
			$laststarttime = $oharray['starttime']; // set up rows for comparison on next cycle
			$lastendtime = $oharray['endtime']; // set up rows for comparison on next cycle

			if(strtotime($modify_date) < strtotime($oharray['modify_date'])) {
				// found a newer modify_date to feed into the listing info.
				$modify_date = $oharray['modify_date'];
			}
		}

		$ohstring.= ($startdate==$enddate ? '': ' - '.(substr($startdate,0,3) == substr($enddate, 0, 3) ? substr($enddate, 4, 10) : $enddate)).', '.$starttime.'-'.$endtime; // assemble it all.
		// finally, compare to the listings' modify date.. maybe there was a feature/photo/price change after open house loaded?
		if(strtotime($insert['modify_date']) < strtotime($modify_date)) {
			// found a newer modify_date to feed into the listing info.
			$insert['modify_date'] = $modify_date;// update modify date based on OH date so that it forces a re-write on clients sites.
		}
		$insert['openhouse'] = $ohstring; // merge in the open house raw string generated.
	}

	return $insert;

}


function get_property_type_id($input) {
	global $settings;
	if (is_array($input)) {
		$i = $input[0];
	} else {
		$i = $input;
	}

	$i = strtolower(trim($i));

	$typeid = array_search($i,array_map('strtolower',$settings['type']));
	if($typeid===false) {
		// nothing in res, so look fro commercial (will be 50 or higher)
		$typeid = array_search($i,array_map('strtolower',$settings['type_commercial']));
		if($typeid===false) {
			// both blank? Maybe its the old legacy "Condominium" parameter from before 2013.
			if($i==strtolower('Condominium')) {
				// some old sites (previous era before type were set) have condominium overridden.. let's go for ID of condos.
				$i = 'condo';
				$typeid = array_search($i,array_map('strtolower',$settings['type']));
			}
		}
	}

	return $typeid;
}

function get_property_remarks_id($input) {
	global $settings;
	if (is_array($input)) {
		$i = $input[0];
	} else {
		$i = $input;
	}

	$i = strtolower(trim($i));
	// run the search match.
	$remarksid = array_search($i,array_map('strtolower',$settings['remarks']));

	if($remarksid=='' || $remarksid===false) {
		// blank? Something is off.
		$remarksid= false;
	}

	return $remarksid;
}

function get_property_cities ($sold='', $query='', $order='name', $asc='asc') {
	// this function retrieves the list of cities,
	// while considering the queries put in, so that cities with no homes attached do not show up.
	global $settings;
	global $mysqli;

	$sql = "SELECT h.id, a.id AS id, a.name AS name FROM homes h LEFT JOIN areas a ON h.city=a.id WHERE h.publish='1'";

	if(is_array($query)) {
		$count = 0;
		foreach($query as $field=>$value) {
			if($count==0) {
				$sql .= " AND (";
				$sql .= $field."='".$value."'";
				$bracketclose = ")";
			} else {
				$sql .= " AND ".$field."='".$value."'";
			}
			$count++;
		}
		$sql .= $bracketclose;
	}

	if($sold!='') {
		if(is_array($sold)) {
			$count = 0;
			$sql .= "AND (";
			foreach($sold as $soldkey) {
				if($count==0) {
					$sql .= "h.sold='".$soldkey."'";
				} else {
					$sql .= " OR h.sold='".$soldkey."'";
				}
				$count++;
			}
			$sql .= ")";
		} else {
			$sql .= " AND h.sold='".$sold."'";
		}
	}
	$sql .=" GROUP BY a.id";
	$sql .= " ORDER BY ".$order." ".$asc."";

	$result = $mysqli->query($sql);
	while($area = $result->fetch_assoc($result)) {
		$id[$area['id']] = $area['name'];
	}
	//echo '<p>Cities SQL: '.$sql.'</p>';
	return $id;
}


function remove_gallery_photos($photo, $objecttype) {
	global $settings;
	global $mysqli;

	// $photo var contains the row from MySQL, often derived from $object->photos var.
	// We require a lot of this data concisely to avoid accidental deletion of rows, god forbid if we pass wrong ID by some variable swap.
	// $photo['filename']
	// $photo['id'] contains the row ID in the `photos` table,
	// $objecttype can be homes, agents, pages, etc... helps us determine which folder in bucket, as well as which reference point to use.
	if(is_array($photo) && $photo['filename']!='') {
		$filename = $photo['filename'];
		$treference = substr($objecttype, 0, strlen($objecttype)-1);// remove s from end.. so instead of homes, we have home, for referencing to the field in $photo var.
		$objectid = $photo[$treference];
		$pid = $photo['id'];

		if($objectid!='' && $pid!='') {
			$localdeletecount = 0;
			$s3deleteresult = array();
			foreach($GLOBALS['S3_IMAGE_SIZES'] as $size => $data) {
				$filepath = getS3FilePath( $settings, $objectid, $objecttype ).'/'.$size.'/'.$filename;
				if(verifyExists($settings['s3_bucket'], $filepath)) {
					$s3deleteresult[] = deleteFile($settings['s3_bucket'], $size, $objectid, $filename, $objecttype);
				} else {
					// write_log("S3 file not found at ".$filepath.PHP_EOL);
				}
			}

			$s3deletecount = 0;
			foreach($s3deleteresult as $results) {
				if($results!==false) {
					$s3deletecount++;
					// echo $results;
				}
			}

			// finally remove from the MySQL photos table.
			$sql = "DELETE FROM `photos` WHERE `id`='".$pid."' AND `".$treference."`='".$objectid."'";
			$mysqli->query($sql);

			// return result array.
			$return = array();
			$return[0] = $localdeletecount;
			$return[1] = $s3deletecount;
			$return[2] = $mysqli->affected_rows;

		} else {
			$return = false;
		}
	} else {
		$return = false;
	}

	return $return;
}

function remove_home($id) {
	return remove_object('homes', $id); // more universal function!
}

function remove_object($table, $id) {
	global $mysqli;
	global $settings;
	global $handle; // if universal error log is set.
	// function that removes a home permanently.
	// remove home, log it.

	$tid = $mysqli->real_escape_string(trim($id));
	if($tid=='') {
		// id blank, false object.
		$object = false;
	} else {
		// limit object types.
		// TODO: the redirect to pages.php or buildings.php should not be part of the removal function - it should be separate in the AJAX file.
		// Removal can happen through any other source such as cron jobs on MLS sync etc. - this is a UI matter!
		if($table=='pages') {
			$page = new page;
			$page->initialize($tid);
			$subject = $page->title;
			$object = $page;
			$returnurl = 'pages.php';
		} else if($table=='resources') {
			$resource = new resource;
			$resource->initialize($tid);
			$subject = $resource->title;
			$object = $resource;
			$returnurl = 'links.php';
		} else if($table=='agents') {
			$agent = new agent;
			$agent->initialize($tid);
			$subject = $agent->displayname;
			$object = $agent;
			$returnurl = 'agents.php';
		} else if($table=='buildings') {
			$building = new building;
			$building->initialize($tid);
			$subject = $building->name;
			$object = $building;
			$returnurl = 'buildings.php';
		} else if($table=='homes') {
			$home = new home;
			$home->initialize($tid);
			$subject = $home->fulladdress;
			$object = $home;
			$returnurl = 'homes.php';
		} else {
			$object = false;
		}
	}

	log_error("Removal of ".$table." Object #".$id." from username (IP: ".$_SERVER['REMOTE_ADDR'].") through file ".$_SERVER["SCRIPT_FILENAME"]." \r\n");

	if($object!==false) {
		if($table=='pages') {
			// pages - have sub pages, recursively delete!
			if($page->children) {
				foreach($page->children as $value) {
					remove_object($table, $value);
				}
				// after all children pages dead, kill the hierarchy pages!
				$sql = "DELETE FROM hierarchy WHERE parent='".$object->id."'";
				$mysqli->query($sql);
			}
		}

		if($object->photos) {
			/*
				Originally we had && $object->source==1 as a condition but not necessayr.
				Because of folder name differences, a source=1 listing being removed will basically result in

			*/
			$localcount = 0;
			$s3count = 0; // count # removed.
			$sqlcount = 0;
			foreach($object->photos as $pcount=>$photo) {
				$removeresult = remove_gallery_photos($photo, $table);
				// echo "Local: ".$removeresult[0].", S3: ".$removeresult[1].", MySQL: ".$removeresult[2]."<br />\r\n";
				$localcount = $localcount+$removeresult[0];
				$s3count = $s3count+$removeresult[1];
				$sqlcount = $sqlcount+$removeresult[2];
			}

		} else {
			log_error("Removing listing, only `homes` row without affecting photos.\r\n");
		}

		// now the mainimages. PDFs etc.
		if(is_array($settings[$table.'_mainphotofilename'])!==true) {
			$settings[$table.'_mainphotofilename'] = array('main.jpg'); // default back to OLD sites where first image wa always main.jpg
		}

		foreach($settings[$table.'_mainphotofilename'] as $count => $filename) {// check for PDF attachments.
			if($filename!='') { // make sure its not blank!!

				$s3_mainimage_delete = deleteFile($settings['s3_bucket'], '', $object->id, $filename, $table);
			}
		}

		// PDFs were array since beginning.
		foreach($settings[$table.'_pdffilename'] as $count => $filename) {// check for PDF attachments.
			if($filename!='') { // make sure its not blank!!

				$s3_pdf_delete = deleteFile($settings['s3_bucket'], '', $object->id, $filename, $table);
			}
		}

		log_error("Removing Object ID ".$tid." and deleting all photos and files of object type ".$table." on S3 bucket ".$settings['s3_bucket'].". \r\n");

		// delete the 4 folders
		$mobiledelete = deleteFile($settings['s3_bucket'], 'mobile', $object->id, '', $table);
		$originaldelete = deleteFile($settings['s3_bucket'], 'original', $object->id, '', $table);
		$thumbdelete = deleteFile($settings['s3_bucket'], 'thumb', $object->id, '', $table);
		$webdelete = deleteFile($settings['s3_bucket'], 'web', $object->id, '', $table);

		// finally remove the folder itself
		$s3_folder_delete = deleteFile($settings['s3_bucket'], '', $object->id, '', $table);

		if($table=='homes') {
			// photo cache file - only applies, really, to the vancouver.brixwork.com style subdomains
			// that are in charge of feeding photo JSON to children sites.
			// TODO: removal of cache should be its own function, even if it's called here?
			$photosjsonpath = $_SERVER['DOCUMENT_ROOT'].'/admin/api/cache/';
			$photosjsonfile = $photosjsonpath.$object->id.'.txt';
			if(file_exists($photosjsonfile)) {
				unlink($photosjsonfile);
			}
		}

		$sql = "DELETE FROM `".$table."` WHERE `id`='".$tid."'";
		$mysqli->query($sql);
		if($mysqli->affected_rows>0) {
			$return = true;
		} else {
			$return = false;
		}
	} else {
		$return = false;
		log_error("Failed removal of ID ".$tid." - does not exist. \r\n");
	}

	return $return;
}


/* ######################################################
#brix_06
Page fetch mechanisms, processing etc.
###################################################### */

function list_pages($parent='', $publish='', $exclude = array('')) {
	// older function, only works on old sites, it only returns page IDs only and nothing else.
	global $mysqli;
	if($parent!='') {
		$sql = "SELECT pages.id AS `id` FROM `pages` LEFT JOIN `hierarchy` ON pages.id=hierarchy.page WHERE hierarchy.parent='".$parent."'";
		if($publish!='') {
			$sql .=" AND `publish`='".$publish."'";
		}
		$sql .=" ORDER BY `ord`";
		$result = $mysqli->query($sql);
		while($page = $result->fetch_assoc()) {
			if(!in_array($page['id'], $exclude)) {
				$array[] = $page['id'];
			}
		}
	} else {
		// select pages that do NOT have a parent page - without the $parent given, means we're querying top pages.
		$sql = 'SELECT p.id as id FROM `pages` p WHERE `id` NOT IN
		(
		SELECT  `page` as `id`
		FROM    hierarchy `h`
		WHERE h.id!=""
		) ';
		if($publish!='') {
			$sql .=" AND `publish`='".$publish."'";
		}
		$sql .=' ORDER BY p.ord ASC';
		$result = $mysqli->query($sql);
		while($page = $result->fetch_assoc()) {
			if(!in_array($page['id'], $exclude)) {
				$array[] = $page['id'];
			}
		}
	}
	return $array;
}

/*
Deprecated on 2017-07-19 by Bruno Fontanella.
New get_brixwork_pages() generated. In case of any issues with the new function, just rename them and all should go back to how it was.
*/
function get_brixwork_pages_old($parent=false, $levels = -1,$publish=true, $exclude = array('')) {
	/*
	NEW FUNCTION to retrieve pages with! Much more in-depth way of doing this.
	*/
	global $mysqli;
	$sql = "SELECT p.id AS `id`, p.publish AS `publish`, p.embedded as `embedded`, p.menu_title as `menu_title`, p.title as `title`, p.custom_pageurl as `custom_pageurl`, p.breed as `breed`, p.slug as `slug`";
	if($parent!==false) {
		$sql .= ", h.parent as `parent` FROM `pages` p LEFT JOIN `hierarchy` h ON p.id=h.page WHERE h.parent='".$parent."'";
		if($publish) {
			$sql .= " AND p.publish='1'";
		}
		$sql .= " ORDER BY p.ord ASC";
	} else {
		// select pages that do NOT have a parent page - without the $parent given, means we're querying top pages.
		$sql .= " FROM `pages` p WHERE `id` NOT IN
		(
		SELECT  `page` as `id`
		FROM    `hierarchy` `h`
		WHERE h.id!=''
		) ";

		if($publish) {
			$sql .=" AND p.publish='".$publish."'";
		}

		$sql .=" ORDER BY p.ord ASC";
	}
	//echo $sql;
	//echo '<br /><br />';
	$result = $mysqli->query($sql);
	if($result->num_rows==0) {
		$array = false; // negative results for this pages query, only happens on children page queries really, as theres no such thing as a website without top pages.
	} else {
		while($page = $result->fetch_assoc()) {
			if(!in_array($page['id'], $exclude)) {
				$array[$page['id']] = $page;

				$array[$page['id']]['pageurl'] = get_page_url($page['id'], $page['custom_pageurl'], $page['slug'], $page['embedded'], $parent);


				if($page['menu_title']=='') {
					$array[$page['id']]['menu_title'] = $page['title'];
				}

				// check for sub-pages.
				if($levels!=0) {
					$children = get_brixwork_pages($page['id'], $levels-1, $publish, $exclude); // call $levels at -1 to reduce nmber of levels.
					$array[$page['id']]['children'] = $children;
				}
			}
		}
	}

	return $array;
}

/*
@author - Bruno Fontanella
@date - 2017-07-19

Fetch all the pages and link them with the correspondent parent/children.
Used to be a recursive function, but now the recursion occurs on get_pages_hierarchy().

@parents - if defined, filter only this parent's children and down.
@levels  - DEPRECATED, since now we return all the pages and this is not the recursive function anymore.
@publish - either query all the pages regardless to their status (false,0) or only the published ones (true,1).
@exclude - array of page IDs to be excluded from the results.

@return  - an array cointaing the pages structure with their respective children. Array key = page ID.
*/
function get_brixwork_pages($parent=false, $levels = -1,$publish=true, $exclude = array('')) {
	/*
	 * SOON TO BE DEPRECATED
	 * Not to be confused with the new cache_brixwork_pages() function in 2018-04, that pre-laods all page, custom fields data into
	 * $GLOBAL array to avoid re-query. This only returns some critical elements to make the menu generation easier -
	 * Once the $subpage->initialize() functions run, thtose will fall back to cache provided by the new function.
	 * */

	global $mysqli;
	$sql = "
		SELECT 
			p.id AS `id`, 
			p.publish AS `publish`,
			p.embedded AS `embedded`,
			p.menu_title AS `menu_title`,
			p.title AS `title`,
			p.custom_pageurl AS `custom_pageurl`,
			p.breed AS `breed`,
			p.slug AS `slug`,
			h.parent AS `parent` 
		FROM `pages` p 
		LEFT OUTER JOIN `hierarchy` h ON p.id = h.page
		WHERE 1=1
		".($publish ? "	AND p.publish = 1" : "")."
		ORDER BY 
			h.parent ASC,
			p.ord ASC";


	$result = $mysqli->query($sql);
	$pages_aux = mysqli_fetch_all($result, MYSQLI_ASSOC);
	mysqli_free_result($result);

	// Removes the excluded results
	if(is_countable($exclude) && count($exclude) > 0 && is_numeric($exclude[0])) {
		$pages_aux = array_filter($pages_aux, function($page) use ($exclude) {
			return (!in_array($page['id'], $exclude));
		});
	}

	// Runs through the array and associates the page_id as the array key for each page
	foreach($pages_aux as $key => $value) {
		$pages[$value['id']] = $value;
	}

	$ret = get_pages_hierarchy($pages, $parent);


	//echo $sql;
	//echo '<br /><br />';
	//print_r($ret);

	return $ret;
}

/*
@author - Bruno Fontanella
@date - 2017-07-19

Recursive function that builds the pages hierarchy.

@pages 	- array containing all the pages to be crawled and structured.
@parent - ID of the parent page, or NULL in case of top pages.
@parent_custom_url - used to avoid parent page object instantiation when using get_page_url.

@return - structured array with parent pages and their children.
*/
function get_pages_hierarchy($pages = array(), $parent = null, $parent_custom_url = '') {
	// Filter all the pages with parent = $parent
	// if $parent is null, this will return the TOP level pages only (where parent is null!)
	// if $parent is present, this will filter out ONLY direct children of the current $parent set.
	$parent_pages = array_filter($pages, function($page) use ($parent) {
		return ($page['parent'] == $parent);
	});

	if(DEBUG==true) {
		// echo 'Filtering pages by parent id '.($parent!='' ? $parent : 'TOP')." and parent URL inherited was ".$parent_custom_url."<br />\r\n";
		// print_r($parent_pages);
	}


	$parent_pages = array_map(function($page) use ($pages, $parent_custom_url) {
		// If the custom_pageurl is empty, then grab the parent's.
		// Since this is recursive, we propagate the parent url down and down until there's a child with a valid one, otherwise, just use the parent's.
		// This way we avoid having to initialize the parent page on the get_page_url to look for a valid url.


		$parent_custom_url = ($page['custom_pageurl']!= '' ? $page['custom_pageurl'] : ($parent_custom_url!='' ? $parent_custom_url : '')); // if parent URL is set, and embedded==1, use the parent custom URL, since its not a stand alone page.



		$page['pageurl'] = get_page_url($page['id'], $page['custom_pageurl'], $page['slug'], $page['embedded'], $page['parent'], $parent_custom_url);

		if(DEBUG==true) {
//			echo 'Processing pages for ID: '.$page['id'].', using custom URL passed '.$parent_custom_url."<br >\r\n";
//			echo 'Parent Custom URL passing down: '.$parent_custom_url.', current page custom URL is: '.$page['custom_pageurl']."<br >\r\n";
//			echo 'Then got URL for Page ID '.$page['id'].': '.$page['pageurl']."<br >\r\n<br >\r\n<br >\r\n";
		}

		// This will recursively attach all the children to the respective parent.
		$filtered_children = get_pages_hierarchy($pages, $page['id'], $parent_custom_url);
		if (count($filtered_children) > 0) {
			$page['children'] = $filtered_children;
		}

		if ($page['menu_title'] == '') {
			$page['menu_title'] = $page['title'];
		}

		//print_r($page);


		return $page;
	}, $parent_pages);


	return $parent_pages;
}


/**
 * This function is useful only for returning the FIRST sibling (or cousin) at same level.
 * This is almost exclusively used on pages_mod.php when creating new subpages.
 *
 * @author Jeff Kee
 *
 * @param object  $parent   Direct Parent object to loop through for subpages.
 * @param object  $topparent   Top level Parent object to loop through for subpages.
 * @param int $depth     The ancestry depth required so we return the first same level sibling or cousin, not any subpage.
 * @param boolean $publishedonly    Self explanatory.
 * @return false|int|array    Integer return happens when the sibling at final level is found. Or it will run again within its own loop with children page arrays, or skip to next one on false return (pages without children).
 */
function find_siblings($parent, $topparent, $depth = 0, $publishedonly = false) {
	if(is_object($parent)) {
		$parentpage = $parent;
	} else {
		$parent = remove_all_but_numbers($parent); // clean up to just numbers & force integer.
		$parentpage = new page;
		$parentpage->initialize($parent);
	}

	if($parentpage->children!=false) {
		// determine which children pages to loop through.
		if($publishedonly==true) {
			$looparray = $parentpage->publishedchildren;
		} else {
			$looparray = $parentpage->children;
		}
	}
	$parentdepth = $depth - 1; // if we're working with direct parent, assume this is just above target.

	if(!is_array($looparray)) {
		// direct parent has no siblings for new page,
		// fall back to higher level and come back down...
		if(is_object($topparent)) {
			$topparentpage = $topparent;
		} else {
			$topparent = remove_all_but_numbers($topparent); // clean up to just numbers & force integer.
			$topparentpage = new page;
			$topparentpage->initialize($topparent);
		}

		$parentdepth = ($topparentpage->parents!=false ? count($topparentpage->parents)+1 : 1);
		if($topparentpage->children!=false) {
			if($publishedonly==true) {
				$looparray = $topparentpage->publishedchildren;
			} else {
				$looparray = $topparentpage->children;
			}
		}
	}

	// get the depth of the $parentpage node in question - top level starts at level 1 not 0 (+1)
	if(is_array($looparray)) {
		if(($parentdepth+1)==$depth) {
			// we are at depth, and there's children array to work with!
			$return =  array_key_first($looparray);
		} else {
			foreach($looparray as $childid=>$throwaway) {
				// not at depth, so get one level deeper to find an equal level sibilng (cousin).
				$childpage = new page;
				$childpage->initialize($childid);

				$siblingid = find_siblings($childid, $depth, $publishedonly);
				// pass same depth and publish flag as what was requested.
				if(is_numeric($siblingid)) {
					$return = $siblingid;
					break; // if numeric is returned, it means the sub loop got right level sibling. STOP loop.
				}
			}
		}
	} else {
		// no children.
		$return = false;
		// This will force the loop above ot keep going until it finds smoething.
	}
	return $return;
}




function get_page_url($id, $custom_pageurl, $slug, $embedded = false, $parents = false, $parent_customurl='') {
	// get the URL of a page based on its data provided.
	// this function can be called based on data from the get_brixwork_pages() function, or from the object itself.
	global $settings;
	global $mysqli;
	global $memcache;
	/*
	Variable usage:
	When using get_brixwork_pages() function (from menu, for example)
	$id = $page[12]['id']
	$custom_pageurl = $page[12]['custom_pageurl']
	$slug = $page[12]['slug']
	$embedded = $page[21]['embedded'] (boolean)
	$parents = Figure out how the array feeds in?

	When called from within page object by $thispage->get_page_url()
	$this->id;
	$custom_pageurl = $this->custom_pageurl
	$slug = $this->slug
	$embedded = $this->embedded
	$parents = $this->parents


	*/
	// get page URL

	if($custom_pageurl!='') {
		if(trim($custom_pageurl)=='/') {// custom URL that has just '/' means Homepage.. therefore sitepath.
			$pageurl = $settings['sitepath'];
		} else if(strpos($custom_pageurl, 'http')!==false) {
			// starts with http;, so it's an external page? Use as-is.
			$pageurl = $custom_pageurl;

		} else {
			// has custom page url set, so this is the master URL. Strip the first / if present, because $settings['sitepath'] will have it.
			$pageurl = $settings['sitepath'].(substr( $custom_pageurl, 0, 1 ) === "/" ? substr( $custom_pageurl, 1 ) : $custom_pageurl);
		}
	} else if($parents || $parent_customurl!='') {
		if($parent_customurl!='') {
			// parent's custom URL was passed, use this.
			$urlbase = $settings['sitepath'].$parent_customurl;
		} else {
			// parent's custom URL is not passed, but has parent, so must extrapolate the custom url from parent page.
			if(is_array($parents)) {
				// loop through parents to see if any higher ancestor has a custom page url set?
				foreach($parents as $parentid) {
					// since we start from the highest level page and cascade down, the closest ancestor with
					// a custom pageURL serves as the URL basis.
					$parentpage = new page;
					$parentpage->initialize($parentid);
					if($parentpage->custom_pageurl!='') {
						$urlbase = $parentpage->pageurl;
					}
				}
			} else {
				$parentid = $parents;
				$directparent = new page;
				$directparent->initialize($parentid);

				$urlbase = $directparent->pageurl;
			}
			// use the parent's URL as base to add /$pageid/$slug
		}

		if($embedded==true || $embedded==1) {
			// embedded page, go for parent page URL!
			// Although this is an extra query, the get_page_url() function will most likely never run on a page that is meant to be embedded.
			$pageurl = $urlbase; // if teh direct parent is also an $embedded page, this will automatically tracde all the way up anyway.
		} else {
			// not embedded, so it must be its own page!
			if($urlbase!='') {// direct parent has custom_pageurl, so go with that.
				$pageurl = $urlbase.'/'.$id.'/'.$slug; // regular subpage structure.
			} else {
				$topparent = new page;
				$topparent->initialize($parents[0]);
				$pageurl = $topparent->pageurl.'/'.$id.'/'.$slug;
			}
		}
	} else if($custom_pageurl=='' && ($parents==false || $parents=='') && ($parent_customurl=='' || $parent_customurl==false) && $embedded!=true) {
		// fallback to homepage.. blank URL, no parents, no custom URL so must be homepage.
		$pageurl = $settings['sitepath'];
	} else {
		// absolute fallback but rarely should happen....
		$pageurl = $settings['sitepath'].$slug;
	}
	return $pageurl;
}

/**
 * Funciton that finds subpage ID, or returns the defaultid (mother page).
 * @param $defaultid
 * @return false|float|int|mixed|string
 */
function get_pageid($defaultid='') {
	global $mysqli;
	$request = explode('/',$_SERVER['REQUEST_URI']);
	$filename = $request[1]; // blank if homepage?
	$contentid = (array_key_exists(2,  $request) ? $request[2] : '');

	if($contentid=='' || !is_numeric($contentid)) {
		// blank.. or not a nujmber?
		if($defaultid=='') {
			// default ID is blank.. let's find out the page by scoping database.
			$sql = "SELECT `id` FROM `pages` WHERE `custom_pageurl`='".$mysqli->real_escape_string($filename)."'";
			$result = $mysqli->query($sql);
			if($result->num_rows>0) {
				$array = $result->fetch_assoc();
				$defaultid = $array['id'];
			} else {
				$defaultid = false;
			}
		}
		$contentid = $defaultid; // default it.
	}
	return $contentid;
}

function find_parents($id, $recurse = false) {
	$parents = array();
	$parentid = $GLOBALS[BRIX_PAGES_CACHE][$id]['parentid'];
	if($parentid!='') {
		$parents[] = $parentid; // add the first parent by default.
		while($parentid!==false) {
			$parentid = find_parent($parentid);
			if($parentid!==false) {
				$parents[] = $parentid;
			} else {
				continue;
			}
		}
	}

	if(count($parents)>0) {
		// because it goes from page, recursing up, the final array needs to be reversed to go from
		// top parent to next, to next, to finally the direct parent.
		$reverse = array_reverse($parents);
		return $reverse;
	} else {
		return false;
	}
}

function find_parent($id) {
	// function to find DIRECT PARENT only, used once.
	// to be used within loop of function find_parents() which recurses in!
	$parent = false;
	$parentid = $GLOBALS[BRIX_PAGES_CACHE][$id]['parentid'];
	if($parentid!='') {
		foreach ($GLOBALS[BRIX_PAGES_CACHE] as $pagesarray) {
			if ($pagesarray['id'] == $parentid) {
				$parent = $pagesarray['id'];
			}
		}
	}

	return $parent;
}


function find_children($id) {
	global $mysqli;
	$children_array = array(); // by default, no children.
	if(is_array($GLOBALS[BRIX_PAGES_CACHE])) {
		foreach($GLOBALS[BRIX_PAGES_CACHE] as $brix_pages) {
			if($id==$brix_pages['parentid']) {
				$children_array[] = $brix_pages;
			}
		}
	} else {
		$childsql = "SELECT p.id AS `id` FROM hierarchy h RIGHT JOIN pages p ON h.page = p.id WHERE h.parent='".$id."' ORDER BY p.ord";
		$childresult = $mysqli->query($childsql);
		$GLOBALS[BRIX_PAGES_QUERY]++;
		if($childresult->num_rows>0) {
			while($children = $childresult->fetch_assoc()){
				$children_array[] = $children;
			}
		}
	}

	if(count($children_array)>0) {
		$return = array();
		foreach($children_array as $children) {
			$return[$children['id']] = $children['id'];
			$subarray = find_children($children['id']);
			if($subarray) {
				$return[$children['id']] = $subarray;
			}
		}
	} else {
		$return = false;
	}
	return $return;
}

/* ######################################################
#brix_07
REsources fetch mechanisms, processing etc.
###################################################### */

function list_resources($category='', $city='', $area='') {
	// TODO: need to refactor for get_resource_categories(), and run that if category is blank (to get list of categories)
	// TODO: then also refactor for get_resources(), and if category/city/area is set, push to $query var and get that instead, with data false for backwards compabitility.
	// This puts the get_XXXX syntax more in line like the get_properties() or get_buildings() functions while
	global $mysqli;
	// if resource category is given, lists the resources under that category.
	// otherwise, it returns the list of IDs of the available categories, based on whether there is content there or not.
	// to be used in categoory specific queries, or
	if($city!='') {$query['city']=$city;}
	if($area!='') {$query['area']=$area;}

	if($category!='') {
		// get links ujnder specific category!
		$query['categoryid'] = $category;
		$return = get_resource_links($query, 'ord', 'asc', false, false); // get IDs only in this case.
	} else {
		// get list of categories only.
		$return = get_resource_link_categories('', 'ord', 'asc', false, false);
	}
	return $return;
}

/**
 * @param $query
 * @param $order
 * @param $asc
 * @param $getcount
 * @param $getdata
 * @return array|int
 */
function get_resource_link_categories($query='', $order = 'ord', $asc = 'ASC', $getcount = false, $getdata = true) {
	global $settings;
	global $mysqli;
	global $mysql_time;
	global $now;
	// there's not much to return, so lets just always return full data.

	if($getdata==true) {
		$target_columns = 'c.id, c.title, c.desc, c.ord'; // do we really need ord?
	} else	if($getcount==true) {
		$target_columns = 'COUNT(*) as cnt';
	} else  {
		$target_columns = 'c.id';
	}

	$sqlfilter = '';


	$sqlhead = 'SELECT '.$target_columns.'  FROM `resourcecategories` c LEFT JOIN `resources` r on c.id=r.category  WHERE 1=1 ';
	$sqlend = ''; // start blank string for now.
	if(is_array($query)) {
		// filters to run!
		$count = 0;
		foreach($query as $field=>$value) {
			$condition = '';
			switch($field) {
				case "has_resources":
					if($query['has_resources']==false || $query['has_resources']==0) {
						// Query for categories that do NOT have resources attached yet.
						$condition = ' r.id IS NULL ';
					} else {
						// query for categories with at least one resource attached but return only once?
						$condition = ' r.id IS NOT NULL ';
					}
					break;
				case "id":
					if (is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach ($value as $homeid) {
							if ($fieldcount > 0) {
								$condition .= ' OR ';
							}
							$condition .= "c.id ='" . cleanupforentry($homeid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if ($value != '') {
						$condition = "c.id = '" . cleanupforentry($value) . "'";
					} else {
						// blank ID value, so enter bogus field so nothing comes up!
						$condition = "c.id = '" . md5($now) . "'";
					}
					break;

				case "name":
					if($value) {
						$condition = "(LOWER(c.title) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%')";
					}
					break;
				case "title":
					// exact same as name...
					if($value) {
						$condition = "(LOWER(c.title) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%')";
					}
					break;
			}
			if($condition!='') {
				// if condition is not blank, that means the passed var had good merit and created a condition
				if($count==0) {
					$sqlfilter .= " AND ("; // if it's the first condition block, start a bracket.
					$sqlfilter .= $condition;
				} else {
					$sqlfilter .= " AND ".$condition; // if it's not the first one, keep adding conditions with AND without brackets
				}
				$count++;
			}
		} // end of foreach block that loops through each $query key
		$sqlfilter.=")";
	} // end of if else block that checks if $query is an array.
	$sqlfilter.=" GROUP BY c.id "; // to prevent multiple rows of each home retruning based on photo count

	// now process the order by columns etc.
	if(is_array($order)) {
		// multiple order columns, in sequence.
		if(!is_array($asc)) {
			$usesingularasc = 1;
		} else {
			$usesingularasc = 0;
		}
		foreach($order as $key=>$column) {
			if($usesingularasc==1) {
				// no matter how many column arrays, they are all one order directive only (ASC or DESC) so do not use the array.
				$columnasc = $asc;
			} else {
				// $asc is ALSO an array, so we match them up.
				$columnasc = $asc[$key]; // match the key first.
				if($columnasc=='') {
					// if $columnasc is blank, that means not enough arrays were given..
					// i.e. $order_by was array('ord', 'feature', 'create_date') and the $asc only had array('ASC', 'DESC');
					// so then we default to the last available array.
					$columnasc = $asc[count($asc)-1];
				}
			}

			if($key>0) {
				$sqlorder.= ', '.generate_order_line($column, $columnasc, 'resourcecategory');
			} else {
				$sqlorder = 'ORDER BY '.generate_order_line($column, $columnasc, 'resourcecategory');
			}
		}
	} else if($order!='') {
		$sqlorder = 'ORDER BY '.generate_order_line($order, $asc, 'resourcecategory');
	} else {
		// no order given whatsoever - default to ord by ASC
		$sqlorder = 'ORDER BY '.generate_order_line('ord', 'ASC', 'resourcecategory');
	}

	// no $sqllimit needed.. there aren't that many.
	$sql = $sqlhead.$sqlfilter.$sqlorder;

	$result = $mysqli->query($sql);

	if($getcount===true) {
		// this query ONLY needs the count of properties of such criteria.
		if($result->num_rows>0) {
			$count = $result->fetch_assoc();
			$return = remove_all_but_numbers($count['cnt']);
		} else {
			$return = 0;
		}
	} else if($getdata===true) {
		// get data, so more comprehensive array.
		if($result->num_rows>0) {
			while($resourcecategories = $result->fetch_assoc()) {
				$data = array();// blank array for pcoessing.
				$data = $resourcecategories;
				$return[$resourcecategories['id']] = $data;
				// now process using prcoess_home_data(); also used in the $home object.

			}
		} else {
			$return = false;
		}
	} else {
		// regular get IDs only.
		if($result->num_rows>0) {
			while($resourcecategories = $result->fetch_assoc()) {
				$return[] = $resourcecategories['id'];
			}
		} else {
			$return = false;
		}
	}
	if(DEBUG===true) {
		echo '<p><strong>Resources category SQL:</strong> '.$sql.'</p>';
		if(!$result) {
			echo '<p><strong>Error:'.$mysqli->error.'</strong></p>';
		} else {
			echo '<p><strong>Num Rows Returned:'.$result->num_rows.'</strong></p>';
		}
	}
	return $return;
}

/**
 * @param $query
 * @param $order
 * @param $asc
 * @param $getcount
 * @param $getdata
 * @return array|false|float|int
 */
function get_resource_links($query, $order = 'ord', $asc = 'ASC', $getcount = false, $getdata = true) {
	global $settings;
	global $mysqli;
	global $mysql_time;
	global $now;
	// there's not much to return, so lets just always return full data.

	if($getdata==true) {
		$target_columns = 'r.id, r.title, r.mainphoto, r.pdf, r.pdf_labels, r.url, r.category, c.title AS categorytitle, r.company, 
		r.address1, r.address2, r.area, r.city, s.name as subarea_name, a.name as city_name, r.postal, 
		r.phone, r.contact, r.email, r.desc, r.publish
		 ';
	} else	if($getcount==true) {
		$target_columns = 'COUNT(*) as cnt';
	} else  {
		$target_columns = 'r.id';
	}

	$sqlfilter = '';

	$sqlhead = 'SELECT '.$target_columns.'  FROM `resources` r LEFT JOIN `resourcecategories` c on r.category=c.id LEFT OUTER JOIN `subareas` s ON r.area=s.id LEFT OUTER JOIN `areas` a ON r.city=a.id WHERE 1=1 ';
	$sqlend = ''; // start blank string for now.
	if(is_array($query)) {
		// filters to run!
		$count = 0;
		foreach($query as $field=>$value) {
			$condition = '';
			switch($field) {
				case "id":
					if (is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach ($value as $homeid) {
							if ($fieldcount > 0) {
								$condition .= ' OR ';
							}
							$condition .= "r.id ='" . cleanupforentry($homeid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if ($value != '') {
						$condition = "r.id = '" . cleanupforentry($value) . "'";
					} else {
						// blank ID value, so enter bogus field so nothing comes up!
						$condition = "r.id = '" . md5($now) . "'";
					}
					break;

				case "name":
					if($value) {
						$condition = "(LOWER(r.title) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%')";
					}
					break;
				case "title":
					// exact same as name...
					if($value) {
						$condition = "(LOWER(r.title) LIKE '%" . $mysqli->real_escape_string(strtolower(trim($value))) . "%')";
					}
					break;

				case "category":
					// type such as "house" or "Townhome" was passed as string
					// convert to ID using get_property_type_id();
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $categorytitle) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}

							$condition .= "LOWER(c.title) LIKE = '%" . $mysqli->real_escape_string(strtolower(trim($categorytitle))) . "%'";
							$fieldcount++;
						}
						$condition .= ')';
					} else {
						$condition = "LOWER(c.title) LIKE '" . $mysqli->real_escape_string(strtolower(trim($categorytitle)))  . "'";
					}
					break;

				case "categoryid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $categoryid) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "c.id = '" . $mysqli->real_escape_string($categoryid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else {
						$condition = "c.id = '" . $mysqli->real_escape_string($value) . "'";
					}
					break;

				case "city":
					if(is_array($value)) {
						$condition = '(';
						$cityarraycount = 0;
						foreach($value as $cityname) {
							$cityname = $mysqli->real_escape_string(strtolower(trim($cityname)));

							if($cityarraycount>0) {
								$condition.=' OR ';
							}
							$condition .= "LOWER(a.name)='".$cityname."'"; // because c. is used for resourcescategory, we used a for city, and s for subarea.
							$cityarraycount++;

						}
						$condition.= ')';
					} else if($value!='') {

						$condition = " LOWER(a.name) = '" . $mysqli->real_escape_string(strtolower(trim($value))) . "'";
					}
					break;

				case "area":
					if(is_array($value)) {
						$condition = '(';
						$areaarraycount = 0;
						foreach($value as $areaname) {
							$areaname = $mysqli->real_escape_string(strtolower(trim($areaname)));
							if($areaarraycount>0) {
								$condition.=' OR ';
							}
							$condition .= "LOWER(s.name)='".$areaname."' ";
							$areaarraycount++;
						}
						$condition.= ')';
					} else {
						$areaname = $mysqli->real_escape_string(strtolower(trim($value)));
						$condition = "LOWER(s.name) = '".$areaname."'";
					}
					break;

				case "cityid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $cityid) {
							$cityid = $mysqli->real_escape_string($cityid);
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "r.city = '" . intval($cityid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false && $value>0) {
						$condition = "r.city = '" . intval($value) . "'";
					}
					break;

				case "areaid":
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $areaid) {
							$areaid = $mysqli->real_escape_string($areaid);
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "r.area = '" . intval($areaid) . "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='' && $value!=false && $value>0) {
						$condition = "r.area = '" . intval($mysqli->real_escape_string($value)) . "'";
					}
					break;

				case "publish":
					if($value === '' || $value === false && $value!=0) $value = 1;// override!
					$condition = " r.publish = '" . intval($value) . "'";
					break;

				default:
					$condition = '';
					break;
			}
			if($condition!='') {
				// if condition is not blank, that means the passed var had good merit and created a condition
				if($count==0) {
					$sqlfilter .= " AND ("; // if it's the first condition block, start a bracket.
					$sqlfilter .= $condition;
				} else {
					$sqlfilter .= " AND ".$condition; // if it's not the first one, keep adding conditions with AND without brackets
				}
				$count++;
			}
		} // end of foreach block that loops through each $query key
		$sqlfilter.=")";
	} // end of if else block that checks if $query is an array.

	// now process the order by columns etc.
	if(is_array($order)) {
		// multiple order columns, in sequence.
		if(!is_array($asc)) {
			$usesingularasc = 1;
		} else {
			$usesingularasc = 0;
		}
		foreach($order as $key=>$column) {
			if($usesingularasc==1) {
				// no matter how many column arrays, they are all one order directive only (ASC or DESC) so do not use the array.
				$columnasc = $asc;
			} else {
				// $asc is ALSO an array, so we match them up.
				$columnasc = $asc[$key]; // match the key first.
				if($columnasc=='') {
					// if $columnasc is blank, that means not enough arrays were given..
					// i.e. $order_by was array('ord', 'feature', 'create_date') and the $asc only had array('ASC', 'DESC');
					// so then we default to the last available array.
					$columnasc = $asc[count($asc)-1];
				}
			}

			if($key>0) {
				$sqlorder.= ', '.generate_order_line($column, $columnasc, 'resource');
			} else {
				$sqlorder = 'ORDER BY '.generate_order_line($column, $columnasc, 'resource');
			}
		}
	} else if($order!='') {
		$sqlorder = 'ORDER BY '.generate_order_line($order, $asc, 'resource');
	} else {
		// no order given whatsoever - default to ord by ASC
		$sqlorder = 'ORDER BY '.generate_order_line('ord', 'ASC', 'resource');
	}

	// no $sqllimit needed.. there aren't that many.
	$sql = $sqlhead.$sqlfilter.$sqlorder;

	$result = $mysqli->query($sql);

	if($getcount===true) {
		// this query ONLY needs the count of properties of such criteria.
		if($result->num_rows>0) {
			$count = $result->fetch_assoc();
			$return = remove_all_but_numbers($count['cnt']);
		} else {
			$return = 0;
		}
	} else if($getdata===true) {
		// get data, so more comprehensive array.
		if($result->num_rows>0) {
			while($resources = $result->fetch_assoc()) {
				$data = array();// blank array for pcoessing.
				$data = $resources;
				$return[$resources['id']] = $data;
				// now process using prcoess_home_data(); also used in the $home object.

			}
		} else {
			$return = false;
		}
	} else {
		// regular get IDs only.
		if($result->num_rows>0) {
			while($resources = $result->fetch_assoc()) {
				$return[] = $resources['id'];
			}
		} else {
			$return = false;
		}
	}
	if(DEBUG===true) {
		echo '<p><strong>Resources SQL:</strong> '.$sql.'</p>';
		if(!$result) {
			echo '<p><strong>Error:'.$mysqli->error.'</strong></p>';
		} else {
			echo '<p><strong>Num Rows Returned:'.$result->num_rows.'</strong></p>';
		}
	}
	return $return;
}

/**
 * Return an array with all the cities from the database.
 *
 * @param bool $published_only - Whether or not to return all cities or only published ones. Default is <b>true</b>.
 *
 * @return array - the array containing the cities.
 */
function list_cities($published_only = true) {
	$city_list = array();
	foreach ($GLOBALS[BRIX_AREAS_CACHE] as $city) {
		if(($published_only==true && $city['publish']==1) || $published_only==false) {
			$city_list[] = $city;
		}
	}
	return $city_list;
}


/* ######################################################
#brix_08
Agents fetch mechanisms, processing etc.
###################################################### */
// why did we call this list_agents, not get_agents? I'll never know.
function list_agents($query='', $order='ord', $asc = 'ASC', $perpage='', $page='', $getcount = false, $getdata = false) {
	return get_agents($query, $order, $asc, $perpage, $page, $getcount, $getdata);
}

function get_agents($query='', $order='ord', $asc = 'ASC', $perpage='', $page='', $getcount = false, $getdata = false) {
	global $mysqli;
	global $memcache;

	/*
	 * 2024 Memcache upgrades
	 * $getdata==true should mean that it gets the IDs, then goes after the memcache data (and falling back to MySQL one listing at a time.
	 * */

	if($getdata===true && $memcache===false) {
		$targetcolumns = 'a.*, c.name AS `classname`, c.name2 AS `classname2`, c.billable AS `billable` ';
	} else if($getdata===true && $memcache!==false) {
		// full data needed, and memcache is on. Just get IDs and let the loop get Memcache into the $data array?
		$targetcolumns = 'a.id ';
	} else if($getcount===true) {
		$targetcolumns = 'COUNT(*) as cnt';
	} else {
		$targetcolumns = 'a.id as id';
	}

	$sqlhead = 'SELECT '.$targetcolumns.' FROM `agents` a LEFT JOIN `agent_classes` c ON a.class = c.id WHERE a.id!="" ';

	if(is_array($query)) {
		$count = 0;
		foreach($query as $field=>$value) {
			// first set up the query...
			$condition = '';
			switch($field) {
				case "id":
					// DB ID
					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $agent_id) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "a.id ='".cleanupforentry($agent_id). "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='') {
						$condition = "a.id = '" . cleanupforentry($value) . "'";
					} else {
						// blank ID value, so enter bogus field so nothing comes up!
						$condition = "a.id = '" . md5($now) . "'";
					}
					break;

				case "name":
					// first OR last name starts with, in this case?
					$value = cleanupforentry($value);
					$condition = " (LOWER(a.fname) LIKE '".$value."%' OR LOWER(a.lname) LIKE '".$value."%'  OR LOWER(a.lname2) LIKE '".$value."%'  OR LOWER(a.fname2) LIKE '".$value."%')";
					break;

				case "lname":
					// Only Last name
					$value = cleanupforentry($value);
					if($value!='') {
						$condition = " (LOWER(a.lname) LIKE '" . $value . "%'  OR LOWER(a.lname2) LIKE '".$value."%')";
					}
					break;

				case "fname":
					// Only first tname
					$value = cleanupforentry($value);
					if($value!='') {
						$condition = " (LOWER(a.fname) LIKE '" . $value . "%' OR LOWER(a.fname2) LIKE '" . $value . "%')";
					}
					break;

				case "agentid":
					// agent ID
					$value = cleanupforentry($value);
					if($value!='') {
						$condition = " LOWER(a.agentid) LIKE '" . $value . "%'";
					}
					break;

				case "class_id":

					if(is_array($value)) {
						$condition = '(';
						$fieldcount = 0;
						foreach($value as $classid) {
							if($fieldcount>0) {
								$condition .= ' OR ';
							}
							$condition .= "a.class ='".intval($classid). "'";
							$fieldcount++;
						}
						$condition .= ')';
					} else if($value!='') {
						$condition = "a.class = '" . intval($value) . "'";
					}

					break;

				case "billable":
					if(!isset($value) || $value=='') {
						$value = 1;
					} else {
						$value = intval($value);
					}
					$condition = " c.billable = '" . $value . "'";
					break;

				case "publish":
					$condition = " a.publish = '" . intval($value) . "'";
					break;

				default:
					$condition = $mysqli->real_escape_string($field)."='".$mysqli->real_escape_string($value)."'";
					break;
			}
			if($condition!='') {
				// if condition is not blank, that means the passed var had good merit and created a condition
				if($count==0) {
					$sqlfilter .= " AND ("; // if it's the first condition block, start a bracket.
					$sqlfilter .= $condition;
				} else {
					$sqlfilter .= " AND ".$condition; // if it's not the first one, keep adding conditions with AND without brackets
				}
				$count++;
			}
		}
		$sqlfilter .= ') '; // close this condition block with a bracket
	}

	// now process the order by columns etc.
	if(is_array($order)) {
		// multiple order columns, in sequence.
		if(!is_array($asc)) {
			$usesingularasc = 1;
		} else {
			$usesingularasc = 0;
		}
		foreach($order as $key=>$column) {
			if($usesingularasc==1) {
				// no matter how many column arrays, they are all one order directive only (ASC or DESC) so do not use the array.
				$columnasc = $asc;
			} else {
				// $asc is ALSO an array, so we match them up.
				$columnasc = $asc[$key]; // match the key first.
				if($columnasc=='') {
					// if $columnasc is blank, that means not enough arrays were given..
					// i.e. $order_by was array('ord', 'feature', 'create_date') and the $asc only had array('ASC', 'DESC');
					// so then we default to the last available array.
					$columnasc = $asc[count($asc)-1];
				}
			}

			if($key>0) {
				$sqlorder.= ', '.generate_order_line($column, $columnasc, "agent");
			} else {
				$sqlorder = 'ORDER BY '.generate_order_line($column, $columnasc, "agent");
			}
		}
	} else if($order!='') {
		$sqlorder = 'ORDER BY '.generate_order_line($order, $asc, "agent");
	} else {
		// no order given whatsoever - default to ord by ASC
		$sqlorder = 'ORDER BY '.generate_order_line('ord', 'ASC', "agent");
	}

	if($getcount!==true) {
		if ($perpage != '') {
			if ($page < 1 || $page == '') {
				$page = 1;
			}
			$truepage = $page - 1;
			$start = $perpage * $truepage;
			$sqllimit = ' LIMIT ' . $start . ', ' . $perpage . '';
		}
	} else {
		// getting count, so do NOT run the limitations.
		$sqllimit = '';
	}

	// set up the MAIN sql
	$sql = $sqlhead.$sqlfilter.$sqlorder.$sqllimit;
	$result = $mysqli->query($sql);
	$GLOBALS[BRIX_PAGES_QUERY]++;
	// and then the total # SQL in order to retrieve the quantity

	if($getcount===true) {
		if($result->num_rows>0) {
			$count = $result->fetch_assoc();
			$id = intval($count['cnt']);
		} else {
			$id = 0;
		}
	} else if($getdata===true) {
		// get data, so more comprehensive array.
		if($result->num_rows>0) {
			$id = array();
			while($agent = $result->fetch_assoc()) {
				if($memcache!==false && count($agent)<3) {
					// $agent column had less than 3 columns.. just `id` probably.
					$memcache_params = array(
						'type'=>'agent',
						'objectid'=>$agent['id']
					);
					$data = get_memcache($memcache_params);
					if(DEBUG===true) {
						echo "get_agents() retrieving memcache and retrieved ".($data===false ? 'FALSE' : count($data))." rows, from param: <br />".PHP_EOL;
						print_r($memcache_params);
					}
					if(is_array($data)) {
						$data['memcache']=true; // add as a flag to test?
						$id[$agent['id']] = $data; // full array to pass as $data
					} else {
						$id[$agent['id']] = $agent['id']; // No memcache yet, so just feed ID only, $agent->initialize() can do the work.
					}
				} else {
					// Non-memcache - the query has ALL the agent table columns
					$id[$agent['id']] = $agent;
				}
			}
		} else {
			$id = false;
		}
	} else {
		// regular get IDs only.
		if($result->num_rows>0) {
			while($agent = $result->fetch_assoc()) {
				$id[] = $agent['id'];
			}
		} else {
			$id = false;
		}
	}
	if(DEBUG===true) {
		echo '<p><strong>Agents SQL:</strong> '.$sql.'</p>';
		if(!$result) {
			echo '<p><strong>Error:'.$mysqli->error.'</strong></p>';
		} else {
			echo '<p><strong>Num Rows Returned:'.$result->num_rows.'</strong></p>';
		}
	}
	return $id;
}


/* ######################################################
#brix_09
Neighbourhoods fetching, processing mechanisms.
###################################################### */

/**
 * Builds the WHERE clause for the given param on the neighbourhood stats query.
 *
 * @param array $array - the array containing the params IDs that are to be included on the query.
 * @param string $param - the param (column name) you want to filter for.
 *
 * @return string - the WHERE clause for that param. <br/>Output example for <b>$array</b> = [1,2,3] and <b>$param</b> = 'type' is: <br/><i>"AND <b>type</b> in (<b>1,2,3</b>)"</i>
 */
function neighbourhood_stats_query_builder($array = [], $param = '') {
	// Sanitize the param and build the query codition
	$sql_condition = '';
	if ($array != '') {
		if (!is_array($array)) {
			$array = [$array];
		}

		// If params were entered as strings, transform it into ID's
		if (!is_numeric($array[0])) {
			$ids = [];
			foreach ($array as $item) {
				if ($param == 'type') {
					$ids[] = get_property_type_id($item);
				} else if ($param == 'area') {
					$ids[] = get_area_id($item, 'subareas');
				} else if ($param == 'city') {
					$ids[] = get_area_id($item);
				}
			}

			$sql_condition = "AND {$param} in (".implode(',',$ids).")";
		} else {
			$sql_condition = "AND {$param} in (".implode(',',$array).")";
		}
	}

	return $sql_condition;
}


/**
 * Get the listings stats for a given neighbourhood.
 *
 * @param array $query - Contains the listings types, areas and cities to be queried. <br/>If no type is passed, then all types for that given area will be returned. <br/>If no area is passed, then all areas for the given city will be returned. <br/> if no city is passed, well, then just query it all.
 *
 * @return array - An array containing the stats grouped by listing type. Array keys are: <b>listing_type</b>, <b>count_for_sale</b>, <b>price_sum</b>, <b>avg_price_per_listing</b> and <b>avg_days_on_market</b>
 */
function get_neighbourhood_stats($query = []) {
	global $mysqli;
	global $settings;

	// Sanitize the items and build the query coditions
	$types_sql = neighbourhood_stats_query_builder($query['type'], 'type');

	$area_sql = neighbourhood_stats_query_builder($query['area'], 'area');

	// if no subarea was passed, let's check if any city was passed at least
	if ($area_sql == '') {
		$area_sql = neighbourhood_stats_query_builder($query['city'], 'city');
	}


	$sql = "SELECT
				type AS 'listing_type',
				count(*) AS 'count_for_sale',
				sum(cast(replace(replace(price,'$',''),',','') AS UNSIGNED)) AS 'price_sum',
				round(sum(cast(replace(replace(price,'$',''),',','') AS UNSIGNED))/count(*)) AS 'avg_price_per_listing',
				round(sum(datediff(curdate(),str_to_date(create_date,'%Y-%m-%d %H:%i:%s')))/count(*)) AS 'avg_days_on_market'
			FROM homes
			WHERE
				publish = 1
				{$types_sql}
				{$area_sql}
			GROUP BY type";


	$result = $mysqli->query($sql);

	$stats_list = [];
	while ($stats = $result->fetch_assoc()) {
		$stats['listing_type'] = $settings['type'][$stats['listing_type']];
		$stats_list[] = $stats;
	}

	return $stats_list;
}

/**
 *
 * Function to get middle point of multiple lat/lng coordinates. Useful for neighbourhood subpages with multiple subareas in one.
 *
 * @param array $coordinates with numeric arrays (0, 1, 2), and subarray with two keys: 'lat' and 'long'!
 * @return array
 *
 *
 *  sample of what $coordinates should look like:
$coordinates = array(
array('lat' => 52.5200, 'long' => 13.4050),
array('lat' => 48.8566, 'long' => 2.3522),
array('lat' => 51.5074, 'long' => -0.1278)
);
 */
function get_middle_point(array $coordinates) {
	$num_coords = count($coordinates);
	$total_lat = 0;
	$total_long = 0;

	foreach ($coordinates as $coord) {
		if(is_numeric($coord['lat']) && is_numeric($coord['long'])) {
			$total_lat += deg2rad($coord['lat']);
			$total_long += deg2rad($coord['long']);
		} else {
			// invalid array passed, so reduce the division denominator.
			$num_coords--;
		}
	}

	$avg_lat = $total_lat / $num_coords;
	$avg_long = $total_long / $num_coords;

	$middle_lat = rad2deg($avg_lat);
	$middle_long = rad2deg($avg_long);

	return array('lat' => $middle_lat, 'long' => $middle_long);
}

/* ######################################################
#brix_10
CURL, other external pings and communication methods.
###################################################### */


function sendToHost($host,$method,$path,$data,$useragent=false) {
	// Supply a default method of GET if the one passed was empty
	// try to use curl_get_file_contents instead. more options. more robust.
	if (empty($method))	$method = 'GET';
	$method = strtoupper($method);
	$fp = fsockopen($host,80);
	if ($method == 'GET') $path .= '?' . $data;
	fputs($fp, "$method $path HTTP/1.1\r\n");
	fputs($fp, "Host: $host\r\n");
	fputs($fp, "Content-Type: application/x-www-form-urlencoded\r\n");
	if ($method == 'POST') fputs($fp, "Content-length: " . strlen($data) . "\r\n");
	if ($useragent) fputs($fp, "User-Agent: MSIE\r\n");
	fputs($fp, "Connection: close\r\n\r\n");
	if ($method == 'POST') fputs($fp, $data);

	while (!feof($fp)) {
		$buf .= fgets($fp,128);
	}
	fclose($fp);
	return $buf;
}

/**
 * Used to use our own CURL raw PHP - now replacing with Guzzle.
 * @param $URL
 * @param string $method
 * @param string $vars
 * @param int $timeout
 * @return bool|string
 */
function curl_get_file_contents($URL, $method='POST', $vars='', $timeout = 2000) {
	$c = curl_init();
	curl_setopt($c, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($c, CURLOPT_SSL_VERIFYPEER, 0); // ignore expired SSL etc.
	curl_setopt($c, CURLOPT_TIMEOUT_MS, $timeout); // default is 2000
	curl_setopt($c, CURLOPT_FOLLOWLOCATION, true);

	if(strpos($URL, 'instagram')===false && strpos($URL, 'brixwork')===false) {
		$user_agent = 'Mozilla/5.0 (Windows NT 6.2; WOW64; rv:17.0) Gecko/20100101 Firefox/17.0'; // recommended on Stack overflow: https://stackoverflow.com/questions/17801094/php-curl-how-to-add-the-user-agent-value-or-overcome-the-servers-blocking-curl-r
		$user_agent = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13'; // what Brixwork had as of 2024-03
		curl_setopt($c, CURLOPT_USERAGENT, $user_agent); // some servers block requests if the requester clearly isnt a real browser.
	}
	curl_setopt($c, CURLOPT_URL, $URL);
	$querystring = '';
	if($method=='POST') {
		curl_setopt($c, CURLOPT_POST, 1); // set POST method
		if(is_array($vars)) {
			$varcount = 0;
			foreach($vars as $key=>$value) {
				if($varcount>0) {
					$querystring.='&';
				}
				$querystring.=$key.'='.$value;
				$varcount++;
			}
			curl_setopt($c, CURLOPT_POSTFIELDS, $querystring);
		}
	}
	$contents = curl_exec($c);

	if ($contents) {
		curl_close($c);

		return $contents;

	} else {
		if(curl_errno($c) && DEBUG==true) {
			echo 'Curl error: ' . curl_error($c).'<br />';
			echo 'Curl info:<br />';
			$curl_info = curl_getinfo($c);
			foreach($curl_info as $key=>$var) {
				echo $key.': '.$var.'<br />';
			}
		}
		curl_close($c);

		return false;
	}
}

function generateQrCode($input, $size = "150", $level = "M", $margin = "0") {
    $url = urlencode($input);

    // Google API is being shut down ... https://developers.google.com/chart/infographics/docs/overview
    //return "https://chart.apis.google.com/chart?chs=" . $size . "x" . $size . "&cht=qr&chld=" . $level . "|" . $margin . "&chl=" . $url;

    // replace with Open source QR code generator
    // it might be worthwhile to just build our own?
    return "https://image-charts.com/chart?chs=" . $size . "x" . $size . "&cht=qr&chld=" . $level . "|" . $margin . "&chl=" . $url;
}






/*
 * For running upgrades, spitting out data etc. for API usage?
 * Ensure to reference and upgrade the main repo (Brixwork-for-Reaotrs) when upgrading the
 * following functions, as they talk to each other.
 */
function api_export_encrypt($data, $key = '', $delimiter = '') {
	global $api_encode_key;
	global $api_encode_delimter;
	$key = ($key!='' ? $key : $api_encode_key);
	$delimiter = ($delimiter!='' ? $delimiter : $api_encode_delimter);

	// Remove the base64 encoding from our key
	$encryption_key = base64_decode($key);
	// Generate an initialization vector
	$iv = openssl_random_pseudo_bytes(openssl_cipher_iv_length('aes-256-cbc'));
	// Encrypt the data using AES 256 encryption in CBC mode using our encryption key and initialization vector.
	$encrypted = openssl_encrypt($data, 'aes-256-cbc', $encryption_key, 0, $iv);
	// The $iv is just as important as the key for decrypting, so save it with our encrypted data using a unique separator (::)
	return base64_encode($encrypted . $delimiter . base64_encode($iv));
}

function api_export_decrypt($data, $key = '', $delimiter = '') {
	global $api_encode_key;
	global $api_encode_delimter;
	$key = ($key!='' ? $key : $api_encode_key);
	$delimiter = ($delimiter!='' ? $delimiter : $api_encode_delimter);

	// Remove the base64 encoding from our key
	$encryption_key = base64_decode($key);
	// To decrypt, split the encrypted data from our IV - our unique separator used was "::"
	list($encrypted_data, $iv) = explode($delimiter, base64_decode($data), 2);
	return openssl_decrypt($encrypted_data, 'aes-256-cbc', $encryption_key, 0, base64_decode($iv));
}

/*
 * Creates random has that decodes to allow remove login by clicking the A button on the list of clients.
 */
function generate_remote_login_hash($username) {
	// Usually we use the cpanel username here, but can pass more stuff as you wish.
	global $local;
	$value = $username.','.$local;
	$return = api_export_encrypt($value);
	return $return;
}




/* ######################################################
#brix_11
Media handling of images, youtube, videos, 3rd party stuff etc.
###################################################### */

function check_s3_attachments($type, $idr, $attachment='mainphoto', $updatetable = true) {
	// returns array of attachments that exist if exists, or false if not.
	// not intended for gallery image checking... yet?
	// also updates the row if update set to true.
	global $settings;
	global $mysqli;
	global $now;

	if($type!='' && $attachment!='' && $idr.''!='') {
		$attachments = array(); // start with BLANK array to start.
		foreach($settings[$type.'_'.$attachment.'filename'] as $akey => $filename) {
			if(attachment_exists_on_s3($type, $idr, $attachment, $akey)) {
				$attachments[$akey] = $akey; // build the array if teh attachment exists.
			}
		}

		if($updatetable===true) {
			// update the table so it knows which attachment exists, so we dont have to call the cloud each time to verify existence of an attachment.
			$updatevar[$attachment] = array_to_delimited_options($attachments);
			$updatevar['modify_date'] = $now;
			$uid = update_to_table($type, $updatevar,$idr);
		}

		return $attachments;
	} else {
		// not enoguh data!
		return false;
	}

}


function get_object_photos($type, $idr) {
	global $mysqli;
	global $settings;
	global $memcache;

	if($type!='' && $idr.'' !='') {
		$typesingular = substr($type, 0, strlen($type)-1); // turn buildings into building, etc.
		$sql = "SELECT id, ".$typesingular.", filename, s3, url, title, timestamp, ord FROM photos WHERE `".$typesingular."`='".$idr."' ORDER BY `ord` ASC, id ASC";


		if($memcache!==false &&
			(
				$typesingular=='page'
				|| $typesingular=='home'
				|| $typesingular=='agent'
				|| $typesingular=='building'
			)
		) {
			$memcache_params = array(
				'type'=> $typesingular.'photos', // pagephotos, homephotos etc.
				'objectid'=>$idr
			);
			$photo_data = get_memcache($memcache_params);
			if($photo_data===false) {
				if(DEBUG==true) {
					echo "Memcache fetch failed to get photos for ".$typesingular." iD ".$idr."<br />".PHP_EOL;
				}
				$result = $mysqli->query($sql);
				$GLOBALS[BRIX_PAGES_QUERY]++;
				if($result->num_rows>0) {
					while($photos = $result->fetch_assoc()) {
						$photo_data[] = $photos;
					}
				} else {
					$photo_data = array(); // blank array. DO NOT USE FALSE! It means NO PHOTOS and thats a valid result!!
				}
				$photo_memcache_key = get_memcache($memcache_params, $photo_data);
				if(DEBUG==true) {
					echo "Key set for photos of page ".$idr." was ".$photo_memcache_key.".<br />".PHP_EOL;
				}
			}
		} else {
			// no memcache enabled, OR it's not a memcache eligible object.
			$result = $mysqli->query($sql);
			$GLOBALS[BRIX_PAGES_QUERY]++;
			if($result->num_rows>0) {
				while($photos = $result->fetch_assoc()) {
					$photo_data[] = $photos;
				}
			} else {
				$photo_data = array(); // blank array. DO NOT USE FALSE!
			}
		}

		if(is_array($photo_data) && count($photo_data)>0) {
			// fallback for local files for not-yet migrated items.
			$localbaseurl = $settings['sitepath'].$type.'/'.$idr;
			// define S3 URLs.

			$cloudbaseurl = $settings['cloudfront_url'].getS3FilePath( $settings, $idr, $type );

			// Taran: If you change the $s3 base URL to be the cloudfron WITH the bucket, folder all built in.. it will generate the URL.
			$pcount = 0;
			$photoarray = array();
			foreach($photo_data as $photos) {
				$baseurl = ($photos['s3']==1 || $photos['url']!='' ? $cloudbaseurl : $localbaseurl); // set base URL, based on whethter this photos local or on the S3 cloud.
				// prevent caching!
				$timestamp = '?timestamp='.$photos['timestamp'];

				$photoarray[$pcount] = array(
					'id'=>$photos['id'],
					's3' => $photos['s3'], // should be part of feed just in case.
					'filename'=>$photos['filename'],
					'title'=>$photos['title'],
					'filepath'=>$baseurl.'/'.($photos['s3']==1 ? 'web/' : '').$photos['filename'],
					'originalfilepath'=>$baseurl.'/'.($settings['mlssite']===true ? 'web' : 'original').'/'.$photos['filename'],
					$typesingular=>$photos[$typesingular] // basically defines [home] => 34456, or [building]=2887 type of referrence to original object.
				);

				if($photos['url']!='') {
					// Some MLS Distributions such as VIVA, or CREA DDF will feed this from their URL.
					// no reason for us to eat up our own S3 and Cloudfront capacities.
					// added in 2020-09 upgrade to reduce our S3/Cloudfront footprint.
					$photoarray[$pcount]['filepath'] = $photos['url']; // instead of building from $baseurl for our own S3/Cloudfront
					$photoarray[$pcount]['originalfilepath'] = $photos['url']; // instead of building from $baseurl for our own S3/Cloudfront
					$photoarray[$pcount]['mobilepath'] = $photos['url'];  // instead of building from $baseurl for our own S3/Cloudfront
					$photoarray[$pcount]['thumbnailpath'] = $baseurl.'/thumb/'.$photos['filename'].$timestamp; // thumbnail we still process on our own as they are too small, or nonexistent on MLS feeds.

				} else if($photos['s3']==1) {
					// get from the S3, all files are raw as /thumb/filename.jpg etc.
					// and add timestamp so that cloudfront caches kick in properly.
					$photoarray[$pcount]['filepath'] = $photoarray[$pcount]['filepath'].$timestamp;
					$photoarray[$pcount]['originalfilepath'] = $photoarray[$pcount]['originalfilepath'].$timestamp;
					$photoarray[$pcount]['mobilepath'] = $baseurl.'/mobile/'.$photos['filename'].$timestamp;
					$photoarray[$pcount]['thumbnailpath'] = $baseurl.'/thumb/'.$photos['filename'].$timestamp;
					if($settings['timthumb']==1) {
						$photoarray[$pcount]['thumbnailpath'] = $settings['sitepath'].'timthumb.php?src='.$baseurl.'/web/'.$photos['filename'].'&w='.$settings['thumbnailwidth'].'&h='.$settings['thumbnailheight'].'&zc=1';
					}

				} else {
					// final fallback for files not yet moved to S3.
					// do we even need this anymore since 2018??
					$photoarray[$pcount]['thumbnailpath']= (file_exists(($settings['fileroot']!='' ? $settings['fileroot'] : $_SERVER['DOCUMENT_ROOT']).'/'.$settings['rootpath'].$type.'/'.$idr.'/thumbs/'.$photos['filename']) ? $baseurl.'/thumbs/'.$photos['filename'] : $settings['sitepath'].'timthumb.php?src='.$baseurl.'/'.$photos['filename'].'&w='.$settings['thumbnailwidth'].'&h='.$settings['thumbnailheight'].'&zc=3');

					$photoarray[$pcount]['mobilepath']= (file_exists(($settings['fileroot']!='' ? $settings['fileroot'] : $_SERVER['DOCUMENT_ROOT']).'/'.$settings['rootpath'].$type.'/'.$idr.'/mobile/'.$photos['filename']) ? $baseurl.'/'.'mobile/'.$photos['filename'] : $settings['sitepath'].'timthumb.php?src='.$baseurl.'/'.$photos['filename'].'&w='.$settings['mobilewidth'].'&zc=1');
				}
				$pcount++;
			}
			$return = $photoarray;
		} else {
			$return = false;
		}


	} else {
		// echo $type.' entered wtih id '.$idr;
		$return = false;
	}

	return $return;
}

function get_main_images_path($type, $object, $num=0, $noimage = 'noimage.png', $fallback=true) {
	global $settings;
	if($type!='' && is_object($object)) {
		if(is_array($object->mainphoto) && array_key_exists($num,$object->mainphoto)) {
			// Specific main image attachment (not a gallery fallback) exists.
			$timestamp = '?mod='.strtotime($object->data['modify_date']);

			$cloudbaseurl = $settings['cloudfront_url'].getS3FilePath( $settings, $object->id, $type ).'/'.$object->mainphoto[$num].$timestamp;

			$return = $cloudbaseurl;

		} else if($object->gallery_exists==1 &&
			(
				// either $fallback to $num because $fallback===true,
				// or fallback to $fallback sequence because it's numeric.
				// either way, make sure photo in gallery exists at designated sequence.
				(array_key_exists($num, $object->photos) && $fallback===true)
				||
				(is_numeric($fallback) && array_key_exists($fallback, $object->photos))
			)
		) {
			if($fallback!==true && is_numeric($fallback)) {
				$num = $fallback;
			}
			if($num>0) {
				// second/3rd/4th main images tend to be smaller, lets use mobile to save bandwidth.
				$return = $object->photos[$num]['filepath'];
			} else {
				// could be main image at the top, so go higher res.
				$return = $object->photos[$num]['filepath'];
			}
		} else {
			// nothing exists, use noimage default.
			if($noimage==false) {
				// if $noimage is false, that means we dont' fall back - return FALSE to denote that there IS no image!
				$return = false;
			} else if(substr( $noimage, 0, 4 ) === "http") {
				// it's own path with full URL for the noimage path!
				$return = $noimage;
			} else {
				// just a filename, so look for it in template image folder.
				$return = ($settings['use_template']==1 ? $settings['templatepath'] : $settings['sitepath']).'images/'.$noimage;
			}

		}
	} else {
		$return = false;
	}
	return $return;
}

function get_pdf_file_link($type, $object, $num=0, $anchor='', $prefix='', $suffix='', $cssclass='') {
	global $settings;
	if($type!='' && is_object($object)) {
		if($anchor=='' && $anchor!==false) {
			if(is_array($object->pdf_labels) && array_key_exists($num, $object->pdf_labels)) {
				$anchor = $object->pdf_labels[$num];
			} else {
				$anchor = 'PDF '.$num;
			}
		}

		if($type=='pages') {
			$subject = $object->title;
		} else if($type=='resources') {
			$subject = $object->title;
		} else if($type=='agents') {
			$subject = $object->displayname;
		} else if($type=='buildings') {
			$subject = $object->name;
		} else if($type=='homes') {
			$subject = $object->fulladdress;
		} else {
			die('invalid object type!');
		}


		if($object->data['modify_date']!='') {
			$timestamp_date = $object->data['modify_date'];
		} else if($object->data['create_date']!='') {
			$timestamp_date = $object->data['modify_date'];
		} else {
			$timestamp_date = false; // object without a date? not really possible.. but in any case, have fallback.
		}

		$timestamp = ($timestamp_date!==false ? '?mod='.strtotime($timestamp_date) : ''); // cache control!

		$s3path = $settings['cloudfront_url'].getS3FilePath( $settings, $object->id, $type ).'/'.$settings[$type.'_pdffilename'][$num].$timestamp;

		if(is_array($object->pdf) && array_key_exists($num, $object->pdf)) {
			// check table if this was uploaded yet or not.
			$pdfpath = $s3path;
		} else {
			$pdfpath = false;
		}

		if($pdfpath) {
			if($anchor==false) {
				$return = $pdfpath;
			} else {
				$return = $prefix . '<a href="' . $pdfpath . '" title="PDF ' . $num . ' of ' . $subject . '" class="' . $cssclass . '" target="_blank">' . $anchor . '</a>' . $suffix;
			}
		} else {
			$return = false;
		}
	} else {
		$return = false;
	}

	return $return;
}

/**
 * More robust than the get_file_extension() function,
 * This one will return a simplified 3 letter lowercased extension.
 * While not as common, sometimes .jpeg files are input, and we need to return the extension as .jpg to streamline.
 * @param $filename
 * @return bool|int|string
 */
function get_image_extension($filename) {
	global $image_extensions;
	$ext = get_file_extension($filename); // strtolower built into get_file_extension already.
	if($ext!='' && $ext!==false) {
		foreach($image_extensions as $image_extension => $possible_vars) {
			if(in_array($filename, $possible_vars)===true) {
				$ext = $image_extension;
			}
		}
		return $ext;
	} else {
		return false;
	}
}

/**
 * This function returns the right mimetype for file upload handlers,
 * based on the extension given. This function does NOT check a file for its actual MIME type
 * It's merely to generate the right tags etc. for the upload modules for main images etc.
 * @param $ext
 * @return bool|int|string
 */
function get_image_mimetype($ext) {
	global $image_mimetypes;
	// use get_image_extension($filename) first if you want to extract the extension only.
	// this function assumes we have extensions ('jpg' or 'png', cleaned up), not a filename.
	if($ext!='' && $ext!==false) {
		$return = false; // default is blank.
		foreach($image_mimetypes as $image_mimetype => $possible_vars) {
			if(in_array($ext, $possible_vars)===true) {
				$return = $image_mimetype;
			}
		}
		return $return;
	} else {
		return false;
	}
}



function getyoutubeid($url) {
	// strip out URL from Youtube to just get the ID of the video!
	// sometimes the host format is youtu.be, not youtube.com format. (https://youtu.be/zDvL0Qgf3YY)
	if(is_string($url)) {
		if (preg_match('%(?:youtube\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/ ]{11})%i', $url, $match)) {
			return $match[1];
		} else {
			return false;
		}
	} else {
		return false;
	}
}

function getvimeoid($url) {
	/*
		this pattern will strip out the id as the second element in the array always
		https://vimeo.com/64878402
		https://vimeo.com/223588697?ref=em-v-share
	*/
	if(is_string($url)) {
		$result = preg_match('/(https?:\/\/(?:www\.)?vimeo\.com\/)(\d*)?([a-zA-Z=\-_?]*)[0-9]*/', $url, $matches);
		if ($result) {
			return $matches[2];
		} else {
			return false;
		}
	} else {
		return false;
	}
}

/**
 * @param $vimeo Enter the video ID or URL. If URL is passed, it will run getvimeoid() to truncate.
 * @param $params Additional parameters in array with keys denoting function. The defaults: divid = generates div id based on filename, autoplay=false, muted=1 etc.
 */
function vimeo_iframe($vimeo, $divid='brixwork_vimeo_container', $params = array()) {
	global $settings;
	global $thispage;
	if(!isset($divid) || $divid=='') {
		$divid = 'brixwork_vimeo_container';
	}

	if(is_url($vimeo)===true) {
		// URL was passed.
		$vimeo = getvimeoid($vimeo);
	}

	if($params['preload_image'] == '') {
		$params['preload_image'] = false;
	} else if(!isset($params['preload_image'])) { // if this is NOT set, then we default. if it's just blank, then it should be non image.
		// if image is blank.. do we just let the background colour of the DIV become preload?
		if(is_object($thispage) && $thispage->get_main_images_path(0, false, false)) {
			$params['preload_image'] = $thispage->get_main_images_path(0, false, false);
		} else {
			$params['preload_image'] = false;
		}
		// this way, we can skip the IMG block if this is false.
	}

	if(isset($params['bg_colour'])===false || $params['bg_colour']==='') {
		$params['bg_colour'] = '#333'; // charcoal grey background.
	}

	if(isset($params['video_width'])===false || $params['video_width']==='') {
		$params['video_width'] = 640; // Default width. Usually this shows as 100% anyway, so this is more for ratio calculations.
	}

	if(isset($params['video_height'])===false || $params['video_height']==='') {
		$params['video_height'] = 360; // Default height. This, with video_width, we calculate the padding-bottom to keep ratio of iFrame ocnsistent.
	}

	if(isset($params['video_class'])===false || $params['video_class']==='') {
		$params['video_class'] = 'hidden-xs'; // hide on mobile by default, so it falls back to image.
	}

	if(isset($params['video_autoplay'])===false || $params['video_autoplay']==='') {
		$params['video_autoplay'] = '1'; // Almost always autoplay!!!!
	}

	if(isset($params['video_loop'])===false || $params['video_loop']=='') {
		$params['video_loop'] = '1'; // Almost always loop!!!!
	}

	if(isset($params['video_meta'])===false || $params['video_meta']=='') {
		$params['video_meta'] = '0'; // Almost always hide meta such as title, byline,
	}

	if(isset($params['overlay_color'])===false || $params['overlay_color']==='') {
		$params['overlay_color'] = '#000'; // black is default, and opacity will lighten it.
	}

	if(isset($params['overlay_opacity'])===false || $params['overlay_opacity']==='') {
		$params['overlay_opacity'] = '0.1'; // Default is 0.2
	}

	if($vimeo!='' && $vimeo!==false && $divid!='' && $divid!==false) {
		// Generate the HTML!
		$return ='
		<!-- Start vimeo frame block by Brixwork for background image placement -->
		'; // start!

		// build the CSS block that comes before the <div> and <iframe>
		$video_ratio = ($params['video_height']/$params['video_width'])*100;
		$video_ratio = $video_ratio.'%';
		$return .= '<style>';
		$return .= '#'.$divid.' {';


		if ($params['video_fullscreen'] === true) {
			$return .= "
					position: relative;
					overflow:hidden;
					background-color: ".$params['bg_colour'].";
					width: 100%;
					height: 100vh;
					";
		} else {
			$return .= "
					position: relative;
					overflow:hidden;
					background-color: ".$params['bg_colour'].";
					width: 100%;
					padding-bottom: ".$video_ratio.";";
		}


		if($params['preload_image']!='' && $params['preload_image']!==false) {
			$return .= "
			background-image: url('".$params['preload_image']."');
			background-repeat: no-repeat;
			background-size: cover;
			";
		}
		$return .= '
		}
		'; // end if #divid

		$return .= '
		#'.$divid.' iframe {';

		if ($params['video_fullscreen'] === true) {
			$return .= 'position: absolute!important;
					height: 56.25vw!important;
					min-height: 100vh;
					width: 100vw!important;
					min-width: 177.77vh;
					top: 50%!important;
					left: 50%!important;
					-webkit-transform: translate(-50%, -50%);
					-moz-transform: translate(-50%, -50%);
					-ms-transform: translate(-50%, -50%);
					-o-transform: translate(-50%, -50%);
					transform: translate(-50%, -50%); ';
		} else {
			$return .= 'position: absolute!important;
					height: 100%!important;
					width: 100%!important;
					top: '.$video_ratio.'!important;
					left: 0!important;
					-webkit-transform: translateY(-'.$video_ratio.');
					-moz-transform: translateY(-'.$video_ratio.');
					-ms-transform: translateY(-'.$video_ratio.');
					-o-transform: translateY(-'.$video_ratio.');
					transform: translateY(-'.$video_ratio.'); ';
		}

		$return .= '
		-webkit-animation: '.$params['animation_delay'].' ease 0s normal forwards 1 fadein1;
		animation: '.$params['animation_delay'].' ease 0s normal forwards 1 fadein1;';

		$return .= '}'; // end of #divid iframe

		$return .= '
		#'.$divid.' div.overlay {
		';
		$return .= 'position: absolute!important;
		height: 100%!important;
		width: 100%!important;
		background-color: '.$params['overlay_color'].';
		opacity: '.$params['overlay_opacity'].' ;
		';
		$return .= '}'; // end of #divid .overlay to prevent hover on video.

		$return .= '
		@keyframes fadein1{
			0% { opacity:0; }
			66% { opacity:0; }
			100% { opacity:1; }
		}                          
		
		@-webkit-keyframes fadein1{
			0% { opacity:0; }
			66% { opacity:0; }
			100% { opacity:1; }
		}
		';

		$return .= '</style>';

		$return .= '<div id="'.$divid.'">';

		// start building the URL for Vimeo embed, that becomes the src="" of <iframe> tag.
		$vimeourl = 'https://player.vimeo.com/video/'.$vimeo.'?';

		$vimeourl .= 'autoplay='.$params['video_autoplay'];
		$vimeourl .= '&amp;loop='.$params['video_loop'];
		$vimeourl .= '&amp;muted=1'; // why would we ever not mute a bg video?
		$vimeourl .= '&amp;background=1'; // why would we ever not mute a bg video?

		if($params['video_meta']=='0') {
			$vimeourl .= '&amp;title=0&amp;byline=0'; // why would we ever not mute a bg video?
		}

		// start building the iFrame!
		$return .='<iframe src="'.$vimeourl.'"  frameborder="0" allowfullscreen class="'.$params['video_class'].'"></iframe>';

		$return .= '<div class="overlay"></div></div>'; // close master div, above <iframe>

		$return .='
		<!-- End Vimeo frame block by Brixwork for background image placement -->
		';

	} else {

		$return = false; // $vimeo and $divid cannot be blank!
	}



	return $return;
}


function resize_image($input,$target,$targetw,$targeth='', $crop = false, $expand = false) {
	global $settings;
	global $now;
	// get width of the current image...
	if(file_exists($input)) {
		$imagedata = getimagesize($input);
		$width = $imagedata[0]; // original width
		$height = $imagedata[1]; // original height
		$mimetype = $imagedata['mime'];

		// see if the photo is smaller than what it should at least be!!!
		$percent = $targetw/$width; // get ratio by which it shoudl shrink

		$src_x = 0; // by default we position original photo to 0 x point.
		$src_y = 0; // by default we position original photo to 0 y point.

		$src_w = $width; // by default, original width & height is used.
		$src_h = $height; // by default, original width & height is used.

		if($percent>1 && $expand===false) {
			// smaller than the max target, we don't need to resize at all!
			$new_width=$width;
			$new_height=$height;
		} else {
			$new_width = $width * $percent;
			$new_height = $height * $percent;

			if(($new_height>$targeth && $targeth!='' && $targeth>0 && $crop===false) || ($new_height<$targeth && $targeth!='' && $targeth>0 && $crop===true)) {
				// when resized, teh height is still over the limit. We will resize to height.
				// but only if crop is set to false. If crop is true, the top / bottom will be stripped anyway.

				// OR!!

				// when resized, the height is too short, and the crop is set to true, therefore we need to preserve the extra height to fill the width.
				// So resize based on height, and the widdth can be whatever.

				$percent = $targeth/$height;
				$new_width = $width * $percent;
				$new_height = $height * $percent;
			}
		}
		// as of the above point, if the crop is set to false, the target width & height is SET.

		if($crop===true) {
			// figure out whether we cut the left/right, or top/bottom!
			$cmp_x = $width / $targetw;
			$cmp_y = $height / $targeth;

			if($new_width>$targetw) {
				// wider than target, so we need to cut the left/right.
				$src_w = round ($targetw / $percent);
				$src_x = round(($width-($targetw/$percent))/2);
				$new_width = $targetw;
			} else if($new_height>$targeth) {
				// taller tahn target, so we need to cut the top/bottom.
				$src_h = round ($targeth  / $percent);
				$src_y = round(($height-($targeth/$percent))/2);
				$new_height = $targeth;
			}
		}

		$int_width = round($new_width);
		$int_height = round($new_height);
		$image_p = imagecreatetruecolor($int_width, $int_height);
		imagesavealpha($image_p, true);
		$trans_colour = imagecolorallocatealpha($image_p, 0, 0, 0, 127);
		imagefill($image_p, 0, 0, $trans_colour);

		switch($mimetype){
			case "image/jpeg":
				$image = imagecreatefromjpeg($input); //jpeg file
				break;
			case "image/gif":
				$image = imagecreatefromgif($input); //gif file
				break;
			case "image/png":
				$image = imagecreatefrompng($input); //png file
				break;
			default:
				$image=imagecreatefromjpeg($input);
				break;
		}
		// imagecopyresampled ($dst_image , $src_image , int $dst_x , int $dst_y , int $src_x , int $src_y , int $dst_w , int $dst_h , int $src_w , int $src_h )
		imagecopyresampled($image_p, $image, 0, 0, $src_x, $src_y, $int_width, $int_height, $src_w, $src_h);

		switch($mimetype){
			//Most likely JPG, but look for fallbacks.
			// TODO: HEIC images from iPHone, enable?
			case "image/gif":
				imagegif($image_p, $target);
				break;
			case "image/png":
				imagepng($image_p, $target, 0);
				break;
			default:
				imagejpeg($image_p, $target, ($settings['imagequality']!='' ? $settings['imagequality'] : 75));
				break;
		}
		return true;
	} else {
		return false;
	}
}

//	Retrieves all the photos for an array of properties in a single curl call.
//	It is used after the get_properties function is run with the data return and
//	when initializing a home using the data option ( $home->initialize(id, data) ).
//	After the home is initialized, you need to assign $home->photos = massphotos_ret[masterid]
//  and set $home->gallery_exists to 1.
//
//	@author JJ
function mass_photos($ids) {
	global $settings;

	$the_ids = $first_id = '';
	if (is_array($ids) && count($ids)>1) {
		foreach ($ids as $id) {
			$the_ids .= $id.';';
		}
		$the_ids = substr($the_ids, 0, -1);
		$first_id = $ids[0];
	} else {
		$first_id = $ids;
	}

	$json = curl_get_file_contents(($settings['mls_import_url']!='' ? $settings['mls_import_url'] : $settings['master_url']).'admin/api/photos.php', 'POST', array('ids'=>$the_ids, 'masterid'=>$first_id, 'hash'=>md5('58300774'.$first_id))); // we got it, so decode it.

	$json = json_decode($json, TRUE); // now that we got it, decode it.

	return $json;
}

// Retrieves a SVG string with whatever classes are passed as parameter.
// You can either pass a string with spaces separated class or array items.
function get_svg($svg, $svg_classes = '') {

	if ($svg != '') {
		if (is_array($svg_classes)) {
			$svg_classes = implode(' ', $svg_classes);
		}

		return ($svg_classes != '' ? str_replace('<svg', '<svg class="'.$svg_classes.'"', $svg) : $svg);
	}
	return false;
}



/* ######################################################
#brix_12
2016 Map search modules!
###################################################### */


function generate_map_script($mapid, $type = 'homes', $baselat='', $baselong='', $basezoom='', $maptype = 'ROADMAP', $fixheight = false, $headerdeduct = 'header', $json = false, $hcount = false, $scriptwrap = true) {
	/*
	PHP encapsulator to generate the initial map. This doesn't need to be separate javascript ever,
	since it will always be part of the DOM upon load. We will never call a map on the fly by AJAX, just the contents of such.
	If you are asking "Why not just centralize into an AJAX module?" youare asking a very good question!
	However. Two reasons, having inline load is faster, so better for SEO to have the first 10~20 buildings/listings
	load immediately so that Google can crawl them better.

	The JSON feed is inline, so instead of AJAX, the javascript just popoulates the content right away on the
	map & list together.
	Initial PHP script gets the buildings/homes objects into array, then turns it into JSON, but also tells total count #
	For pagination to be immediately generated.
	*/
	global $settings;


	// $maptype can be ROADMAP (default), SATELLITE, HYBRID, TERRAIN

	if($mapid=='' || $mapid==false) {
		// map id cannot be empty!!
		$mapid = 'gmap'; // default to gmap.
	}

	if($basezoom=='' || $basezoom==false) {
		// map id cannot be empty!!
		$basezoom = 16;
	}

	if($baselat=='' || $baselong=='') {
		// map id cannot be empty!!
		$baselat = $settings['office_lat'];
		$baselong = $settings['office_long'];
	}

	$return = '';
	if($scriptwrap==true) {
		$return.='<script type="text/javascript">';
	}

	$return .="
		WebFontConfig = {
		google: { families: [ 'Roboto:400,700:latin', 'Roboto+Condensed:400,400italic,700,700italic:latin' ] }
		};
		(function() {
		var wf = document.createElement('script');
		wf.src = ('https:' == document.location.protocol ? 'https' : 'http') +
		  '://ajax.googleapis.com/ajax/libs/webfont/1/webfont.js';
		wf.type = 'text/javascript';
		wf.async = 'true';
		var s = document.getElementsByTagName('script')[0];
		s.parentNode.insertBefore(wf, s);
		})(); // loading the fonts used from Google fonts.
		
		$.getScript( '".$settings['master_url']."js/modernizr-custom.js', function() {
			// modernizer scripts to detect touch.
			if (Modernizr.touch){
			   // bind to touchstart, touchmove, touchend etc and watch `event.streamId`
			} else {
			   // bind to normal click, mousemove, etc
			}
		});
	"; // load roboto condensed font and other dependencies .


	$return .='
		
	var '.$mapid.'; // define map ID based on the #id of the DIV targeted. 
	
	window.infowindow = {};
	window.markers = {};
	window.mapactiveid = {};
	window.subareas = {};
	window.coordinates = {}; // stores the coordinates & name info etc., not the actual google object for polygons. 
	window.polygons = {}; // actual polygon objects as per new google.maps.Polygon method.
	window.map_json_string = {};
	window.map_json = {};
	window.map_count = {};
	window.mapsearchcityactive = false; // set to false so that city/subarea activation runs once. 
	'.($type=='homes' ? 'window.map_plotted = {}' : '').'
	window.mapid = "'.$mapid.'"; // for reference later. 
	';

	if($json) {
		// default $json should be fed in at all times, really. This stuff kicks in IF there's no URL parameters after the # indicating a custom search URL.
		$return .='
		window.map_json_string["'.$mapid.'"] = \''.$json.'\';
	
		// console.log(window.map_json_string["'.$mapid.'"]);
		window.map_json["'.$mapid.'"] = jQuery.parseJSON(window.map_json_string["'.$mapid.'"]);
		
		';
	}

	if($hcount) {
		// default $json should be fed in at all times, really. This stuff kicks in IF there's no URL parameters after the # indicating a custom search URL.
		$json_count = count(json_decode($json)) * 1;
		$return .='window.map_count["'.$mapid.'"] = '.$json_count.';';
	}

	// TODO: really shoudl set these lat/lng in the tag in the <form> then have it fetched via JS on load, no tinline.
	$return .='window.baselat = '.$baselat.';';
	$return .='window.baselng = '.$baselong.';';

	$return .='window.latlng = brixwork_get_latlng("'.$baselat.'","'.$baselong.'")'; // set up lat/long for map.

	$return .="
		$(document).ready(function(){

		brixwork_mapsearch_loadmap('".$mapid."', ".$basezoom.", '".$type."');
	";

//	$return .= '
//		// attach function to DOM load to run & generate the map.
//
//		brixwork_mapsearch_loadmap("'.$mapid.'", '.$basezoom.', "'.$type.'");
//
//	';


	if($fixheight==true) {
		// set the map div to have fixed height, most likely for vertical views on phones etc.
		$return .= "
			resizemap('".$headerdeduct."'); // run on load, then again in a few seconds after the search form dropdowns setup
			setTimeout(function(){ resizemap('".$headerdeduct."'); }, 2000);
			
			window.onresize = function(event) {// also fire up when window resizes
				resizemap('".$headerdeduct."');
			};
		";
	}

	if($type=='homes') {
		$return .="
			// determine min and max price range for teh form. NOT what the user passed, this is site wide setting. 
			
		";
	}


	$return .='});'; // end of $(document).ready functions to run to initilze it all.

	if($scriptwrap==true) {
		$return.='</script>';
	}

	return $return;
}

function generate_map_html($mapid, $type = 'homes') {
	global $settings;
	global $mysqli;
	global $query;
	global $price;
	global $price_defaults;
	global $perpage;
	global $maxpage;
	global $homeurlbase;
	global $buildingurlbase;
	global $blanketfilter;
	global $brixwork_version;

	$return ='


<link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
<link href="'.$settings['master_url'].'css/brixwork_maps.css?v='.$brixwork_version.'" rel="stylesheet" />
<script type="text/javascript" src="'.$settings['master_url'].'js/markerclusterer.js"></script>
<div class="brixwork_map_container full_grid">
	<div class="brixwork_map_half" id="'.$mapid.'left">
		<div class="brixwork_map_display" id="'.$mapid.'">
		</div>
		<div class="brixwork_map_overlay">
			<div class="uil-magnify-css" style="transform:scale(0.6);"><div class="group"><div class="grip"></div><div class="inner-circle"></div><div class="outer-circle"></div></div></div>
		</div>	
	</div>
	
	
	<div class="brixwork_map_half brixwork_map_results" id="'.$mapid.'right">
		<div class="mobile_search_button_container">
			<a class="mobile_search_button">Refine Your Search</a>
		</div>
		<div class="brixwork_map_search_container" id="'.$mapid.'searchcontainer">
			';


	if($type=='homes') {
		// homes MLS search form.
		$return .='<form id="'.$mapid.'searchform" class="brixwork_map_search_form brixwork_map_search_form_homes"
			data-brixwork_search_min_price="'.($settings['brixwork_search_min_price']!='' ? $settings['brixwork_search_min_price'] : '0').'"
			data-brixwork_search_max_price="'.($settings['brixwork_search_max_price']!='' ? $settings['brixwork_search_max_price'] : '5000000').'"
			data-brixwork_search_price_increments="'.($settings['brixwork_search_price_increments']!='' ? $settings['brixwork_search_price_increments'] : '25000').'"
			
			data-brixwork_search_min_sqft="'.($settings['brixwork_search_min_sqft']!='' ? $settings['brixwork_search_min_sqft'] : '5000000').'"
			data-brixwork_search_max_sqft="'.($settings['brixwork_search_max_sqft']!='' ? $settings['brixwork_search_max_sqft'] : '5000000').'"
			data-brixwork_search_sqft_increments="'.($settings['brixwork_search_sqft_increments']!='' ? $settings['brixwork_search_sqft_increments'] : '500').'"
			
			
			
			
			>';
		$return .='<input type="hidden" name="sold" value="0" autocomplete="off" />';
		$return .='<input type="hidden" name="publish" value="1" autocomplete="off" />';

		$homeurlbase = ($homeurlbase!='' ? $homeurlbase : 'showlisting/'); // helps build the URL - should be specified in the actual php file in template folder, or defaults.
		$return .='<input type="hidden" name="homeurlbase" value="'.$homeurlbase.'" autocomplete="off" />';
	} else {
		// buildings/presales seach form. $type=='buildilngs', essentially.
		$return .='<form id="'.$mapid.'searchform" class="brixwork_map_search_form brixwork_map_search_form_buildings">';
		$return .='<input type="hidden" name="feature" value="1" />'; // building ALWAYS looks for feature 1!
		$buildingurlbase = ($buildingurlbase!='' ? $buildingurlbase : 'listings/');
		$return .='<input type="hidden" name="buildingurlbase" value="'.$buildingurlbase.'" autocomplete="off" />';// helps build the URL - should be specified in the actual php file in template folder, or defaults.
	}
	// common search parameters in hidden input fields.
	$return .='<input type="hidden" name="brixwork_search_type" class="brixwork_search_type" value="'.$type.'" autocomplete="off" />
		';


	$return .='<input type="hidden" class="brixwork_map_lat" name="lat" value="" autocomplete="off" />
		<input type="hidden" class="brixwork_map_lng" name="lng" value="" autocomplete="off" />
		<input type="hidden" class="brixwork_map_zoom" name="zoom" value="" autocomplete="off" />
		<input type="hidden" class="brixwork_map_interaction" name="form" value="form" autocomplete="off" />
		
		<input type="hidden" class="brixwork_map_lat_min" name="lat_min" value="" autocomplete="off" />
		<input type="hidden" class="brixwork_map_lat_max" name="lat_max" value="" autocomplete="off" />
		<input type="hidden" class="brixwork_map_lng_min" name="lng_min" value="" autocomplete="off" />
		<input type="hidden" class="brixwork_map_lng_max" name="lng_max" value="" autocomplete="off" />
		
		
		';

	// these two should be filled out upon load.

	// city container.
	$return .= '<div class="brixwork_map_search_city_container">';
	$return .=' <select name="cityid" id="'.$mapid.'searchcity" class="brixwork_map_search_form_dropdown" data-placeholder="Select City" style="width:100%;" autocomplete="off" data-default="'.($query['city']!='' ? ' '.$query['city'].'"' : '').'">';
	$return .= '<option value="">Select City</option>';

	$cities_query['publish'] = 1;
	$cities_ids = get_areas($cities_query);

	foreach ($cities_ids as $city_id) {
		$city = new area();
		$city->initialize($city_id);

		$return .='<option value="'.$city->id.'" rel="'.$city->name.'" data-lat="'.($city->lat!='' ? $city->lat : '').'" data-long="'.($city->long!=''? $city->long : '').'" data-polygon="'.$city->polygon.'" data-zoomlevel="'.$city->zoomlevel.'">'.$city->name.'</option>';
	}

	$return .= '</select>';
	$return .= '</div><div class="brixwork_map_search_area_container">'; // end of city container, open area cotnainer.
	$return .='<select name="areaid[]" id="'.$mapid.'searcharea" class="brixwork_map_search_form_dropdown" multiple style="width:100%;" data-placeholder="Select City First" autocomplete="off">
			<option value="">All Subareas</option>
		</select>';

	$return .='<input type="hidden" name="listing_search_perpage" class="brixwork_listing_search_perpage" value="'.($perpage!='' ? $perpage : 20).'" autocomplete="off" />';
	$return .='<input type="hidden" name="listing_search_maxpage" class="brixwork_listing_search_maxpage" value="'.($maxpage!='' ? $maxpage : 20).'" autocomplete="off" />';

	$return .='<input type="hidden" name="listing_search_page" class="brixwork_listing_search_page" value="1" autocomplete="off" />';

	$return .= '</div>'; // end of .brixwork_map_search_subarea_container

	if($type=='homes') {
		// homes MLS search form.


		$return .='<div class="brixwork_map_search_home_filters">
							<input type="hidden" name="min_price" class="brixwork_listing_min_price" value="" autocomplete="off" />
							<input type="hidden" name="max_price" class="brixwork_listing_max_price" value="" autocomplete="off" />
			
							<div class="brixwork_slider_wrap">
								<div class="brixwork_slider_price brixwork_sliders ui-slider"> </div>
								<div class="brixwork_search_display_amount_min brixwork_slider_min_display">&nbsp;</div>
								<div class="brixwork_search_display_amount_max brixwork_slider_max_display">&nbsp;</div>
							</div>';

		// Property Types!
		$return .='<div class="brixwork_map_search_home_types">';
		if(is_array($settings['brixwork_search_type']) && count($settings['brixwork_search_type'])>0) {
			$searchtype = $settings['brixwork_search_type'];
		} else {
			$searchtype = $dwelling_type;
		}

		foreach($searchtype as $keyid=> $typeid) {
			$return .='<div class="brixwork_map_checkbox_group brixwork_map_checkbox_group_type">
				<label for="'.$mapid.$settings['type'][$typeid].'" class="brixwork_map_checkbox_panel">
				<div class="brixwork_map_checkbox_input"><input type="checkbox" class="brixwork_map_checkbox" name="type[]" id="'.$mapid.$settings['type'][$typeid].'" value="'.$settings['type'][$typeid].'" autocomplete="off" /></div>
				<div class="brixwork_map_checkbox_label">'.$settings['type'][$typeid].'</div>
				</label>
				</div>';
		}

		$return .= '</div>'; // end of brixwork_map_search_home_types

		// Bed bath etc.
		$return .='<div class="brixwork_map_spinner_group">
				<label for="'.$mapid.'bedrooms_display">Beds:</label>
				<span class="brixwork_spinner">
					<a class="brixwork_spinner_button brixwork_spinner_down" tabindex="-1" href="#"><span class="brixwork_spinner_text">-</span></a>
					<input type="text" value="" autocomplete="off" class="brixwork_spinner_display" id="'.$mapid.'bedrooms_display" data-min="0" data-max="10" data-inputid="'.$mapid.'bedrooms" data-any="Any" data-ultd="10+" autocomplete="off" readonly />
					<input type="hidden" name="bedroom" class="brixwork_map_search_bedrooms brixwork_spinner_value" id="'.$mapid.'bedrooms" value="" autocomplete="off" />
					<a class="brixwork_spinner_button brixwork_spinner_up" tabindex="-1" href="#"><span class="brixwork_spinner_text">+</span></a>
				</span>
			</div>';

		$return .='<div class="brixwork_map_spinner_group">
				<label for="'.$mapid.'bathrooms_display">Baths:</label>
				<span class="brixwork_spinner">
					<a class="brixwork_spinner_button brixwork_spinner_down" tabindex="-1" href="#"><span class="brixwork_spinner_text">-</span></a>
					<input type="text" value="" autocomplete="off" class="brixwork_spinner_display" id="'.$mapid.'bathrooms_display" data-min="1" data-max="5" data-inputid="'.$mapid.'bathrooms" data-any="Any" data-ultd="5+" autocomplete="off" readonly />
					<input type="hidden" name="bathroom" class="brixwork_map_search_bathrooms brixwork_spinner_value" id="'.$mapid.'bathrooms" value="'.($params['bathrooms']!='' ? $params['bathrooms'] : '').'" autocomplete="off" />
					<a class="brixwork_spinner_button brixwork_spinner_up" tabindex="-1" href="#"><span class="brixwork_spinner_text">+</span></a>
				</span>
			</div>';

		$return .='<div class="brixwork_search_sqft_container">
			
			<input type="hidden" name="min_sqft" class="brixwork_listing_min_sqft" value="" autocomplete="off" />
			<input type="hidden" name="max_sqft" class="brixwork_listing_max_sqft" value="" autocomplete="off" />
					
			<div class="brixwork_slider_wrap">	
				<div class="brixwork_slider_sqft brixwork_sliders"></div>
				<div class="brixwork_search_display_sqft_min brixwork_slider_min_display">&nbsp;</div>
				<div class="brixwork_search_display_sqft_max brixwork_slider_max_display">&nbsp;</div>
			</div>';


		$return .= '</div>'; // end of brixwork_search_sqft_container


		$return .= '<div class="brixwork_search_orderby_container">
				<label for="'.$mapid.'listing_order_by">Order By:</label>
				<div class="brixwork_search_select_container brixwork_search_orderby_column">
					<select name="listing_order_by" id="'.$mapid.'listing_order_by" autocomplete="off">
						<option value="create_date">List Date</option>
						<option value="modify_date">Updated</option>
						
						<option value="price" selected>Price</option>
						<option value="sqft">Sqft</option>
						<!--<option value="bedroom">Bedrooms</option>
						<option value="bathroom">Bathrooms</option>-->
					</select>
				</div>
				<div class="brixwork_search_select_container brixwork_search_orderby_direction">
					<select name="listing_order_direction" id="'.$mapid.'listing_order_direction" autocomplete="off">
						<option value="DESC" selected>High to Low</option>
						<option value="ASC">Low to High</option>
					</select>
				</div>
			</div>
			';
		$return .= '<div class="brixwork_map_searchbutton_container"><input type="submit" class="brixwork_map_search_button" value="Search" id="'.$mapid.'searchbutton" /></div>';


		$return .='</div>'; // end of .brixwork_map_search_home_filters

	} else {
		// buildings/presales seach form.
		$return .='<div class="brixwork_map_search_building_filters">';
		$return .='<div class="brixwork_map_checkbox_group brixwork_map_checkbox_group_pets"><input type="checkbox" class="brixwork_map_checkbox" name="pets" id="'.$mapid.'pets" /><label for="'.$mapid.'pets">Pets Allowed</label></div>';
		$return .='<div class="brixwork_map_checkbox_group brixwork_map_checkbox_group_rentals"><input type="checkbox" class="brixwork_map_checkbox" name="rentals" id="'.$mapid.'rentals" /><label for="'.$mapid.'rentals">Rental Allowed</label></div>';
		$return .='<div class="brixwork_map_checkbox_group brixwork_map_checkbox_group_has_listings"><input type="checkbox" class="brixwork_map_checkbox" name="has_listings" id="'.$mapid.'has_listings" /><label for="'.$mapid.'has_listings">Has Units For Sale</label></div>';

		$return .= '<div class="brixwork_map_searchbutton_container"><input type="button" class="brixwork_map_search_button" value="Search" id="'.$mapid.'searchbutton" /></div>';

		$return .= '</div>'; // end of brixwork_map_search_building_filters
	} // end of homes or buildings switch


	if(is_array($blanketfilter)) {
		// blanket filter should override everything.
		foreach($blanketfilter as $filtername=>$filtervalue) {
			if(is_array($filtervalue)) {
				foreach($filtervalue as $filtervaluearray) {
					$return .='<input type="hidden" name="'.$filtername.'[]" value="'.$filtervaluearray.'" autocomplete="off" />
						';
				}
			} else {
				$return .='<input type="hidden" name="'.$filtername.'" value="'.$filtervalue.'" autocomplete="off" />
					';
			}
		}
	}

	$return .= '</form><div class="clear"></div>'; // end <form> and .brixwork_map_search_container

	$return .= '</div>'; // end of brixwork_map_search_container

	$return .='<div class="brixwork_map_list" id="'.$mapid.'list"></div>';// self closing divs.
	$return .='<div class="brixwork_search_overlay brixwork_search_bars"><div class="uil-facebook-css" style="-webkit-transform:scale(0.6)"><div></div><div></div><div></div></div></div>'; // self closing divs.
	$return .='<div class="brixwork_search_overlay brixwork_search_message_container">
			<div class="brixwork_search_message">
				<h5 class="brixwork_search_message_title">I am a title here</h5>
				<p class="brixwork_search_message_text">Sample text.</p>
			</div>
		</div>';
	$return .='</div>'; // end of map_half right searchcontainer.

	$return .= '</div>
	';// end of .brixwork_map_container

	if($settings['brixwork_search_enabled']==0) {
		// override to disable if search is NOT enabled.
		$return = "<h6>Map search (new) must be enabled on the search settings by the Brixwork team after billing is arranged.</h6>";
	}
	return $return;
}



function generate_map_json($type, $items, $homeurlbase='showlisting/', $buildingurlbase='listings/', $noimage = 'noimage.jpg', $img_size_path = 'thumb') {
	global $settings;
	// $items to contain results of get_properties() or get_buildings() query so as to generate the ID rows.
	// what are the fields we need for display? create mapping to transpose to JSON.

	if(!isset($type) || $type=='') {
		$type = 'homes';
	}

	$fields['homes'] = array(
		'id'=>'idr',
		'status'=>'status',
		'showlisting'=>'showlisting',
		'source'=>'source',
		'buildingid'=>'buildingid',
		'building'=>'building',
		'address'=>'address',
		'area'=>'area',
		'city'=>'city',
		'mls' => 'mls',
		'areacity'=>'areacity',
		'masterid'=>'masterid',
		'sqft'=>'sqft',
		'lot'=>'lot',
		'year'=>'year',
		'lat'=>'lat',
		'long'=>'lng',
		'sold'=>'sold',
		'type'=>'type',
		'price'=>'price',
		'bedroom'=>'bedroom',
		'bathroom'=>'bathroom',
		'openhouse'=>'openhouse',
		'remarks'=>'remarks',
		'firm_1'=>'firm_1',
		'firm_2'=>'firm_2',
		'firm_3'=>'firm_3',
		'create_date'=>'create_date',
		'modify_date'=>'modify_date'
	);

	$fields['buildings'] = array(
		'id'=>'idr',
		'name'=>'bname', // .name is a predefined namespace in javascript nodes..
		'defaultname'=>'defaultname',
		'photos'=>'photos',
		'status'=>'status',
		'address'=>'address',
		'area'=>'area',
		'city'=>'city',
		'areacity'=>'areacity',
		'lat'=>'lat',
		'long'=>'lng',
		'builder'=>'builder',
		'numlistings'=>'numlistings',
		'numactivelistings'=>'numactivelistings',
		'unittypes'=>'unittypes',
		'rental'=>'rental',
		'pets'=>'pets',
		'pricelow'=>'pricelow',
		'pricehigh'=>'pricehigh',
		'sqftlow'=>'sqftlow',
		'sqfthigh'=>'sqfthigh',
		'create_date'=>'create_date',
		'modify_date'=>'modify_date'
	);
	$count = 0;
	if(is_countable($items)) {
		foreach($items as $id => $data) {
			// loop through each home row.

			switch ($type) {
				case "homes":
					$object = new home;
					$object->initialize($id, $data); // with ugpraded class object as well as get_properties() function, the $data contains the home ID already and does NOT constitute another SQL.
					break;

				case "buildings":
					$object = new building;
					$object->initialize($id, $data); // eventually needs to be updated to array, not just building ID.
					$object->get_listings(); // slows it down a bit, so far we have no easy join statement for simplifying this...
					break;
			}
			$array = array();// reset it
			$array = get_object_vars($object);
			foreach($array as $key=>$value) {
				if (array_key_exists($key, $fields[$type])) {
					// provide only what exists.
					// for explicit booleans lets change to 1 for true, 0 for false?
					if($value===true) {
						$value = 1;
					} else if($value===false) {
						$value = 0;
					}

					if(is_array($value)) {
						foreach($value as $subkey=>$subval) {
							$value[$subkey] = cleanupfortextfield($subval);
						}
					} else {
						$value = cleanupfortextfield($value);
					}
					$json_array[$count][$fields[$type][$key]] = $value;

				}
				$json_array[$count]['category'] = cleanupfortextfield($type); // add final array, is it "homes" or "buildings"?
				// now get main image var.
				$json_array[$count]['mainimage']  = $object->get_main_images_path(0, $noimage);

				// if we should load smaller img sizes other than web (to use thumbnail sized imgs for basically)
				if (($img_size_path != 'web') && (strpos($json_array[$count]['mainimage'], '/web/') !== false)) {
					$json_array[$count]['mainimage'] = str_replace('/web/','/'.$img_size_path.'/',$json_array[$count]['mainimage']);
				}

				$json_array[$count]['statusid'] = cleanupfortextfield($object->data['status']);
				switch ($type) {
					case "homes":
						$json_array[$count]['url'] = $object->get_property_link($settings['url_trail'],($homeurlbase=='' ? 'showlisting/' :$homeurlbase));
						break;

					case "buildings":
						$json_array[$count]['url'] = $object->get_building_link($trail='',($buildingurlbase=='' ? 'listings/' : $buildingurlbase));
						break;
				}
			}
			$count++;
		}
	}

	return array($json_array, json_encode($json_array));
}


function generate_polygon_of_subareas($cityid) {
	if(!is_object($cityid)) {
		$city = new area;
		$city->initialize($cityid);
	} else {
		$city = $cityid; //object passed.
	}
	$polygons = array();
	foreach($city->subareas as $subareaid=>$subareaname) {
		$subarea = new subarea;
		$subarea->initialize($subareaid);
		if($subarea->polygon) {
			$polygons[$subarea->id] = array(
				'id'=>$subarea->id,
				'areaname'=>$subarea->name,
				'lat'=>$subarea->lat,
				'lng'=>$subarea->long,
				'polygon'=>$subarea->polygon, // Array ( [0] => 50.156336,-122.961903 [1] => 50.153586,-122.973919 [2] => 50.144896,-122.973061 [3] => 50.140826,-122.967739 ) is raw array - single level.
				'infowindow'=>'<h6>'.$subarea->name.'</h6>'
			);
		}
	}
	if(is_array($polygons) && count($polygons)>0) {
		$return = $polygons;
	} else {
		$return = false;
	}
	return $return;
}


/* ######################################################
#brix_13
PopUp Functions (jun 2016, JJ)
###################################################### */


/*
IMPORTANT NOTES:

REQUIREMENTS, STUFF YOU'LL NEED TO EDIT THAT'S NOT IN THE BACK END:
1. fancybox.js - "engine" to make it run
2. header.php - load html header or not
3. header_html.php - set and echo the actual js code
4. footer.php - load html footer or not
5. brixwork_popup.php - the actual pop up that'll appear. In the templates folder as it's customizeable on a site by site basis.
6. populate the settings table with the proper variables. popup_timer = ms value, other settings = number of views on page.

Refer to https://docs.google.com/document/d/1lY1F42-qArgSUNC0lhIZ51hKJxdPrLs5ZjSE6xh0AlM/edit#heading=h.8j8wgndjrmny for further instructions.
*/

function delete_popup_cookies() {
	global $settings;
	$popup['timer'] = (int)$settings['popup_timer'];
	$popup['views'] = (int)$settings['popup_pageviews'];
	$popup['showl'] = (int)$settings['popup_detailviews'];
	$popup['listn'] = (int)$settings['popup_listingsviews'];

	foreach ($popup as $key=>$val) {
		$c_name = 'brix_'.$key;
		setcookie($c_name, 0, time() - 1, "/");
	}
	setcookie('brixwork_popup_fired', 0, time() - 1, "/");

}

function set_popup($page = '') {
//this function relies on fancybox loading the contact form in an iframe, to avoid id conflicts.
//$page values = '', 'showl', 'listn'

	global $settings;
	//brixwork_popup_fired
	if (!isset($_COOKIE['brixwork_popup_fired']) || $_COOKIE['brixwork_popup_fired'] != 1) {
		$popup['timer'] = (int)$settings['popup_timer'];
		$popup['views'] = (int)$settings['popup_pageviews'];
		$popup['showl'] = (int)$settings['popup_detailviews'];
		$popup['listn'] = (int)$settings['popup_listingsviews'];

		//print_r($popup);

		$return .= "
			<script type=\"text/javascript\">
				function brixwork_popup(time_fired) {

					console.log('brix_popup running');
					$.ajax({
						url: '".$settings['templatepath']."ajax_popup.php',
						data: {
							'timer': time_fired,							
							".( $popup['views'] > 0 ? "'views': ".(int)$_COOKIE['brix_views']."," : '' )."							
							".( $popup['showl'] > 0 && $page == 'showl' ? "'showl': ".(int)$_COOKIE['brix_showl']."," : '')."
							".( $popup['listn'] > 0 && $page == 'listn' ? "'listn': ".(int)$_COOKIE['brix_listn']."," : '')."
						},
						type: 'POST',
						success: function(data) {
							console.log('ajax done');
							
							if (data != '') {
								console.log('data be here');
								//$('#bodywrap').append(data);
								
								$.fancybox.open([
									{
										href: data,
										openEffect  : 'fade',
										closeEffect	: 'fade',
										prevEffect	: 'fade',
										nextEffect	: 'fade',
										type: 'iframe',
									}
								]);
							} else {
								console.log('data be empty :(');
							}
							
						}
					});
				}
				
				document.addEventListener(\"DOMContentLoaded\", function(event) {";
		//if jquery is loaded in the footer $(document) is not an object so have to fallback on the javascript equivalent of $(document).load() to make sure it loaded all the file it needs

		if (
			$popup['views'] > 0 ||
			$popup['showl'] > 0 ||
			$popup['listn'] > 0

		) {
			$return .= "brixwork_popup(0);";
		}
		if ($popup['timer'] > 0) {
			$return .= "setTimeout(function() { brixwork_popup(1); }, ".$popup['timer']."000);";
		}


		$return .= "
			});
		</script>
		";

		return $return;
	} else {
		return false;
	}
}
function get_average_price_per_sqft_for_main_building($main_building_id, array $type_number = null) {
	global $mysqli;

	// first check if we received a numeric value from the caller -- if not, exit:
	// "42" is valid. "42 something" is not valid. is_numeric handles the coercion.
	if ( !is_numeric($main_building_id) ) {
		return false;
	}

	// this sql statement will cast and replace the dollar sign in price and turn it into a decimal
	// There is a need for a subquery because a building can have a mainbuilding! So we need a list of
	// all the buildings with the same main building.
	// We don't need to do a group by because we are doing an aggregation on the entire result set
	// as the result set is tied to one MAIN building.

	// CALLER HAS TO SUPPLY THE MAIN BUILDING ID


	// there may be the case where we don't have a main building -- that is, the building is alone and the mainid will be 0.
	// in such a case, we just need make sure the building id is equal to the id passed in.
	$column_name = 'aveppsqf';
	$sql =
		"
			SELECT AVG(CAST(REPLACE(REPLACE(IFNULL(price,0),',',''),'$','') AS DECIMAL(10,2)))
				/AVG(sqft) AS '{$column_name}'
			FROM homes
			WHERE CAST(REPLACE(REPLACE(IFNULL(price,0),',',''),'$','') AS DECIMAL(10,2)) > 0
			AND ( building IN (
				
				SELECT id
				FROM buildings
				WHERE mainid = ?
				
			) OR
				
				building = ?
				
			)
			";

	// if the user provides a type number, filter by said type number
	if ( $type_number !== null ){
		$sql .= "AND type IN(";

		for($i = 0; $i < count($type_number); $i++) {
			if ($i == 0) {
				$sql .= $type_number[$i];
				continue;
			}

			$sql .= ', '.$type_number[$i];
		}

		$sql .= ")";
	}

	// implement simple checks that will give error messages to user if we fail to execute any sql
	if (!($prepared_statement = $mysqli->prepare($sql))) {
		echo '<h1>failed to prepare sql</h1>';
	}

	if (!($prepared_statement->bind_param("ii", $main_building_id, $main_building_id))) {
		echo '<h1>failed to bind sql</h1>';
	}

	if (!($prepared_statement->execute())) {
		echo '<h1>failed to exec sql</h1>';
	}


	$result = $prepared_statement->get_result();

	// if we don't get anything back, just return false -- don't return 0 because 0 is a valid price
	if (mysqli_num_rows($result) <= 0) {
		return false;
	}

	$result = $result->fetch_assoc();

	// round the return variable for the caller :)
	return round( $result[$column_name], 2) ;
}


/* ######################################################
#brix_14
Cookie tracking stuff!

###################################################### */

function set_visitor_cookie($sessionid, $visitorid='', $expiry = false) {
	global $settings;
	global $mysqli;
	global $local;

	// setting $expiry to 0 invalidates cookie - this is how cookies are UNSET.
	if($expiry==false) {
		// default is false,
		$expiry = $local + 3600*24*30; // 1 mth.
	}

	setcookie('sessionid', $sessionid, $expiry, '/');

	if($visitorid!='') {
		setcookie('visitorid', $visitorid, $expiry, '/');
	}
}

/**
 * @param $cookieid
 * @param $cookiename
 * @param $new
 * @param bool $old
 * Modifies an entire ROW of a cookie, finds the row by $cookiename.
 */
function modify_json_cookie($cookieid, $cookiename, $new, $old=false) {

	global $settings;
	global $local;

	$allowedcookies  = array(
		'listing_history',
		'search_history'
	);

	$return = false;

	if($cookiename!='' && in_array($cookiename, $allowedcookies)!==false) {
		if(is_array($old)) {
			$old[] = $new; // add new array level below.
			foreach($old as $row) {
				$cookievalue[] = $row; // merely resets to key 0, 1, without affecting sub-array keys such as pid, bedroom etc.
			}
		} else {
			$cookievalue = array($new); // single array for the new row - each home is an array key!
		}

		$return = set_json_cookie_row($cookieid, $cookiename, $cookievalue);
	}
	return $return;
}

/**
 * @param $cookieid
 * @param $cookiename
 * Simply gets the cookie text from the row that contains the cookie name. multi level array turned into JSON.
 */
function get_json_cookie_row($cookieid, $cookiename) {
	$return = false;
	$cookiefilepath = $GLOBALS[BRIX_COOKIE_FOLDER].$cookieid;
	if($cookieid!='' && file_exists($cookiefilepath) ) {
		$cookiearray = file($cookiefilepath);

		foreach($cookiearray as $rcount => $cookierow) {
			$cookieline =  json_decode($cookierow, true);

			if($cookieline['name']==$cookiename) {
				$return = $cookieline['value'];
				break;
			}
		}

	}

	return $return;
}

function set_json_cookie_row($cookieid, $cookiename, $cookievalue) {
	$return = false;

	$newline = json_encode(array('name'=>$cookiename, 'value'=>$cookievalue));
	$cookiefilepath = $GLOBALS[BRIX_COOKIE_FOLDER].$cookieid;
	if($cookieid!='' && $cookiename!='') {
		if(!file_exists($cookiefilepath)) {
			// brand new file, so just write in single line!
			$cookiefile = fopen($cookiefilepath, 'w');
			if($cookiefile) {
				$return = fwrite($cookiefile, $newline);
				fclose($cookiefile);
			}
			chmod($cookiefilepath, 0644);
		} else {
			// replace existing line in the file.
			$linefound = false;
			$cookiearray = file($cookiefilepath);
			$newfile = array();// start building new file array.
			foreach($cookiearray as $rcount => $cookierow) {
				$cookievar = json_decode($cookierow, true);
				if($cookievar['name']==$cookiename) {
					// replace this line with new value.
					//echo "Found line {$cookiename} at {$rcount} so replacing with new line<br />\n";
					$linefound = true;
					$newfile[] = $newline;
				} else if(strlen($cookierow)>1) {
					//echo "Keeping {$rcount} as length was ".strlen($cookierow)."<br />\n";
					$newfile[] = $cookierow; // preserve these lines.. but skip blank ones.
				}
			}

			if($linefound!==true) {
				// file existed, but specific $cookiename was NOT found.
				$newfile[] = $newline;
			}
			//echo "Final File array: <br />\n";
			//print_r($newfile);
			$return = file_put_contents($cookiefilepath, implode("\n", $newfile)."\n");
		}
	}

	return $return;
}


/* ######################################################
#brix_15
CRM INtegration stuff! Such as Mailchimp, FollowupBoss etc.
###################################################### */

// TODO: Re-write all these functions as part of API upgrade. https://app.asana.com/0/283822686917686/1204541838853455
/**
 * Updated to new Mailchiimp API standards in 2023.
 * Returns list merge fields (FNAME, LNAME and any other custom) from any list. Needs valid List ID in $options['listid']
 *
 * @param $mcobject
 * @param $options
 * @return array
 */
function mailchimp_get_list_fields($mcobject, $options) {
	$mergeFields = $mcobject->lists->getListMergeFields($options['listid']);
	// also have $options['fieldtype'] to use?
	$fields = array(); // blank.

	foreach ($mergeFields->merge_fields as $mergeField) {
		$fields[] = array('tag'=> $mergeField->tag, 'name' => $mergeField->name);
	}
	return $fields;
}

/**
 * Returns fresh API object with Mailchimp Marketing (2023 upgrade),
 *
 * If $apikey is blank, it defaults to the Brixwork's main API - mostly used to add Users to the active list and group them to right MLS zones etc.
 *
 * @param $apikey
 * @return \MailchimpMarketing\ApiClient
 */
function mailchimp_get_api($apikey='') {

	if($apikey=='') {
		global $settings;
		$apikey = $settings['mailchimp_brixwork_api'];
	}
	$MailChimpClient = new MailchimpMarketing\ApiClient();
	list($throwaway, $server_prefix) = explode('-', $apikey);
	$MailChimpClient->setConfig([
		'apiKey' => $apikey,
		'server' => $server_prefix
	]);
	return $MailChimpClient;
}

function mailchimp_get_groups_list($mailchimpapi, $groupid='') {
	/*
	 * Short hand function to get IDs of each MLS zone IDs, from the Brixwork Active clients list.
	 * if we need to add a new MLS zone,. we need to run this after adding another group, so that new users under those websites are aggregatedd to the right zone.
	 * */
	global $settings;

	$activelistid = 'c3120ac935'; // This is our Active Clients list on Mailchimkp since 2011. Never changes.
	$return = array();
	if($groupid!='') {
		$interestgroupcount = 100;
		$listinfo = $mailchimpapi->lists->listInterestCategoryInterests($activelistid, $groupid, null, null, $interestgroupcount, 0);
		foreach ($listinfo->interests as $category) {
			$return[$category->name ] = $category->id; // vancouver.brixwork.com  => 5434a5e592 for example.
		}
	} else {
		$listinfo = $mailchimpapi->lists->getListInterestCategories($activelistid);
		foreach ($listinfo->categories as $category) {
			$return[$category->title ] =  $category->id; // vancouver.brixwork.com  => 5434a5e592 for example.
		}
		/*
		 * As of 2023-05, the categories are:
		 * ["Location"]=>
			  string(10) "76f8bf1273"
			  ["MLS"]=>
			  string(10) "74ca86066e"
			  ["Wordpress Blog"]=>
			  string(10) "ded0766c8f"
			  ["Rental"]=>
			  string(10) "edf9c339d0"
			  ["SSL"]=>
			  string(10) "47fa770867"
		 * */
	}



	return $return;
}

/**
 * @param $mcobject - most likely the customer (website operator)'s Mailchimp Object.
 * @param $options
 * @return array
 */
function mailchimp_add_subscriber($mcobject, $options) {
	global $settings;
	/*
	 *
	 * ONLY USE for adding regular leads to website owner (client)'s Mailchimp list.
	 *
	 * To add users to the Brixwork Active list for updates, tutorials etc., use the class object user->addToBrixworkMailchimp() function.
	 * Syntax we want for subscriber is
	 *
	$subscriber = [
    	'email_address' => $email,
    	'status' => 'subscribed',
    	'merge_fields' => [
       	 'FNAME' => $firstName,
       	 'LNAME' => $lastName
    	]
	];

	 * */
	$subscriber_data['email_address'] = $options['email'];
	$subscriber_data['status'] = 'subscribed';

	// start buliding the 'merge_fields' subarray using first/last name pairs.

	if ($options['fname'] != '') {
		$firstname = trim($options['fname']);
	}
	if ($options['lname'] != '') {
		$lastname = trim($options['lname']);
	}

	if($options['fname']!='') {
		/*
		 * 	Build the 'merge_fields' array/
		 * Mailchimp wants nthe following fromat.. even if we don' thave email addresses etc. since we're updating.
		 * $subscriber_data = array(
		 * 		'key/email/etc' => $email,
		 * 		'merage_data' => array(
		 * 			'FNAME' => $first_name,
		 * 		)
		 * )
		 * */
		$subscriber_data['merge_fields'] = array(); // blank array by default.

		if(isset($firstname) && $settings['mailchimp_first_name_tag']!='') {
			$subscriber_data['merge_fields'][$settings['mailchimp_first_name_tag']] = $firstname;
		}
		if(isset($lastname) && $settings['mailchimp_last_name_tag']!='') {
			$subscriber_data['merge_fields'][$settings['mailchimp_last_name_tag']] = $lastname;
		}

		if(isset($options['phone']) && $settings['mailchimp_phone_number_tag']!='') {
			$subscriber_data['merge_fields'][$settings['mailchimp_phone_number_tag']] = $options['phone'];
		}
		if(isset($options['message']) && $settings['mailchimp_message_tag']!='') {
			$subscriber_data['merge_fields'][$settings['mailchimp_message_tag']] = $options['message'];
		}
	}

	try {
		$response = $mcobject->lists->setListMember($options['listid'], md5(strtolower($subscriber_data['email_address'])), $subscriber_data);
	} catch (Exception $error) {
		var_dump($error);
	}
	/*
	 * $response looksl ike:
	[id] => 38c68ac055fbf5c89c34993b71e14fe2
    [email_address] => jeff@jeffkee.com
    [unique_email_id] => 73bf637c98
    [contact_id] => 01d2ad53e5538d71567664f53ad544fa
    [full_name] => Jeff Kee
    [web_id] => 35879341
    [email_type] => html
    [status] => subscribed
    [consents_to_one_to_one_messaging] => 1
    [merge_fields] => stdClass Object
        (
            [FNAME] => Jeff
            [LNAME] => Kee
            [ACTVDATE] => 2011-01-01
            [URL] => https://www.silvervalleyhomes.com/
        )


	 *
	 * */
	$return = array('id'=>$id, 'result' => $result, 'status' => $status, 'message' => $message);
	return $return;
}

function followupboss_api_action($options) {
	global $settings;

	$apikey = $settings['followupboss_api_key'];

	// event data
	$data = array(
		"source" => get_host($settings['sitepath']),
		"type" => ($options['type']!='' ? $options['type'] : 'Property Inquiry'),
		"message" => $options['message'],
		"person" => array(
			"firstName" => $options['fname'],
			"lastName" => $options['lname'],
			"emails" => array(array("value" => $options['email'])),
			"phones" => array(array("value" => $options['phone'])),
			"tags" => $options['tags']
		),
		"property" => array(
			"street" => $options['street'],
			"city" => $options['city'],
			"state" => $options['province'],
			"code" => $options['postal'],
			"mlsNumber" => $options['mls'],
			"price" => $options['price'],
			"forRent" => $options['for_rent'],
			"url" => $options['url'],
			"type" => $options['property_type'],
			"bedrooms" => $options['bedroom'],
			"bathrooms" => $options['bathroom'],
			"area" => $options['sqft'],
			"lot" => $options['lot']
		)
	);

	// init cURL - because it requires basic auth, we dont' use our built-in function.. just custom.
	$ch = curl_init('https://api.followupboss.com/v1/events');
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
	curl_setopt($ch, CURLOPT_USERPWD, $apikey . ':');
	curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
	curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
	curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));

	$response = curl_exec($ch);
	if ($response === false) {
		exit('cURL error: ' . curl_error($ch) . "\n");
	}
// check HTTP status code
	$code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
	if ($code == 201) {
		$return = 1; // New contact
		$message = 'New lead created on FollowupBoss.';
	} elseif ($code == 200) {
		$return = 2; // update existing contact
		$message = 'Existing  on FollowupBoss.';
	} else {
		$return = 0;
		$message = "Error, status code: {$code}\n";
	}
// dump response
//	if ($response) {
//		$response = json_decode($response);
//		var_dump($response);
//	}

	return $return;

}

function spark_form_api_action($options, $REQ = 'POST') {
	global $settings;

	$apikey = $settings['spark_form_api_key'];

	// event data
	$data = array(
		"contact" => [
			"agent" 			=> $options['agent'],
			"first_name"		=> $options['fname'],
			"last_name" 		=> $options['lname'],
			"email" 			=> $options['email'],
			"phone" 			=> $options['phone'],
//			"answer_attributes" => $options['answers'],
			"origin"			=> $options['origin'],
			"supplied_source"	=> $options['origin'],
			"comments"			=> $options['message'],
		]
	);

	// init cURL - because it requires basic auth, we dont' use our built-in function.. just custom.
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'https://api.spark.re/v1/contacts');
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $REQ);

	$headers = array();
	$headers[] = 'Authorization: Token token="'.$apikey.'"';
	$headers[] = 'Content-Type: application/json';

	curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
	curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data, JSON_PRETTY_PRINT));

	$response = curl_exec($ch);
	if ( curl_errno($ch) ) {
		echo "ERROR: " . curl_error($ch);
	}
	if ($response === false) {
		exit('cURL error: ' . curl_error($ch) . "\n");
	}
// check HTTP status code
	$code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
	if ($code == 201) {
		$return = 1; // New contact
		$message = 'New lead created on FollowupBoss.';
	} elseif ($code == 200) {
		$return = 2; // update existing contact
		$message = 'Existing  on FollowupBoss.';
	} else {
		$return = 0;
		$message = "Error, status code: {$code}\n";
	}
// dump response
//	if ($response) {
//		$response = json_decode($response);
//		var_dump($response);
//	}

	return $return;

}


/*
 * Generates a static map image tag with URL based on the parameters provided.
 */
function brixwork_generate_static_map(
		$lat,
		$long,
		$zoom = 14,
		$width = 640,
		$height = 250,
		$custom_icon = false,
		$icon_color = '0x777777',
		$icon_filename = '',
		$styles = array(),
		$dynamic_onclick = true,
		$directions_link = false,
		$directions_text = 'get directions',
		$pano = false,
		$alt='') {
	global $settings;
	$return = '';

	// ensure lat and long are set
	if($lat == '') {
		$lat = $settings['mapsearch_lat'];
	}
	if($long == '') {
		$long = $settings['mapsearch_long'];
	}

	// ensure lat and long have at least one decimal point
	$lat = brixwork_ensure_number_has_one_decimal($lat);
	$long = brixwork_ensure_number_has_one_decimal($long);

	// make sure icon colour doesn't contain hashes in the url
	$icon_color = str_replace('#', '0x', $icon_color);

	// if custom icon is on and icon file name is not set, set default
	if ( $custom_icon && $icon_filename == '' && !$pano) {
		$icon_filename = 'mapicon.png';
	}

	// build basics needed for static map
	$map_type = $pano ? '' : '&maptype=roadmap';
	$map = $pano ? 'streetview' : 'staticmap';
	$static_map_url = "https://maps.googleapis.com/maps/api/$map?format=png32$map_type";
	$static_map_url .= '&key='.$settings['google_maps_api_key'];

	if(!$pano) {
		$static_map_url .= ($lat != '' ? '&center='.$lat.','.$long : '');
		$static_map_url .= ($custom_icon ? '' : '&markers=size:mid|color:'.$icon_color);
		$static_map_url .= ($lat != '' && !$custom_icon ? '|'.$lat.','.$long : '');
	} else {
		$static_map_url .= ($lat != '' ? '&location="'.$lat.','.$long.'"' : '');
	}

	// if we want custom styles in the static map
	if(!empty($styles) && !$pano) {
		// turn the styles json into an url string and add it to the url
		$static_map_url .= brixwork_generate_static_map_styles($styles);
	}

	// set the zoom to be different for mobile and desktop
	$heading_and_pitch = '';
	if(!$pano) {
		$static_map_url .= '&zoom=' . $zoom;
	} else {
		$heading_and_pitch = '&heading=34&pitch=10';
		$static_map_url .= $heading_and_pitch;
	}

	$static_map_url .= '&size=' . $width . 'x' . $height . '&scale=2';

	// If we don't want the site to become dynamic on click, generate and external link
	if($dynamic_onclick == false) {
// 	https://www.google.com/maps/@49.2561465,-123.0285304,3a,75y,140h,90t/data=!3m5!1e1!3m3!1s7ONu8G3ktNVPzuH3cpWYeA!2e0!6s%2F%2Fgeo1.ggpht.com%2Fcbk%3Fpanoid%3D7ONu8G3ktNVPzuH3cpWYeA%26output%3Dthumbnail%26cb_client%3Dmaps_sv.tactile.gps%26thumb%3D2%26w%3D203%26h%3D100%26yaw%3D140%26pitch%3D-10%26thumbfov%3D100
		$external_link = 'https://www.google.com/maps/';
		$external_link .= $pano ? "@?api=1&map_action=pano$heading_and_pitch&viewpoint=$lat,$long" : "place/$lat,$long/@$lat,$long,".$zoom."z";

		$return .= "<a href='$external_link' target='_blank' title='View on Google Maps'>";
	}

	// return a mobile map and a desktop/tablet map.
	$return .= '<img alt="'.$alt.'" title="'.$alt.'" class="full-width static test' . ($pano ? ' street_view' : '') . '" src=\''.$static_map_url.'\' />';

	// If we want a custom icon (which we should), set it here.
	if ( $custom_icon && !$pano ) {
		$return .= '<img alt="map marker icon" title="map marker icon" class="marker_icon static" src="'.$settings['templatepath'].'images/'.$icon_filename.'" />';
	}

	// if we want the static map to become dynamic on click, close the anchor tag
	if($dynamic_onclick == false) {
		$return .= '</a>';
	}

	return $return;
}

/*
 * Generates a map that will be targeted by JS with or without a static map inside.
 */
function brixwork_generate_map_div($id = '', $class = '', $lat = '', $long = '', $zoom = '', $include_static = false, $default_static_object = array(), $directions_link = false, $directions_text = 'get directions', $pano = false, $alt = 'Address on Google Maps') {
	global $settings;

	// set default lat and long to map search from settings
	$map_lat = $lat != '' ? $lat : $settings['mapsearch_lat'];
	$map_long = $long != '' ? $long : $settings['mapsearch_long'];
	$map_zoom = $zoom != '' ? $zoom : '16';

	// build HTML attributes
	$attr_id = $id != '' ? ' id="'.$id.'"' : '';

	$default_class = 'brixwork_onclick';
	$attr_class = ' class="'.($include_static ? $default_class.' ' : '');
	$attr_class .= ($pano ? 'street_view ' : '');
	$attr_class .= ($class = '' ? $class : '').'"';
	$attr_lat = ' data-lat='.$map_lat;
	$attr_long = ' data-lng='.$map_long;
	$attr_zoom = ' data-basezoom='.$map_zoom;
	$attr_pano = ' data-pano='.$pano;

	$data_onclick = ($include_static && (!isset($default_static_object->dynamic_onclick) || $default_static_object->dynamic_onclick)) ? 1 : 0;
	$attr_onclick = ' data-onclick="'.$data_onclick.'"';

	if($include_static) {
//		if(!is_array($default_static_object)) {
//			unset($default_static_object);
//			$default_static_object = array();
//			// often we mistakenly passed a blank string instead of an array!
//		}
		// Set defaults here first.
		$default_static_object->lat = $map_lat;
		$default_static_object->long = $map_long;
		$default_static_object->zoom = $map_zoom;
		$default_static_object->directions_link = $directions_link;
		$default_static_object->directions_text = $directions_text;
		$default_static_object->pano = $pano;
		$default_static_object->alt = $alt;
		$static_object = brixwork_generate_map_static_object($default_static_object);

		/*
		 * unfortunately because php 7 does not allow us to unpack
		 * objects, we need to select width and height using numeric keys
		 */
		$attr_width = " data-width=".$static_object[3];

		$attr_height = " data-height=".$static_object[4];
	}

	$return = '<div class="map_wrapper"><div'.$attr_width.$attr_height.$attr_onclick.$attr_id.$attr_class.$attr_lat.$attr_long.$attr_zoom.$attr_pano.'>';

	// If the map is meant to be static on load, set it.
	if($include_static) {
		// Set using the handy unpack operator.
		$return .= brixwork_generate_static_map(...$static_object);
	}

	$return .= '</div>';

	// If a directions link is wanted, generate one.
	if($directions_link) {
		$return .= brixwork_map_get_directions_link($directions_text, $map_lat, $map_long);
	}

	$return .= '</div>';

	// set css selectors
	$css_id = '#';
	$css_id .= $id;
	$css_class = '.';
	$css_class .= "$default_class";
	$css_class .= $class != '' ? ".$class" : '';

	$css_selector = $id != '' ? "$css_id, " : '';
	$css_selector .= $css_class;
	$css_marker_selector = $id != '' ? "$css_id"." .marker_icon.static, " : '';
	$css_marker_selector .= "$css_class"." .marker_icon.static";
	$css_image_selector = $id != '' ? "$css_id"." img.static, " : '';
	$css_image_selector .= "$css_class"." img.static";
	$css_padding_bottom = ($static_object[4] / $static_object[3] * 100).'%';

	// return map styles.
	// TODO find a way to make including this more than once optional
	/**
	 * GOOGLE STATIC MAPS is limited at 640x64 - or scaled to 1280x1280 ONLY.
	 * https://github.com/siteorigin/so-widgets-bundle/issues/157
	 *
	 * Use CSS to manipulate the static image.
	 *
	 * max-width: ".$static_object[3]."px; the width that has been passed in as variable.
	 */
	$return .= "
	<style>
		$css_selector {
			width: 100%;
			padding-bottom: $css_padding_bottom;
			position: relative;
		} 
		".($include_static
			? ".map_wrapper {
				max-width: ".$static_object[3]."px;
				margin-left: auto;
				margin-right: auto;
				overflow: hidden;
		}
		$css_image_selector {
			position: absolute;
			width: 100%;
			top: 50%; 
			left: 50%;
			-webkit-transform: 	translate(-50%, -50%);
			-ms-transform: 		translate(-50%, -50%);
			transform: 			translate(-50%, -50%);
		}
		$css_image_selector.street_view {
			width: 100%;
		}"
			: '').
		($include_static && isset($default_static_object->custom_icon) && $default_static_object->custom_icon
			? "$css_marker_selector { 
				-webkit-transform: 	translate(-50%, -100%);
				-ms-transform: 		translate(-50%, -100%);
				transform: 			translate(-50%, -100%);
				width: auto;
			}"
			: '')."
	</style>";

	return $return;
}

/*
 * Generates the URL encode styles for static maps
 */
function brixwork_generate_map_static_object($static_object) {
	$default_static_object = (object) array(
		'lat' 				=> $lat,
		'long' 				=> $long,
		'zoom' 				=> 14,
		'width' 			=> 640,
		'height' 			=> 640,
		'custom_icon' 		=> false,
		'icon_color' 		=> '0x868686',
		'icon_filename'		=> '',
		'styles' 			=> array (),
		'dynamic_onclick'	=> true,
		'directions_link'	=> false,
		'directions_text'	=> 'directions',
		'pano'				=> false,
		'alt'				=> '',
	);

	$return = array();

	// if the static_object is empty, just return the default
	if(empty($static_object) || $static_object == '') {

		// return the default as a disassociative array, though
		foreach ( $default_static_object as $key=>$value) {
			$return[] = $value;
		}
	} else {
		/*
		 * If the static object is not empty, loop through the default static object
		 * to ensure order set there is kept.
		 */
		foreach ( $default_static_object as $key=>$value) {
			/*
			 * if the key is not set, return the default value
			 *
			 * Don't set key so we can use the handy unpack feature later
			 * (Why order matters))
			 */

			if(!isset($static_object->$key)) {
				$return[] = $value;
			} else {
				// if the key is set, return the new value
				$return[] = $static_object->$key;
			}
		}
	}

	return $return;
}

/*
 * generate styles from each object inside json
 */

function brixwork_generate_static_map_styles($styles) {
	// If styles is a string, then a raw json was input, so let's fix that
	if(is_string($styles)) {
		$styles = json_decode($styles);
	}

	// loop through each object in json and convert into string starting with &style=
	$return = array();

	// Verify $styles is valid before looping through it.
	if (is_array($styles) || is_object($styles)) {

		foreach($styles as $key => $style) {
			$return[] = brixwork_static_map_styles_to_string($style);
		}
	}

	// Turn return array into a string
	$return = implode($return);

	// make sure any hexadecimal colours are returned in an URL friendly manner
	return str_replace('#', '0x', $return);
}

/*
 * a function that turns the json array of styles into a static map url
 */

function brixwork_static_map_styles_to_string($style_layer, $glue = '&style=') {
	$return_array= array();
	$return = $glue;

	// loop through the base level
	foreach($style_layer as $style_key => $style) {
		// if the key is featureType or elementType
		if($style_key === "featureType" || $style_key === "elementType") {
			//remove the "Type" and add a colon ':'
			$return_array[$style_key] = ($style_key == "featureType" ? 'feature:' : 'element:');

			//add the style
			$return_array[$style_key] .= $style;
		} else {
			// else don't create anything yet, loop through the array of objects
			foreach($style as $styler) {
				// loop through each object
				foreach($styler as $styler_key=>$value) {
					// add key & value to url.
					$return_array[$styler_key][] = "$styler_key:$value";
				}
			}

			// convert each array into a string separated by '|'
			foreach( $return_array as $key=>$array) {
				if(is_array($array)) {
					//overwrite the current key with the string.
					$return_array[$key] = implode('|', $array);
				}
			}

			// do the same with the current style key.
			if(is_array($return_array[$style_key])) {
				$return_array[$style_key] = implode('|', $return_array[$style_key]);
			}
		}
	}

	// convert the whole return array into a string glued together by '|'
	$return .= implode('|', $return_array);

	return $return;
}

/*
 * a function to generate an external link to google maps for directions
 */

function brixwork_map_get_directions_link($directions_text = "directions", $lat_to = null, $long_to = null, $lat_from = null, $long_from = null) {
	global $settings;

	// if destination lat and long are not set manually, default to lat and long for office set in backend
	$lat_to = $lat_to === null ? $settings['office_lat'] : $lat_to;
	$long_to = $long_to === null ? $settings['office_long'] : $long_to;

	// create start of anchor tag.
	$return = '<a target="_blank"';

	// create href and start of link
	$return .= "href='https://www.google.com/maps/dir/?api=1";

	// input lat and long starting point into the url else don't to default to "my location"
	$return .= $lat_from !== null && $long_from != null ? "&origin=$lat_from,$long_from" : '';

	// input destination lat and long as well as the link's text.
	$return .= "&destination=$lat_to,$long_to' >$directions_text</a>";

	return $return;
}

/*
 *
 * Run this function to automatically generate an MLS disclaimer
 * based on mls_import_url set in the backend.
 *
 * If MLS Integration is turned on but the MLS import url wasn't
 * in brixwork's system at the time this function was written, a
 * message for the coder will be written in the discliamer's
 * place.
 *
 */

function brixwork_mls_disclaimer() {
	global $settings;
	global $year;

	$owner = (is_array($settings['owner']) ? $settings['owner'][0] : $settings['owner']);

	$disclaimer = '';

	// is MLS integration turned on? YES
	if($settings['mls_integrated'] == 1) {
		$mls_import_url = get_host($settings['mls_import_url']);
		// set MLS disclaimer based on MLS urls currently set up
		switch ($mls_import_url) {
			case ('vancouver.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer">
							<img src="' . brixwork_core_url('images/mlsrlogo.gif') . '" alt="Vancouver, Fraser Valley and Chilliwack MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style="float: left; margin-right: 10px; margin-bottom: 5px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System, courtesy of '.$owner.'  for your convenience.<br />
							Disclaimer: This representation is based in whole or in part on data generated by the Chilliwack &amp; District Real Estate Board, Fraser Valley Real Estate Board or Real Estate Board of Greater Vancouver which assumes no responsibility for its accuracy.
						</p>';
				break;
			case ('halifax.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer">
							<img src="' . brixwork_core_url('images/mls-color.gif.png') . '" class="alignleft" alt="Nova Scotia Real Estate Commission" title="Nova Scotia Real Estate Commission" />
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System and NSREC (Nova Scotia Real Estate Commission), All Rights Reserved, brought to you by '.$owner.' for your convenience.<br>
							The information contained on this site is based in whole or in part on information that is provided by members of The Canadian Real Estate Association, who are responsible for its accuracy. CREA reproduces and distributes this information as a service for its members and assumes no responsibility for its accuracy.<br />
							The trademarks REALTOR&reg;, REALTORS&reg; and the REALTOR&reg; logo are controlled by The Canadian Real Estate Association (CREA) and identify real estate professionals who are members of CREA. The trademarks MLS&reg;, Multiple Listing Service® and the associated logos are owned by CREA and identify the quality of services provided by real estate professionals who are members of CREA. Used under license.
						</p>';
				break;

			case ('kamloopsbc.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer">
							<img src="' . brixwork_core_url('images/mlsrlogo.gif') . '" alt="Kamloops BC MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style=" float: left; margin-right: 10px; margin-bottom: 5px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System, courtesy of Brixwork for your convenience.<br />
							Disclaimer: MLS® property information is provided under copyright© by the Kamloops and District Real Estate Association.
							The information is from sources deemed reliable, but should not be relied upon without independent verification.
						</p>';
				break;
			case ('viva.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer">
							<img src="' . brixwork_core_url('images/vreb_reciprocity.png') . '" alt="Victoria and Vancouver Island MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style=" float: left; margin-right: 10px; margin-bottom: 5px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System, courtesy of Brixwork for your convenience.<br />
							Disclaimer: MLS® property information is provided under copyright© by the Victoria Real Estate Board &amp; Vancouver Island Real Estate Board.
							The information is from sources deemed reliable, but should not be relied upon without independent verification.
						</p>';
				break;
			case ('toronto.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer">
							<img src="' . brixwork_core_url('images/mlsrlogo.gif') . '" class="alignleft" />
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System, courtesy of Brixwork for your convenience.<br>
							Disclaimer: This representation is based in whole or in part on data generated by the Brampton Real Estate Board, Durham Region Association of REALTORS®, Mississauga Real Estate Board, The Oakville, Milton and District Real Estate Board and the Toronto Real Estate Board which assumes no responsibility for its accuracy.
						</p>';
				break;
			case ('edmonton.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer">
								<img src="' . brixwork_core_url('images/mlsrlogo.gif') . '" alt="MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style="float: left; margin-right: 10px; margin-bottom: 5px;"/>
								Brought to you by your friendly REALTORS&reg; through the MLS&reg; System, courtesy of Brixwork for your convenience.<br />
								Disclaimer: This representation is based in whole or in part on data generated by the REALTORS&reg; Association of Edmonton which assumes no responsibility for its accuracy.
							</p>';
				break;
			case ('kelowna.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer ddf_dislaimer">
							<img src="' . brixwork_core_url('images/mls-color.gif') . '" alt="MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style="float: left; margin-right: 10px; margin-bottom: 5px; width: 100px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System and OMREB (Okanagan Mainland Real Estate Board), courtesy of '.$owner.' for your convenience.<br />
							The information contained on this site is based in whole or in part on information that is provided by members of The Canadian Real Estate Association, who are responsible for its accuracy. CREA reproduces and distributes this information as a service for its members and assumes no responsibility for its accuracy.
						</p>';
				break;
			case ('penticton.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer ddf_dislaimer">
							<img src="' . brixwork_core_url('images/mls-color.gif') . '" alt="MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style="float: left; margin-right: 10px; margin-bottom: 5px; width: 100px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System and SOREB (Southern Okanagan Real Estate Board), courtesy of '.$owner.', for your convenience.<br />
							The information contained on this site is based in whole or in part on information that is provided by members of The Canadian Real Estate Association, who are responsible for its accuracy. CREA reproduces and distributes this information as a service for its members and assumes no responsibility for its accuracy.
						</p>';
				break;
			case ('ottawa.brixwork.com'):
				$disclaimer = '<p class="mls_disclaimer disclaimer ddf_dislaimer">
							<img src="' . brixwork_core_url('images/mls-color.gif') . '" alt="MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style="float: left; margin-right: 10px; margin-bottom: 5px; width: 100px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System and OREB (Ottawa Real Estate Board), courtesy of '.$owner.' for your convenience.<br />
							The information contained on this site is based in whole or in part on information that is provided by members of The Canadian Real Estate Association, who are responsible for its accuracy. CREA reproduces and distributes this information as a service for its members and assumes no responsibility for its accuracy.<br />
							The trademarks REALTOR&reg;, REALTORS&reg; and the REALTOR&reg; logo are controlled by The Canadian Real Estate Association (CREA) and identify real estate professionals who are members of CREA. The trademarks MLS&reg;, Multiple Listing Service® and the associated logos are owned by CREA and identify the quality of services provided by real estate professionals who are members of CREA. Used under license.
						</p>';

			case ('tillsonburg.brixwork.com'):
				// TODO: update for Tillsonburg board notes for Marius!
				$disclaimer = '<p class="mls_disclaimer disclaimer ddf_dislaimer">
							<img src="' . brixwork_core_url('images/mls-color.gif') . '" alt="MLS&reg; Reciprocity" title="MLS&reg; Reciprocity" style="float: left; margin-right: 10px; margin-bottom: 5px; width: 100px;"/>
							Brought to you by your friendly REALTORS&reg; through the MLS&reg; System and TDREB (Tillsonburg District Real Estate Board), courtesy of Brixwork for your convenience.<br />
							The information contained on this site is based in whole or in part on information that is provided by members of The Canadian Real Estate Association, who are responsible for its accuracy. CREA reproduces and distributes this information as a service for its members and assumes no responsibility for its accuracy.<br />
							The trademarks REALTOR&reg;, REALTORS&reg; and the REALTOR&reg; logo are controlled by The Canadian Real Estate Association (CREA) and identify real estate professionals who are members of CREA. The trademarks MLS&reg;, Multiple Listing Service® and the associated logos are owned by CREA and identify the quality of services provided by real estate professionals who are members of CREA. Used under license.
						</p>';
				break;
			// MLS integrated is true, but the MLS import url is not recognized.
			// Leave a message for the coder, as this should not be the case.
			default:
				$disclaimer = '<h1>NEW MLS BOARD, SET UP DISCLAIMER</h1>';
				break;
		}
	}
	// if MLS integration is not turned on, do nothing.

	return $disclaimer;
}

/**
 * @param $params
 * $param['ptag'] = TRUE or FALSE - whether to return the opening and closing <p> tags or not.
 * $param['cssclass'] = The CSS class name(s) to return. Useless if $param['ptag'] is set to FALSE.
 * @return string
 */
function brixwork_crea_ddf_footer_disclaimer($params) {
	$class = ($params['cssclass']!='' ? $params['cssclass'] : 'footer_crea_ddf_disclaimer');
	$ptag = (isset($params['ptag']) ? $params['ptag'] : true);

	$url = ($params['url']!='' ? $params['url'] : '');

	$return = ($ptag===true ? '<p class="'.$class.'">' : '');
	$return .= 'The listing content on this website is protected by copyright and other laws, and is intended solely for the private, non-commercial use by individuals. Any other reproduction, distribution or use of the content, in whole or in part, is specifically forbidden. The prohibited uses include commercial use, &ldquo;screen scraping&rdquo;, &ldquo;database scraping&rdquo;, and any other activity intended to collect, store, reorganize or manipulate data on the pages produced by or displayed on this website.';
	$return .= ($ptag===true ? '</p>' : '');

	return $return;
}

function site_is_crawling(){
	//path to robots.txt
	$robotsUrl = $_SERVER['DOCUMENT_ROOT'] . "/robots.txt";

	$fh = fopen($robotsUrl,'r');
	$crawling = false;
	//read each line of the robots.txt
	while (($line = fgets($fh)) != false) {

		//check if it is strictly set to disallow crawling
		if (preg_match("/^allow.*/i", $line)){
			$crawling = true;
		}else if (preg_match("/disallow.*/i", $line)){
			//check if it is strictly set to allow crawling
			$crawling = false;
		}
	}
	return $crawling;

}


/**
 * SITEMAP GENERATION FUNCTIONS
 * 2023-06-26 / Brian Yang
 *
 * V.0 BETA TEST RUN FUNCTIONS FOR KEN STEF SEO
 *
 * USAGE
 * Run create_sitemap_file() at client root
 *
 * Helpful Pages that were used for research
 * 1. Google Search Central - https://developers.google.com/search/docs/crawling-indexing/sitemaps/overview
 * 2. Google Search Central - https://developers.google.com/search/docs/crawling-indexing/sitemaps/build-sitemap
 * 3. Semrush Blog - https://www.semrush.com/blog/submit-sitemap-to-google/
 *
 * PREP WORK
 * 1. Need `XML Sitemap` row on the `settings` table - add manually for Ken Stef, but also add to `upgrade_queries` under master.
 * 1-1. `0` means off, `1` means run automatic sitemap generation.
 * 1-2. Don't need UI for now, XML sitemap generation is for specific clients only.
 *
 * PROCESS
 * 1. Generate sitemap.xml file in the root (right under public_html)
 * 2. Generate relevant URL to be in the sitemap.xml
 * 3. Submit the sitemap.xml to the relevant Google Search Console.
 *
 *
 * SOMETHING TO THINK ABOUT
 * 1. Automation.
 * 1-1. How to automatically create + update sitemap regularly?
 *
 * 2. Frequency - hourly along with mls sync
 * 2-1. Creation + update of sitemap.xml should be something that happens periodically.
 *
 * 3. How to submit?
 * https://developers.google.com/search/docs/crawling-indexing/sitemaps/build-sitemap#addsitemap
 * Summary:
 * 3-1. HTTP Request: PUT https://www.googleapis.com/webmasters/v3/sites/siteUrl/sitemaps/feedpath
 * 3-2. Insert the following line anywhere in your robots.txt file, specifying the path to your sitemap. We will find it the next time we crawl your robots.txt file.
 * 3-3. Enter manually using Google Search Console.
 *
 *
 * NOTES
 * 1. Google ignores <priority> and <changefreq> values.
 * 2. Sitemap size limits: All formats limit a single sitemap to 50MB (uncompressed) or 50,000 URLs. If you have a larger file or more URLs, you must break your sitemap into multiple sitemaps. You can optionally create a sitemap index file and submit that single index file to Google.
 */
/**
 * First, create file function ... Only create new sitemap.xml if it doesn't exist yet.
 * @param string $filename             name of the file to create, make sure to have file extension as well
 * @param string $additional_directory file directory, usually wherever `index.php` is.
 */
function create_sitemap_file(string $filename = 'sitemap.xml', string $additional_directory = '/'): bool {
	// write file directly in the remote directory.
	$base_directory = $_SERVER['DOCUMENT_ROOT'];
	$directory      = $base_directory.$additional_directory;
	$filePath       = $directory.$filename;

	$file = fopen($filePath, 'w'); // open file
	if ($file) {
		// first time opening the file ... write the first two important lines.
		fwrite($file, "<?xml version='1.0' encoding='UTF-8'?>\n<urlset xmlns='http://www.sitemaps.org/schemas/sitemap/0.9'>\n");
		fwrite($file, xml_generate_pages());    // get all published pages
		fwrite($file, xml_generate_listings()); // now all listings.
		fwrite($file, "</urlset>");         // append closing tag
		fclose($file);

		// update robots.txt to notify Chrome crawler where the sitemap is.
		update_robots_txt();
		return true;
	} else {
		// Unable to create the sitemap file. File does not exist
		return false;
	}
}

/**
 * Helper function for Sitemap Generation: Query & Loop through all MLS listings.
 * @return string   XML formatted string ready to be inserted into the sitemap.xml file.
 */
function xml_generate_listings(array $options = array()): string {
	global $settings;
	$data_array = array(); // return array.

	// build query
	// also add query for published cities only.
	$options['query']['source'] = 1;
	$options['query']['cityid'] = get_areas(array('publish' => 1));
	$options['per_page'] = $options['per_page'] ?: 48000; // max allowed urls in a xml file is 50k lines. Leave space for 2k for pages. Most sites will never reach this number though.

	// query listings ... max lines for xml is 50k or 50mb.
	$listings = get_properties('', $options['query'], array('create_date'), array('DESC'), $options['per_page'], 1, false, true );

	// This will loop through the query result and prep data to be used in xml_generate_syntax().
	foreach ($listings as $listing) {
		$each_listing = new home;
		$each_listing->initialize($listing['id'], $listing);

		$listing_modified_date = new DateTime($each_listing->modify_date);
		$formattedDate = $listing_modified_date->format('Y-m-d'); // get 2023-12-30

		$data_array[] = array(
			'url' => $each_listing->get_property_link(), // client_domain.com/showlisting/...
			'last_mod' => $formattedDate,
		);
	}

	// generate xml syntax.
	return xml_format_syntax($data_array);
}

/**
 * Helper function for Sitemap Generation: Query & Loop through all published pages
 * @return string   XML formatted string ready to be inserted into the sitemap.xml file.
 */
function xml_generate_pages(): string {
	$formatted_page_data = get_all_published_pages(get_brixwork_pages());
	return xml_format_syntax($formatted_page_data);
}

/**
 * Helper function for Sitemap Generation:  Recurse function that gets all published pages
 * should return in array of $data = array('url', 'last_mod', 'change_freq')
 * @param array $brixwork_pages     array of IDs of Brixwork pages
 * @param array $data_array         data array to be returned later. Keep adds new key value pair
 * @return array    Formatted to be used in the xml_format_syntax function.
 */
function get_all_published_pages(array $brixwork_pages, array $data_array = array()): array {
	foreach ($brixwork_pages as $page_id => $content) {
		$each_page = new page;
		$each_page->initialize($page_id);

		$page_modified_date = new DateTime($each_page->modify_date);
		$formattedDate = $page_modified_date->format('Y-m-d'); // get 2023-12-30

		// Skip condition: do not sitemap the embedded or not published pages.
		if ($each_page->embedded == 1 || $each_page->publish == 0) continue;

		// Url must end with trailing slash
		$each_page_url = substr($each_page->pageurl, -1) !== '/' ? $each_page->pageurl.'/' : $each_page->pageurl;

		// Skip condition ... duplicate url
		$duplicateFound = false;
		foreach ($data_array as $item) {
			if ($item['url'] === $each_page_url) {
				$duplicateFound = true;
				break;
			}
		}

		if (!$duplicateFound) {
			$data_array[] = array(
				'url' => $each_page_url,
				'last_mod' => $formattedDate,
			);
		}

		// get all the child pages as well.
		if ($each_page->publishedchildrencount > 0) {
			$data_array = get_all_published_pages($each_page->publishedchildren, $data_array);
		}
	}

	return $data_array;
}

/**
 * Helper function for Sitemap Generation: Prep the data generated by xml_generate_listings() to be inserted into sitemap.xml file.
 * @param array $data_array
 * @return string
 */
function xml_format_syntax(array $data_array = array()): string {
	if (empty($data_array)) return '';

	// Generate XML syntax for each URL ... opening tags for the XML syntax should already be written in the file.
	$sitemap = '';
	foreach ($data_array as $data) {
		$sitemap .= "\t<url>\n";
		$sitemap .= "\t\t<loc>" . htmlspecialchars($data['url']) . "</loc>\n";
		$sitemap .= "\t\t<lastmod>" . htmlspecialchars($data['last_mod']) . "</lastmod>\n";
		$sitemap .= "\t</url>\n";
	}

	return $sitemap;
}

/**
 * Helper function for Sitemap Generation: Update robots.txt
 *
 * Original content:
 * User-agent: *
 * Disallow: /admin
 * Allow: /
 */
function update_robots_txt(): void {
	global $settings;
	$base_directory = $_SERVER['DOCUMENT_ROOT'];
	$directory      = $base_directory.'/';
	$filePath       = $directory.'robots.txt';

	$robotsContent  = file_get_contents($filePath);
	$newLineToAdd   = 'Sitemap: '.$settings['sitepath'].'sitemap.xml';

	if ($robotsContent) {
		if (!str_contains($robotsContent, 'Sitemap:')) {
			// "sitemap" string does not exist... just append
			$robotsContent .= "\n" . $newLineToAdd;

			// Write the updated content back to the file
			file_put_contents($filePath, $robotsContent);
		} else {
			// "sitemap:" string exists, double check correct domain
			$domainUrl = '';
			$lines = explode("\n", $robotsContent); // extract current domain string from file.
			foreach ($lines as $each_line) {
				// this foreach is probably unnecessary, as the "Sitemap: ..." will always be the last line.
				if (stripos($each_line, 'sitemap:') === 0) {
					// Extract the domain URL from the line
					$parts = explode(':', $each_line, 2);
					$domainUrl = isset($parts[1]) ? trim($parts[1]) : '';
				}
			}
			// current domain does not match sitemap domain ... replace!
			if ($settings['sitepath'] !== $domainUrl) {
				array_pop($lines); // remove last line that says "Sitemap: ..." as this contains wrong domain.
				$lines[] = $newLineToAdd; // append the new line that contains the proper domain.

				$new_lines = implode(PHP_EOL, $lines);
				file_put_contents($filePath, $new_lines);
			}
		}
	}
}